diff --git a/books/bookvol0.pamphlet b/books/bookvol0.pamphlet
index 3487c16..c7c47e5 100644
--- a/books/bookvol0.pamphlet
+++ b/books/bookvol0.pamphlet
@@ -24701,6 +24701,262 @@ AXIOM domains and packages. The sections are organized by constructor
 names.
 
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+\domainhead{ApplicationProgramInterface}
+
+The ApplicationProgramInterface exposes Axiom internal functions
+which might be useful for understanding, debugging, or creating tools.
+
+The getDomains function takes the name of a category and returns
+a set of domains which inherit from that category:
+\begin{verbatim}
+  getDomains 'Collection
+
+   {AssociationList, Bits, CharacterClass, DataList, EqTable, FlexibleArray,
+    GeneralPolynomialSet, GeneralSparseTable, GeneralTriangularSet, HashTable,
+    IndexedBits, IndexedFlexibleArray, IndexedList, IndexedOneDimensionalArray,
+    IndexedString, IndexedVector, InnerTable, KeyedAccessFile, Library, List,
+    ListMultiDictionary, Multiset, OneDimensionalArray, Point, PrimitiveArray,
+    RegularChain, RegularTriangularSet, Result, RoutinesTable, Set,
+    SparseTable, SquareFreeRegularTriangularSet, Stream, String, StringTable,
+    Table, Vector, WuWenTsunTriangularSet}
+                                                             Type: Set Symbol
+\end{verbatim}
+This can be used to form the set-difference of two categories:
+\begin{verbatim}
+  difference(getDomains 'IndexedAggregate, getDomains 'Collection)
+
+   {DirectProduct, DirectProductMatrixModule, DirectProductModule,
+    HomogeneousDirectProduct, OrderedDirectProduct,
+    SplitHomogeneousDirectProduct}
+                                                             Type: Set Symbol
+\end{verbatim}
+The credits function prints a list of the people who have contributed
+to the development of Axiom. This is equivalent to the )credits command.
+
+The summary function prints a short list of useful console commands.
+
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+\domainhead{ArrayStack}
+
+An ArrayStack object is represented as a list ordered by last-in,
+first-out. It operates like a pile of books, where the ``next'' book is
+the one on the top of the pile.
+
+Here we create an array stack of integers from a list. Notice that the
+order in the list is the order in the stack.
+\begin{verbatim}
+   a:ArrayStack INT:= arrayStack [1,2,3,4,5]
+      [1,2,3,4,5]
+\end{verbatim}
+We can remove the top of the stack using pop!:
+\begin{verbatim}
+   pop! a
+      1
+\end{verbatim}
+Notice that the use of pop! is destructive (destructive operations
+in Axiom usually end with ! to indicate that the underylying data
+structure is changed).
+\begin{verbatim}
+   a
+      [2,3,4,5]
+\end{verbatim}
+The extract! operation is another name for the pop! operation and
+has the same effect. This operation treats the stack as a BagAggregate:
+\begin{verbatim}
+   extract! a
+      2
+\end{verbatim}
+and you can see that it also has destructively modified the stack:
+\begin{verbatim}
+   a
+      [3,4,5]
+\end{verbatim}
+Next we push a new element on top of the stack:
+\begin{verbatim}
+   push!(9,a)
+      9
+\end{verbatim}
+Again, the push! operation is destructive so the stack is changed:
+\begin{verbatim}
+   a
+      [9,3,4,5]
+\end{verbatim}
+Another name for push! is insert!, which treats the stack as a BagAggregate:
+\begin{verbatim}
+   insert!(8,a)
+      [8,9,3,4,5]
+\end{verbatim}
+and it modifies the stack:
+\begin{verbatim}
+   a
+      [8,9,3,4,5]
+\end{verbatim}
+The inspect function returns the top of the stack without modification,
+viewed as a BagAggregate:
+\begin{verbatim}
+   inspect a
+      8
+\end{verbatim}
+The empty? operation returns true only if there are no element on the
+stack, otherwise it returns false:
+\begin{verbatim}
+   empty? a
+      false
+\end{verbatim}
+The top operation returns the top of stack without modification, viewed
+as a Stack:
+\begin{verbatim}
+   top a
+      8
+\end{verbatim}
+The depth operation returns the number of elements on the stack:
+\begin{verbatim}
+   depth a
+      5
+\end{verbatim}
+which is the same as the \# (length) operation:
+\begin{verbatim}
+   #a
+       5
+\end{verbatim}
+The less? predicate will compare the stack length to an integer:
+\begin{verbatim}
+   less?(a,9)
+        true
+\end{verbatim}
+The more? predicate will compare the stack length to an integer:
+\begin{verbatim}
+   more?(a,9)
+        false
+\end{verbatim}
+The size? operation will compare the stack length to an integer:
+\begin{verbatim}
+   size?(a,#a)
+        true
+\end{verbatim}
+and since the last computation must alwasy be true we try:
+\begin{verbatim}
+   size?(a,9)
+        false
+\end{verbatim}
+The parts function will return  the stack as a list of its elements:
+\begin{verbatim}
+   parts a
+        [8,9,3,4,5]
+\end{verbatim}
+If we have a BagAggregate of elements we can use it to construct a stack.
+Notice that the elements are pushed in reverse order:
+\begin{verbatim}
+   bag([1,2,3,4,5])$ArrayStack(INT)
+        [5,4,3,2,1]
+\end{verbatim}
+The empty function will construct an empty stack of a given type:
+\begin{verbatim}
+   b:=empty()$(ArrayStack INT)
+        []
+\end{verbatim}
+and the empty? predicate allows us to find out if a stack is empty:
+\begin{verbatim}
+   empty? b
+        true
+\end{verbatim}
+The sample function returns a sample, empty stack:
+\begin{verbatim}
+   sample()$ArrayStack(INT)
+        []
+\end{verbatim}
+We can copy a stack and it does not share storage so subsequent
+modifications of the original stack will not affect the copy:
+\begin{verbatim}
+   c:=copy a
+        [8,9,3,4,5]
+\end{verbatim}
+The eq? function is only true if the lists are the same reference,
+so even though c is a copy of a, they are not the same:
+\begin{verbatim}
+   eq?(a,c)
+        false
+\end{verbatim}
+However, a clearly shares a reference with itself:
+\begin{verbatim}
+   eq?(a,a)
+        true
+\end{verbatim}
+But we can compare a and c for equality:
+\begin{verbatim}
+   (a=c)@Boolean
+        true
+\end{verbatim}
+and clearly a is equal to itself:
+\begin{verbatim}
+   (a=a)@Boolean
+        true
+\end{verbatim}
+and since a and c are equal, they are clearly NOT not-equal:
+\begin{verbatim}
+   a~=c
+        false
+\end{verbatim}
+We can use the any? function to see if a predicate is true for any element:
+\begin{verbatim}
+   any?(x+->(x=4),a)
+        true
+\end{verbatim}
+or false for every element:
+\begin{verbatim}
+   any?(x+->(x=11),a)
+        false
+\end{verbatim}
+We can use the every? function to check every element satisfies a predicate:
+\begin{verbatim}
+   every?(x+->(x=11),a)
+        false
+\end{verbatim}
+We can count the elements that are equal to an argument of this type:
+\begin{verbatim}
+   count(4,a)
+        1
+\end{verbatim}
+or we can count against a boolean function:
+\begin{verbatim}
+   count(x+->(x>2),a)
+        5
+\end{verbatim}
+You can also map a function over every element, returning a new stack:
+\begin{verbatim}
+   map(x+->x+10,a)
+        [18,19,13,14,15]
+\end{verbatim}
+Notice that the orignal stack is unchanged:
+\begin{verbatim}
+   a
+        [8,9,3,4,5]
+\end{verbatim}
+You can use map! to map a function over every element and change
+the original stack since map! is destructive:
+\begin{verbatim}
+   map!(x+->x+10,a)
+       [18,19,13,14,15]
+\end{verbatim}
+Notice that the orignal stack has been changed:
+\begin{verbatim}
+   a
+       [18,19,13,14,15]
+\end{verbatim}
+The member function can also get the element of the stack as a list:
+\begin{verbatim}
+   members a
+       [18,19,13,14,15]
+\end{verbatim}
+and using member? we can test if the stack holds a given element:
+\begin{verbatim}
+   member?(14,a)
+       true
+\end{verbatim}
+Also see \domainref{Stack}, \domainref{Queue}, \domainref{Dequeue},
+\domainref{Heap}, and \domainref{BagAggregate}
+
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 \domainhead{AssociationList}
 
 The {\tt AssociationList} constructor provides a general structure for
@@ -28825,6 +29081,320 @@ $$
 \returnType{Type: Polynomial DecimalExpansion}
 
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+\domainhead{Dequeue}
+
+A Dequeue is a double-ended queue so elements can be added to either end.
+
+Here we create an dequeue of integers from a list. Notice that the
+order in the list is the order in the dequeue.
+\begin{verbatim}
+   a:Dequeue INT:= dequeue [1,2,3,4,5]
+      [1,2,3,4,5]
+\end{verbatim}
+We can remove the top of the dequeue using dequeue!:
+\begin{verbatim}
+   dequeue! a
+      1
+\end{verbatim}
+Notice that the use of dequeue! is destructive (destructive operations
+in Axiom usually end with ! to indicate that the underylying data
+structure is changed).
+\begin{verbatim}
+   a
+      [2,3,4,5]
+\end{verbatim}
+The extract! operation is another name for the dequeue! operation and
+has the same effect. This operation treats the dequeue as a BagAggregate:
+\begin{verbatim}
+   extract! a
+      2
+\end{verbatim}
+and you can see that it also has destructively modified the dequeue:
+\begin{verbatim}
+   a
+      [3,4,5]
+\end{verbatim}
+Next we use enqueue! to add a new element to the end of the dequeue:
+\begin{verbatim}
+   enqueue!(9,a)
+      9
+\end{verbatim}
+Again, the enqueue! operation is destructive so the dequeue is changed:
+\begin{verbatim}
+   a
+      [3,4,5,9]
+\end{verbatim}
+Another name for enqueue! is insert!, which treats the dequeue as a 
+BagAggregate:
+\begin{verbatim}
+   insert!(8,a)
+      [3,4,5,9,8]
+\end{verbatim}
+and it modifies the dequeue:
+\begin{verbatim}
+   a
+      [3,4,5,9,8]
+\end{verbatim}
+The front operation returns the item at the front of the dequeue:
+\begin{verbatim}
+   front a
+      3
+\end{verbatim}
+The back operation returns the item at the back of the dequeue:
+\begin{verbatim}
+   back a
+      8
+\end{verbatim}
+The bottom! operation returns the item at the back of the dequeue:
+\begin{verbatim}
+   bottom! a
+      8
+\end{verbatim}
+and it modifies the dequeue:
+\begin{verbatim}
+   a
+      [3,4,5,9]
+\end{verbatim}
+The depth function returns the number of elements in the dequeue:
+\begin{verbatim}
+   depth a
+      4
+\end{verbatim}
+The height function returns the number of elements in the dequeue:
+\begin{verbatim}
+   height a
+      4
+\end{verbatim}
+The insertBottom! function adds the element at the end:
+\begin{verbatim}
+   insertBottom!(6,a)
+      6
+\end{verbatim}
+and it modifies the dequeue:
+\begin{verbatim}
+   a
+      [3,4,5,9,6]
+\end{verbatim}
+The extractBottom! function removes the element at the end:
+\begin{verbatim}
+   extractBottom! a
+      6
+\end{verbatim}
+and it modifies the dequeue:
+\begin{verbatim}
+   a
+      [3,4,5,9]
+\end{verbatim}
+The insertTop! function adds the element at the top:
+\begin{verbatim}
+   insertTop!(7,a)
+      7
+\end{verbatim}
+and it modifies the dequeue:
+\begin{verbatim}
+   a
+      [7,3,4,5,9]
+\end{verbatim}
+The extractTop! function adds the element at the top:
+\begin{verbatim}
+   extractTop! a
+      7
+\end{verbatim}
+and it modifies the dequeue:
+\begin{verbatim}
+   a
+      [3,4,5,9]
+\end{verbatim}
+The top function returns the top element:
+\begin{verbatim}
+   top a
+      3
+\end{verbatim}
+and it does not modifies the dequeue:
+\begin{verbatim}
+   a
+      [3,4,5,9]
+\end{verbatim}
+The top! function returns the top element:
+\begin{verbatim}
+   top! a
+      3
+\end{verbatim}
+and it modifies the dequeue:
+\begin{verbatim}
+   a
+      [4,5,9]
+\end{verbatim}
+The reverse! operation destructively reverses the elements of the dequeue:
+\begin{verbatim}
+   reverse! a
+      [9,5,4]
+\end{verbatim}
+The rotate! operation moves the top element to the bottom:
+\begin{verbatim}
+   rotate! a
+      [5,4,9]
+\end{verbatim}
+The inspect function returns the top of the dequeue without modification,
+viewed as a BagAggregate:
+\begin{verbatim}
+   inspect a
+      5
+\end{verbatim}
+The empty? operation returns true only if there are no element on the
+dequeue, otherwise it returns false:
+\begin{verbatim}
+   empty? a
+      false
+\end{verbatim}
+The \# (length) operation:
+\begin{verbatim}
+   #a
+       3
+\end{verbatim}
+The length operation does the same thing:
+\begin{verbatim}
+   length a
+       3
+\end{verbatim}
+The less? predicate will compare the dequeue length to an integer:
+\begin{verbatim}
+   less?(a,9)
+        true
+\end{verbatim}
+The more? predicate will compare the dequeue length to an integer:
+\begin{verbatim}
+   more?(a,9)
+        false
+\end{verbatim}
+The size? operation will compare the dequeue length to an integer:
+\begin{verbatim}
+   size?(a,#a)
+        true
+\end{verbatim}
+and since the last computation must alwasy be true we try:
+\begin{verbatim}
+   size?(a,9)
+        false
+\end{verbatim}
+The parts function will return  the dequeue as a list of its elements:
+\begin{verbatim}
+   parts a
+        [5,4,9]
+\end{verbatim}
+If we have a BagAggregate of elements we can use it to construct a dequeue:
+\begin{verbatim}
+   bag([1,2,3,4,5])$Dequeue(INT)
+        [1,2,3,4,5]
+\end{verbatim}
+The empty function will construct an empty dequeue of a given type:
+\begin{verbatim}
+   b:=empty()$(Dequeue INT)
+        []
+\end{verbatim}
+and the empty? predicate allows us to find out if a dequeue is empty:
+\begin{verbatim}
+   empty? b
+        true
+\end{verbatim}
+The sample function returns a sample, empty dequeue:
+\begin{verbatim}
+   sample()$Dequeue(INT)
+        []
+\end{verbatim}
+We can copy a dequeue and it does not share storage so subsequent
+modifications of the original dequeue will not affect the copy:
+\begin{verbatim}
+   c:=copy a
+        [5,4,9]
+\end{verbatim}
+The eq? function is only true if the lists are the same reference,
+so even though c is a copy of a, they are not the same:
+\begin{verbatim}
+   eq?(a,c)
+        false
+\end{verbatim}
+However, a clearly shares a reference with itself:
+\begin{verbatim}
+   eq?(a,a)
+        true
+\end{verbatim}
+But we can compare a and c for equality:
+\begin{verbatim}
+   (a=c)@Boolean
+        true
+\end{verbatim}
+and clearly a is equal to itself:
+\begin{verbatim}
+   (a=a)@Boolean
+        true
+\end{verbatim}
+and since a and c are equal, they are clearly NOT not-equal:
+\begin{verbatim}
+   a~=c
+        false
+\end{verbatim}
+We can use the any? function to see if a predicate is true for any element:
+\begin{verbatim}
+   any?(x+->(x=4),a)
+        true
+\end{verbatim}
+or false for every element:
+\begin{verbatim}
+   any?(x+->(x=11),a)
+        false
+\end{verbatim}
+We can use the every? function to check every element satisfies a predicate:
+\begin{verbatim}
+   every?(x+->(x=11),a)
+        false
+\end{verbatim}
+We can count the elements that are equal to an argument of this type:
+\begin{verbatim}
+   count(4,a)
+        1
+\end{verbatim}
+or we can count against a boolean function:
+\begin{verbatim}
+   count(x+->(x>2),a)
+        3
+\end{verbatim}
+You can also map a function over every element, returning a new dequeue:
+\begin{verbatim}
+   map(x+->x+10,a)
+        [15,14,19]
+\end{verbatim}
+Notice that the orignal dequeue is unchanged:
+\begin{verbatim}
+   a
+        [5,4,9]
+\end{verbatim}
+You can use map! to map a function over every element and change
+the original dequeue since map! is destructive:
+\begin{verbatim}
+   map!(x+->x+10,a)
+       [15,14,19]
+\end{verbatim}
+Notice that the orignal dequeue has been changed:
+\begin{verbatim}
+   a
+       [15,14,19]
+\end{verbatim}
+The member function can also get the element of the dequeue as a list:
+\begin{verbatim}
+   members a
+       [15,14,19]
+\end{verbatim}
+and using member? we can test if the dequeue holds a given element:
+\begin{verbatim}
+   member?(14,a)
+       true
+\end{verbatim}
+
+See \domainref{Stack}, \domainref{ArrayStack}, \domainref{Queue},
+\domainref{Dequeue}, \domainref{Heap}
+
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 \domainhead{DistributedMultivariatePolynomial}
 
 \hyphenation{Homo-gen-eous-Dis-tributed-Multi-var-i-ate-Pol-y-nomial}
@@ -29259,6 +29829,62 @@ $$
 \returnType{Type: Boolean}
 
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+\domainhead{EuclideanGroebnerBasisPackage}
+
+Example to call euclideanGroebner:
+\begin{verbatim}
+  a1:DMP([y,x],INT):= (9*x**2 + 5*x - 3)+ y*(3*x**2 + 2*x + 1)
+  a2:DMP([y,x],INT):= (6*x**3 - 2*x**2 - 3*x +3) + y*(2*x**3 - x - 1)
+  a3:DMP([y,x],INT):= (3*x**3 + 2*x**2) + y*(x**3 + x**2)
+  an:=[a1,a2,a3]
+  euclideanGroebner(an)
+\end{verbatim}
+This will return the weak euclidean Groebner basis set.
+All reductions are total reductions.
+
+You can get more information by providing a second argument.
+To get the reduced critical pairs do:
+\begin{verbatim}
+  euclideanGroebner(an,"redcrit")
+\end{verbatim}
+You can get other information by calling:
+\begin{verbatim}
+  euclideanGroebner(an,"info")
+\end{verbatim}
+which returns:
+\begin{verbatim}
+   ci  =>  Leading monomial  for critpair calculation
+   tci =>  Number of terms of polynomial i
+   cj  =>  Leading monomial  for critpair calculation
+   tcj =>  Number of terms of polynomial j
+   c   =>  Leading monomial of critpair polynomial
+   tc  =>  Number of terms of critpair polynomial
+   rc  =>  Leading monomial of redcritpair polynomial
+   trc =>  Number of terms of redcritpair polynomial
+   tH  =>  Number of polynomials in reduction list H
+   tD  =>  Number of critpairs still to do
+\end{verbatim}
+The three argument form returns all of the information:
+\begin{verbatim}
+  euclideanGroebner(an,"info","redcrit")
+\end{verbatim}
+
+The term ordering is determined by the polynomial type used. 
+Suggested types include
+\begin{verbatim}
+   DistributedMultivariatePolynomial
+   HomogeneousDistributedMultivariatePolynomial
+   GeneralDistributedMultivariatePolynomial
+\end{verbatim} 
+
+See 
+\domainref{EuclideanGroebnerBasisPackage},
+\domainref{DistributedMultivariatePolynomial},
+\domainref{HomogeneousDistributedMultivariatePolynomial},
+\domainref{GeneralDistributedMultivariatePolynomial}, and
+\domainref{GroebnerPackage}
+
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 \domainhead{Exit}
 
 A function that does not return directly to its caller has {\tt Exit}
@@ -31353,6 +31979,105 @@ For more information, see the paper: Bronstein, M and Salvy, B.
 \domainref{PartialFraction} for standard partial fraction decompositions.
 
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+\domainhead{GeneralDistributedMultivariatePolynomial}
+
+DistributedMultivariatePolynomial which is abbreviated as DMP and 
+HomogeneousDistributedMultivariatePolynomial, which is abbreviated
+as HDMP, are very similar to MultivariatePolynomial except that 
+they are represented and displayed in a non-recursive manner.
+\begin{verbatim}
+  (d1,d2,d3) : DMP([z,y,x],FRAC INT) 
+                      Type: Void
+\end{verbatim}
+The constructor DMP orders its monomials lexicographically while
+HDMP orders them by total order refined by reverse lexicographic
+order.
+\begin{verbatim}
+  d1 := -4*z + 4*y**2*x + 16*x**2 + 1 
+            2       2
+   - 4z + 4y x + 16x  + 1
+            Type: DistributedMultivariatePolynomial([z,y,x],Fraction Integer)
+\end{verbatim}
+\begin{verbatim}
+  d2 := 2*z*y**2 + 4*x + 1 
+       2
+   2z y  + 4x + 1
+            Type: DistributedMultivariatePolynomial([z,y,x],Fraction Integer)
+\end{verbatim}
+\begin{verbatim}
+  d3 := 2*z*x**2 - 2*y**2 - x 
+       2     2
+   2z x  - 2y  - x
+            Type: DistributedMultivariatePolynomial([z,y,x],Fraction Integer)
+\end{verbatim}
+These constructors are mostly used in Groebner basis calculations.
+\begin{verbatim}
+  groebner [d1,d2,d3]
+        1568  6   1264  5    6   4   182  3   2047  2    103      2857
+   [z - ---- x  - ---- x  + --- x  + --- x  - ---- x  - ---- x - -----,
+        2745       305      305      549       610      2745     10980
+     2    112  6    84  5   1264  4    13  3    84  2   1772       2
+    y  + ---- x  - --- x  - ---- x  - --- x  + --- x  + ---- x + ----,
+         2745      305       305      549      305      2745     2745
+     7   29  6   17  4   11  3    1  2   15     1
+    x  + -- x  - -- x  - -- x  + -- x  + -- x + -]
+          4      16       8      32      16     4
+       Type: List DistributedMultivariatePolynomial([z,y,x],Fraction Integer)
+\end{verbatim}
+\begin{verbatim}
+  (n1,n2,n3) : HDMP([z,y,x],FRAC INT)
+                      Type: Void
+\end{verbatim}
+\begin{verbatim}
+  n1 := d1
+     2       2
+   4y x + 16x  - 4z + 1
+ Type: HomogeneousDistributedMultivariatePolynomial([z,y,x],Fraction Integer)
+\end{verbatim}
+\begin{verbatim}
+  n2 := d2
+       2
+   2z y  + 4x + 1
+ Type: HomogeneousDistributedMultivariatePolynomial([z,y,x],Fraction Integer)
+\end{verbatim}
+\begin{verbatim}
+  n3 := d3
+       2     2
+   2z x  - 2y  - x
+ Type: HomogeneousDistributedMultivariatePolynomial([z,y,x],Fraction Integer)
+\end{verbatim}
+Note that we get a different Groebner basis when we use the HDMP
+polynomials, as expected.
+\begin{verbatim}
+  groebner [n1,n2,n3]
+     4     3   3  2   1     1   4   29  3   1  2   7        9     1
+   [y  + 2x  - - x  + - z - -, x  + -- x  - - y  - - z x - -- x - -,
+               2      2     8        4      8      4       16     4
+       2        1   2      2       1     2    2   1
+    z y  + 2x + -, y x + 4x  - z + -, z x  - y  - - x,
+                2                  4              2
+     2     2     2   1     3
+    z  - 4y  + 2x  - - z - - x]
+                     4     2
+      Type: List HomogeneousDistributedMultivariatePolynomial([z,y,x],
+                                                           Fraction Integer)
+\end{verbatim}
+GeneralDistributedMultivariatePolynomial is somewhat more flexible in
+the sense that as well as accepting a list of variables to specify the
+variable ordering, it also takes a predicate on exponent vectors to
+specify the term ordering.  With this polynomial type the user can
+experiment with the effect of using completely arbitrary term orderings.  
+This flexibility is mostly important for algorithms such as Groebner 
+basis calculations which can be very sensitive to term ordering.
+
+See 
+\domainref{Polynomial}\\
+\domainref{UnivariatePolynomial}\\
+\domainref{MultivariatePolynomial}\\
+\domainref{HomogeneousDistributedMultivariatePolynomial}, and\\
+\domainref{DistributedMultivariatePolynomial}
+
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 \domainhead{GeneralSparseTable}
 
 Sometimes when working with tables there is a natural value to use as
@@ -31613,6 +32338,53 @@ code for {\tt GroebnerFactorizationPackage} in {\bf groebf.input}
 for more details about the algorithms used.
 
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+\domainhead{GroebnerPackage}
+
+Example to call groebner:
+\begin{verbatim}
+  s1:DMP[w,p,z,t,s,b]RN:= 45*p + 35*s - 165*b - 36
+  s2:DMP[w,p,z,t,s,b]RN:= 35*p + 40*z + 25*t - 27*s
+  s3:DMP[w,p,z,t,s,b]RN:= 15*w + 25*p*s + 30*z - 18*t - 165*b**2
+  s4:DMP[w,p,z,t,s,b]RN:= -9*w + 15*p*t + 20*z*s
+  s5:DMP[w,p,z,t,s,b]RN:= w*p + 2*z*t - 11*b**3
+  s6:DMP[w,p,z,t,s,b]RN:= 99*w - 11*b*s + 3*b**2
+  s7:DMP[w,p,z,t,s,b]RN:= b**2 + 33/50*b + 2673/10000
+
+  sn7:=[s1,s2,s3,s4,s5,s6,s7]
+
+  groebner(sn7,info)
+\end{verbatim}
+groebner calculates a minimal Groebner Basis
+all reductions are TOTAL reductions
+
+To get the reduced critical pairs do:
+\begin{verbatim}
+  groebner(sn7,"redcrit")
+\end{verbatim}
+You can get other information by calling:
+\begin{verbatim}
+  groebner(sn7,"info")
+\end{verbatim}
+which returns:
+\begin{verbatim}
+      ci  =>  Leading monomial  for critpair calculation
+      tci =>  Number of terms of polynomial i
+      cj  =>  Leading monomial  for critpair calculation
+      tcj =>  Number of terms of polynomial j
+      c   =>  Leading monomial of critpair polynomial
+      tc  =>  Number of terms of critpair polynomial
+      rc  =>  Leading monomial of redcritpair polynomial
+      trc =>  Number of terms of redcritpair polynomial
+      tF  =>  Number of polynomials in reduction list F
+      tD  =>  Number of critpairs still to do
+\end{verbatim} 
+See 
+\domainref{GroebnerPackage}\\
+\domainref{DistributedMultivariatePolynomial}\\
+\domainref{HomogeneousDistributedMultivariatePolynomial}\\
+\domainref{EuclideanGroebnerBasisPackage}
+
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 \domainhead{Heap}
 
 The domain {\tt Heap(S)} implements a priority queue of objects of
@@ -31786,6 +32558,108 @@ $$
 \returnType{Type: Polynomial HexadecimalExpansion}
 
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+\domainhead{HomogeneousDistributedMultivariatePolynomial}
+
+DistributedMultivariatePolynomial which is abbreviated as DMP and 
+HomogeneousDistributedMultivariatePolynomial, which is abbreviated
+as HDMP, are very similar to MultivariatePolynomial except that 
+they are represented and displayed in a non-recursive manner.
+\begin{verbatim}
+  (d1,d2,d3) : DMP([z,y,x],FRAC INT) 
+                      Type: Void
+\end{verbatim}
+The constructor DMP orders its monomials lexicographically while
+HDMP orders them by total order refined by reverse lexicographic
+order.
+\begin{verbatim}
+  d1 := -4*z + 4*y**2*x + 16*x**2 + 1 
+            2       2
+   - 4z + 4y x + 16x  + 1
+            Type: DistributedMultivariatePolynomial([z,y,x],Fraction Integer)
+\end{verbatim}
+\begin{verbatim}
+  d2 := 2*z*y**2 + 4*x + 1 
+       2
+   2z y  + 4x + 1
+            Type: DistributedMultivariatePolynomial([z,y,x],Fraction Integer)
+\end{verbatim}
+\begin{verbatim}
+  d3 := 2*z*x**2 - 2*y**2 - x 
+       2     2
+   2z x  - 2y  - x
+            Type: DistributedMultivariatePolynomial([z,y,x],Fraction Integer)
+\end{verbatim}
+These constructors are mostly used in Groebner basis calculations.
+\begin{verbatim}
+  groebner [d1,d2,d3]
+        1568  6   1264  5    6   4   182  3   2047  2    103      2857
+   [z - ---- x  - ---- x  + --- x  + --- x  - ---- x  - ---- x - -----,
+        2745       305      305      549       610      2745     10980
+     2    112  6    84  5   1264  4    13  3    84  2   1772       2
+    y  + ---- x  - --- x  - ---- x  - --- x  + --- x  + ---- x + ----,
+         2745      305       305      549      305      2745     2745
+     7   29  6   17  4   11  3    1  2   15     1
+    x  + -- x  - -- x  - -- x  + -- x  + -- x + -]
+          4      16       8      32      16     4
+       Type: List DistributedMultivariatePolynomial([z,y,x],Fraction Integer)
+\end{verbatim}
+\begin{verbatim}
+  (n1,n2,n3) : HDMP([z,y,x],FRAC INT)
+                      Type: Void
+\end{verbatim}
+\begin{verbatim}
+  n1 := d1
+     2       2
+   4y x + 16x  - 4z + 1
+ Type: HomogeneousDistributedMultivariatePolynomial([z,y,x],Fraction Integer)
+\end{verbatim}
+\begin{verbatim}
+  n2 := d2
+       2
+   2z y  + 4x + 1
+ Type: HomogeneousDistributedMultivariatePolynomial([z,y,x],Fraction Integer)
+\end{verbatim}
+\begin{verbatim}
+  n3 := d3
+       2     2
+   2z x  - 2y  - x
+ Type: HomogeneousDistributedMultivariatePolynomial([z,y,x],Fraction Integer)
+\end{verbatim}
+\begin{verbatim}
+
+Note that we get a different Groebner basis when we use the HDMP
+polynomials, as expected.
+\begin{verbatim}
+  groebner [n1,n2,n3]
+     4     3   3  2   1     1   4   29  3   1  2   7        9     1
+   [y  + 2x  - - x  + - z - -, x  + -- x  - - y  - - z x - -- x - -,
+               2      2     8        4      8      4       16     4
+       2        1   2      2       1     2    2   1
+    z y  + 2x + -, y x + 4x  - z + -, z x  - y  - - x,
+                2                  4              2
+     2     2     2   1     3
+    z  - 4y  + 2x  - - z - - x]
+                     4     2
+      Type: List HomogeneousDistributedMultivariatePolynomial([z,y,x],
+                                                           Fraction Integer)
+\end{verbatim}
+
+GeneralDistributedMultivariatePolynomial is somewhat more flexible in
+the sense that as well as accepting a list of variables to specify the
+variable ordering, it also takes a predicate on exponent vectors to
+specify the term ordering.  With this polynomial type the user can
+experiment with the effect of using completely arbitrary term orderings.  
+This flexibility is mostly important for algorithms such as Groebner 
+basis calculations which can be very sensitive to term ordering.
+
+See 
+\domainref{Polynomial},\\
+\domainref{UnivariatePolynomial},\\
+\domainref{MultivariatePolynomial},\\
+\domainref{DistributedMultivariatePolynomial}, and\\
+\domainref{GeneralDistributedMultivariatePolynomial}
+
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 \domainhead{Integer}
 
 Axiom provides many operations for manipulating arbitrary precision
@@ -41738,6 +42612,42 @@ $$
 \returnType{Type: List NonNegativeInteger}
 
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+\domainhead{NottinghamGroup}
+
+If F is a finite field with $p^n$  elements, then we may form the group
+of all formal power series $\{t(1+a_1 t+a_2 t+...)\}$ where $u(0)=0$ and 
+$u^{'}(0)=1$ and $a_i \in F$.
+The group operation is substitution (composition).
+This is called the Nottingham Group. 
+
+The Nottingham Group is the projective limit of finite p-groups.
+Every finite p-group can be embedded in the Nottingham Group.
+\begin{verbatim}
+   x:=monomial(1,1)$UFPS PF 1783
+     x
+\end{verbatim}
+\begin{verbatim}
+   s:=retract(sin x)$NOTTING PF 1783
+             3        5       7       9      11
+     x + 297x  + 1679x  + 427x  + 316x  + O(x  )
+
+   s^2
+             3       5        7        9      11
+     x + 594x  + 535x  + 1166x  + 1379x  + O(x  )
+
+   s^-1
+              3       5       7        9      11
+     x + 1486x  + 847x  + 207x  + 1701x  + O(x  )
+
+   s^-1*s
+            11
+     x + O(x  )
+
+   s*s^-1
+               11
+        x + O(x  )
+\end{verbatim}
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 \domainhead{Octonion}
 
 The Octonions, also called the Cayley-Dixon algebra, defined over a
@@ -42964,6 +43874,55 @@ $$
 \returnType{Type: List NonNegativeInteger}
 
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+\domainhead{Permuation}
+
+
+We represent a permutation as two lists of equal length representing preimages
+and images of moved points. Fixed points do not occur in either of these
+lists. This enables us to compute the set of fixed points and the set of moved
+points easily.
+\begin{verbatim} 
+  p := coercePreimagesImages([[1,2,3],[1,2,3]])
+    1
+                      Type: Permutation PositiveInteger
+\end{verbatim}
+\begin{verbatim}
+  movedPoints p
+    {}
+                      Type: Set PositiveInteger
+\end{verbatim}
+\begin{verbatim}
+  even? p
+    true
+                       Type: Boolean
+\end{verbatim}
+\begin{verbatim}
+  p := coercePreimagesImages([[0,1,2,3],[3,0,2,1]])$PERM ZMOD 4
+    (1 0 3)
+                       Type: Permutation IntegerMod 4
+\end{verbatim}
+\begin{verbatim}
+  fixedPoints p
+    {2}
+                       Type: Set IntegerMod 4
+\end{verbatim}
+\begin{verbatim}
+  q := coercePreimagesImages([[0,1,2,3],[1,0]])$PERM ZMOD 4
+    (1 0)
+                       Type: Permutation IntegerMod 4
+\end{verbatim}
+\begin{verbatim}
+  fixedPoints(p*q)
+    {2,0}
+                       Type: Set IntegerMod 4
+\end{verbatim}
+\begin{verbatim}
+  even?(p*q)
+    false
+                       Type: Boolean
+\end{verbatim}
+
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 \domainhead{Polynomial}
 
 The domain constructor {\tt Polynomial} (abbreviation: {\tt POLY})
@@ -44519,6 +45478,105 @@ $$
 \returnType{Type: Boolean}
 
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+\domainhead{RealSolvePackage}
+\begin{verbatim}
+p := 4*x^3 - 3*x^2 + 2*x - 4
+ 
+
+          3     2
+   (1)  4x  - 3x  + 2x - 4
+                                                     Type: Polynomial Integer
+\end{verbatim}
+\begin{verbatim}
+ans1 := solve(p,0.01)$REALSOLV
+ 
+
+   (2)  [1.11328125]
+                                                             Type: List Float
+\end{verbatim}
+\begin{verbatim}
+ans2 := solve(p::POLY(FRAC(INT)),0.01)$REALSOLV
+ 
+
+   (3)  [1.11328125]
+                                                             Type: List Float
+\end{verbatim}
+\begin{verbatim}
+R := Integer
+ 
+
+   (4)  Integer
+                                                                 Type: Domain
+\end{verbatim}
+\begin{verbatim}
+ls : List Symbol := [x,y,z,t]
+ 
+
+   (5)  [x,y,z,t]
+                                                            Type: List Symbol
+\end{verbatim}
+\begin{verbatim}
+ls2 : List Symbol := [x,y,z,t,new()$Symbol]
+ 
+
+   (6)  [x,y,z,t,%A]
+                                                            Type: List Symbol
+\end{verbatim}
+\begin{verbatim}
+pack := ZDSOLVE(R,ls,ls2)
+ 
+
+   (7)  ZeroDimensionalSolvePackage(Integer,[x,y,z,t],[x,y,z,t,%A])
+                                                                 Type: Domain
+\end{verbatim}
+\begin{verbatim}
+p1 := x**2*y*z + y*z
+ 
+
+          2
+   (8)  (x  + 1)y z
+                                                     Type: Polynomial Integer
+\end{verbatim}
+\begin{verbatim}
+p2 := x**2*y**2*z + x + z
+ 
+
+          2 2
+   (9)  (x y  + 1)z + x
+                                                     Type: Polynomial Integer
+\end{verbatim}
+\begin{verbatim}
+p3 := x**2*y**2*z**2 +  z + 1
+ 
+
+          2 2 2
+   (10)  x y z  + z + 1
+                                                     Type: Polynomial Integer
+\end{verbatim}
+\begin{verbatim}
+lp := [p1, p2, p3]
+ 
+
+            2           2 2            2 2 2
+   (11)  [(x  + 1)y z,(x y  + 1)z + x,x y z  + z + 1]
+                                                Type: List Polynomial Integer
+\end{verbatim}
+\begin{verbatim}
+lsv:List(Symbol):=[x,y,z]
+ 
+
+   (12)  [x,y,z]
+                                                            Type: List Symbol
+\end{verbatim}
+\begin{verbatim}
+ans3 := realSolve(lp,lsv,0.01)$REALSOLV
+ 
+
+   (13)  [ [1.0,0.0,- 1.0] ]
+                                                        Type: List List Float
+\end{verbatim}
+
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 \domainhead{RegularTriangularSet}
 
 The {\tt RegularTriangularSet} domain constructor implements regular
@@ -48300,6 +49358,261 @@ information on related topics, see
 \domainref{Matrix} and \domainref{OneDimensionalArray}.
 
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+\domainhead{TwoDimensionalViewport}
+
+We want to graph $x^3 * (a+b*x)$ on the interval $x=-1..1$
+so we clear out the workspace.
+
+We assign values to the constants
+\begin{verbatim}
+  a:=0.5
+    0.5
+                              Type: Float
+\end{verbatim}
+\begin{verbatim}
+  b:=0.5
+    0.5
+                              Type: Float
+\end{verbatim}
+
+We draw the first case of the graph
+\begin{verbatim}
+  y1:=draw(x^3*(a+b*x),x=-1..1,title=="2.2.10 explicit")
+    TwoDimensionalViewport: "2.2.10 explicit"
+                              Type: TwoDimensionalViewport
+\end{verbatim}
+which results in the image:\\
+\includegraphics[scale=2.00]{ps/v0plot1.eps}
+
+We fetch the graph of the first object
+\begin{verbatim}
+  g1:=getGraph(y1,1)
+    Graph with 1 point list
+                              Type: GraphImage
+\end{verbatim}
+
+We extract its points
+\begin{verbatim}
+  pointLists g1
+   [
+    [ [-1.,0.,1.,3.], [-0.95833333333333337,-1.8336166570216028E-2,1.,3.],
+      [-0.91666666666666674,-3.2093942901234518E-2,1.,3.],
+      [-0.87500000000000011,-4.18701171875E-2,1.,3.],
+      [-0.83333333333333348,-4.8225308641975301E-2,1.,3.],
+      [-0.79166666666666685,-5.1683967496141986E-2,1.,3.],
+      [-0.75000000000000022,-5.2734375E-2,1.,3.],
+      [-0.70833333333333359,-5.1828643422067916E-2,1.,3.],
+      [-0.66666666666666696,-4.9382716049382741E-2,1.,3.],
+      [-0.62500000000000033,-4.5776367187500042E-2,1.,3.],
+      [-0.5833333333333337,-4.1353202160493867E-2,1.,3.],
+      [-0.54166666666666707,-3.6420657310956832E-2,1.,3.],
+      [-0.50000000000000044,-3.1250000000000056E-2,1.,3.],
+      [-0.45833333333333376,-2.6076328607253136E-2,1.,3.],
+      [-0.41666666666666707,-2.1098572530864244E-2,1.,3.],
+      [-0.37500000000000039,-1.6479492187500042E-2,1.,3.],
+      [-0.3333333333333337,-1.2345679012345713E-2,1.,3.],
+      [-0.29166666666666702,-8.7875554591049648E-3,1.,3.],
+      [-0.25000000000000033,-5.8593750000000208E-3,1.,3.],
+      [-0.20833333333333368,-3.5792221257716214E-3,1.,3.],
+      [-0.16666666666666702,-1.9290123456790237E-3,1.,3.],
+      [-0.12500000000000036,-8.5449218750000705E-4,1.,3.],
+      [-8.3333333333333703E-2,-2.6523919753086765E-4,1.,3.],
+      [-4.1666666666667039E-2,-3.4661940586420673E-5,1.,3.],
+      [-3.7470027081099033E-16,-2.6304013894372334E-47,1.,3.],
+      [4.166666666666629E-2,3.7676022376542178E-5,1.,3.],
+      [8.3333333333332954E-2,3.1346450617283515E-4,1.,3.],
+      [0.12499999999999961,1.0986328124999894E-3,1.,3.],
+      [0.16666666666666627,2.7006172839505972E-3,1.,3.],
+      [0.20833333333333293,5.463023244598731E-3,1.,3.],
+      [0.24999999999999958,9.765624999999948E-3,1.,3.],
+      [0.29166666666666624,1.6024365837191284E-2,1.,3.],
+      [0.33333333333333293,2.469135802469126E-2,1.,3.],
+      [0.37499999999999961,3.6254882812499882E-2,1.,3.],
+      [0.4166666666666663,5.1239390432098617E-2,1.,3.],
+      [0.45833333333333298,7.0205500096450435E-2,1.,3.],
+      [0.49999999999999967,9.3749999999999792E-2,1.,3.],
+      [0.5416666666666663,0.12250584731867258,1.,3.],
+      [0.58333333333333293,0.15714216820987617,1.,3.],
+      [0.62499999999999956,0.1983642578124995,1.,3.],
+      [0.66666666666666619,0.24691358024691298,1.,3.],
+      [0.70833333333333282,0.30356776861496837,1.,3.],
+      [0.74999999999999944,0.369140624999999,1.,3.],
+      [0.79166666666666607,0.44448212046681984,1.,3.],
+      [0.8333333333333327,0.530478395061727,1.,3.],
+      [0.87499999999999933,0.62805175781249845,1.,3.],
+      [0.91666666666666596,0.73816068672839308,1.,3.],
+      [0.95833333333333259,0.86179982880015205,1.,3.], [1.,1.,1.,3.]]
+     ]
+                        Type: List List Point DoubleFloat
+\end{verbatim}
+Now we create a second graph with a changed parameter
+\begin{verbatim}
+  b:=1.0
+    1.0
+                        Type: Float
+\end{verbatim}
+We draw it
+\begin{verbatim}
+  y2:=draw(x^3*(a+b*x),x=-1..1)
+    TwoDimensionalViewport: "AXIOM2D"
+                        Type: TwoDimensionalViewport
+\end{verbatim}
+which results in the image:\\
+\includegraphics[scale=2.00]{ps/v0plot2.eps}
+
+We fetch this new graph
+\begin{verbatim}
+  g2:=getGraph(y2,1)
+    Graph with 1 point list
+                       Type: GraphImage
+\end{verbatim}
+We get the points from this graph
+\begin{verbatim}
+  pointLists g2
+   [
+    [ [-1.,0.5,1.,3.], [-0.95833333333333337,0.40339566454475323,1.,3.],
+      [-0.91666666666666674,0.32093942901234584,1.,3.],
+      [-0.87500000000000011,0.25122070312500017,1.,3.],
+      [-0.83333333333333348,0.19290123456790137,1.,3.],
+      [-0.79166666666666685,0.14471510898919768,1.,3.],
+      [-0.75000000000000022,0.10546875000000019,1.,3.],
+      [-0.70833333333333359,7.404091917438288E-2,1.,3.],
+      [-0.66666666666666696,4.938271604938288E-2,1.,3.],
+      [-0.62500000000000033,3.0517578125000125E-2,1.,3.],
+      [-0.5833333333333337,1.6541280864197649E-2,1.,3.],
+      [-0.54166666666666707,6.6219376929013279E-3,1.,3.],
+      [-0.50000000000000044,5.5511151231257827E-17,1.,3.],
+      [-0.45833333333333376,-4.011742862654287E-3,1.,3.],
+      [-0.41666666666666707,-6.0281635802469057E-3,1.,3.],
+      [-0.37500000000000039,-6.5917968750000035E-3,1.,3.],
+      [-0.3333333333333337,-6.1728395061728461E-3,1.,3.],
+      [-0.29166666666666702,-5.1691502700617377E-3,1.,3.],
+      [-0.25000000000000033,-3.9062500000000104E-3,1.,3.],
+      [-0.20833333333333368,-2.6373215663580349E-3,1.,3.],
+      [-0.16666666666666702,-1.543209876543218E-3,1.,3.],
+      [-0.12500000000000036,-7.3242187500000564E-4,1.,3.],
+      [-8.3333333333333703E-2,-2.4112654320987957E-4,1.,3.],
+      [-4.1666666666667039E-2,-3.315489969135889E-5,1.,3.],
+      [-3.7470027081099033E-16,-2.6304013894372324E-47,1.,3.],
+      [4.166666666666629E-2,3.9183063271603852E-5,1.,3.],
+      [8.3333333333332954E-2,3.3757716049382237E-4,1.,3.],
+      [0.12499999999999961,1.2207031249999879E-3,1.,3.],
+      [0.16666666666666627,3.0864197530863957E-3,1.,3.],
+      [0.20833333333333293,6.4049238040123045E-3,1.,3.],
+      [0.24999999999999958,1.1718749999999934E-2,1.,3.],
+      [0.29166666666666624,1.9642771026234473E-2,1.,3.],
+      [0.33333333333333293,3.0864197530864071E-2,1.,3.],
+      [0.37499999999999961,4.6142578124999847E-2,1.,3.],
+      [0.4166666666666663,6.6309799382715848E-2,1.,3.],
+      [0.45833333333333298,9.2270085841049135E-2,1.,3.],
+      [0.49999999999999967,0.12499999999999971,1.,3.],
+      [0.5416666666666663,0.16554844232253049,1.,3.],
+      [0.58333333333333293,0.21503665123456736,1.,3.],
+      [0.62499999999999956,0.27465820312499928,1.,3.],
+      [0.66666666666666619,0.3456790123456781,1.,3.],
+      [0.70833333333333282,0.42943733121141858,1.,3.],
+      [0.74999999999999944,0.52734374999999845,1.,3.],
+      [0.79166666666666607,0.64088119695215873,1.,3.],
+      [0.8333333333333327,0.77160493827160281,1.,3.],
+      [0.87499999999999933,0.92114257812499756,1.,3.],
+      [0.91666666666666596,1.0911940586419722,1.,3.],
+      [0.95833333333333259,1.2835316599151199,1.,3.], [1.,1.5,1.,3.]]
+     ]
+                           Type: List List Point DoubleFloat
+\end{verbatim}
+and we put these points, g2 onto the first graph y1 as graph 2
+\begin{verbatim}
+  putGraph(y1,g2,2)
+                           Type: Void
+\end{verbatim}
+And now we do the whole sequence again
+\begin{verbatim}
+  b:=2.0
+    2.0
+                           Type: Float
+\end{verbatim}
+\begin{verbatim}
+  y3:=draw(x^3*(a+b*x),x=-1..1)
+    TwoDimensionalViewport: "AXIOM2D"
+                          Type: TwoDimensionalViewport
+\end{verbatim}
+which results in the image:\\
+\includegraphics[scale=2.00]{ps/v0plot3.eps}
+
+\begin{verbatim}
+  g3:=getGraph(y3,1)
+    Graph with 1 point list
+                          Type: GraphImage
+\end{verbatim}
+\begin{verbatim}
+  pointLists g3
+   [
+    [ [-1.,1.5,1.,3.], [-0.95833333333333337,1.2468593267746917,1.,3.],
+      [-0.91666666666666674,1.0270061728395066,1.,3.],
+      [-0.87500000000000011,0.83740234375000044,1.,3.],
+      [-0.83333333333333348,0.67515432098765471,1.,3.],
+      [-0.79166666666666685,0.53751326195987703,1.,3.],
+      [-0.75000000000000022,0.42187500000000056,1.,3.],
+      [-0.70833333333333359,0.32578004436728447,1.,3.],
+      [-0.66666666666666696,0.24691358024691412,1.,3.],
+      [-0.62500000000000033,0.18310546875000044,1.,3.],
+      [-0.5833333333333337,0.1323302469135807,1.,3.],
+      [-0.54166666666666707,9.2707127700617648E-2,1.,3.],
+      [-0.50000000000000044,6.2500000000000278E-2,1.,3.],
+      [-0.45833333333333376,4.0117428626543411E-2,1.,3.],
+      [-0.41666666666666707,2.4112654320987775E-2,1.,3.],
+      [-0.37500000000000039,1.3183593750000073E-2,1.,3.],
+      [-0.3333333333333337,6.1728395061728877E-3,1.,3.],
+      [-0.29166666666666702,2.0676601080247183E-3,1.,3.],
+      [-0.25000000000000033,1.0408340855860843E-17,1.,3.],
+      [-0.20833333333333368,-7.5352044753086191E-4,1.,3.],
+      [-0.16666666666666702,-7.7160493827160663E-4,1.,3.],
+      [-0.12500000000000036,-4.8828125000000282E-4,1.,3.],
+      [-8.3333333333333703E-2,-1.9290123456790339E-4,1.,3.],
+      [-4.1666666666667039E-2,-3.0140817901235325E-5,1.,3.],
+      [-3.7470027081099033E-16,-2.6304013894372305E-47,1.,3.],
+      [4.166666666666629E-2,4.21971450617272E-5,1.,3.],
+      [8.3333333333332954E-2,3.8580246913579681E-4,1.,3.],
+      [0.12499999999999961,1.4648437499999848E-3,1.,3.],
+      [0.16666666666666627,3.8580246913579933E-3,1.,3.],
+      [0.20833333333333293,8.2887249228394497E-3,1.,3.],
+      [0.24999999999999958,1.562499999999991E-2,1.,3.],
+      [0.29166666666666624,2.6879581404320851E-2,1.,3.],
+      [0.33333333333333293,4.3209876543209694E-2,1.,3.],
+      [0.37499999999999961,6.5917968749999764E-2,1.,3.],
+      [0.4166666666666663,9.6450617283950296E-2,1.,3.],
+      [0.45833333333333298,0.13639925733024652,1.,3.],
+      [0.49999999999999967,0.18749999999999956,1.,3.],
+      [0.5416666666666663,0.25163363233024633,1.,3.],
+      [0.58333333333333293,0.33082561728394977,1.,3.],
+      [0.62499999999999956,0.42724609374999883,1.,3.],
+      [0.66666666666666619,0.5432098765432084,1.,3.],
+      [0.70833333333333282,0.68117645640431912,1.,3.],
+      [0.74999999999999944,0.84374999999999756,1.,3.],
+      [0.79166666666666607,1.0336793499228365,1.,3.],
+      [0.8333333333333327,1.2538580246913544,1.,3.],
+      [0.87499999999999933,1.507324218749996,1.,3.],
+      [0.91666666666666596,1.7972608024691306,1.,3.],
+      [0.95833333333333259,2.1269953221450555,1.,3.], [1.,2.5,1.,3.]]
+     ]
+                        Type: List List Point DoubleFloat
+\end{verbatim}
+and put the third graphs points g3 onto the first graph y1 as graph 3
+\begin{verbatim}
+  putGraph(y1,g3,3)
+                        Type: Void
+\end{verbatim}
+Finally we show the combined result
+\begin{verbatim}
+  vp:=makeViewport2D(y1)
+    TwoDimensionalViewport: "2.2.10 explicit"
+                        Type: TwoDimensionalViewport
+\end{verbatim}
+which results in the image:\\
+\includegraphics[scale=2.00]{ps/v0plot4.eps}\\
+which shows all of the graphs in a single image.
+
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 \domainhead{UnivariatePolynomial}
 
 The domain constructor {\tt UnivariatePolynomial} (abbreviated {\tt
diff --git a/books/bookvol10.3.pamphlet b/books/bookvol10.3.pamphlet
index 2a4d9e4..2299641 100644
--- a/books/bookvol10.3.pamphlet
+++ b/books/bookvol10.3.pamphlet
@@ -2196,7 +2196,7 @@ the original stack since map! is destructive:
 
    map!(x+->x+10,a)
        [18,19,13,14,15]
-o
+
 Notice that the orignal stack has been changed:
 
    a
@@ -63017,6 +63017,17 @@ sample()$NOTTING(PF(1783))
 ====================================================================
 NottinghamGroup examples
 ====================================================================
+                             n
+If F is a finite field with p  elements, then we may form the group
+of all formal power series {t(1+a t+a t+...)} where u(0)=0 and 
+ ,                               1   2
+u (0)=1 and $a is an element of F. 
+              i
+The group operation is substitution (composition).
+This is called the Nottingham Group. 
+
+The Nottingham Group is the projective limit of finite p-groups.
+Every finite p-group can be embedded in the Nottingham Group.
 
    x:=monomial(1,1)$UFPS PF 1783
      x
@@ -63049,14 +63060,6 @@ o )show UnivariateFormalPowerSeries
 \pagehead{NottinghamGroup}{NOTTING}
 \pagepic{ps/v103nottinghamgroup.ps}{NOTTING}{1.00}
 
-If F is a finite field with $p^n$ elements, then we may form the group
-of all formal power series $\{t(1+a_1t+a_2t+\ldots)\}$ where $u(0)=0$ and 
-$u^{'}(0)=1$ and $a_i \in F$. 
-The group operation is substitution (composition).
-This is called the Nottingham Group. 
-
-The Nottingham Group is the projective limit of finite p-groups.
-Every finite p-group can be embedded in the Nottingham Group.
 {\bf Exports:}\\
 \begin{tabular}{lllll}
 \cross{NOTTING}{1} &
@@ -70096,6 +70099,124 @@ PendantTree(S: SetCategory): T == C where
 @
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 \section{domain PERM Permutation}
+<<Permutation.input>>=
+)set break resume
+)sys rm -f Permutation.output
+)spool Permutation.output
+)set message test on
+)set message auto off
+)clear all
+--S 1 of 8
+p := coercePreimagesImages([[1,2,3],[1,2,3]])
+--R 
+--R
+--R   (1)  1
+--R                                            Type: Permutation PositiveInteger
+--E 1
+
+--S 2 of 8
+movedPoints p    -- should return {}
+--R 
+--R
+--R   (2)  {}
+--R                                                    Type: Set PositiveInteger
+--E 2
+
+--S 3 of 8
+even? p          -- should return true
+--R 
+--R
+--R   (3)  true
+--R                                                                Type: Boolean
+--E 3
+
+--S 4 of 8
+p := coercePreimagesImages([[0,1,2,3],[3,0,2,1]])$PERM ZMOD 4
+--R 
+--R
+--R   (4)  (1 0 3)
+--R                                               Type: Permutation IntegerMod 4
+--E 4
+
+--S 5 of 8
+fixedPoints p    -- should return {2}
+--R 
+--R
+--R   (5)  {2}
+--R                                                       Type: Set IntegerMod 4
+--E 5
+
+--S 6 of 8
+q := coercePreimagesImages([[0,1,2,3],[1,0]])$PERM ZMOD 4
+--R 
+--R
+--R   (6)  (1 0)
+--R                                               Type: Permutation IntegerMod 4
+--E 6
+
+--S 7 of 8
+fixedPoints(p*q) -- should return {2,0}
+--R 
+--R
+--R   (7)  {2,0}
+--R                                                       Type: Set IntegerMod 4
+--E 7
+
+--S 8 of 8
+even?(p*q)       -- should return false
+--R 
+--R
+--R   (8)  false
+--R                                                                Type: Boolean
+--E 8
+)spool
+)lisp (bye)
+@
+<<Permutation.help>>=
+====================================================================
+Permutation Examples
+====================================================================
+
+We represent a permutation as two lists of equal length representing preimages
+and images of moved points. I.e., fixed points do not occur in either of these
+lists. This enables us to compute the set of fixed points and the set of moved
+points easily.
+ 
+  p := coercePreimagesImages([[1,2,3],[1,2,3]])
+    1
+                      Type: Permutation PositiveInteger
+
+  movedPoints p
+    {}
+                      Type: Set PositiveInteger
+
+  even? p
+    true
+                       Type: Boolean
+
+  p := coercePreimagesImages([[0,1,2,3],[3,0,2,1]])$PERM ZMOD 4
+    (1 0 3)
+                       Type: Permutation IntegerMod 4
+
+  fixedPoints p
+    {2}
+                       Type: Set IntegerMod 4
+
+  q := coercePreimagesImages([[0,1,2,3],[1,0]])$PERM ZMOD 4
+    (1 0)
+                       Type: Permutation IntegerMod 4
+
+  fixedPoints(p*q)
+    {2,0}
+                       Type: Set IntegerMod 4
+  even?(p*q)
+    false
+                       Type: Boolean
+
+See Also:
+o )show Permutation
+
+@
 \pagehead{Permutation}{PERM}
 \pagepic{ps/v103permutation.ps}{PERM}{1.00}
 
@@ -70191,6 +70312,9 @@ Permutation(S:SetCategory): public == private where
       ++ coercePreimagesImages(lls) coerces the representation {\em lls}
       ++ of a permutation as a list of preimages and images to a permutation.
       ++ We assume that both preimage and image do not contain repetitions.
+      ++ 
+      ++X p := coercePreimagesImages([[1,2,3],[1,2,3]])
+      ++X q := coercePreimagesImages([[0,1,2,3],[3,0,2,1]])$PERM ZMOD 4
     coerce            :  List List S      ->  %
       ++ coerce(lls) coerces a list of cycles {\em lls} to a
       ++ permutation, each cycle being a list with no
@@ -70216,6 +70340,9 @@ Permutation(S:SetCategory): public == private where
       ++ permutation p.
     movedPoints       :  %                ->  Set S
       ++ movedPoints(p) returns the set of points moved by the permutation p.
+      ++ 
+      ++X p := coercePreimagesImages([[1,2,3],[1,2,3]])
+      ++X movedPoints p
     cyclePartition    :  %                ->  Partition
       ++ cyclePartition(p) returns the cycle structure of a permutation
       ++ p including cycles of length 1 only if S is finite.
@@ -70229,6 +70356,9 @@ Permutation(S:SetCategory): public == private where
     even?             :  %                ->  Boolean
       ++ even?(p) returns true if and only if p is an even permutation,
       ++ i.e. {\em sign(p)} is 1.
+      ++ 
+      ++X p := coercePreimagesImages([[1,2,3],[1,2,3]])
+      ++X even? p
     odd?              :  %                ->  Boolean
       ++ odd?(p) returns true if and only if p is an odd permutation
       ++ i.e. {\em sign(p)} is {\em -1}.
@@ -70241,6 +70371,8 @@ Permutation(S:SetCategory): public == private where
     if S has Finite then
       fixedPoints     :  %                ->  Set S
         ++ fixedPoints(p) returns the points fixed by the permutation p.
+        ++X p := coercePreimagesImages([[0,1,2,3],[3,0,2,1]])$PERM ZMOD 4
+        ++X fixedPoints p
     if S has IntegerNumberSystem or S has Finite then
       coerceImages    :  L S              ->  %
         ++ coerceImages(ls) coerces the list {\em ls} to a permutation
@@ -70254,130 +70386,7 @@ Permutation(S:SetCategory): public == private where
     -- representation of the object:
 
     Rep  := V L S
-@
-
-We represent a permutation as two lists of equal length representing preimages
-and images of moved points. I.e., fixed points do not occur in either of these
-lists. This enables us to compute the set of fixed points and the set of moved
-points easily.
- 
-Note that this was not respected in versions before [[patch--50]] of this
-domain.
-
-<<Permutation.input>>=
-)set break resume
-)sys rm -f Permutation.output
-)spool Permutation.output
-)set message test on
-)set message auto off
-)clear all
---S 1 of 8
-p := coercePreimagesImages([[1,2,3],[1,2,3]])
---R 
---R
---R   (1)  1
---R                                            Type: Permutation PositiveInteger
---E 1
-
---S 2 of 8
-movedPoints p    -- should return {}
---R 
---R
---R   (2)  {}
---R                                                    Type: Set PositiveInteger
---E 2
-
---S 3 of 8
-even? p          -- should return true
---R 
---R
---R   (3)  true
---R                                                                Type: Boolean
---E 3
-
---S 4 of 8
-p := coercePreimagesImages([[0,1,2,3],[3,0,2,1]])$PERM ZMOD 4
---R 
---R
---R   (4)  (1 0 3)
---R                                               Type: Permutation IntegerMod 4
---E 4
-
---S 5 of 8
-fixedPoints p    -- should return {2}
---R 
---R
---R   (5)  {2}
---R                                                       Type: Set IntegerMod 4
---E 5
-
---S 6 of 8
-q := coercePreimagesImages([[0,1,2,3],[1,0]])$PERM ZMOD 4
---R 
---R
---R   (6)  (1 0)
---R                                               Type: Permutation IntegerMod 4
---E 6
-
---S 7 of 8
-fixedPoints(p*q) -- should return {2,0}
---R 
---R
---R   (7)  {2,0}
---R                                                       Type: Set IntegerMod 4
---E 7
-
---S 8 of 8
-even?(p*q)       -- should return false
---R 
---R
---R   (8)  false
---R                                                                Type: Boolean
---E 8
-)spool
-)lisp (bye)
-@
-<<Permutation.help>>=
-====================================================================
-Permutation Examples
-====================================================================
-
-  p := coercePreimagesImages([[1,2,3],[1,2,3]])
-    1
-                      Type: Permutation PositiveInteger
-
-  movedPoints p
-    {}
-                      Type: Set PositiveInteger
-
-  even? p
-    true
-                       Type: Boolean
-
-  p := coercePreimagesImages([[0,1,2,3],[3,0,2,1]])$PERM ZMOD 4
-    (1 0 3)
-                       Type: Permutation IntegerMod 4
-
-  fixedPoints p
-    {2}
-                       Type: Set IntegerMod 4
-
-  q := coercePreimagesImages([[0,1,2,3],[1,0]])$PERM ZMOD 4
-    (1 0)
-                       Type: Permutation IntegerMod 4
-
-  fixedPoints(p*q)
-    {2,0}
-                       Type: Set IntegerMod 4
-  even?(p*q)
-    false
-                       Type: Boolean
-
-See Also:
-o )show Permutation
 
-@
-<<domain PERM Permutation>>=
     -- import of domains and packages
 
     import OutputForm
@@ -70491,26 +70500,6 @@ o )show Permutation
             image := cons(pi, image)
 
       [preImage, image]
-@ 
-
-This operation transforms a pair of preimages and images into an element of the
-domain. Since we assume that fixed points do not occur in the representation,
-we have to sort them out here. 
-
-Note that before [[patch--50]] this read
-\begin{verbatim}
-      coercePreimagesImages preImageAndImage ==
-       p : % := [preImageAndImage.1,preImageAndImage.2]
-\end{verbatim}
-causing bugs when computing [[movedPoints]], [[fixedPoints]], [[even?]],
-[[odd?]], etc., as reported in Issue~\#295.
-
-The other coercion facilities check for fixed points. It also seems that [[*]]
-removes fixed points from its result.
-
-Up to [[patch--50]] we did not check for duplicates.
- 
-<<domain PERM Permutation>>=
 
     movedPoints p == construct p.1
 
@@ -70546,7 +70535,6 @@ Up to [[patch--50]] we did not check for duplicates.
       even? p => 1
       - 1
 
-
     even?(p) ==  even?(#(p.1) - numberOfCycles p)
       -- see the book of James and Kerber on symmetric groups
       -- for this formula.
@@ -71613,8 +71601,10 @@ Pi(): Exports == Implementation where
 )set message test on
 )set message auto off
 )clear all
---S 1 of 1
-makeSketch(x+y,x,y,-1/2..1/2,-1/2..1/2)$ACPLOT
+
+--S 1 of 5
+sketch:=makeSketch(x+y,x,y,-1/2..1/2,-1/2..1/2)$ACPLOT
+--R
 --R   (1)                    ACPLOT
 --R                       1         1      1         1
 --R        y + x = 0,   - - <= x <= -,   - - <= y <= -
@@ -71623,6 +71613,548 @@ makeSketch(x+y,x,y,-1/2..1/2,-1/2..1/2)$ACPLOT
 --R                        [- 0.5,0.5]
 --R                                                Type: PlaneAlgebraicCurvePlot
 --E 1
+
+--S 2 of 5
+refined:=refine(sketch,0.1)
+--R
+--R   (2)                      ACPLOT
+--R                         1         1      1         1
+--R          y + x = 0,   - - <= x <= -,   - - <= y <= -
+--R                         2         2      2         2
+--R                          [0.5,- 0.5]
+--R          [0.49600000000000083,- 0.49600000000000083]
+--R          [0.49200000000000083,- 0.49200000000000083]
+--R          [0.48800000000000082,- 0.48800000000000082]
+--R          [0.48400000000000082,- 0.48400000000000082]
+--R          [0.48000000000000081,- 0.48000000000000081]
+--R          [0.47600000000000081,- 0.47600000000000081]
+--R          [0.47200000000000081,- 0.47200000000000081]
+--R           [0.4680000000000008,- 0.4680000000000008]
+--R           [0.4640000000000008,- 0.4640000000000008]
+--R           [0.4600000000000008,- 0.4600000000000008]
+--R          [0.45600000000000079,- 0.45600000000000079]
+--R          [0.45200000000000079,- 0.45200000000000079]
+--R          [0.44800000000000079,- 0.44800000000000079]
+--R          [0.44400000000000078,- 0.44400000000000078]
+--R          [0.44000000000000078,- 0.44000000000000078]
+--R          [0.43600000000000078,- 0.43600000000000078]
+--R          [0.43200000000000077,- 0.43200000000000077]
+--R          [0.42800000000000077,- 0.42800000000000077]
+--R          [0.42400000000000077,- 0.42400000000000077]
+--R          [0.42000000000000076,- 0.42000000000000076]
+--R          [0.41600000000000076,- 0.41600000000000076]
+--R          [0.41200000000000075,- 0.41200000000000075]
+--R          [0.40800000000000075,- 0.40800000000000075]
+--R          [0.40400000000000075,- 0.40400000000000075]
+--R          [0.40000000000000074,- 0.40000000000000074]
+--R          [0.39600000000000074,- 0.39600000000000074]
+--R          [0.39200000000000074,- 0.39200000000000074]
+--R          [0.38800000000000073,- 0.38800000000000073]
+--R          [0.38400000000000073,- 0.38400000000000073]
+--R          [0.38000000000000073,- 0.38000000000000073]
+--R          [0.37600000000000072,- 0.37600000000000072]
+--R          [0.37200000000000072,- 0.37200000000000072]
+--R          [0.36800000000000072,- 0.36800000000000072]
+--R          [0.36400000000000071,- 0.36400000000000071]
+--R          [0.36000000000000071,- 0.36000000000000071]
+--R           [0.3560000000000007,- 0.3560000000000007]
+--R           [0.3520000000000007,- 0.3520000000000007]
+--R           [0.3480000000000007,- 0.3480000000000007]
+--R          [0.34400000000000069,- 0.34400000000000069]
+--R          [0.34000000000000069,- 0.34000000000000069]
+--R          [0.33600000000000069,- 0.33600000000000069]
+--R          [0.33200000000000068,- 0.33200000000000068]
+--R          [0.32800000000000068,- 0.32800000000000068]
+--R          [0.32400000000000068,- 0.32400000000000068]
+--R          [0.32000000000000067,- 0.32000000000000067]
+--R          [0.31600000000000067,- 0.31600000000000067]
+--R          [0.31200000000000067,- 0.31200000000000067]
+--R          [0.30800000000000066,- 0.30800000000000066]
+--R          [0.30400000000000066,- 0.30400000000000066]
+--R          [0.30000000000000066,- 0.30000000000000066]
+--R          [0.29600000000000065,- 0.29600000000000065]
+--R          [0.29200000000000065,- 0.29200000000000065]
+--R          [0.28800000000000064,- 0.28800000000000064]
+--R          [0.28400000000000064,- 0.28400000000000064]
+--R          [0.28000000000000064,- 0.28000000000000064]
+--R          [0.27600000000000063,- 0.27600000000000063]
+--R          [0.27200000000000063,- 0.27200000000000063]
+--R          [0.26800000000000063,- 0.26800000000000063]
+--R          [0.26400000000000062,- 0.26400000000000062]
+--R          [0.26000000000000062,- 0.26000000000000062]
+--R          [0.25600000000000062,- 0.25600000000000062]
+--R          [0.25200000000000061,- 0.25200000000000061]
+--R          [0.24800000000000061,- 0.24800000000000061]
+--R          [0.24400000000000061,- 0.24400000000000061]
+--R           [0.2400000000000006,- 0.2400000000000006]
+--R           [0.2360000000000006,- 0.2360000000000006]
+--R          [0.23200000000000059,- 0.23200000000000059]
+--R          [0.22800000000000059,- 0.22800000000000059]
+--R          [0.22400000000000059,- 0.22400000000000059]
+--R          [0.22000000000000058,- 0.22000000000000058]
+--R          [0.21600000000000058,- 0.21600000000000058]
+--R          [0.21200000000000058,- 0.21200000000000058]
+--R          [0.20800000000000057,- 0.20800000000000057]
+--R          [0.20400000000000057,- 0.20400000000000057]
+--R          [0.20000000000000057,- 0.20000000000000057]
+--R          [0.19600000000000056,- 0.19600000000000056]
+--R          [0.19200000000000056,- 0.19200000000000056]
+--R          [0.18800000000000056,- 0.18800000000000056]
+--R          [0.18400000000000055,- 0.18400000000000055]
+--R          [0.18000000000000055,- 0.18000000000000055]
+--R          [0.17600000000000054,- 0.17600000000000054]
+--R          [0.17200000000000054,- 0.17200000000000054]
+--R          [0.16800000000000054,- 0.16800000000000054]
+--R          [0.16400000000000053,- 0.16400000000000053]
+--R          [0.16000000000000053,- 0.16000000000000053]
+--R          [0.15600000000000053,- 0.15600000000000053]
+--R          [0.15200000000000052,- 0.15200000000000052]
+--R          [0.14800000000000052,- 0.14800000000000052]
+--R          [0.14400000000000052,- 0.14400000000000052]
+--R          [0.14000000000000051,- 0.14000000000000051]
+--R          [0.13600000000000051,- 0.13600000000000051]
+--R          [0.13200000000000051,- 0.13200000000000051]
+--R           [0.1280000000000005,- 0.1280000000000005]
+--R           [0.1240000000000005,- 0.1240000000000005]
+--R           [0.1200000000000005,- 0.1200000000000005]
+--R          [0.11600000000000049,- 0.11600000000000049]
+--R          [0.11200000000000049,- 0.11200000000000049]
+--R          [0.10800000000000048,- 0.10800000000000048]
+--R          [0.10400000000000048,- 0.10400000000000048]
+--R          [0.10000000000000048,- 0.10000000000000048]
+--R        [9.6000000000000474E-2,- 9.6000000000000474E-2]
+--R         [9.200000000000047E-2,- 9.200000000000047E-2]
+--R        [8.8000000000000467E-2,- 8.8000000000000467E-2]
+--R        [8.4000000000000463E-2,- 8.4000000000000463E-2]
+--R         [8.000000000000046E-2,- 8.000000000000046E-2]
+--R        [7.6000000000000456E-2,- 7.6000000000000456E-2]
+--R        [7.2000000000000453E-2,- 7.2000000000000453E-2]
+--R        [6.8000000000000449E-2,- 6.8000000000000449E-2]
+--R        [6.4000000000000445E-2,- 6.4000000000000445E-2]
+--R        [6.0000000000000442E-2,- 6.0000000000000442E-2]
+--R        [5.6000000000000438E-2,- 5.6000000000000438E-2]
+--R        [5.2000000000000435E-2,- 5.2000000000000435E-2]
+--R        [4.8000000000000431E-2,- 4.8000000000000431E-2]
+--R        [4.4000000000000428E-2,- 4.4000000000000428E-2]
+--R        [4.0000000000000424E-2,- 4.0000000000000424E-2]
+--R        [3.6000000000000421E-2,- 3.6000000000000421E-2]
+--R        [3.2000000000000417E-2,- 3.2000000000000417E-2]
+--R        [2.8000000000000417E-2,- 2.8000000000000417E-2]
+--R        [2.4000000000000417E-2,- 2.4000000000000417E-2]
+--R        [2.0000000000000417E-2,- 2.0000000000000417E-2]
+--R        [1.6000000000000417E-2,- 1.6000000000000417E-2]
+--R        [1.2000000000000417E-2,- 1.2000000000000417E-2]
+--R        [8.0000000000004165E-3,- 8.0000000000004165E-3]
+--R        [4.0000000000004164E-3,- 4.0000000000004164E-3]
+--R        [4.163336342344337E-16,- 4.163336342344337E-16]
+--R        [- 3.9999999999995837E-3,3.9999999999995837E-3]
+--R        [- 7.9999999999995838E-3,7.9999999999995838E-3]
+--R        [- 1.1999999999999584E-2,1.1999999999999584E-2]
+--R        [- 1.5999999999999584E-2,1.5999999999999584E-2]
+--R        [- 1.9999999999999584E-2,1.9999999999999584E-2]
+--R        [- 2.3999999999999584E-2,2.3999999999999584E-2]
+--R        [- 2.7999999999999584E-2,2.7999999999999584E-2]
+--R        [- 3.1999999999999584E-2,3.1999999999999584E-2]
+--R        [- 3.5999999999999588E-2,3.5999999999999588E-2]
+--R        [- 3.9999999999999591E-2,3.9999999999999591E-2]
+--R        [- 4.3999999999999595E-2,4.3999999999999595E-2]
+--R        [- 4.7999999999999599E-2,4.7999999999999599E-2]
+--R        [- 5.1999999999999602E-2,5.1999999999999602E-2]
+--R        [- 5.5999999999999606E-2,5.5999999999999606E-2]
+--R        [- 5.9999999999999609E-2,5.9999999999999609E-2]
+--R        [- 6.3999999999999613E-2,6.3999999999999613E-2]
+--R        [- 6.7999999999999616E-2,6.7999999999999616E-2]
+--R         [- 7.199999999999962E-2,7.199999999999962E-2]
+--R        [- 7.5999999999999623E-2,7.5999999999999623E-2]
+--R        [- 7.9999999999999627E-2,7.9999999999999627E-2]
+--R        [- 8.3999999999999631E-2,8.3999999999999631E-2]
+--R        [- 8.7999999999999634E-2,8.7999999999999634E-2]
+--R        [- 9.1999999999999638E-2,9.1999999999999638E-2]
+--R        [- 9.5999999999999641E-2,9.5999999999999641E-2]
+--R        [- 9.9999999999999645E-2,9.9999999999999645E-2]
+--R          [- 0.10399999999999965,0.10399999999999965]
+--R          [- 0.10799999999999965,0.10799999999999965]
+--R          [- 0.11199999999999966,0.11199999999999966]
+--R          [- 0.11599999999999966,0.11599999999999966]
+--R          [- 0.11999999999999966,0.11999999999999966]
+--R          [- 0.12399999999999967,0.12399999999999967]
+--R          [- 0.12799999999999967,0.12799999999999967]
+--R          [- 0.13199999999999967,0.13199999999999967]
+--R          [- 0.13599999999999968,0.13599999999999968]
+--R          [- 0.13999999999999968,0.13999999999999968]
+--R          [- 0.14399999999999968,0.14399999999999968]
+--R          [- 0.14799999999999969,0.14799999999999969]
+--R          [- 0.15199999999999969,0.15199999999999969]
+--R          [- 0.15599999999999969,0.15599999999999969]
+--R           [- 0.1599999999999997,0.1599999999999997]
+--R           [- 0.1639999999999997,0.1639999999999997]
+--R          [- 0.16799999999999971,0.16799999999999971]
+--R          [- 0.17199999999999971,0.17199999999999971]
+--R          [- 0.17599999999999971,0.17599999999999971]
+--R          [- 0.17999999999999972,0.17999999999999972]
+--R          [- 0.18399999999999972,0.18399999999999972]
+--R          [- 0.18799999999999972,0.18799999999999972]
+--R          [- 0.19199999999999973,0.19199999999999973]
+--R          [- 0.19599999999999973,0.19599999999999973]
+--R          [- 0.19999999999999973,0.19999999999999973]
+--R          [- 0.20399999999999974,0.20399999999999974]
+--R          [- 0.20799999999999974,0.20799999999999974]
+--R          [- 0.21199999999999974,0.21199999999999974]
+--R          [- 0.21599999999999975,0.21599999999999975]
+--R          [- 0.21999999999999975,0.21999999999999975]
+--R          [- 0.22399999999999975,0.22399999999999975]
+--R          [- 0.22799999999999976,0.22799999999999976]
+--R          [- 0.23199999999999976,0.23199999999999976]
+--R          [- 0.23599999999999977,0.23599999999999977]
+--R          [- 0.23999999999999977,0.23999999999999977]
+--R          [- 0.24399999999999977,0.24399999999999977]
+--R          [- 0.24799999999999978,0.24799999999999978]
+--R          [- 0.25199999999999978,0.25199999999999978]
+--R          [- 0.25599999999999978,0.25599999999999978]
+--R          [- 0.25999999999999979,0.25999999999999979]
+--R          [- 0.26399999999999979,0.26399999999999979]
+--R          [- 0.26799999999999979,0.26799999999999979]
+--R           [- 0.2719999999999998,0.2719999999999998]
+--R           [- 0.2759999999999998,0.2759999999999998]
+--R           [- 0.2799999999999998,0.2799999999999998]
+--R          [- 0.28399999999999981,0.28399999999999981]
+--R          [- 0.28799999999999981,0.28799999999999981]
+--R          [- 0.29199999999999982,0.29199999999999982]
+--R          [- 0.29599999999999982,0.29599999999999982]
+--R          [- 0.29999999999999982,0.29999999999999982]
+--R          [- 0.30399999999999983,0.30399999999999983]
+--R          [- 0.30799999999999983,0.30799999999999983]
+--R          [- 0.31199999999999983,0.31199999999999983]
+--R          [- 0.31599999999999984,0.31599999999999984]
+--R          [- 0.31999999999999984,0.31999999999999984]
+--R          [- 0.32399999999999984,0.32399999999999984]
+--R          [- 0.32799999999999985,0.32799999999999985]
+--R          [- 0.33199999999999985,0.33199999999999985]
+--R          [- 0.33599999999999985,0.33599999999999985]
+--R          [- 0.33999999999999986,0.33999999999999986]
+--R          [- 0.34399999999999986,0.34399999999999986]
+--R          [- 0.34799999999999986,0.34799999999999986]
+--R          [- 0.35199999999999987,0.35199999999999987]
+--R          [- 0.35599999999999987,0.35599999999999987]
+--R          [- 0.35999999999999988,0.35999999999999988]
+--R          [- 0.36399999999999988,0.36399999999999988]
+--R          [- 0.36799999999999988,0.36799999999999988]
+--R          [- 0.37199999999999989,0.37199999999999989]
+--R          [- 0.37599999999999989,0.37599999999999989]
+--R          [- 0.37999999999999989,0.37999999999999989]
+--R           [- 0.3839999999999999,0.3839999999999999]
+--R           [- 0.3879999999999999,0.3879999999999999]
+--R           [- 0.3919999999999999,0.3919999999999999]
+--R          [- 0.39599999999999991,0.39599999999999991]
+--R          [- 0.39999999999999991,0.39999999999999991]
+--R          [- 0.40399999999999991,0.40399999999999991]
+--R          [- 0.40799999999999992,0.40799999999999992]
+--R          [- 0.41199999999999992,0.41199999999999992]
+--R          [- 0.41599999999999993,0.41599999999999993]
+--R          [- 0.41999999999999993,0.41999999999999993]
+--R          [- 0.42399999999999993,0.42399999999999993]
+--R          [- 0.42799999999999994,0.42799999999999994]
+--R          [- 0.43199999999999994,0.43199999999999994]
+--R          [- 0.43599999999999994,0.43599999999999994]
+--R          [- 0.43999999999999995,0.43999999999999995]
+--R          [- 0.44399999999999995,0.44399999999999995]
+--R          [- 0.44799999999999995,0.44799999999999995]
+--R          [- 0.45199999999999996,0.45199999999999996]
+--R          [- 0.45599999999999996,0.45599999999999996]
+--R          [- 0.45999999999999996,0.45999999999999996]
+--R          [- 0.46399999999999997,0.46399999999999997]
+--R          [- 0.46799999999999997,0.46799999999999997]
+--R          [- 0.47199999999999998,0.47199999999999998]
+--R          [- 0.47599999999999998,0.47599999999999998]
+--R          [- 0.47999999999999998,0.47999999999999998]
+--R          [- 0.48399999999999999,0.48399999999999999]
+--R          [- 0.48799999999999999,0.48799999999999999]
+--R          [- 0.49199999999999999,0.49199999999999999]
+--R                        [- 0.496,0.496]
+--R                          [- 0.5,0.5]
+--R                                                Type: PlaneAlgebraicCurvePlot
+--E 2
+
+--S 3 of 5
+listBranches(sketch)
+--R
+--R   (3)  [[[0.5,- 0.5],[- 0.5,0.5]]]
+--R                                            Type: List List Point DoubleFloat
+--E 3
+
+--S 4 of 5
+listBranches(refined)
+--R
+--R   (4)
+--R   [
+--R     [[0.5,- 0.5], [0.49600000000000083,- 0.49600000000000083],
+--R      [0.49200000000000083,- 0.49200000000000083],
+--R      [0.48800000000000082,- 0.48800000000000082],
+--R      [0.48400000000000082,- 0.48400000000000082],
+--R      [0.48000000000000081,- 0.48000000000000081],
+--R      [0.47600000000000081,- 0.47600000000000081],
+--R      [0.47200000000000081,- 0.47200000000000081],
+--R      [0.4680000000000008,- 0.4680000000000008],
+--R      [0.4640000000000008,- 0.4640000000000008],
+--R      [0.4600000000000008,- 0.4600000000000008],
+--R      [0.45600000000000079,- 0.45600000000000079],
+--R      [0.45200000000000079,- 0.45200000000000079],
+--R      [0.44800000000000079,- 0.44800000000000079],
+--R      [0.44400000000000078,- 0.44400000000000078],
+--R      [0.44000000000000078,- 0.44000000000000078],
+--R      [0.43600000000000078,- 0.43600000000000078],
+--R      [0.43200000000000077,- 0.43200000000000077],
+--R      [0.42800000000000077,- 0.42800000000000077],
+--R      [0.42400000000000077,- 0.42400000000000077],
+--R      [0.42000000000000076,- 0.42000000000000076],
+--R      [0.41600000000000076,- 0.41600000000000076],
+--R      [0.41200000000000075,- 0.41200000000000075],
+--R      [0.40800000000000075,- 0.40800000000000075],
+--R      [0.40400000000000075,- 0.40400000000000075],
+--R      [0.40000000000000074,- 0.40000000000000074],
+--R      [0.39600000000000074,- 0.39600000000000074],
+--R      [0.39200000000000074,- 0.39200000000000074],
+--R      [0.38800000000000073,- 0.38800000000000073],
+--R      [0.38400000000000073,- 0.38400000000000073],
+--R      [0.38000000000000073,- 0.38000000000000073],
+--R      [0.37600000000000072,- 0.37600000000000072],
+--R      [0.37200000000000072,- 0.37200000000000072],
+--R      [0.36800000000000072,- 0.36800000000000072],
+--R      [0.36400000000000071,- 0.36400000000000071],
+--R      [0.36000000000000071,- 0.36000000000000071],
+--R      [0.3560000000000007,- 0.3560000000000007],
+--R      [0.3520000000000007,- 0.3520000000000007],
+--R      [0.3480000000000007,- 0.3480000000000007],
+--R      [0.34400000000000069,- 0.34400000000000069],
+--R      [0.34000000000000069,- 0.34000000000000069],
+--R      [0.33600000000000069,- 0.33600000000000069],
+--R      [0.33200000000000068,- 0.33200000000000068],
+--R      [0.32800000000000068,- 0.32800000000000068],
+--R      [0.32400000000000068,- 0.32400000000000068],
+--R      [0.32000000000000067,- 0.32000000000000067],
+--R      [0.31600000000000067,- 0.31600000000000067],
+--R      [0.31200000000000067,- 0.31200000000000067],
+--R      [0.30800000000000066,- 0.30800000000000066],
+--R      [0.30400000000000066,- 0.30400000000000066],
+--R      [0.30000000000000066,- 0.30000000000000066],
+--R      [0.29600000000000065,- 0.29600000000000065],
+--R      [0.29200000000000065,- 0.29200000000000065],
+--R      [0.28800000000000064,- 0.28800000000000064],
+--R      [0.28400000000000064,- 0.28400000000000064],
+--R      [0.28000000000000064,- 0.28000000000000064],
+--R      [0.27600000000000063,- 0.27600000000000063],
+--R      [0.27200000000000063,- 0.27200000000000063],
+--R      [0.26800000000000063,- 0.26800000000000063],
+--R      [0.26400000000000062,- 0.26400000000000062],
+--R      [0.26000000000000062,- 0.26000000000000062],
+--R      [0.25600000000000062,- 0.25600000000000062],
+--R      [0.25200000000000061,- 0.25200000000000061],
+--R      [0.24800000000000061,- 0.24800000000000061],
+--R      [0.24400000000000061,- 0.24400000000000061],
+--R      [0.2400000000000006,- 0.2400000000000006],
+--R      [0.2360000000000006,- 0.2360000000000006],
+--R      [0.23200000000000059,- 0.23200000000000059],
+--R      [0.22800000000000059,- 0.22800000000000059],
+--R      [0.22400000000000059,- 0.22400000000000059],
+--R      [0.22000000000000058,- 0.22000000000000058],
+--R      [0.21600000000000058,- 0.21600000000000058],
+--R      [0.21200000000000058,- 0.21200000000000058],
+--R      [0.20800000000000057,- 0.20800000000000057],
+--R      [0.20400000000000057,- 0.20400000000000057],
+--R      [0.20000000000000057,- 0.20000000000000057],
+--R      [0.19600000000000056,- 0.19600000000000056],
+--R      [0.19200000000000056,- 0.19200000000000056],
+--R      [0.18800000000000056,- 0.18800000000000056],
+--R      [0.18400000000000055,- 0.18400000000000055],
+--R      [0.18000000000000055,- 0.18000000000000055],
+--R      [0.17600000000000054,- 0.17600000000000054],
+--R      [0.17200000000000054,- 0.17200000000000054],
+--R      [0.16800000000000054,- 0.16800000000000054],
+--R      [0.16400000000000053,- 0.16400000000000053],
+--R      [0.16000000000000053,- 0.16000000000000053],
+--R      [0.15600000000000053,- 0.15600000000000053],
+--R      [0.15200000000000052,- 0.15200000000000052],
+--R      [0.14800000000000052,- 0.14800000000000052],
+--R      [0.14400000000000052,- 0.14400000000000052],
+--R      [0.14000000000000051,- 0.14000000000000051],
+--R      [0.13600000000000051,- 0.13600000000000051],
+--R      [0.13200000000000051,- 0.13200000000000051],
+--R      [0.1280000000000005,- 0.1280000000000005],
+--R      [0.1240000000000005,- 0.1240000000000005],
+--R      [0.1200000000000005,- 0.1200000000000005],
+--R      [0.11600000000000049,- 0.11600000000000049],
+--R      [0.11200000000000049,- 0.11200000000000049],
+--R      [0.10800000000000048,- 0.10800000000000048],
+--R      [0.10400000000000048,- 0.10400000000000048],
+--R      [0.10000000000000048,- 0.10000000000000048],
+--R      [9.6000000000000474E-2,- 9.6000000000000474E-2],
+--R      [9.200000000000047E-2,- 9.200000000000047E-2],
+--R      [8.8000000000000467E-2,- 8.8000000000000467E-2],
+--R      [8.4000000000000463E-2,- 8.4000000000000463E-2],
+--R      [8.000000000000046E-2,- 8.000000000000046E-2],
+--R      [7.6000000000000456E-2,- 7.6000000000000456E-2],
+--R      [7.2000000000000453E-2,- 7.2000000000000453E-2],
+--R      [6.8000000000000449E-2,- 6.8000000000000449E-2],
+--R      [6.4000000000000445E-2,- 6.4000000000000445E-2],
+--R      [6.0000000000000442E-2,- 6.0000000000000442E-2],
+--R      [5.6000000000000438E-2,- 5.6000000000000438E-2],
+--R      [5.2000000000000435E-2,- 5.2000000000000435E-2],
+--R      [4.8000000000000431E-2,- 4.8000000000000431E-2],
+--R      [4.4000000000000428E-2,- 4.4000000000000428E-2],
+--R      [4.0000000000000424E-2,- 4.0000000000000424E-2],
+--R      [3.6000000000000421E-2,- 3.6000000000000421E-2],
+--R      [3.2000000000000417E-2,- 3.2000000000000417E-2],
+--R      [2.8000000000000417E-2,- 2.8000000000000417E-2],
+--R      [2.4000000000000417E-2,- 2.4000000000000417E-2],
+--R      [2.0000000000000417E-2,- 2.0000000000000417E-2],
+--R      [1.6000000000000417E-2,- 1.6000000000000417E-2],
+--R      [1.2000000000000417E-2,- 1.2000000000000417E-2],
+--R      [8.0000000000004165E-3,- 8.0000000000004165E-3],
+--R      [4.0000000000004164E-3,- 4.0000000000004164E-3],
+--R      [4.163336342344337E-16,- 4.163336342344337E-16],
+--R      [- 3.9999999999995837E-3,3.9999999999995837E-3],
+--R      [- 7.9999999999995838E-3,7.9999999999995838E-3],
+--R      [- 1.1999999999999584E-2,1.1999999999999584E-2],
+--R      [- 1.5999999999999584E-2,1.5999999999999584E-2],
+--R      [- 1.9999999999999584E-2,1.9999999999999584E-2],
+--R      [- 2.3999999999999584E-2,2.3999999999999584E-2],
+--R      [- 2.7999999999999584E-2,2.7999999999999584E-2],
+--R      [- 3.1999999999999584E-2,3.1999999999999584E-2],
+--R      [- 3.5999999999999588E-2,3.5999999999999588E-2],
+--R      [- 3.9999999999999591E-2,3.9999999999999591E-2],
+--R      [- 4.3999999999999595E-2,4.3999999999999595E-2],
+--R      [- 4.7999999999999599E-2,4.7999999999999599E-2],
+--R      [- 5.1999999999999602E-2,5.1999999999999602E-2],
+--R      [- 5.5999999999999606E-2,5.5999999999999606E-2],
+--R      [- 5.9999999999999609E-2,5.9999999999999609E-2],
+--R      [- 6.3999999999999613E-2,6.3999999999999613E-2],
+--R      [- 6.7999999999999616E-2,6.7999999999999616E-2],
+--R      [- 7.199999999999962E-2,7.199999999999962E-2],
+--R      [- 7.5999999999999623E-2,7.5999999999999623E-2],
+--R      [- 7.9999999999999627E-2,7.9999999999999627E-2],
+--R      [- 8.3999999999999631E-2,8.3999999999999631E-2],
+--R      [- 8.7999999999999634E-2,8.7999999999999634E-2],
+--R      [- 9.1999999999999638E-2,9.1999999999999638E-2],
+--R      [- 9.5999999999999641E-2,9.5999999999999641E-2],
+--R      [- 9.9999999999999645E-2,9.9999999999999645E-2],
+--R      [- 0.10399999999999965,0.10399999999999965],
+--R      [- 0.10799999999999965,0.10799999999999965],
+--R      [- 0.11199999999999966,0.11199999999999966],
+--R      [- 0.11599999999999966,0.11599999999999966],
+--R      [- 0.11999999999999966,0.11999999999999966],
+--R      [- 0.12399999999999967,0.12399999999999967],
+--R      [- 0.12799999999999967,0.12799999999999967],
+--R      [- 0.13199999999999967,0.13199999999999967],
+--R      [- 0.13599999999999968,0.13599999999999968],
+--R      [- 0.13999999999999968,0.13999999999999968],
+--R      [- 0.14399999999999968,0.14399999999999968],
+--R      [- 0.14799999999999969,0.14799999999999969],
+--R      [- 0.15199999999999969,0.15199999999999969],
+--R      [- 0.15599999999999969,0.15599999999999969],
+--R      [- 0.1599999999999997,0.1599999999999997],
+--R      [- 0.1639999999999997,0.1639999999999997],
+--R      [- 0.16799999999999971,0.16799999999999971],
+--R      [- 0.17199999999999971,0.17199999999999971],
+--R      [- 0.17599999999999971,0.17599999999999971],
+--R      [- 0.17999999999999972,0.17999999999999972],
+--R      [- 0.18399999999999972,0.18399999999999972],
+--R      [- 0.18799999999999972,0.18799999999999972],
+--R      [- 0.19199999999999973,0.19199999999999973],
+--R      [- 0.19599999999999973,0.19599999999999973],
+--R      [- 0.19999999999999973,0.19999999999999973],
+--R      [- 0.20399999999999974,0.20399999999999974],
+--R      [- 0.20799999999999974,0.20799999999999974],
+--R      [- 0.21199999999999974,0.21199999999999974],
+--R      [- 0.21599999999999975,0.21599999999999975],
+--R      [- 0.21999999999999975,0.21999999999999975],
+--R      [- 0.22399999999999975,0.22399999999999975],
+--R      [- 0.22799999999999976,0.22799999999999976],
+--R      [- 0.23199999999999976,0.23199999999999976],
+--R      [- 0.23599999999999977,0.23599999999999977],
+--R      [- 0.23999999999999977,0.23999999999999977],
+--R      [- 0.24399999999999977,0.24399999999999977],
+--R      [- 0.24799999999999978,0.24799999999999978],
+--R      [- 0.25199999999999978,0.25199999999999978],
+--R      [- 0.25599999999999978,0.25599999999999978],
+--R      [- 0.25999999999999979,0.25999999999999979],
+--R      [- 0.26399999999999979,0.26399999999999979],
+--R      [- 0.26799999999999979,0.26799999999999979],
+--R      [- 0.2719999999999998,0.2719999999999998],
+--R      [- 0.2759999999999998,0.2759999999999998],
+--R      [- 0.2799999999999998,0.2799999999999998],
+--R      [- 0.28399999999999981,0.28399999999999981],
+--R      [- 0.28799999999999981,0.28799999999999981],
+--R      [- 0.29199999999999982,0.29199999999999982],
+--R      [- 0.29599999999999982,0.29599999999999982],
+--R      [- 0.29999999999999982,0.29999999999999982],
+--R      [- 0.30399999999999983,0.30399999999999983],
+--R      [- 0.30799999999999983,0.30799999999999983],
+--R      [- 0.31199999999999983,0.31199999999999983],
+--R      [- 0.31599999999999984,0.31599999999999984],
+--R      [- 0.31999999999999984,0.31999999999999984],
+--R      [- 0.32399999999999984,0.32399999999999984],
+--R      [- 0.32799999999999985,0.32799999999999985],
+--R      [- 0.33199999999999985,0.33199999999999985],
+--R      [- 0.33599999999999985,0.33599999999999985],
+--R      [- 0.33999999999999986,0.33999999999999986],
+--R      [- 0.34399999999999986,0.34399999999999986],
+--R      [- 0.34799999999999986,0.34799999999999986],
+--R      [- 0.35199999999999987,0.35199999999999987],
+--R      [- 0.35599999999999987,0.35599999999999987],
+--R      [- 0.35999999999999988,0.35999999999999988],
+--R      [- 0.36399999999999988,0.36399999999999988],
+--R      [- 0.36799999999999988,0.36799999999999988],
+--R      [- 0.37199999999999989,0.37199999999999989],
+--R      [- 0.37599999999999989,0.37599999999999989],
+--R      [- 0.37999999999999989,0.37999999999999989],
+--R      [- 0.3839999999999999,0.3839999999999999],
+--R      [- 0.3879999999999999,0.3879999999999999],
+--R      [- 0.3919999999999999,0.3919999999999999],
+--R      [- 0.39599999999999991,0.39599999999999991],
+--R      [- 0.39999999999999991,0.39999999999999991],
+--R      [- 0.40399999999999991,0.40399999999999991],
+--R      [- 0.40799999999999992,0.40799999999999992],
+--R      [- 0.41199999999999992,0.41199999999999992],
+--R      [- 0.41599999999999993,0.41599999999999993],
+--R      [- 0.41999999999999993,0.41999999999999993],
+--R      [- 0.42399999999999993,0.42399999999999993],
+--R      [- 0.42799999999999994,0.42799999999999994],
+--R      [- 0.43199999999999994,0.43199999999999994],
+--R      [- 0.43599999999999994,0.43599999999999994],
+--R      [- 0.43999999999999995,0.43999999999999995],
+--R      [- 0.44399999999999995,0.44399999999999995],
+--R      [- 0.44799999999999995,0.44799999999999995],
+--R      [- 0.45199999999999996,0.45199999999999996],
+--R      [- 0.45599999999999996,0.45599999999999996],
+--R      [- 0.45999999999999996,0.45999999999999996],
+--R      [- 0.46399999999999997,0.46399999999999997],
+--R      [- 0.46799999999999997,0.46799999999999997],
+--R      [- 0.47199999999999998,0.47199999999999998],
+--R      [- 0.47599999999999998,0.47599999999999998],
+--R      [- 0.47999999999999998,0.47999999999999998],
+--R      [- 0.48399999999999999,0.48399999999999999],
+--R      [- 0.48799999999999999,0.48799999999999999],
+--R      [- 0.49199999999999999,0.49199999999999999], [- 0.496,0.496],
+--R      [- 0.5,0.5]]
+--R     ]
+--R                                            Type: List List Point DoubleFloat
+--E 4
+
+--S 5 of 5
+)show ACPLOT
+--R PlaneAlgebraicCurvePlot  is a domain constructor
+--R Abbreviation for PlaneAlgebraicCurvePlot is ACPLOT 
+--R This constructor is not exposed in this frame.
+--R Issue )edit bookvol10.3.spad.pamphlet to see algebra source code for ACPLOT 
+--R
+--R------------------------------- Operations --------------------------------
+--R coerce : % -> OutputForm              refine : (%,DoubleFloat) -> %
+--R xRange : % -> Segment DoubleFloat     yRange : % -> Segment DoubleFloat
+--R listBranches : % -> List List Point DoubleFloat
+--R makeSketch : (Polynomial Integer,Symbol,Symbol,Segment Fraction Integer,Segment Fraction Integer) -> %
+--R
+--E 5
+
 )spool
 )lisp (bye)
 @
@@ -71631,10 +72163,50 @@ makeSketch(x+y,x,y,-1/2..1/2,-1/2..1/2)$ACPLOT
 PlaneAlgebraicCurvePlot examples
 ====================================================================
 
-  makeSketch(x+y,x,y,-1/2..1/2,-1/2..1/2)$ACPLOT
+sketch:=makeSketch(x+y,x,y,-1/2..1/2,-1/2..1/2)$ACPLOT
 
-See Also:
-o )show PlaneAlgebraicCurvePlot
+                          ACPLOT
+                       1         1      1         1
+        y + x = 0,   - - <= x <= -,   - - <= y <= -
+                       2         2      2         2
+                        [0.5,- 0.5]
+                        [- 0.5,0.5]
+
+
+
+refined:=refine(sketch,0.1)
+
+                            ACPLOT
+                         1         1      1         1
+          y + x = 0,   - - <= x <= -,   - - <= y <= -
+                         2         2      2         2
+                          [0.5,- 0.5]
+          [0.49600000000000083,- 0.49600000000000083]
+          [0.49200000000000083,- 0.49200000000000083]
+          [0.48800000000000082,- 0.48800000000000082]
+          [0.48400000000000082,- 0.48400000000000082]
+          ...
+          [- 0.48399999999999999,0.48399999999999999]
+          [- 0.48799999999999999,0.48799999999999999]
+          [- 0.49199999999999999,0.49199999999999999]
+                        [- 0.496,0.496]
+                          [- 0.5,0.5]
+
+listBranches(sketch)
+
+   [[[0.5,- 0.5],[- 0.5,0.5]]]
+
+
+listBranches(refined)
+
+   [
+     [[0.5,- 0.5], [0.49600000000000083,- 0.49600000000000083],
+      [0.49200000000000083,- 0.49200000000000083],
+      [0.48800000000000082,- 0.48800000000000082],
+      ...
+      [- 0.48399999999999999,0.48399999999999999],
+      [- 0.48799999999999999,0.48799999999999999],
+      [- 0.49199999999999999,0.49199999999999999], [- 0.496,0.496],
 
 @
 \pagehead{PlaneAlgebraicCurvePlot}{ACPLOT}
@@ -71681,8 +72253,14 @@ PlaneAlgebraicCurvePlot(): PlottablePlaneCurveCategory _
      ++ the vertical axis is the y-axis.  The rational numbers
      ++ xMin,...,yMax specify the boundaries of the region in
      ++ which the curve is to be plotted.
+     ++
+     ++X makeSketch(x+y,x,y,-1/2..1/2,-1/2..1/2)$ACPLOT
+
   refine:(%,DoubleFloat) -> %
      ++ refine(p,x) \undocumented{}
+     ++
+     ++X sketch:=makeSketch(x+y,x,y,-1/2..1/2,-1/2..1/2)$ACPLOT
+     ++X refined:=refine(sketch,0.1)
 
  == add
 
diff --git a/books/bookvol10.4.pamphlet b/books/bookvol10.4.pamphlet
index 0e014b7..0760a9d 100644
--- a/books/bookvol10.4.pamphlet
+++ b/books/bookvol10.4.pamphlet
@@ -43692,7 +43692,8 @@ factor t6
 )set message test on
 )set message auto off
 )clear all
---S 1
+
+--S 1 of 36
 M := SQMATRIX(2,INT)
 --R 
 --R
@@ -43700,7 +43701,7 @@ M := SQMATRIX(2,INT)
 --R                                                                 Type: Domain
 --E 1
 
---S 2
+--S 2 of 36
 m1: M := squareMatrix matrix [ [1, 2], [0, -1] ]
 --R 
 --R
@@ -43710,7 +43711,7 @@ m1: M := squareMatrix matrix [ [1, 2], [0, -1] ]
 --R                                                Type: SquareMatrix(2,Integer)
 --E 2
 
---S 3
+--S 3 of 36
 m2: M := squareMatrix matrix [ [2, 3], [1, -2] ]
 --R 
 --R
@@ -43720,7 +43721,7 @@ m2: M := squareMatrix matrix [ [2, 3], [1, -2] ]
 --R                                                Type: SquareMatrix(2,Integer)
 --E 3
 
---S 4
+--S 4 of 36
 m3: M := squareMatrix matrix [ [3, 4], [2, -3] ]
 --R 
 --R
@@ -43730,7 +43731,7 @@ m3: M := squareMatrix matrix [ [3, 4], [2, -3] ]
 --R                                                Type: SquareMatrix(2,Integer)
 --E 4
 
---S 5
+--S 5 of 36
 linearlyDependentOverZ? vector [m1, m2, m3]
 --R 
 --R
@@ -43738,7 +43739,7 @@ linearlyDependentOverZ? vector [m1, m2, m3]
 --R                                                                Type: Boolean
 --E 5
 
---S 6
+--S 6 of 36
 c := linearDependenceOverZ vector [m1, m2, m3]
 --R 
 --R
@@ -43746,7 +43747,7 @@ c := linearDependenceOverZ vector [m1, m2, m3]
 --R                                              Type: Union(Vector Integer,...)
 --E 6
 
---S 7
+--S 7 of 36
 c.1 * m1 + c.2 * m2 + c.3 * m3
 --R 
 --R
@@ -43756,7 +43757,7 @@ c.1 * m1 + c.2 * m2 + c.3 * m3
 --R                                                Type: SquareMatrix(2,Integer)
 --E 7
 
---S 8
+--S 8 of 36
 solveLinearlyOverQ(vector [m1, m3], m2)
 --R 
 --R
@@ -47406,6 +47407,970 @@ LaplaceTransform(R, F): Exports == Implementation where
 @
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 \section{package LAZM3PK LazardSetSolvingPackage}
+<<LazardSetSolvingPackage.input>>=
+)set break resume
+)sys rm -f LazardSetSolvingPackage.output
+)spool LazardSetSolvingPackage.output
+)set message test on
+)set message auto off
+)clear all
+
+--S 1 of 36
+R := Integer
+--R
+--R   (1)  Integer
+--R                                                                 Type: Domain
+--E 1
+
+--S 2 of 36
+ls : List Symbol := [b1,x,y,z,t,v,u,w] 
+--R
+--R   (2)  [b1,x,y,z,t,v,u,w]
+--R                                                            Type: List Symbol
+--E 2
+
+--S 3 of 36
+V := OVAR(ls)
+--R
+--R   (3)  OrderedVariableList [b1,x,y,z,t,v,u,w]
+--R                                                                 Type: Domain
+--E 3
+
+--S 4 of 36
+E := IndexedExponents V
+--R
+--R   (4)  IndexedExponents OrderedVariableList [b1,x,y,z,t,v,u,w]
+--R                                                                 Type: Domain
+--E 4
+
+--S 5 of 36
+P := NSMP(R, V)
+--R
+--R   (5)
+--R  NewSparseMultivariatePolynomial(Integer,OrderedVariableList [b1,x,y,z,t,v,u,w
+--R  ])
+--R                                                                 Type: Domain
+--E 5
+
+--S 6 of 36
+b1: P := 'b1
+--R
+--R   (6)  b1
+--RType: NewSparseMultivariatePolynomial(Integer,OrderedVariableList [b1,x,y,z,t,v,u,w])
+--E 6
+
+--S 7 of 36
+x: P := 'x
+--R
+--R   (7)  x
+--RType: NewSparseMultivariatePolynomial(Integer,OrderedVariableList [b1,x,y,z,t,v,u,w])
+--E 7
+
+--S 8 of 36
+y: P := 'y
+--R
+--R   (8)  y
+--RType: NewSparseMultivariatePolynomial(Integer,OrderedVariableList [b1,x,y,z,t,v,u,w])
+--E 8
+
+--S 9 of 36
+z: P := 'z
+--R
+--R   (9)  z
+--RType: NewSparseMultivariatePolynomial(Integer,OrderedVariableList [b1,x,y,z,t,v,u,w])
+--E 9
+
+--S 10 of 36
+t: P := 't
+--R
+--R   (10)  t
+--RType: NewSparseMultivariatePolynomial(Integer,OrderedVariableList [b1,x,y,z,t,v,u,w])
+--E 10
+
+--S 11 of 36
+u: P := 'u
+--R
+--R   (11)  u
+--RType: NewSparseMultivariatePolynomial(Integer,OrderedVariableList [b1,x,y,z,t,v,u,w])
+--E 11
+
+--S 12 of 36
+v: P := 'v
+--R
+--R   (12)  v
+--RType: NewSparseMultivariatePolynomial(Integer,OrderedVariableList [b1,x,y,z,t,v,u,w])
+--E 12
+
+--S 13 of 36
+w: P := 'w
+--R
+--R   (13)  w
+--RType: NewSparseMultivariatePolynomial(Integer,OrderedVariableList [b1,x,y,z,t,v,u,w])
+--E 13
+
+--S 14 of 36
+T := REGSET(R,E,V,P)
+--R
+--R   (14)
+--R  RegularTriangularSet(Integer,IndexedExponents OrderedVariableList [b1,x,y,z,t
+--R  ,v,u,w],OrderedVariableList [b1,x,y,z,t,v,u,w],NewSparseMultivariatePolynomia
+--R  l(Integer,OrderedVariableList [b1,x,y,z,t,v,u,w]))
+--R                                                                 Type: Domain
+--E 14
+
+--S 15 of 36
+p0 := b1 + y + z - t - w
+--R
+--R   (15)  b1 + y + z - t - w
+--RType: NewSparseMultivariatePolynomial(Integer,OrderedVariableList [b1,x,y,z,t,v,u,w])
+--E 15
+
+--S 16 of 36
+p1 := 2*z*u + 2*y*v + 2*t*w - 2*w**2 - w - 1
+--R
+--R                                2
+--R   (16)  2v y + 2u z + 2w t - 2w  - w - 1
+--RType: NewSparseMultivariatePolynomial(Integer,OrderedVariableList [b1,x,y,z,t,v,u,w])
+--E 16
+
+--S 17 of 36
+p2 := 3*z*u**2 + 3*y*v**2 - 3*t*w**2 + 3*w**3 + 3*w**2 - t + 4*w
+--R
+--R           2      2         2           3     2
+--R   (17)  3v y + 3u z + (- 3w  - 1)t + 3w  + 3w  + 4w
+--RType: NewSparseMultivariatePolynomial(Integer,OrderedVariableList [b1,x,y,z,t,v,u,w])
+--E 17
+
+--S 18 of 36
+p3 := 6*x*z*v - 6*t*w**2 + 6*w**3 - 3*t*w + 6*w**2 - t + 4*w
+--R
+--R                       2                3     2
+--R   (18)  6v z x + (- 6w  - 3w - 1)t + 6w  + 6w  + 4w
+--RType: NewSparseMultivariatePolynomial(Integer,OrderedVariableList [b1,x,y,z,t,v,u,w])
+--E 18
+
+--S 19 of 36
+p4 := 4*z*u**3+ 4*y*v**3+ 4*t*w**3- 4*w**4 - 6*w**3+ 4*t*w- 10*w**2- w- 1
+--R
+--R           3      3       3            4     3      2
+--R   (19)  4v y + 4u z + (4w  + 4w)t - 4w  - 6w  - 10w  - w - 1
+--RType: NewSparseMultivariatePolynomial(Integer,OrderedVariableList [b1,x,y,z,t,v,u,w])
+--E 19
+
+--S 20 of 36
+p5 := 8*x*z*u*v +8*t*w**3 -8*w**4 +4*t*w**2 -12*w**3 +4*t*w -14*w**2 -3*w -1
+--R
+--R                       3     2            4      3      2
+--R   (20)  8u v z x + (8w  + 4w  + 4w)t - 8w  - 12w  - 14w  - 3w - 1
+--RType: NewSparseMultivariatePolynomial(Integer,OrderedVariableList [b1,x,y,z,t,v,u,w])
+--E 20
+
+--S 21 of 36
+p6 := 12*x*z*v**2+12*t*w**3 -12*w**4 +12*t*w**2 -18*w**3 +8*t*w -14*w**2 -w -1
+--R
+--R            2          3      2             4      3      2
+--R   (21)  12v z x + (12w  + 12w  + 8w)t - 12w  - 18w  - 14w  - w - 1
+--RType: NewSparseMultivariatePolynomial(Integer,OrderedVariableList [b1,x,y,z,t,v,u,w])
+--E 21
+
+--S 22 of 36
+p7 := -24*t*w**3 + 24*w**4 - 24*t*w**2 + 36*w**3 - 8*t*w + 26*w**2 + 7*w + 1
+--R
+--R               3      2             4      3      2
+--R   (22)  (- 24w  - 24w  - 8w)t + 24w  + 36w  + 26w  + 7w + 1
+--RType: NewSparseMultivariatePolynomial(Integer,OrderedVariableList [b1,x,y,z,t,v,u,w])
+--E 22
+
+--S 23 of 36
+lp := [p0, p1, p2, p3, p4, p5, p6, p7]
+--R
+--R   (23)
+--R                                               2
+--R   [b1 + y + z - t - w, 2v y + 2u z + 2w t - 2w  - w - 1,
+--R      2      2         2           3     2
+--R    3v y + 3u z + (- 3w  - 1)t + 3w  + 3w  + 4w,
+--R                  2                3     2
+--R    6v z x + (- 6w  - 3w - 1)t + 6w  + 6w  + 4w,
+--R      3      3       3            4     3      2
+--R    4v y + 4u z + (4w  + 4w)t - 4w  - 6w  - 10w  - w - 1,
+--R                  3     2            4      3      2
+--R    8u v z x + (8w  + 4w  + 4w)t - 8w  - 12w  - 14w  - 3w - 1,
+--R       2          3      2             4      3      2
+--R    12v z x + (12w  + 12w  + 8w)t - 12w  - 18w  - 14w  - w - 1,
+--R          3      2             4      3      2
+--R    (- 24w  - 24w  - 8w)t + 24w  + 36w  + 26w  + 7w + 1]
+--RType: List NewSparseMultivariatePolynomial(Integer,OrderedVariableList [b1,x,y,z,t,v,u,w])
+--E 23
+
+--S 24 of 36
+lts := zeroSetSplit(lp,false)$T
+--R
+--R   (24)
+--R   [{w + 1,u,v,t + 1,b1 + y + z + 2}, {w + 1,v,t + 1,z,b1 + y + 2},
+--R    {w + 1,t + 1,z,y,b1 + 2}, {w + 1,v - u,t + 1,y + z,x,b1 + 2},
+--R    {w + 1,u,t + 1,y,x,b1 + z + 2},
+--R
+--R          5       4      3     2
+--R     {144w  + 216w  + 96w  + 6w  - 11w - 1,
+--R          2                 5       4      3     2
+--R      (12w  + 9w + 1)u - 72w  - 108w  - 42w  - 9w  - 3w,
+--R          2                 4      3      2
+--R      (12w  + 9w + 1)v + 36w  + 54w  + 18w ,
+--R          3      2             4      3      2
+--R      (24w  + 24w  + 8w)t - 24w  - 36w  - 26w  - 7w - 1,
+--R
+--R                     2                 2                        4      3     2
+--R         (12u v - 12u )z + (12w v + 12w  + 4)t + (3w - 5)v + 36w  + 42w  + 6w
+--R       + 
+--R         - 16w
+--R       ,
+--R                             2
+--R      2v y + 2u z + 2w t - 2w  - w - 1,
+--R                    2                3     2
+--R      6v z x + (- 6w  - 3w - 1)t + 6w  + 6w  + 4w, b1 + y + z - t - w}
+--R     ]
+--RType: List RegularTriangularSet(Integer,IndexedExponents OrderedVariableList [b1,x,y,z,t,v,u,w],OrderedVariableList [b1,x,y,z,t,v,u,w],NewSparseMultivariatePolynomial(Integer,OrderedVariableList [b1,x,y,z,t,v,u,w]))
+--E 24
+
+--S 25 of 36
+[coHeight(ts) for ts in lts]
+--R
+--R   (25)  [3,3,3,2,2,0]
+--R                                                Type: List NonNegativeInteger
+--E 25
+
+--S 26 of 36
+ST := SREGSET(R,E,V,P)
+--R
+--R   (26)
+--R  SquareFreeRegularTriangularSet(Integer,IndexedExponents OrderedVariableList [
+--R  b1,x,y,z,t,v,u,w],OrderedVariableList [b1,x,y,z,t,v,u,w],NewSparseMultivariat
+--R  ePolynomial(Integer,OrderedVariableList [b1,x,y,z,t,v,u,w]))
+--R                                                                 Type: Domain
+--E 26
+
+--S 27 of 36
+pack := LAZM3PK(R,E,V,P,T,ST)
+--R
+--R   (27)
+--R  LazardSetSolvingPackage(Integer,IndexedExponents OrderedVariableList [b1,x,y,
+--R  z,t,v,u,w],OrderedVariableList [b1,x,y,z,t,v,u,w],NewSparseMultivariatePolyno
+--R  mial(Integer,OrderedVariableList [b1,x,y,z,t,v,u,w]),RegularTriangularSet(Int
+--R  eger,IndexedExponents OrderedVariableList [b1,x,y,z,t,v,u,w],OrderedVariableL
+--R  ist [b1,x,y,z,t,v,u,w],NewSparseMultivariatePolynomial(Integer,OrderedVariabl
+--R  eList [b1,x,y,z,t,v,u,w])),SquareFreeRegularTriangularSet(Integer,IndexedExpo
+--R  nents OrderedVariableList [b1,x,y,z,t,v,u,w],OrderedVariableList [b1,x,y,z,t,
+--R  v,u,w],NewSparseMultivariatePolynomial(Integer,OrderedVariableList [b1,x,y,z,
+--R  t,v,u,w])))
+--R                                                                 Type: Domain
+--E 27
+
+--S 28 of 36
+zeroSetSplit(lp,false)$pack
+--R
+--R   (28)
+--R   [{w + 1,t + 1,z,y,b1 + 2}, {w + 1,v,t + 1,z,b1 + y + 2},
+--R    {w + 1,u,v,t + 1,b1 + y + z + 2}, {w + 1,v - u,t + 1,y + z,x,b1 + 2},
+--R    {w + 1,u,t + 1,y,x,b1 + z + 2},
+--R
+--R          5       4      3     2                   4      3      2
+--R     {144w  + 216w  + 96w  + 6w  - 11w - 1, u - 24w  - 36w  - 14w  + w + 1,
+--R              4      3      2                  4      3      2
+--R      3v - 48w  - 60w  - 10w  + 8w + 2, t - 24w  - 36w  - 14w  - w + 1,
+--R                  4        3        2
+--R      486z - 2772w  - 4662w  - 2055w  + 30w + 127,
+--R                    4         3        2
+--R      2916y - 22752w  - 30312w  - 8220w  + 2064w + 1561,
+--R                  4        3       2
+--R      356x - 3696w  - 4536w  - 968w  + 822w + 371,
+--R                     4         3         2
+--R      2916b1 - 30600w  - 46692w  - 20274w  - 8076w + 593}
+--R     ]
+--RType: List SquareFreeRegularTriangularSet(Integer,IndexedExponents OrderedVariableList [b1,x,y,z,t,v,u,w],OrderedVariableList [b1,x,y,z,t,v,u,w],NewSparseMultivariatePolynomial(Integer,OrderedVariableList [b1,x,y,z,t,v,u,w]))
+--E 28
+
+--S 29 of 36
+f0 := (w - v) ** 2 + (u - t) ** 2 - 1
+--R
+--R          2           2           2    2
+--R   (29)  t  - 2u t + v  - 2w v + u  + w  - 1
+--RType: NewSparseMultivariatePolynomial(Integer,OrderedVariableList [b1,x,y,z,t,v,u,w])
+--E 29
+
+--S 30 of 36
+f1 := t ** 2 - v ** 3
+--R
+--R          2    3
+--R   (30)  t  - v
+--RType: NewSparseMultivariatePolynomial(Integer,OrderedVariableList [b1,x,y,z,t,v,u,w])
+--E 30
+
+--S 31 of 36
+f2 := 2 * t * (w - v) + 3 * v ** 2 * (u - t)
+--R
+--R              2                   2
+--R   (31)  (- 3v  - 2v + 2w)t + 3u v
+--RType: NewSparseMultivariatePolynomial(Integer,OrderedVariableList [b1,x,y,z,t,v,u,w])
+--E 31
+
+--S 32 of 36
+f3 := (3 * z * v ** 2 - 1) * (2 * z * t - 1)
+--R
+--R           2   2             2
+--R   (32)  6v t z  + (- 2t - 3v )z + 1
+--RType: NewSparseMultivariatePolynomial(Integer,OrderedVariableList [b1,x,y,z,t,v,u,w])
+--E 32
+
+--S 33 of 36
+lf := [f0, f1, f2, f3]
+--R
+--R   (33)
+--R     2           2           2    2       2    3       2                   2
+--R   [t  - 2u t + v  - 2w v + u  + w  - 1, t  - v , (- 3v  - 2v + 2w)t + 3u v ,
+--R      2   2             2
+--R    6v t z  + (- 2t - 3v )z + 1]
+--RType: List NewSparseMultivariatePolynomial(Integer,OrderedVariableList [b1,x,y,z,t,v,u,w])
+--E 33
+
+--S 34 of 36
+zeroSetSplit(lf,true)$T
+--R
+--R   (34)
+--R   [
+--R     {
+--R             6           3       2                 4
+--R         729u  + (- 1458w  + 729w  - 4158w - 1685)u
+--R       + 
+--R              6        5        4        3       2                2       8
+--R         (729w  - 1458w  - 2619w  - 4892w  - 297w  + 5814w + 427)u  + 729w
+--R       + 
+--R             7        6        5        4        3        2
+--R         216w  - 2900w  - 2376w  + 3870w  + 4072w  - 1188w  - 1656w + 529
+--R       ,
+--R
+--R                  4           3       2                  2        6        5
+--R             2187u  + (- 4374w  - 972w  - 12474w - 2868)u  + 2187w  - 1944w
+--R           + 
+--R                     4        3        2
+--R             - 10125w  - 4800w  + 2501w  + 4968w - 1587
+--R        *
+--R           v
+--R       + 
+--R               3       2  2       6        5        4       3        2
+--R         (1944w  - 108w )u  + 972w  + 3024w  - 1080w  + 496w  + 1116w
+--R       ,
+--R         2                   2                    2  2           2
+--R      (3v  + 2v - 2w)t - 3u v , ((4v - 4w)t - 6u v )z  + (2t + 3v )z - 1}
+--R     ]
+--RType: List RegularTriangularSet(Integer,IndexedExponents OrderedVariableList [b1,x,y,z,t,v,u,w],OrderedVariableList [b1,x,y,z,t,v,u,w],NewSparseMultivariatePolynomial(Integer,OrderedVariableList [b1,x,y,z,t,v,u,w]))
+--E 34
+
+--S 35 of 36
+zeroSetSplit(lf,false)$T
+--R
+--R   (35)
+--R   [
+--R     {
+--R             6           3       2                 4
+--R         729u  + (- 1458w  + 729w  - 4158w - 1685)u
+--R       + 
+--R              6        5        4        3       2                2       8
+--R         (729w  - 1458w  - 2619w  - 4892w  - 297w  + 5814w + 427)u  + 729w
+--R       + 
+--R             7        6        5        4        3        2
+--R         216w  - 2900w  - 2376w  + 3870w  + 4072w  - 1188w  - 1656w + 529
+--R       ,
+--R
+--R                  4           3       2                  2        6        5
+--R             2187u  + (- 4374w  - 972w  - 12474w - 2868)u  + 2187w  - 1944w
+--R           + 
+--R                     4        3        2
+--R             - 10125w  - 4800w  + 2501w  + 4968w - 1587
+--R        *
+--R           v
+--R       + 
+--R               3       2  2       6        5        4       3        2
+--R         (1944w  - 108w )u  + 972w  + 3024w  - 1080w  + 496w  + 1116w
+--R       ,
+--R         2                   2                    2  2           2
+--R      (3v  + 2v - 2w)t - 3u v , ((4v - 4w)t - 6u v )z  + (2t + 3v )z - 1}
+--R     ,
+--R
+--R         4     3      2                               2
+--R     {27w  + 4w  - 54w  - 36w + 23, u, (12w + 2)v - 9w  - 2w + 9,
+--R        2          2
+--R      6t  - 2v - 3w  + 2w + 3, 2t z - 1}
+--R     ,
+--R
+--R            6         5         4          3         2
+--R     {59049w  + 91854w  - 45198w  + 145152w  + 63549w  + 60922w + 21420,
+--R
+--R                            5                  4                  3
+--R             31484448266904w  - 18316865522574w  + 23676995746098w
+--R           + 
+--R                           2
+--R             6657857188965w  + 8904703998546w + 3890631403260
+--R        *
+--R            2
+--R           u
+--R       + 
+--R                        5                  4                  3
+--R         94262810316408w  - 82887296576616w  + 89801831438784w
+--R       + 
+--R                        2
+--R         28141734167208w  + 38070359425432w + 16003865949120
+--R       ,
+--R           2             2         2       3      2                    3     2
+--R      (243w  + 36w + 85)v  + (- 81u  - 162w  + 36w  + 154w + 72)v - 72w  + 4w ,
+--R         2                   2                    2  2           2
+--R      (3v  + 2v - 2w)t - 3u v , ((4v - 4w)t - 6u v )z  + (2t + 3v )z - 1}
+--R     ,
+--R
+--R         4     3      2                               2
+--R     {27w  + 4w  - 54w  - 36w + 23, u, (12w + 2)v - 9w  - 2w + 9,
+--R        2          2             2
+--R      6t  - 2v - 3w  + 2w + 3, 3v z - 1}
+--R     ]
+--RType: List RegularTriangularSet(Integer,IndexedExponents OrderedVariableList [b1,x,y,z,t,v,u,w],OrderedVariableList [b1,x,y,z,t,v,u,w],NewSparseMultivariatePolynomial(Integer,OrderedVariableList [b1,x,y,z,t,v,u,w]))
+--E 35
+
+--S 36 of 36
+zeroSetSplit(lf,false)$pack
+--R
+--R   (36)
+--R   [
+--R     {
+--R             6           3       2                 4
+--R         729u  + (- 1458w  + 729w  - 4158w - 1685)u
+--R       + 
+--R              6        5        4        3       2                2       8
+--R         (729w  - 1458w  - 2619w  - 4892w  - 297w  + 5814w + 427)u  + 729w
+--R       + 
+--R             7        6        5        4        3        2
+--R         216w  - 2900w  - 2376w  + 3870w  + 4072w  - 1188w  - 1656w + 529
+--R       ,
+--R
+--R                  4           3       2                  2        6        5
+--R             2187u  + (- 4374w  - 972w  - 12474w - 2868)u  + 2187w  - 1944w
+--R           + 
+--R                     4        3        2
+--R             - 10125w  - 4800w  + 2501w  + 4968w - 1587
+--R        *
+--R           v
+--R       + 
+--R               3       2  2       6        5        4       3        2
+--R         (1944w  - 108w )u  + 972w  + 3024w  - 1080w  + 496w  + 1116w
+--R       ,
+--R         2                   2                    2  2           2
+--R      (3v  + 2v - 2w)t - 3u v , ((4v - 4w)t - 6u v )z  + (2t + 3v )z - 1}
+--R     ,
+--R
+--R         2                 2                   2
+--R     {81w  + 18w + 28, 729u  - 1890w - 533, 81v  + (- 162w + 27)v - 72w - 112,
+--R      11881t + (972w + 2997)u v + (- 11448w - 11536)u,
+--R
+--R                         2
+--R         641237934604288z
+--R       + 
+--R                 (78614584763904w + 26785578742272)u + 236143618655616w
+--R               + 
+--R                 70221988585728
+--R            *
+--R               v
+--R           + 
+--R             (358520253138432w + 101922133759488)u + 142598803536000w
+--R           + 
+--R             54166419595008
+--R        *
+--R           z
+--R       + 
+--R         (32655103844499w - 44224572465882)u v
+--R       + 
+--R         (43213900115457w - 32432039102070)u
+--R       }
+--R     ,
+--R
+--R         4     3      2                           3     2
+--R     {27w  + 4w  - 54w  - 36w + 23, u, 218v - 162w  + 3w  + 160w + 153,
+--R          2      3      2                             3      2
+--R      109t  - 27w  - 54w  + 63w + 80, 1744z + (- 1458w  + 27w  + 1440w + 505)t}
+--R     ,
+--R
+--R         4     3      2                           3     2
+--R     {27w  + 4w  - 54w  - 36w + 23, u, 218v - 162w  + 3w  + 160w + 153,
+--R          2      3      2                         3     2
+--R      109t  - 27w  - 54w  + 63w + 80, 1308z + 162w  - 3w  - 814w - 153}
+--R     ,
+--R
+--R          4       3        2                   2      2
+--R     {729w  + 972w  - 1026w  + 1684w + 765, 81u  + 72w  + 16w - 72,
+--R                 3       2
+--R      702v - 162w  - 225w  + 40w - 99,
+--R                    3       2
+--R      11336t + (324w  - 603w  - 1718w - 1557)u,
+--R
+--R                   2
+--R         595003968z
+--R       + 
+--R                          3             2
+--R             (- 963325386w  - 898607682w  + 1516286466w - 3239166186)u
+--R           + 
+--R                          3              2
+--R             - 1579048992w  - 1796454288w  + 2428328160w - 4368495024
+--R        *
+--R           z
+--R       + 
+--R                     3              2
+--R         (9713133306w  + 9678670317w  - 16726834476w + 28144233593)u
+--R       }
+--R     ]
+--RType: List SquareFreeRegularTriangularSet(Integer,IndexedExponents OrderedVariableList [b1,x,y,z,t,v,u,w],OrderedVariableList [b1,x,y,z,t,v,u,w],NewSparseMultivariatePolynomial(Integer,OrderedVariableList [b1,x,y,z,t,v,u,w]))
+--E 36
+
+)spool
+)lisp (bye)
+@
+<<LazardSetSolvingPackage.help>>=
+====================================================================
+LazardSetSolvingPackage examples
+====================================================================
+
+The LazardSetSolvingPackage package constructor solves polynomial
+systems by means of Lazard triangular sets.  However one condition is
+relaxed: Regular triangular sets whose saturated ideals have positive
+dimension are not necessarily normalized.
+
+The decompositions are computed in two steps.  First the algorithm of
+Moreno Maza (implemented in the RegularTriangularSet domain
+constructor) is called.  Then the resulting decompositions are
+converted into lists of square-free regular triangular sets and the
+redundant components are removed.  Moreover, zero-dimensional regular
+triangular sets are normalized.
+
+Note that the way of understanding triangular decompositions is
+detailed in the example of the RegularTriangularSet constructor.
+
+The LazardSetSolvingPackage constructor takes six arguments.  The
+first one, R, is the coefficient ring of the polynomials; it must
+belong to the category GcdDomain.  The second one, E, is the exponent
+monoid of the polynomials; it must belong to the category
+OrderedAbelianMonoidSup.  the third one, V, is the ordered set of
+variables; it must belong to the category OrderedSet.  The fourth one
+is the polynomial ring; it must belong to the category
+RecursivePolynomialCategory(R,E,V).  The fifth one is a domain of the
+category RegularTriangularSetCategory(R,E,V,P) and the last one is a
+domain of the category SquareFreeRegularTriangularSetCategory(R,E,V,P).  
+The abbreviation for LazardSetSolvingPackage is LAZM3PK.
+
+For the purpose of solving zero-dimensional algebraic systems, see
+also LexTriangularPackage and ZeroDimensionalSolvePackage.  These
+packages are easier to call than LAZM3PK.  Moreover, the
+ZeroDimensionalSolvePackage package provides operations to compute
+either the complex roots or the real roots.
+
+We illustrate now the use of the LazardSetSolvingPackage package 
+constructor with two examples (Butcher and Vermeer).
+
+Define the coefficient ring.
+
+R := Integer
+    Integer 
+
+Define the list of variables,
+
+ls : List Symbol := [b1,x,y,z,t,v,u,w] 
+    [b1,x,y,z,t,v,u,w]
+
+and make it an ordered set:
+
+V := OVAR(ls)
+    OrderedVariableList [b1,x,y,z,t,v,u,w]
+
+then define the exponent monoid.
+
+E := IndexedExponents V
+
+Define the polynomial ring.
+
+P := NSMP(R, V)
+
+Let the variables be polynomial.
+
+b1: P := 'b1
+
+x: P := 'x
+
+y: P := 'y
+
+z: P := 'z
+
+t: P := 't
+
+u: P := 'u
+
+v: P := 'v
+
+w: P := 'w
+
+Now call the {\tt RegularTriangularSet} domain constructor.
+
+T := REGSET(R,E,V,P)
+
+Define a polynomial system (the Butcher example).
+
+p0 := b1 + y + z - t - w
+
+p1 := 2*z*u + 2*y*v + 2*t*w - 2*w**2 - w - 1
+
+p2 := 3*z*u**2 + 3*y*v**2 - 3*t*w**2 + 3*w**3 + 3*w**2 - t + 4*w
+
+p3 := 6*x*z*v - 6*t*w**2 + 6*w**3 - 3*t*w + 6*w**2 - t + 4*w
+
+p4 := 4*z*u**3+ 4*y*v**3+ 4*t*w**3- 4*w**4 - 6*w**3+ 4*t*w- 10*w**2- w- 1
+
+p5 := 8*x*z*u*v +8*t*w**3 -8*w**4 +4*t*w**2 -12*w**3 +4*t*w -14*w**2 -3*w -1
+
+p6 := 12*x*z*v**2+12*t*w**3 -12*w**4 +12*t*w**2 -18*w**3 +8*t*w -14*w**2 -w -1
+
+p7 := -24*t*w**3 + 24*w**4 - 24*t*w**2 + 36*w**3 - 8*t*w + 26*w**2 + 7*w + 1
+
+lp := [p0, p1, p2, p3, p4, p5, p6, p7]
+   [b1 + y + z - t - w, 2v y + 2u z + 2w t - 2w  - w - 1,
+      2      2         2           3     2
+    3v y + 3u z + (- 3w  - 1)t + 3w  + 3w  + 4w,
+                  2                3     2
+    6v z x + (- 6w  - 3w - 1)t + 6w  + 6w  + 4w,
+      3      3       3            4     3      2
+    4v y + 4u z + (4w  + 4w)t - 4w  - 6w  - 10w  - w - 1,
+                  3     2            4      3      2
+    8u v z x + (8w  + 4w  + 4w)t - 8w  - 12w  - 14w  - 3w - 1,
+       2          3      2             4      3      2
+    12v z x + (12w  + 12w  + 8w)t - 12w  - 18w  - 14w  - w - 1,
+          3      2             4      3      2
+    (- 24w  - 24w  - 8w)t + 24w  + 36w  + 26w  + 7w + 1]
+
+First of all, let us solve this system in the sense of Lazard by means
+of the REGSET constructor:
+
+lts := zeroSetSplit(lp,false)$T
+   [{w + 1,u,v,t + 1,b1 + y + z + 2}, {w + 1,v,t + 1,z,b1 + y + 2},
+    {w + 1,t + 1,z,y,b1 + 2}, {w + 1,v - u,t + 1,y + z,x,b1 + 2},
+    {w + 1,u,t + 1,y,x,b1 + z + 2},
+
+          5       4      3     2
+     {144w  + 216w  + 96w  + 6w  - 11w - 1,
+          2                 5       4      3     2
+      (12w  + 9w + 1)u - 72w  - 108w  - 42w  - 9w  - 3w,
+          2                 4      3      2
+      (12w  + 9w + 1)v + 36w  + 54w  + 18w ,
+          3      2             4      3      2
+      (24w  + 24w  + 8w)t - 24w  - 36w  - 26w  - 7w - 1,
+
+                     2                 2                        4      3     2
+         (12u v - 12u )z + (12w v + 12w  + 4)t + (3w - 5)v + 36w  + 42w  + 6w
+       + 
+         - 16w
+       ,
+                             2
+      2v y + 2u z + 2w t - 2w  - w - 1,
+                    2                3     2
+      6v z x + (- 6w  - 3w - 1)t + 6w  + 6w  + 4w, b1 + y + z - t - w}
+     ]
+
+We can get the dimensions of each component
+of a decomposition as follows.
+
+[coHeight(ts) for ts in lts]
+    [3,3,3,2,2,0]
+
+The first five sets have a simple shape.  However, the last one, which
+has dimension zero, can be simplified by using Lazard triangular sets.
+
+Thus we call the SquareFreeRegularTriangularSet domain constructor,
+
+ST := SREGSET(R,E,V,P)
+
+and set the LAZM3PK package constructor to our situation.
+
+pack := LAZM3PK(R,E,V,P,T,ST)
+
+We are ready to solve the system by means of Lazard triangular sets:
+
+zeroSetSplit(lp,false)$pack
+   [{w + 1,t + 1,z,y,b1 + 2}, {w + 1,v,t + 1,z,b1 + y + 2},
+    {w + 1,u,v,t + 1,b1 + y + z + 2}, {w + 1,v - u,t + 1,y + z,x,b1 + 2},
+    {w + 1,u,t + 1,y,x,b1 + z + 2},
+
+          5       4      3     2                   4      3      2
+     {144w  + 216w  + 96w  + 6w  - 11w - 1, u - 24w  - 36w  - 14w  + w + 1,
+              4      3      2                  4      3      2
+      3v - 48w  - 60w  - 10w  + 8w + 2, t - 24w  - 36w  - 14w  - w + 1,
+                  4        3        2
+      486z - 2772w  - 4662w  - 2055w  + 30w + 127,
+                    4         3        2
+      2916y - 22752w  - 30312w  - 8220w  + 2064w + 1561,
+                  4        3       2
+      356x - 3696w  - 4536w  - 968w  + 822w + 371,
+                     4         3         2
+      2916b1 - 30600w  - 46692w  - 20274w  - 8076w + 593}
+     ]
+
+We see the sixth triangular set is {\em nicer} now: each one of its
+polynomials has a constant initial.
+
+We follow with the Vermeer example. The ordering is the usual one
+for this system.
+
+Define the polynomial system.
+
+f0 := (w - v) ** 2 + (u - t) ** 2 - 1
+
+
+      2           2           2    2
+     t  - 2u t + v  - 2w v + u  + w  - 1
+
+
+f1 := t ** 2 - v ** 3
+
+      2    3
+     t  - v
+
+f2 := 2 * t * (w - v) + 3 * v ** 2 * (u - t)
+
+          2                   2
+     (- 3v  - 2v + 2w)t + 3u v
+
+f3 := (3 * z * v ** 2 - 1) * (2 * z * t - 1)
+
+       2   2             2
+     6v t z  + (- 2t - 3v )z + 1
+
+lf := [f0, f1, f2, f3]
+
+     2           2           2    2       2    3       2                   2
+   [t  - 2u t + v  - 2w v + u  + w  - 1, t  - v , (- 3v  - 2v + 2w)t + 3u v ,
+      2   2             2
+    6v t z  + (- 2t - 3v )z + 1]
+
+First of all, let us solve this system in the sense of Kalkbrener by
+means of the REGSET constructor:
+
+zeroSetSplit(lf,true)$T
+   [
+     {
+             6           3       2                 4
+         729u  + (- 1458w  + 729w  - 4158w - 1685)u
+       + 
+              6        5        4        3       2                2       8
+         (729w  - 1458w  - 2619w  - 4892w  - 297w  + 5814w + 427)u  + 729w
+       + 
+             7        6        5        4        3        2
+         216w  - 2900w  - 2376w  + 3870w  + 4072w  - 1188w  - 1656w + 529
+       ,
+
+                  4           3       2                  2        6        5
+             2187u  + (- 4374w  - 972w  - 12474w - 2868)u  + 2187w  - 1944w
+           + 
+                     4        3        2
+             - 10125w  - 4800w  + 2501w  + 4968w - 1587
+        *
+           v
+       + 
+               3       2  2       6        5        4       3        2
+         (1944w  - 108w )u  + 972w  + 3024w  - 1080w  + 496w  + 1116w
+       ,
+         2                   2                    2  2           2
+      (3v  + 2v - 2w)t - 3u v , ((4v - 4w)t - 6u v )z  + (2t + 3v )z - 1}
+     ]
+
+We have obtained one regular chain (i.e. regular triangular set) with
+dimension 1.  This set is in fact a characterist set of the (radical
+of) of the ideal generated by the input system lf.  Thus we have
+only the generic points of the variety associated with lf
+(for the elimination ordering given by ls).
+
+So let us get now a full description of this variety.
+
+Hence, we solve this system in the sense of Lazard by means of the REGSET
+constructor:
+
+zeroSetSplit(lf,false)$T
+   [
+     {
+             6           3       2                 4
+         729u  + (- 1458w  + 729w  - 4158w - 1685)u
+       + 
+              6        5        4        3       2                2       8
+         (729w  - 1458w  - 2619w  - 4892w  - 297w  + 5814w + 427)u  + 729w
+       + 
+             7        6        5        4        3        2
+         216w  - 2900w  - 2376w  + 3870w  + 4072w  - 1188w  - 1656w + 529
+       ,
+
+                  4           3       2                  2        6        5
+             2187u  + (- 4374w  - 972w  - 12474w - 2868)u  + 2187w  - 1944w
+           + 
+                     4        3        2
+             - 10125w  - 4800w  + 2501w  + 4968w - 1587
+        *
+           v
+       + 
+               3       2  2       6        5        4       3        2
+         (1944w  - 108w )u  + 972w  + 3024w  - 1080w  + 496w  + 1116w
+       ,
+         2                   2                    2  2           2
+      (3v  + 2v - 2w)t - 3u v , ((4v - 4w)t - 6u v )z  + (2t + 3v )z - 1}
+     ,
+
+         4     3      2                               2
+     {27w  + 4w  - 54w  - 36w + 23, u, (12w + 2)v - 9w  - 2w + 9,
+        2          2
+      6t  - 2v - 3w  + 2w + 3, 2t z - 1}
+     ,
+
+            6         5         4          3         2
+     {59049w  + 91854w  - 45198w  + 145152w  + 63549w  + 60922w + 21420,
+
+                            5                  4                  3
+             31484448266904w  - 18316865522574w  + 23676995746098w
+           + 
+                           2
+             6657857188965w  + 8904703998546w + 3890631403260
+        *
+            2
+           u
+       + 
+                        5                  4                  3
+         94262810316408w  - 82887296576616w  + 89801831438784w
+       + 
+                        2
+         28141734167208w  + 38070359425432w + 16003865949120
+       ,
+           2             2         2       3      2                    3     2
+      (243w  + 36w + 85)v  + (- 81u  - 162w  + 36w  + 154w + 72)v - 72w  + 4w ,
+         2                   2                    2  2           2
+      (3v  + 2v - 2w)t - 3u v , ((4v - 4w)t - 6u v )z  + (2t + 3v )z - 1}
+     ,
+
+         4     3      2                               2
+     {27w  + 4w  - 54w  - 36w + 23, u, (12w + 2)v - 9w  - 2w + 9,
+        2          2             2
+      6t  - 2v - 3w  + 2w + 3, 3v z - 1}
+     ]
+
+
+We retrieve our regular chain of dimension 1 and we get three regular
+chains of dimension 0 corresponding to the degenerated cases.
+We want now to simplify these zero-dimensional regular chains by using
+Lazard triangular sets.  Moreover, this will allow us to prove that
+the above decomposition has no redundant component.  
+
+Generally, decompositions computed by the REGSET constructor do
+not have redundant components.  However, to be sure that no redundant
+component occurs one needs to use the SREGSET or LAZM3PK constructors.
+
+So let us solve the input system in the sense of Lazard by means of
+the LAZM3PK constructor:
+
+zeroSetSplit(lf,false)$pack
+   [
+     {
+             6           3       2                 4
+         729u  + (- 1458w  + 729w  - 4158w - 1685)u
+       + 
+              6        5        4        3       2                2       8
+         (729w  - 1458w  - 2619w  - 4892w  - 297w  + 5814w + 427)u  + 729w
+       + 
+             7        6        5        4        3        2
+         216w  - 2900w  - 2376w  + 3870w  + 4072w  - 1188w  - 1656w + 529
+       ,
+
+                  4           3       2                  2        6        5
+             2187u  + (- 4374w  - 972w  - 12474w - 2868)u  + 2187w  - 1944w
+           + 
+                     4        3        2
+             - 10125w  - 4800w  + 2501w  + 4968w - 1587
+        *
+           v
+       + 
+               3       2  2       6        5        4       3        2
+         (1944w  - 108w )u  + 972w  + 3024w  - 1080w  + 496w  + 1116w
+       ,
+         2                   2                    2  2           2
+      (3v  + 2v - 2w)t - 3u v , ((4v - 4w)t - 6u v )z  + (2t + 3v )z - 1}
+     ,
+
+         2                 2                   2
+     {81w  + 18w + 28, 729u  - 1890w - 533, 81v  + (- 162w + 27)v - 72w - 112,
+      11881t + (972w + 2997)u v + (- 11448w - 11536)u,
+
+                         2
+         641237934604288z
+       + 
+                 (78614584763904w + 26785578742272)u + 236143618655616w
+               + 
+                 70221988585728
+            *
+               v
+           + 
+             (358520253138432w + 101922133759488)u + 142598803536000w
+           + 
+             54166419595008
+        *
+           z
+       + 
+         (32655103844499w - 44224572465882)u v
+       + 
+         (43213900115457w - 32432039102070)u
+       }
+     ,
+
+         4     3      2                           3     2
+     {27w  + 4w  - 54w  - 36w + 23, u, 218v - 162w  + 3w  + 160w + 153,
+          2      3      2                             3      2
+      109t  - 27w  - 54w  + 63w + 80, 1744z + (- 1458w  + 27w  + 1440w + 505)t}
+     ,
+
+         4     3      2                           3     2
+     {27w  + 4w  - 54w  - 36w + 23, u, 218v - 162w  + 3w  + 160w + 153,
+          2      3      2                         3     2
+      109t  - 27w  - 54w  + 63w + 80, 1308z + 162w  - 3w  - 814w - 153}
+     ,
+
+          4       3        2                   2      2
+     {729w  + 972w  - 1026w  + 1684w + 765, 81u  + 72w  + 16w - 72,
+                 3       2
+      702v - 162w  - 225w  + 40w - 99,
+                    3       2
+      11336t + (324w  - 603w  - 1718w - 1557)u,
+
+                   2
+         595003968z
+       + 
+                          3             2
+             (- 963325386w  - 898607682w  + 1516286466w - 3239166186)u
+           + 
+                          3              2
+             - 1579048992w  - 1796454288w  + 2428328160w - 4368495024
+        *
+           z
+       + 
+                     3              2
+         (9713133306w  + 9678670317w  - 16726834476w + 28144233593)u
+       }
+     ]
+
+Due to square-free factorization, we obtained now four
+zero-dimensional regular chains.  Moreover, each of them is normalized
+(the initials are constant).  Note that these zero-dimensional
+components may be investigated further with the 
+ZeroDimensionalSolvePackage package constructor.
+
+See also:
+o )show LazardSetSolvingPackage
+o )show ZeroDimensionalSolvePackage
+
+@
 \pagehead{LazardSetSolvingPackage}{LAZM3PK}
 \pagepic{ps/v104lazardsetsolvingpackage.ps}{LAZM3PK}{1.00}
 
diff --git a/books/ps/v0plot1.eps b/books/ps/v0plot1.eps
new file mode 100644
index 0000000..6490f81
--- /dev/null
+++ b/books/ps/v0plot1.eps
@@ -0,0 +1,1340 @@
+%!PS-Adobe-3.0 EPSF-3.0
+%%Creator: GIMP PostScript file plugin V 1.17 by Peter Kirchgessner
+%%Title: v0plot1.eps
+%%CreationDate: Thu Mar 19 15:34:01 2009
+%%DocumentData: Clean7Bit
+%%LanguageLevel: 2
+%%Pages: 1
+%%BoundingBox: 14 14 142 146
+%%EndComments
+%%BeginProlog
+% Use own dictionary to avoid conflicts
+10 dict begin
+%%EndProlog
+%%Page: 1 1
+% Translate for offset
+14.173228346456694 14.173228346456694 translate
+% Translate to begin of first scanline
+0 131.17539273108105 translate
+127.10551181102363 -131.17539273108105 scale
+% Image geometry
+406 419 8
+% Transformation matrix
+[ 406 0 0 419 0 0 ]
+% Strings to hold RGB-samples per scanline
+/rstr 406 string def
+/gstr 406 string def
+/bstr 406 string def
+{currentfile /ASCII85Decode filter /RunLengthDecode filter rstr readstring pop}
+{currentfile /ASCII85Decode filter /RunLengthDecode filter gstr readstring pop}
+{currentfile /ASCII85Decode filter /RunLengthDecode filter bstr readstring pop}
+true 3
+%%BeginData:        37876 ASCII Bytes
+colorimage
+r;V>^J\H]LotLA(J,~>
+r;V>VJ[U-<osXeuJ,~>
+r;V>VJ[U-<osXeuJ,~>
+rr<#4J_G\/W7h74o@sAojR_.-dH'oS!7Cf"s1\L4J,~>
+rr<#,J^f8#W71h*o@F#di:GP$bM`!D!6bAks0hq,J,~>
+rr<#,J^f8#W71h*o@F#di:GP$bM`!D!6bAks0hq,J,~>
+s8N)5J_5P+VUtn-o@X/jiUb_'cf+KK!71Sq!l"^7J,~>
+s8N)-J^T+tVU>J#o@*f_h=K+sakcR<!6P/e!k/./J,~>
+s8N)-J^T+tVU>J#o@*f_h=K+sakcR<!6P/e!k/./J,~>
+!WTn1f(1#8eq)D`ec=V!f)a.Ro@F#fhu;4.gYDbZs4dP)!6tDl!P\Sa~>
+!WTV)d.9k\d"0QTciDhldK.DCo?mZ[g]#Y$fDX+uf%9oL!6=u`!Oi#Y~>
+!WTV)d.<$Dd"0QTciDhldK.DCo?mZ[g]#Y$fDX+uf%9oL!6=u`!Oi#Y~>
+!WTn1e,UWaEW@55eFV/lec#O%qpY]+s4Znj$MFDrk1&Ais8268J^j;@!8[7s!R0BseH4Fbg\fS5
+bh^h"g?%GQe^`O<jk827bkolj^Ai]~>
+!WTV)c2^K0T)_K7cL]<`ci!gnqp#9!s4-P_$M=;pj3HK\s8200J^3l4!86ti!QEahcN;VSf)3i*
+`S&S`eD]B>cd1>(iRH3"`V[p][f:j~>
+!WTV)c2`XmcN&`OcL]<`ci!gnqp#9!s4-P_$M=;pj3HK\s8200J^3l4!86ti!QEahcN;VSf)3i*
+`S&S`eD]B>cd1>(iRH3"`V[p][f:j~>
+!5A9W!?cFW1]_V>J^X/<"5a(Xk53R.e(<(:dL,9mmf(_os4uQ/mt&pYdK&%ndfIVGqpPW*io0ga
+&B`bVe(<X:j4rGMhW*29e&qO8!5<s~>
+!4M^I!D9!YAHADqJ^!`0"5<eTj87%%cI0u*bR3R`m/G;cs4H'%m"*CPbQ-5cblP`5qoo2uhVJ+S
+&B!)Dc-kP(hq6T=g>LB'c,9D%!4IC~>
+!4M^I!Jf"qU]JesJ^!`0"5<eTj87%%cI0u*bR3R`m/G;cs4H'%m"*CPbQ-5cblP`5qoo2uhVJ+S
+&B!)Dc-kP(hq6T=g>LB'c,9D%!4IC~>
+!5A9U%>b&9f\+p1g"P6:h>`:^d.>U&lhg;Fd,t5Tp[6r=f?i^Zqr#iYs7$$Tmf)SLcjA\2e)12W
+d,k8SJ^F&9!86tk!Q`skd/r:`iV_((aP$R?#M\7oio8eRgA]J"aSO6`^46~>
+!4M^G%>t2?gYCQ=h;-rFhuARbb4Eaol21&Bb2`?Dp?UK5dE:PJqV96Js6fjOm/H8GapHr)cJ/BH
+b2WEEJ]dW-!7^V`!Q!:_b6$MRh>GFs_:8J-#M.bahVQoAf)Ehm_>;:S[X\~>
+!4M^G%>Fi3eCE(!f%8R-gAckXb4Eaol21&Bb2`?Dp?UK5dE:PJqV96Js6fjOm/H8GapHr)cJ/BH
+b2WEEJ]dW-!7^V`!Q!:_b6$MRh>GFs_:8J-#M.bahVQoAf)Ehm_>;:S[X\~>
+!5A9S#DiE5g"P-5g]$"1huAL`cL]=#qX<SGda.X^qpF7"e^a][lho)bs5iDCjlZTjr6>Yrp@-A`
+s4,EOs3lPEoZdHgo?RHXfDa))f&,BEh;[>Lf$D[_fDX#!g#:]?iS"1U!6=r]!5<s~>
+!4M^E!fI$5rS7\7hr*GOs,)BKo>hmHmGn2ian>E)bh<$Cd/W%fr5mXlioC'uj8[=#a9p,`m`=)]
+d)ar@c@O(/a8jZ[a8s'(rl>Mpg=tK:hV6c2aN2-ErQ#/lgt('3e,@>f^\Z"O[X\~>
+!4M^E%>Fi5f%8L)f\,!4h#E(ZaRdIlq<d5AbfTPPqTRXmd*VgNkkrQUs5N)=ioC'^r5]5gp$ToS
+s3Sj@s3?2:oZ.$\o>gsIdf.;rd+[72f\YB:d)a;Cdf%5jeD/X+gsc5C!5JBO!4IC~>
+!5A9R!f6m2r7hJ3hr*GmLk3hCboG@8in=@hc/AWcc/&ELh#Gp]s3fa'e_U8Th#Gk%bmVhepsI@B
+s4#<Srm-/?oZ[Bdo?@<Tec*f%hqd&Ag"Y9;hp'Ebec!_rf\bE:hq7nP!6+fZ!5<s~>
+!4M^C!K-pTh?MlqiSrksMLie>`Z3D+hUDMZ`n^UU`n:=:fDj1Ms30-qce/9Cf`04p`XBiVpWCM.
+s3AXBrlBZ1oYpmWo>UgEci1omg=Y!-eCN4'g;_.Gci(iedbE:$gX?&?!586K!4IC~>
+!4M^C%>Fi6f\+p1g"Y9:h>`1[`q77jdJr(Ps4bQKs5h8Qs3B6rce8?Bf`0:Ms3B9sc2GWia7/iG
+`n:=:`o-j;J]@?%!718V!PQhY`XLSRf%/@%f%A]r`kB^s`WafFeC<7$rPeiNqSiNDJ,~>
+!5A9P%>b&>h;6uEhr!ANiW"^bbOisXk5G;rm`kP!r6a:!daS6TlMSl\s3f[%dbFfMrQ>Q7r7B??
+g],mYqs8mWo?.-_o?%*Oe,IJudbNX8g#(T?d`T_Me,IJpf%ns7h:LK5rlP5YqTAlQJ,~>
+!4M^A%>t2Chr*DMiSieVj8Y!f`:UtJir/lnm)Jekr6*^lbg$1DkPW<Ns30*pbLcd;rPT'.r6ia,
+fDj:KqW`XMo>CXRo>C[Bc2PWic.L_)e_Jj1c,@Q5c2PWddG!('g=+a%rknfLqSWBBJ,~>
+!4M^A%>Fi7g"P-5gt^`BhuAC]`:UtJir/lnm)Jekr6*^lbg$1DkPW<Ns30*pbLcd;rPT'.r6ia,
+fDj:KqW`XMo>CXRo>C[Bc2PWic.L_)e_Jj1c,@Q5c2PWddG!('g=+a%rknfLqSWBBJ,~>
+!5A9N%>b&?hV[2Ii8N\Tj8Xpdan3[pp%-Y]m/?2DbOY,Us3\sKr;,0igAfRSs3TL"d/D)brs$j(
+s8Vu]b^mn-aT0`fa8jQ_f`]XBaMQ@%a9(,Kg\f,(_U6HGcJ7"+e(!1(gs4!^_YV@S^46~>
+!4M^?%>t2DiSrhUj5]4^jo:3h_Xt\bo^^8Ol29]<`:30Es3&:;r;,$^ec3hCs2rmlb5K3Urs$Wr
+s8VrZ`IYnt_>qdY_#VURe-*n0_7Ihe_#i3:f)3>q]$%q+aOnklcHb%gfZ:nF])'8D[X\~>
+!4M^?%>Fi9gYCQ=h;7&Hi;\L^_Xt\bo^^8Ol29]<`:30Es3&:;r;,$^ec3hCs2rmlb5K3Urs$Wr
+s8VrZ`IYnt_>qdY_#VURe-*n0_7Ihe_#i3:f)3>q]$%q+aOnklcHb%gfZ:nF])'8D[X\~>
+!5A9L%>b&Ai8NPMi8N\Tj8Xpda+;:B`rOHb`W=cFr7;,*fZ(qHchk]`g">!U`Xor3`l?9YgX=*]
+dbER$`l>gj`rNi(~>
+!4M^=%>t2FioB"Wj5]4^jo:3h^k';4^];IT^]2g]dKS.L^V@;"qnE3^e("<1&@ffr^W4sXbeLp;
+f@S$W^UX-U!4IC~>
+!4M^=%>Fi;h;-i@h;7&Hi;\L^^k';4^];IT^]2g]dKS.L^V@;"qnE3^e("<1&@ffr^W4sXbeLp;
+f@S$W^UX-U!4IC~>
+!5A9J%>b&Ai8NVQioB([jo:-f`IZ">`;n0^_uS$Xf*'=9`4jLn_ue3:c2>K\^<QYq!R&Xa`;e!Z
+_uROJ`;mW&~>
+!4M^;%>t2FioB%Yj5f=ak5U<i^4F#0^&Z1P]`H.$r6kht`kB'o`r!FNa4/0-]`GR]rk/?O`;RCL
+`;[FM[ed]<[X\~>
+!4M^;!ep[0rS7\7i8EVSs+Q$<J\J_0!65#O!QNRcdfn1>]tLkoqn3'OeAqL#!Og#I]`H*jrOr6L
+rk/<?qRus<J,~>
+!5A9H!/U=J!/Q3DJ]#(:!6auN!PQ\J_?%?no>1L@qSN<IJ,~>
+!4M^9!/gIL!/c??J\8S,!6"K?!OTf:\cK1Vo==q/qRcg:J,~>
+!4M^9!/:+G!/6!:J\8S,!6"K?!OTf:\cK1Vo==q/qRcg:J,~>
+!5A9Fo8%t6J\eq6!6OiJ!P?JF^]D'ho=t@<qS<0GJ,~>
+!4M^7o88+1J\&G(!5\9:!OBQ5\,inOo=+e+qRQ[8J,~>
+!4M^7o7_b,J\&G(!5\9:!OBQ5\,inOo=+e+qRQ[8J,~>
+J\H]LUV6`Ko=b79a7I"G\]=<U!4hp>J,~>
+J[U-<UUC0;o<n\(^[nl7YeTe<!3l:-J,~>
+J[U-<UUC0;o<n\(^[nl7YeTe<!3l:-J,~>
+rk<s`JcC<$nc/U&J,~>
+rjICXJcC<$nc/TsJ,~>
+rjICXJcC<$nc/TsJ,~>
+rk<s`JcC<$nc/U&J,~>
+rjICXJcC<$nc/TsJ,~>
+rjICXJcC<$nc/TsJ,~>
+rk<s`JcC<$nc/U&J,~>
+rjICXJcC<$nc/TsJ,~>
+rjICXJcC<$nc/TsJ,~>
+rk<s`JcC<$nc/U&J,~>
+rjICXJcC<$nc/TsJ,~>
+rjICXJcC<$nc/TsJ,~>
+rk<s`JcC<$nc/U&J,~>
+rjICXJcC<$nc/TsJ,~>
+rjICXJcC<$nc/TsJ,~>
+rk<s`JcC<$nc/U&J,~>
+rjICXJcC<$nc/TsJ,~>
+rjICXJcC<$nc/TsJ,~>
+rk<s`jo>=pq#C?.p\t6.r;Qc3jo>@qJcEpnrk<m~>
+rjICXjo><pq#C>.p\t5.r;Qb3jo>?qJcEpnrjI=~>
+rjICXjo><7q#C=Jp\t4Jr;QaOjo>?8JcEpnrjI=~>
+rk<s`k5PFrrr2u5qYpQ1rr2u5q>^K0rVlr6s1d[q!5JI3!5J7-!5JL4!5F*birB"lJ,~>
+rjICXk5PErrr2t5qYpP1rr2t5q>^J0rVlq6s(^Zq!,DH3!,D6-!,DK4!,@)birB"dJ,~>
+rjICXk5PE9rr2sQqYpOMrr2sQq>^ILrVlpRs"WX8!&=EO!&=3I!&=HP!&9')irB"dJ,~>
+rk<s`k5PFrrr2u5qYpQ1rr2u5qYpW3s1eR5!5JO5!5I[r!5Ik"!5F*birB"lJ,~>
+rjICXk5PErrr2t5qYpP1rr2t5qYpV3s(_Q5!,DN5!,CZr!,Cj"!,@)birB"dJ,~>
+rjICXk5PE9rr2sQqYpOMrr2sQqYpUOs"XNQ!&=KQ!&<X9!&<g>!&9')irB"dJ,~>
+rk<s`ir9"npAY--q#:?/rr2u5rr2u5q>^H/s8N)6rr3#6s8B_2rrBh4s8Tk4s8Ke4s8Tk5s8B]`
+s5a4Z^46~>
+rjICXir9!npAY,-q#:>/rr2t5rr2t5q>^G/s8N(6rr3"6s8?^2rr?g4s8Qj4s8Hd4s8Qj5s8?\`
+s5a4Z[X\~>
+rjICXir9!5pAY+Iq#:=Krr2sQrr2sQq>^FKs8N'Rrr3!Rs8=\Nrr=ePs8OhPs8FbPs8OhQs8=['
+s5a4Z[X\~>
+rk<s`j8T+opAY--p\t6.rr2u5rr2u5qYpQ1rr38=s8Tk6^]4>Krr2u5rr2u5r;Qc3rr2u5rr2u5
+rr2u5rVll4JcFa0rk<m~>
+rjICXj8T*opAY,-p\t5.rr2t5rr2t5qYpP1rr37=s8Qj6CB+<Krr2t5rr2t5r;Qb3rr2t5rr2t5
+rr2t5rVlk4JcFa0rjI=~>
+rjICXj8T*6pAY+Ip\t4Jrr2sQrr2sQqYpOMrr36Ys8OhR1&q8.rr2sQrr2sQr;QaOrr2sQrr2sQ
+rr2sQrVljPJcFa0rjI=~>
+rk<s`jSo4ppAY--pAY--rr2u5rr2u5qZ$K.rr2u5rr2u5rr2u5rr2u5r;Qc3rr2u5qYpQ1rVll4
+JcFa0rk<m~>
+rjICXjSo3ppAY,-pAY,-rr2t5rr2t5qZ$J.rr2t5rr2t5rr2t5rr2t5r;Qb3rr2t5qYpP1rVlk4
+JcFa0rjI=~>
+rjICXjSo37pAY+IpAY+Irr2sQrr2sQqZ$IJrr2sQrr2sQrr2sQrr2sQr;QaOrr2sQqYpOMrVljP
+JcFa0rjI=~>
+rk<s`jo5=qpAY--p&>$,rr2u5rr2u5qYpQ1qYpQ1rr2u5rr2u5rr2u5r;Qc3rr2u5qYpQ1rVll4
+JcFa0rk<m~>
+rjICXjo5<qpAY,-p&>#,rr2t5rr2t5qYpP1qYpP1rr2t5rr2t5rr2t5r;Qb3rr2t5qYpP1rVlk4
+JcFa0rjI=~>
+rjICXjo5<8pAY+Ip&>"Hrr2sQrr2sQqYpOMqYpOMrr2sQrr2sQrr2sQr;QaOrr2sQqYpOMrVljP
+JcFa0rjI=~>
+rk<s`k5PFrqYpQ1rr2u5qYpQ1r;Qc3rVlr6s1eC0!5JO5#J^<=^]2(Ks8B_2rrBh3rrBh5rrBh5
+rrBh5rrBh4rr^%9s1a-bjo>=oJ,~>
+rjICXk5PErqYpP1rr2t5qYpP1r;Qb3rVlq6s(_B0!,DN5#AX;=CB&&Ks8?^2rr?g3rr?g5rr?g5
+rr?g5rr?g4rr[$9s([,bjo>=gJ,~>
+rjICXk5PE9qYpOMrr2sQqYpOMr;QaOrVlpRs"X?L!&=KQ#;Q8Y1&j!.s8=\Nrr=eOrr=eQrr=eQ
+rr=eQrr=ePrrY"Us"T*)jo>=gJ,~>
+rk<s`k5Y@os8W)5s8W#3s8W)5s8W#3rr2u5p](6-s8N)6rr3&7s1eI2rkJI4rkJI4rkJI4rkJF3
+s1a-bjT#4nJ,~>
+rjICXk5Y?os8W(5s8W"3s8W(5s8W"3rr2t5p](5-s8N(6rr3%7s(_H2rbDH4rbDH4rbDH4rbDE3
+s([,bjT#4fJ,~>
+rjICXk5Y?6s8W'Qs8W!Os8W'Qs8W!Orr2sQp](4Is8N'Rrr3$Ss"XENr\=EPr\=EPr\=EPr\=BO
+s"T*)jT#4fJ,~>
+rk<s`hZ!SjpAY--i;WelJcEXfrk<m~>
+rjICXhZ!RjpAY,-i;WdlJcEXfrjI=~>
+rjICXhZ!R1pAY+Ii;Wd3JcEXfrjI=~>
+rk<s`Yl=^<JcEXfrk<m~>
+rjICXYl=]<JcEXfrjI=~>
+rjICXYl=\XJcEXfrjI=~>
+rk<s`JcC<$nc/U&J,~>
+rjICXJcC<$nc/TsJ,~>
+rjICXJcC<$nc/TsJ,~>
+rk<s`JcC<$nc/U&J,~>
+rjICXJcC<$nc/TsJ,~>
+rjICXJcC<$nc/TsJ,~>
+rk<s`JcC<$nc/U&J,~>
+rjICXJcC<$nc/TsJ,~>
+rjICXJcC<$nc/TsJ,~>
+rk<s`JcC<$nc/U&J,~>
+rjICXJcC<$nc/TsJ,~>
+rjICXJcC<$nc/TsJ,~>
+rk<s`JcC<$nc/U&J,~>
+rjICXJcC<$nc/TsJ,~>
+rjICXJcC<$nc/TsJ,~>
+rk<s`JcC<$nc/U&J,~>
+rjICXJcC<$nc/TsJ,~>
+rjICXJcC<$nc/TsJ,~>
+rk<s`JcC<$nc/U&J,~>
+rjICXJcC<$nc/TsJ,~>
+rjICXJcC<$nc/TsJ,~>
+rk<s`\c2ZgJcE=]rk<m~>
+rjICX\c2Z:JcE=]rjI=~>
+rjICX\c2YKJcE=]rjI=~>
+rk<s`\c2ZgJcE=]rk<m~>
+rjICX\c2Z:JcE=]rjI=~>
+rjICX\c2YKJcE=]rjI=~>
+rk<s`\c2ZgJcE=]rk<m~>
+rjICX\c2Z:JcE=]rjI=~>
+rjICX\c2YKJcE=]rjI=~>
+rk<s`\c2ZgJcE=]rk<m~>
+rjICX\c2Z:JcE=]rjI=~>
+rjICX\c2YKJcE=]rjI=~>
+rk<s`\c2ZgJcE=]rk<m~>
+rjICX\c2Z:JcE=]rjI=~>
+rjICX\c2YKJcE=]rjI=~>
+rk<s`\c2ZgJcE=]rk<m~>
+rjICX\c2Z:JcE=]rjI=~>
+rjICX\c2YKJcE=]rjI=~>
+rk<s`\c2ZgJcE=]rk<m~>
+rjICX\c2Z:JcE=]rjI=~>
+rjICX\c2YKJcE=]rjI=~>
+rk<s`\c2ZgJcF'rs1e"%rk<m~>
+rjICX\c2Z:JcF'rs"WsArjI=~>
+rjICX\c2YKJcF'rs"WsArjI=~>
+rk<s`\c2ZgJcF'rs1e"%rk<m~>
+rjICX\c2Z:JcF'rs"WsArjI=~>
+rjICX\c2YKJcF'rs"WsArjI=~>
+rk<s`\c2ZgJcF'r!$1J,rk<m~>
+rjICX\c2Z:JcF'r!0lmNrjI=~>
+rjICX\c2YKJcF'r!$1J,rjI=~>
+rk<s`\c2ZgJcF'r!$1J,rk<m~>
+rjICX\c2Z:JcF'r!0lmNrjI=~>
+rjICX\c2YKJcF'r!$1J,rjI=~>
+rk<s`\c2ZgJcF*s!$1G+rk<m~>
+rjICX\c2Z:JcF*s!0ljMrjI=~>
+rjICX\c2YKJcF*s!$1G+rjI=~>
+rk<s`\c2ZgJcF*s!$1G+rk<m~>
+rjICX\c2Z:JcF*s!0ljMrjI=~>
+rjICX\c2YKJcF*s!$1G+rjI=~>
+rk<s`\c2ZgJcF*s!$1G+rk<m~>
+rjICX\c2Z:JcF*s!0ljMrjI=~>
+rjICX\c2YKJcF*s!$1G+rjI=~>
+rk<s`\c2ZgJcF*s!$1G+rk<m~>
+rjICX\c2Z:JcF*s!0ljMrjI=~>
+rjICX\c2YKJcF*s!$1G+rjI=~>
+rk<s`\c2ZgJcF*s!$1G+rk<m~>
+rjICX\c2Z:JcF*s!0ljMrjI=~>
+rjICX\c2YKJcF*s!$1G+rjI=~>
+rk<s`\c2ZgJcF*s!$1G+rk<m~>
+rjICX\c2Z:JcF*s!0ljMrjI=~>
+rjICX\c2YKJcF*s!$1G+rjI=~>
+rk<s`\c2ZgJcF*s!$1G+rk<m~>
+rjICX\c2Z:JcF*s!0ljMrjI=~>
+rjICX\c2YKJcF*s!$1G+rjI=~>
+rk<s`\c2ZgJcF-t!$1D*rk<m~>
+rjICX\c2Z:JcF-t!0lgLrjI=~>
+rjICX\c2YKJcF-t!$1D*rjI=~>
+rk<s`\c2ZgJcF-t!$1D*rk<m~>
+rjICX\c2Z:JcF-t!0lgLrjI=~>
+rjICX\c2YKJcF-t!$1D*rjI=~>
+rk<s`\c2ZgJcF-t!$1D*rk<m~>
+rjICX\c2Z:JcF-t!0lgLrjI=~>
+rjICX\c2YKJcF-t!$1D*rjI=~>
+rk<s`\c2ZgJcF-t!$1D*rk<m~>
+rjICX\c2Z:JcF-t!0lgLrjI=~>
+rjICX\c2YKJcF-t!$1D*rjI=~>
+rk<s`\c2ZgJcF-t!$1D*rk<m~>
+rjICX\c2Z:JcF-t!0lgLrjI=~>
+rjICX\c2YKJcF-t!$1D*rjI=~>
+rk<s`\c2ZgJcF-t!$1D*rk<m~>
+rjICX\c2Z:JcF-t!0lgLrjI=~>
+rjICX\c2YKJcF-t!$1D*rjI=~>
+rk<s`\c2ZgJcF0u!$1A)rk<m~>
+rjICX\c2Z:JcF0u!0ldKrjI=~>
+rjICX\c2YKJcF0u!$1A)rjI=~>
+rk<s`\c2ZgJcF0u!$1A)rk<m~>
+rjICX\c2Z:JcF0u!0ldKrjI=~>
+rjICX\c2YKJcF0u!$1A)rjI=~>
+rk<s`\c2ZgJcF0u!$1A)rk<m~>
+rjICX\c2Z:JcF0u!0ldKrjI=~>
+rjICX\c2YKJcF0u!$1A)rjI=~>
+rk<s`\c2ZgJcF0u!$1A)rk<m~>
+rjICX\c2Z:JcF0u!0ldKrjI=~>
+rjICX\c2YKJcF0u!$1A)rjI=~>
+rk<s`\c2ZgJcF0u!$1A)rk<m~>
+rjICX\c2Z:JcF0u!0ldKrjI=~>
+rjICX\c2YKJcF0u!$1A)rjI=~>
+rk<s`\c2ZgJcF0u!$1A)rk<m~>
+rjICX\c2Z:JcF0u!0ldKrjI=~>
+rjICX\c2YKJcF0u!$1A)rjI=~>
+rk<s`\c2ZgJcF0u!$1A)rk<m~>
+rjICX\c2Z:JcF0u!0ldKrjI=~>
+rjICX\c2YKJcF0u!$1A)rjI=~>
+rk<s`\c2ZgJcF4!!$1>(rk<m~>
+rjICX\c2Z:JcF4!!0laJrjI=~>
+rjICX\c2YKJcF4!!$1>(rjI=~>
+rk<s`\c2ZgJcF4!!$1>(rk<m~>
+rjICX\c2Z:JcF4!!0laJrjI=~>
+rjICX\c2YKJcF4!!$1>(rjI=~>
+rk<s`\c2ZgJcF4!!$1>(rk<m~>
+rjICX\c2Z:JcF4!!0laJrjI=~>
+rjICX\c2YKJcF4!!$1>(rjI=~>
+rk<s`\c2ZgJcF4!!$1>(rk<m~>
+rjICX\c2Z:JcF4!!0laJrjI=~>
+rjICX\c2YKJcF4!!$1>(rjI=~>
+rk<s`\c2ZgJcF4!!$1>(rk<m~>
+rjICX\c2Z:JcF4!!0laJrjI=~>
+rjICX\c2YKJcF4!!$1>(rjI=~>
+rk<s`\c2ZgJcF4!!$1>(rk<m~>
+rjICX\c2Z:JcF4!!0laJrjI=~>
+rjICX\c2YKJcF4!!$1>(rjI=~>
+rk<s`\c2ZgJcF4!!$1>(rk<m~>
+rjICX\c2Z:JcF4!!0laJrjI=~>
+rjICX\c2YKJcF4!!$1>(rjI=~>
+rk<s`\c2ZgJcF7"!$1;'rk<m~>
+rjICX\c2Z:JcF7"!0l^IrjI=~>
+rjICX\c2YKJcF7"!$1;'rjI=~>
+rk<s`\c2ZgJcF7"!$1;'rk<m~>
+rjICX\c2Z:JcF7"!0l^IrjI=~>
+rjICX\c2YKJcF7"!$1;'rjI=~>
+rk<s`\c2ZgJcF7"!$1;'rk<m~>
+rjICX\c2Z:JcF7"!0l^IrjI=~>
+rjICX\c2YKJcF7"!$1;'rjI=~>
+rk<s`\c2ZgJcF7"!$1;'rk<m~>
+rjICX\c2Z:JcF7"!0l^IrjI=~>
+rjICX\c2YKJcF7"!$1;'rjI=~>
+rk<s`\c2ZgJcF7"!$1;'rk<m~>
+rjICX\c2Z:JcF7"!0l^IrjI=~>
+rjICX\c2YKJcF7"!$1;'rjI=~>
+rk<s`\c2ZgJcF7"!$1;'rk<m~>
+rjICX\c2Z:JcF7"!0l^IrjI=~>
+rjICX\c2YKJcF7"!$1;'rjI=~>
+rk<s`\c2ZgJcF:#!$18&rk<m~>
+rjICX\c2Z:JcF:#!0l[HrjI=~>
+rjICX\c2YKJcF:#!$18&rjI=~>
+rk<s`\c2ZgJcF:#!$18&rk<m~>
+rjICX\c2Z:JcF:#!0l[HrjI=~>
+rjICX\c2YKJcF:#!$18&rjI=~>
+rk<s`\c2ZgJcF:#!$18&rk<m~>
+rjICX\c2Z:JcF:#!0l[HrjI=~>
+rjICX\c2YKJcF:#!$18&rjI=~>
+rk<s`\c2ZgJcF:#!$18&rk<m~>
+rjICX\c2Z:JcF:#!0l[HrjI=~>
+rjICX\c2YKJcF:#!$18&rjI=~>
+rk<s`\c2ZgJcF:#!$18&rk<m~>
+rjICX\c2Z:JcF:#!0l[HrjI=~>
+rjICX\c2YKJcF:#!$18&rjI=~>
+rk<s`\c2ZgJcF:#!$18&rk<m~>
+rjICX\c2Z:JcF:#!0l[HrjI=~>
+rjICX\c2YKJcF:#!$18&rjI=~>
+rk<s`\c2ZgJcF:#!$18&rk<m~>
+rjICX\c2Z:JcF:#!0l[HrjI=~>
+rjICX\c2YKJcF:#!$18&rjI=~>
+rk<s`\c2ZgJcF=$!$15%rk<m~>
+rjICX\c2Z:JcF=$!0lXGrjI=~>
+rjICX\c2YKJcF=$!$15%rjI=~>
+rk<s`\c2ZgJcF=$!$15%rk<m~>
+rjICX\c2Z:JcF=$!0lXGrjI=~>
+rjICX\c2YKJcF=$!$15%rjI=~>
+rk<s`\c2ZgJcF=$!$15%rk<m~>
+rjICX\c2Z:JcF=$!0lXGrjI=~>
+rjICX\c2YKJcF=$!$15%rjI=~>
+rk<s`\c2ZgJcF=$!?Jr<s8K`_~>
+rjICX\c2Z:JcF=$!L,>%s8KHW~>
+rjICX\c2YKJcF=$!?EoXs8KHW~>
+rk<s`\c2ZgJcF=$s1dasrk<m~>
+rjICX\c2Z:JcF=$s"W^:rjI=~>
+rjICX\c2YKJcF=$s"W^:rjI=~>
+rk<s`\c2ZgJcF=$!$15%rk<m~>
+rjICX\c2Z:JcF=$!0lXGrjI=~>
+rjICX\c2YKJcF=$!$15%rjI=~>
+rk<s`\c2ZgJcF@%!$12$rk<m~>
+rjICX\c2Z:JcF@%!0lUFrjI=~>
+rjICX\c2YKJcF@%!$12$rjI=~>
+rk<s`\c2ZgJcF@%!$12$rk<m~>
+rjICX\c2Z:JcF@%!0lUFrjI=~>
+rjICX\c2YKJcF@%!$12$rjI=~>
+rk<s`\c2ZgJcF@%!$12$rk<m~>
+rjICX\c2Z:JcF@%!0lUFrjI=~>
+rjICX\c2YKJcF@%!$12$rjI=~>
+rk<s`\c2ZgJcF@%!$12$rk<m~>
+rjICX\c2Z:JcF@%!0lUFrjI=~>
+rjICX\c2YKJcF@%!$12$rjI=~>
+rk<s`\c2ZgJcF@%!$12$rk<m~>
+rjICX\c2Z:JcF@%!0lUFrjI=~>
+rjICX\c2YKJcF@%!$12$rjI=~>
+rk<s`\c2ZgJcFC&!$1/#rk<m~>
+rjICX\c2Z:JcFC&!0lRErjI=~>
+rjICX\c2YKJcFC&!$1/#rjI=~>
+rk<s`\c2ZgJcFC&!$1/#rk<m~>
+rjICX\c2Z:JcFC&!0lRErjI=~>
+rjICX\c2YKJcFC&!$1/#rjI=~>
+rk<s`\c2ZgJcFC&!$1/#rk<m~>
+rjICX\c2Z:JcFC&!0lRErjI=~>
+rjICX\c2YKJcFC&!$1/#rjI=~>
+rk<s`\c2ZgJcFC&!$1/#rk<m~>
+rjICX\c2Z:JcFC&!0lRErjI=~>
+rjICX\c2YKJcFC&!$1/#rjI=~>
+rk<s`\c2ZgJcFC&!$1/#rk<m~>
+rjICX\c2Z:JcFC&!0lRErjI=~>
+rjICX\c2YKJcFC&!$1/#rjI=~>
+rk<s`\c2ZgJcFC&!$1/#rk<m~>
+rjICX\c2Z:JcFC&!0lRErjI=~>
+rjICX\c2YKJcFC&!$1/#rjI=~>
+rk<s`\c2ZgJcFF'!$1,"rk<m~>
+rjICX\c2Z:JcFF'!0lODrjI=~>
+rjICX\c2YKJcFF'!$1,"rjI=~>
+rk<s`\c2ZgJcFF'!$1,"rk<m~>
+rjICX\c2Z:JcFF'!0lODrjI=~>
+rjICX\c2YKJcFF'!$1,"rjI=~>
+rk<s`\c2ZgJcFF'!$1,"rk<m~>
+rjICX\c2Z:JcFF'!0lODrjI=~>
+rjICX\c2YKJcFF'!$1,"rjI=~>
+rk<s`\c2ZgJcFF'!$1,"rk<m~>
+rjICX\c2Z:JcFF'!0lODrjI=~>
+rjICX\c2YKJcFF'!$1,"rjI=~>
+rk<s`\c2ZgJcFF'!$1,"rk<m~>
+rjICX\c2Z:JcFF'!0lODrjI=~>
+rjICX\c2YKJcFF'!$1,"rjI=~>
+rk<s`\c2ZgJcFI(!$1)!rk<m~>
+rjICX\c2Z:JcFI(!0lLCrjI=~>
+rjICX\c2YKJcFI(!$1)!rjI=~>
+rk<s`\c2ZgJcFI(!$1)!rk<m~>
+rjICX\c2Z:JcFI(!0lLCrjI=~>
+rjICX\c2YKJcFI(!$1)!rjI=~>
+rk<s`\c2ZgJcFI(!$1)!rk<m~>
+rjICX\c2Z:JcFI(!0lLCrjI=~>
+rjICX\c2YKJcFI(!$1)!rjI=~>
+rk<s`\c2ZgJcFI(!$1)!rk<m~>
+rjICX\c2Z:JcFI(!0lLCrjI=~>
+rjICX\c2YKJcFI(!$1)!rjI=~>
+rk<s`\c2ZgJcFI(!$1)!rk<m~>
+rjICX\c2Z:JcFI(!0lLCrjI=~>
+rjICX\c2YKJcFI(!$1)!rjI=~>
+rk<s`\c2ZgJcFL)!$1%urk<m~>
+rjICX\c2Z:JcFL)!0lIBrjI=~>
+rjICX\c2YKJcFL)!$1%urjI=~>
+rk<s`\c2ZgJcFL)!$1%urk<m~>
+rjICX\c2Z:JcFL)!0lIBrjI=~>
+rjICX\c2YKJcFL)!$1%urjI=~>
+rk<s`\c2ZgJcFL)!$1%urk<m~>
+rjICX\c2Z:JcFL)!0lIBrjI=~>
+rjICX\c2YKJcFL)!$1%urjI=~>
+rk<s`\c2ZgJcFL)!$1%urk<m~>
+rjICX\c2Z:JcFL)!0lIBrjI=~>
+rjICX\c2YKJcFL)!$1%urjI=~>
+rk<s`\c2ZgJcFL)!$1%urk<m~>
+rjICX\c2Z:JcFL)!0lIBrjI=~>
+rjICX\c2YKJcFL)!$1%urjI=~>
+rk<s`\c2ZgJcFO*!$1"trk<m~>
+rjICX\c2Z:JcFO*!0lFArjI=~>
+rjICX\c2YKJcFO*!$1"trjI=~>
+rk<s`\c2ZgJcFO*!$1"trk<m~>
+rjICX\c2Z:JcFO*!0lFArjI=~>
+rjICX\c2YKJcFO*!$1"trjI=~>
+rk<s`\c2ZgJcFO*!$1"trk<m~>
+rjICX\c2Z:JcFO*!0lFArjI=~>
+rjICX\c2YKJcFO*!$1"trjI=~>
+rk<s`\c2ZgJcFO*!$1"trk<m~>
+rjICX\c2Z:JcFO*!0lFArjI=~>
+rjICX\c2YKJcFO*!$1"trjI=~>
+rk<s`\c2ZgJcFO*!$1"trk<m~>
+rjICX\c2Z:JcFO*!0lFArjI=~>
+rjICX\c2YKJcFO*!$1"trjI=~>
+rk<s`\c2ZgJcFO*!$1"trk<m~>
+rjICX\c2Z:JcFO*!0lFArjI=~>
+rjICX\c2YKJcFO*!$1"trjI=~>
+rk<s`\c2ZgJcFR+!$0tsrk<m~>
+rjICX\c2Z:JcFR+!0lC@rjI=~>
+rjICX\c2YKJcFR+!$0tsrjI=~>
+rk<s`\c2ZgJcFR+!$0tsrk<m~>
+rjICX\c2Z:JcFR+!0lC@rjI=~>
+rjICX\c2YKJcFR+!$0tsrjI=~>
+rk<s`\c2ZgJcFR+!$0tsrk<m~>
+rjICX\c2Z:JcFR+!0lC@rjI=~>
+rjICX\c2YKJcFR+!$0tsrjI=~>
+rk<s`\c2ZgJcFR+!$0tsrk<m~>
+rjICX\c2Z:JcFR+!0lC@rjI=~>
+rjICX\c2YKJcFR+!$0tsrjI=~>
+rk<s`\c2ZgJcFR+!$0tsrk<m~>
+rjICX\c2Z:JcFR+!0lC@rjI=~>
+rjICX\c2YKJcFR+!$0tsrjI=~>
+rk<s`\c2ZgJcFU,!$0qrrk<m~>
+rjICX\c2Z:JcFU,!0l@?rjI=~>
+rjICX\c2YKJcFU,!$0qrrjI=~>
+rk<s`\c2ZgJcFU,!$0qrrk<m~>
+rjICX\c2Z:JcFU,!0l@?rjI=~>
+rjICX\c2YKJcFU,!$0qrrjI=~>
+rk<s`\c2ZgJcFU,!?Jr4s8K`_~>
+rjICX\c2Z:JcFU,!L,=rs8KHW~>
+rjICX\c2YKJcFU,!?EoPs8KHW~>
+rk<s`\c2ZgJcFU,s1dIkrk<m~>
+rjICX\c2Z:JcFU,s"WF2rjI=~>
+rjICX\c2YKJcFU,s"WF2rjI=~>
+rk<s`\c2ZgJcFU,!$0qrrk<m~>
+rjICX\c2Z:JcFU,!0l@?rjI=~>
+rjICX\c2YKJcFU,!$0qrrjI=~>
+rk<s`\c2ZgJcFX-!$0nqrk<m~>
+rjICX\c2Z:JcFX-!0l=>rjI=~>
+rjICX\c2YKJcFX-!$0nqrjI=~>
+rk<s`\c2ZgJcFX-!$0nqrk<m~>
+rjICX\c2Z:JcFX-!0l=>rjI=~>
+rjICX\c2YKJcFX-!$0nqrjI=~>
+rk<s`\c2ZgJcFX-!$0nqrk<m~>
+rjICX\c2Z:JcFX-!0l=>rjI=~>
+rjICX\c2YKJcFX-!$0nqrjI=~>
+rk<s`\c2ZgJcFX-!$0nqrk<m~>
+rjICX\c2Z:JcFX-!0l=>rjI=~>
+rjICX\c2YKJcFX-!$0nqrjI=~>
+rk<s`\c2ZgJcFX-!$0nqrk<m~>
+rjICX\c2Z:JcFX-!0l=>rjI=~>
+rjICX\c2YKJcFX-!$0nqrjI=~>
+rk<s`\c2ZgJcFX-!$0nqrk<m~>
+rjICX\c2Z:JcFX-!0l=>rjI=~>
+rjICX\c2YKJcFX-!$0nqrjI=~>
+rk<s`\c2ZgJcF[.!$0kprk<m~>
+rjICX\c2Z:JcF[.!0l:=rjI=~>
+rjICX\c2YKJcF[.!$0kprjI=~>
+rk<s`\c2ZgJcF[.!$0kprk<m~>
+rjICX\c2Z:JcF[.!0l:=rjI=~>
+rjICX\c2YKJcF[.!$0kprjI=~>
+rk<s`\c2ZgJcF[.!$0kprk<m~>
+rjICX\c2Z:JcF[.!0l:=rjI=~>
+rjICX\c2YKJcF[.!$0kprjI=~>
+rk<s`\c2ZgJcF[.!$0kprk<m~>
+rjICX\c2Z:JcF[.!0l:=rjI=~>
+rjICX\c2YKJcF[.!$0kprjI=~>
+rk<s`\c2ZgJcF[.!$0kprk<m~>
+rjICX\c2Z:JcF[.!0l:=rjI=~>
+rjICX\c2YKJcF[.!$0kprjI=~>
+rk<s`\c2ZgJcF^/!$0hork<m~>
+rjICX\c2Z:JcF^/!0l7<rjI=~>
+rjICX\c2YKJcF^/!$0horjI=~>
+rk<s`\c2ZgJcF^/!$0hork<m~>
+rjICX\c2Z:JcF^/!0l7<rjI=~>
+rjICX\c2YKJcF^/!$0horjI=~>
+rk<s`\c2ZgJcF^/!$0hork<m~>
+rjICX\c2Z:JcF^/!0l7<rjI=~>
+rjICX\c2YKJcF^/!$0horjI=~>
+rk<s`\c2ZgJcF^/!$0hork<m~>
+rjICX\c2Z:JcF^/!0l7<rjI=~>
+rjICX\c2YKJcF^/!$0horjI=~>
+rk<s`\c2ZgJcF^/!$0hork<m~>
+rjICX\c2Z:JcF^/!0l7<rjI=~>
+rjICX\c2YKJcF^/!$0horjI=~>
+rk<s`\c2ZgJcFa0!$0enrk<m~>
+rjICX\c2Z:JcFa0!0l4;rjI=~>
+rjICX\c2YKJcFa0!$0enrjI=~>
+rk<s`\c2ZgJcFa0!$0enrk<m~>
+rjICX\c2Z:JcFa0!0l4;rjI=~>
+rjICX\c2YKJcFa0!$0enrjI=~>
+rk<s`\c2ZgJcFa0!$0enrk<m~>
+rjICX\c2Z:JcFa0!0l4;rjI=~>
+rjICX\c2YKJcFa0!$0enrjI=~>
+rk<s`\c2ZgJcFa0!$0enrk<m~>
+rjICX\c2Z:JcFa0!0l4;rjI=~>
+rjICX\c2YKJcFa0!$0enrjI=~>
+rk<s`\c2ZgJcFa0!$0enrk<m~>
+rjICX\c2Z:JcFa0!0l4;rjI=~>
+rjICX\c2YKJcFa0!$0enrjI=~>
+rk<s`\c2ZgJcFa0!$0enrk<m~>
+rjICX\c2Z:JcFa0!0l4;rjI=~>
+rjICX\c2YKJcFa0!$0enrjI=~>
+rk<s`\c2ZgJcFd1!$0bmrk<m~>
+rjICX\c2Z:JcFd1!0l1:rjI=~>
+rjICX\c2YKJcFd1!$0bmrjI=~>
+rk<s`\c2ZgJcFd1!$0bmrk<m~>
+rjICX\c2Z:JcFd1!0l1:rjI=~>
+rjICX\c2YKJcFd1!$0bmrjI=~>
+rk<s`\c2ZgJcFd1!$0bmrk<m~>
+rjICX\c2Z:JcFd1!0l1:rjI=~>
+rjICX\c2YKJcFd1!$0bmrjI=~>
+rk<s`\c2ZgJcFd1!$0bmrk<m~>
+rjICX\c2Z:JcFd1!0l1:rjI=~>
+rjICX\c2YKJcFd1!$0bmrjI=~>
+rk<s`\c2ZgJcFd1!$0bmrk<m~>
+rjICX\c2Z:JcFd1!0l1:rjI=~>
+rjICX\c2YKJcFd1!$0bmrjI=~>
+rk<s`\c2ZgJcFg2!$0_lrk<m~>
+rjICX\c2Z:JcFg2!0l.9rjI=~>
+rjICX\c2YKJcFg2!$0_lrjI=~>
+rk<s`\c2ZgJcFg2!$0_lrk<m~>
+rjICX\c2Z:JcFg2!0l.9rjI=~>
+rjICX\c2YKJcFg2!$0_lrjI=~>
+rk<s`\c2ZgJcFg2!$0_lrk<m~>
+rjICX\c2Z:JcFg2!0l.9rjI=~>
+rjICX\c2YKJcFg2!$0_lrjI=~>
+rk<s`\c2ZgJcFg2!$0_lrk<m~>
+rjICX\c2Z:JcFg2!0l.9rjI=~>
+rjICX\c2YKJcFg2!$0_lrjI=~>
+rk<s`\c2ZgJcFg2!$0_lrk<m~>
+rjICX\c2Z:JcFg2!0l.9rjI=~>
+rjICX\c2YKJcFg2!$0_lrjI=~>
+rk<s`\c2ZgJcFg2!$0_lrk<m~>
+rjICX\c2Z:JcFg2!0l.9rjI=~>
+rjICX\c2YKJcFg2!$0_lrjI=~>
+rk<s`\c2ZgJcFj3!$0\krk<m~>
+rjICX\c2Z:JcFj3!0l+8rjI=~>
+rjICX\c2YKJcFj3!$0\krjI=~>
+rk<s`\c2ZgJcFj3!$0\krk<m~>
+rjICX\c2Z:JcFj3!0l+8rjI=~>
+rjICX\c2YKJcFj3!$0\krjI=~>
+rk<s`\c2ZgJcFj3!?Jr-s8K`_~>
+rjICX\c2Z:JcFj3!L,=ks8KHW~>
+rjICX\c2YKJcFj3!?EoIs8KHW~>
+rk<s`\c2ZgJcFj3s1d4drk<m~>
+rjICX\c2Z:JcFj3s"W1+rjI=~>
+rjICX\c2YKJcFj3s"W1+rjI=~>
+rk<s`\c2ZgJcFj3!$0\krk<m~>
+rjICX\c2Z:JcFj3!0l+8rjI=~>
+rjICX\c2YKJcFj3!$0\krjI=~>
+rk<s`\c2ZgJcFm4!$0Yjrk<m~>
+rjICX\c2Z:JcFm4!0l(7rjI=~>
+rjICX\c2YKJcFm4!$0YjrjI=~>
+rk<s`\c2ZgJcFm4!$0Yjrk<m~>
+rjICX\c2Z:JcFm4!0l(7rjI=~>
+rjICX\c2YKJcFm4!$0YjrjI=~>
+rk<s`\c2ZgJcFm4!$0Yjrk<m~>
+rjICX\c2Z:JcFm4!0l(7rjI=~>
+rjICX\c2YKJcFm4!$0YjrjI=~>
+rk<s`\c2ZgJcFm4!$0Yjrk<m~>
+rjICX\c2Z:JcFm4!0l(7rjI=~>
+rjICX\c2YKJcFm4!$0YjrjI=~>
+rk<s`\c2ZgJcFp5!$0Virk<m~>
+rjICX\c2Z:JcFp5!0l%6rjI=~>
+rjICX\c2YKJcFp5!$0VirjI=~>
+rk<s`\c2ZgJcFp5!$0Virk<m~>
+rjICX\c2Z:JcFp5!0l%6rjI=~>
+rjICX\c2YKJcFp5!$0VirjI=~>
+rk<s`\c2ZgJcFp5!$0Virk<m~>
+rjICX\c2Z:JcFp5!0l%6rjI=~>
+rjICX\c2YKJcFp5!$0VirjI=~>
+rk<s`\c2ZgJcFp5!$0Virk<m~>
+rjICX\c2Z:JcFp5!0l%6rjI=~>
+rjICX\c2YKJcFp5!$0VirjI=~>
+rk<s`\c2ZgJcFs6!$0Shrk<m~>
+rjICX\c2Z:JcFs6!0l"5rjI=~>
+rjICX\c2YKJcFs6!$0ShrjI=~>
+rk<s`\c2ZgJcFs6!$0Shrk<m~>
+rjICX\c2Z:JcFs6!0l"5rjI=~>
+rjICX\c2YKJcFs6!$0ShrjI=~>
+rk<s`\c2ZgJcFs6!$0Shrk<m~>
+rjICX\c2Z:JcFs6!0l"5rjI=~>
+rjICX\c2YKJcFs6!$0ShrjI=~>
+rk<s`\c2ZgJcFs6!$0Shrk<m~>
+rjICX\c2Z:JcFs6!0l"5rjI=~>
+rjICX\c2YKJcFs6!$0ShrjI=~>
+rk<s`\c2ZgJcG!7!$0Pgrk<m~>
+rjICX\c2Z:JcG!7!0kt4rjI=~>
+rjICX\c2YKJcG!7!$0PgrjI=~>
+rk<s`\c2ZgJcG!7!$0Pgrk<m~>
+rjICX\c2Z:JcG!7!0kt4rjI=~>
+rjICX\c2YKJcG!7!$0PgrjI=~>
+rk<s`\c2ZgJcG!7!$0Pgrk<m~>
+rjICX\c2Z:JcG!7!0kt4rjI=~>
+rjICX\c2YKJcG!7!$0PgrjI=~>
+rk<s`\c2ZgJcG!7!$0Pgrk<m~>
+rjICX\c2Z:JcG!7!0kt4rjI=~>
+rjICX\c2YKJcG!7!$0PgrjI=~>
+rk<s`\c2ZgJcG$8!$0Mfrk<m~>
+rjICX\c2Z:JcG$8!0kq3rjI=~>
+rjICX\c2YKJcG$8!$0MfrjI=~>
+rk<s`\c2ZgJcG$8!$0Mfrk<m~>
+rjICX\c2Z:JcG$8!0kq3rjI=~>
+rjICX\c2YKJcG$8!$0MfrjI=~>
+rk<s`\c2ZgJcG$8!$0Mfrk<m~>
+rjICX\c2Z:JcG$8!0kq3rjI=~>
+rjICX\c2YKJcG$8!$0MfrjI=~>
+rk<s`\c2ZgJcG$8!$0Mfrk<m~>
+rjICX\c2Z:JcG$8!0kq3rjI=~>
+rjICX\c2YKJcG$8!$0MfrjI=~>
+rk<s`\c2ZgJcG'9!$0Jerk<m~>
+rjICX\c2Z:JcG'9!0kn2rjI=~>
+rjICX\c2YKJcG'9!$0JerjI=~>
+rk<s`\c2ZgJcG'9!$0Jerk<m~>
+rjICX\c2Z:JcG'9!0kn2rjI=~>
+rjICX\c2YKJcG'9!$0JerjI=~>
+rk<s`\c2ZgJcG'9!$0Jerk<m~>
+rjICX\c2Z:JcG'9!0kn2rjI=~>
+rjICX\c2YKJcG'9!$0JerjI=~>
+rk<s`\c2ZgJcG'9!$0Jerk<m~>
+rjICX\c2Z:JcG'9!0kn2rjI=~>
+rjICX\c2YKJcG'9!$0JerjI=~>
+rk<s`\c2ZgJcG*:!$0Gdrk<m~>
+rjICX\c2Z:JcG*:!0kk1rjI=~>
+rjICX\c2YKJcG*:!$0GdrjI=~>
+rk<s`\c2ZgJcG*:!$0Gdrk<m~>
+rjICX\c2Z:JcG*:!0kk1rjI=~>
+rjICX\c2YKJcG*:!$0GdrjI=~>
+rk<s`\c2ZgJcG*:!$0Gdrk<m~>
+rjICX\c2Z:JcG*:!0kk1rjI=~>
+rjICX\c2YKJcG*:!$0GdrjI=~>
+rk<s`\c2ZgJcG*:!$0Gdrk<m~>
+rjICX\c2Z:JcG*:!0kk1rjI=~>
+rjICX\c2YKJcG*:!$0GdrjI=~>
+rk<s`\c2ZgJcG-;!$0Dcrk<m~>
+rjICX\c2Z:JcG-;!0kh0rjI=~>
+rjICX\c2YKJcG-;!$0DcrjI=~>
+rk<s`\c2ZgJcG-;!$0Dcrk<m~>
+rjICX\c2Z:JcG-;!0kh0rjI=~>
+rjICX\c2YKJcG-;!$0DcrjI=~>
+rk<s`\c2ZgJcG-;!?Jr%s8K`_~>
+rjICX\c2Z:JcG-;!L,=cs8KHW~>
+rjICX\c2YKJcG-;!?EoAs8KHW~>
+rk<s`\c2ZgJcG-;s1cq\rk<m~>
+rjICX\c2Z:JcG-;s"Vn#rjI=~>
+rjICX\c2YKJcG-;s"Vn#rjI=~>
+rk<s`\c2ZgJcG-;!$0Dcrk<m~>
+rjICX\c2Z:JcG-;!0kh0rjI=~>
+rjICX\c2YKJcG-;!$0DcrjI=~>
+rk<s`\c2ZgJcG0<!$0Abrk<m~>
+rjICX\c2Z:JcG0<!0ke/rjI=~>
+rjICX\c2YKJcG0<!$0AbrjI=~>
+rk<s`\c2ZgJcG0<!$0Abrk<m~>
+rjICX\c2Z:JcG0<!0ke/rjI=~>
+rjICX\c2YKJcG0<!$0AbrjI=~>
+rk<s`\c2ZgJcG0<!$0Abrk<m~>
+rjICX\c2Z:JcG0<!0ke/rjI=~>
+rjICX\c2YKJcG0<!$0AbrjI=~>
+rk<s`\c2ZgJcG0<!$0Abrk<m~>
+rjICX\c2Z:JcG0<!0ke/rjI=~>
+rjICX\c2YKJcG0<!$0AbrjI=~>
+rk<s`\c2ZgJcG3=!$0>ark<m~>
+rjICX\c2Z:JcG3=!0kb.rjI=~>
+rjICX\c2YKJcG3=!$0>arjI=~>
+rk<s`\c2ZgJcG3=!$0>ark<m~>
+rjICX\c2Z:JcG3=!0kb.rjI=~>
+rjICX\c2YKJcG3=!$0>arjI=~>
+rk<s`\c2ZgJcG3=!$0>ark<m~>
+rjICX\c2Z:JcG3=!0kb.rjI=~>
+rjICX\c2YKJcG3=!$0>arjI=~>
+rk<s`\c2ZgJcG3=!$0>ark<m~>
+rjICX\c2Z:JcG3=!0kb.rjI=~>
+rjICX\c2YKJcG3=!$0>arjI=~>
+rk<s`\c2ZgJcG6>!$0;`rk<m~>
+rjICX\c2Z:JcG6>!0k_-rjI=~>
+rjICX\c2YKJcG6>!$0;`rjI=~>
+rk<s`\c2ZgJcG6>!$0;`rk<m~>
+rjICX\c2Z:JcG6>!0k_-rjI=~>
+rjICX\c2YKJcG6>!$0;`rjI=~>
+rk<s`\c2ZgJcG6>!$0;`rk<m~>
+rjICX\c2Z:JcG6>!0k_-rjI=~>
+rjICX\c2YKJcG6>!$0;`rjI=~>
+rk<s`\c2ZgJcG6>!$0;`rk<m~>
+rjICX\c2Z:JcG6>!0k_-rjI=~>
+rjICX\c2YKJcG6>!$0;`rjI=~>
+rk<s`\c2ZgJcG9?!$08_rk<m~>
+rjICX\c2Z:JcG9?!0k\,rjI=~>
+rjICX\c2YKJcG9?!$08_rjI=~>
+rk<s`\c2ZgJcG9?!$08_rk<m~>
+rjICX\c2Z:JcG9?!0k\,rjI=~>
+rjICX\c2YKJcG9?!$08_rjI=~>
+rk<s`\c2ZgJcG9?!$08_rk<m~>
+rjICX\c2Z:JcG9?!0k\,rjI=~>
+rjICX\c2YKJcG9?!$08_rjI=~>
+rk<s`\c2ZgJcG9?!$08_rk<m~>
+rjICX\c2Z:JcG9?!0k\,rjI=~>
+rjICX\c2YKJcG9?!$08_rjI=~>
+rk<s`\c2ZgJcG9?!$08_rk<m~>
+rjICX\c2Z:JcG9?!0k\,rjI=~>
+rjICX\c2YKJcG9?!$08_rjI=~>
+rk<s`\c2ZgJcG<@!$05^rk<m~>
+rjICX\c2Z:JcG<@!0kY+rjI=~>
+rjICX\c2YKJcG<@!$05^rjI=~>
+rk<s`\c2ZgJcG<@!$05^rk<m~>
+rjICX\c2Z:JcG<@!0kY+rjI=~>
+rjICX\c2YKJcG<@!$05^rjI=~>
+rk<s`\c2ZgJcG<@!$05^rk<m~>
+rjICX\c2Z:JcG<@!0kY+rjI=~>
+rjICX\c2YKJcG<@!$05^rjI=~>
+rk<s`\c2ZgJcG<@!$05^rk<m~>
+rjICX\c2Z:JcG<@!0kY+rjI=~>
+rjICX\c2YKJcG<@!$05^rjI=~>
+rk<s`\c2ZgJcG?A!$02]rk<m~>
+rjICX\c2Z:JcG?A!0kV*rjI=~>
+rjICX\c2YKJcG?A!$02]rjI=~>
+rk<s`\c2ZgJcG?A!$02]rk<m~>
+rjICX\c2Z:JcG?A!0kV*rjI=~>
+rjICX\c2YKJcG?A!$02]rjI=~>
+rk<s`\c2ZgJcG?A!$02]rk<m~>
+rjICX\c2Z:JcG?A!0kV*rjI=~>
+rjICX\c2YKJcG?A!$02]rjI=~>
+rk<s`\c2ZgJcG?A!$02]rk<m~>
+rjICX\c2Z:JcG?A!0kV*rjI=~>
+rjICX\c2YKJcG?A!$02]rjI=~>
+rk<s`\c2ZgJcGBB!$0/\rk<m~>
+rjICX\c2Z:JcGBB!0kS)rjI=~>
+rjICX\c2YKJcGBB!$0/\rjI=~>
+rk<s`\c2ZgJcGBB!$0/\rk<m~>
+rjICX\c2Z:JcGBB!0kS)rjI=~>
+rjICX\c2YKJcGBB!$0/\rjI=~>
+rk<s`\c2ZgJcGBB!?Jqss8K`_~>
+rjICX\c2Z:JcGBB!L,=\s8KHW~>
+rjICX\c2YKJcGBB!?Eo:s8KHW~>
+rk<s`\c2ZgJcGBBs1c\Urk<m~>
+rjICX\c2Z:JcGBBs"VXqrjI=~>
+rjICX\c2YKJcGBBs"VXqrjI=~>
+rk<s`\c2ZgJcGEC!$0,[rk<m~>
+rjICX\c2Z:JcGEC!0kP(rjI=~>
+rjICX\c2YKJcGEC!$0,[rjI=~>
+rk<s`\c2ZgJcGEC!$0,[rk<m~>
+rjICX\c2Z:JcGEC!0kP(rjI=~>
+rjICX\c2YKJcGEC!$0,[rjI=~>
+rk<s`\c2ZgJcGEC!$0,[rk<m~>
+rjICX\c2Z:JcGEC!0kP(rjI=~>
+rjICX\c2YKJcGEC!$0,[rjI=~>
+rk<s`\c2ZgJcGHD!$0)Zrk<m~>
+rjICX\c2Z:JcGHD!0kM'rjI=~>
+rjICX\c2YKJcGHD!$0)ZrjI=~>
+rk<s`\c2ZgJcGHD!$0)Zrk<m~>
+rjICX\c2Z:JcGHD!0kM'rjI=~>
+rjICX\c2YKJcGHD!$0)ZrjI=~>
+rk<s`\c2ZgJcGHD!$0)Zrk<m~>
+rjICX\c2Z:JcGHD!0kM'rjI=~>
+rjICX\c2YKJcGHD!$0)ZrjI=~>
+rk<s`\c2ZgJcGKE!$0&Yrk<m~>
+rjICX\c2Z:JcGKE!0kJ&rjI=~>
+rjICX\c2YKJcGKE!$0&YrjI=~>
+rk<s`\c2ZgJcGKE!$0&Yrk<m~>
+rjICX\c2Z:JcGKE!0kJ&rjI=~>
+rjICX\c2YKJcGKE!$0&YrjI=~>
+rk<s`\c2ZgJcGKE!$0&Yrk<m~>
+rjICX\c2Z:JcGKE!0kJ&rjI=~>
+rjICX\c2YKJcGKE!$0&YrjI=~>
+rk<s`\c2ZgJcGNF!$0#Xrk<m~>
+rjICX\c2Z:JcGNF!0kG%rjI=~>
+rjICX\c2YKJcGNF!$0#XrjI=~>
+rk<s`\c2ZgJcGNF!$0#Xrk<m~>
+rjICX\c2Z:JcGNF!0kG%rjI=~>
+rjICX\c2YKJcGNF!$0#XrjI=~>
+rk<s`\c2ZgJcGNF!$0#Xrk<m~>
+rjICX\c2Z:JcGNF!0kG%rjI=~>
+rjICX\c2YKJcGNF!$0#XrjI=~>
+rk<s`\c2ZgJcGNF!$0#Xrk<m~>
+rjICX\c2Z:JcGNF!0kG%rjI=~>
+rjICX\c2YKJcGNF!$0#XrjI=~>
+rk<s`\c2ZgJcGQG!$/uWrk<m~>
+rjICX\c2Z:JcGQG!0kD$rjI=~>
+rjICX\c2YKJcGQG!$/uWrjI=~>
+rk<s`\c2ZgJcGQG!$/uWrk<m~>
+rjICX\c2Z:JcGQG!0kD$rjI=~>
+rjICX\c2YKJcGQG!$/uWrjI=~>
+rk<s`\c2ZgJcGQG!$/uWrk<m~>
+rjICX\c2Z:JcGQG!0kD$rjI=~>
+rjICX\c2YKJcGQG!$/uWrjI=~>
+rk<s`\c2ZgJcGTH!$/rVrk<m~>
+rjICX\c2Z:JcGTH!0kA#rjI=~>
+rjICX\c2YKJcGTH!$/rVrjI=~>
+rk<s`\c2ZgJcGTH!$/rVrk<m~>
+rjICX\c2Z:JcGTH!0kA#rjI=~>
+rjICX\c2YKJcGTH!$/rVrjI=~>
+rk<s`\c2ZgJcGTH!$/rVrk<m~>
+rjICX\c2Z:JcGTH!0kA#rjI=~>
+rjICX\c2YKJcGTH!$/rVrjI=~>
+rk<s`\c2ZgJcGWI!$/oUrk<m~>
+rjICX\c2Z:JcGWI!0k>"rjI=~>
+rjICX\c2YKJcGWI!$/oUrjI=~>
+rk<s`\c2ZgJcGWI!$/oUrk<m~>
+rjICX\c2Z:JcGWI!0k>"rjI=~>
+rjICX\c2YKJcGWI!$/oUrjI=~>
+rk<s`\c2ZgJcGWI!$/oUrk<m~>
+rjICX\c2Z:JcGWI!0k>"rjI=~>
+rjICX\c2YKJcGWI!$/oUrjI=~>
+rk<s`\c2ZgJcGZJ!$/lTrk<m~>
+rjICX\c2Z:JcGZJ!0k;!rjI=~>
+rjICX\c2YKJcGZJ!$/lTrjI=~>
+rk<s`\c2ZgJcGZJ!?Jqks8K`_~>
+rjICX\c2Z:JcGZJ!L,=Ts8KHW~>
+rjICX\c2YKJcGZJ!?Eo2s8KHW~>
+rk<s`\c2ZgJcGZJs1cDMrk<m~>
+rjICX\c2Z:JcGZJs"V@irjI=~>
+rjICX\c2YKJcGZJs"V@irjI=~>
+rk<s`\c2ZgJcG]K!$/iSrk<m~>
+rjICX\c2Z:JcG]K!0k7urjI=~>
+rjICX\c2YKJcG]K!$/iSrjI=~>
+rk<s`\c2ZgJcG]K!$/iSrk<m~>
+rjICX\c2Z:JcG]K!0k7urjI=~>
+rjICX\c2YKJcG]K!$/iSrjI=~>
+rk<s`\c2ZgJcG]K!$/iSrk<m~>
+rjICX\c2Z:JcG]K!0k7urjI=~>
+rjICX\c2YKJcG]K!$/iSrjI=~>
+rk<s`\c2ZgJcG`L!$/fRrk<m~>
+rjICX\c2Z:JcG`L!0k4trjI=~>
+rjICX\c2YKJcG`L!$/fRrjI=~>
+rk<s`\c2ZgJcG`L!$/fRrk<m~>
+rjICX\c2Z:JcG`L!0k4trjI=~>
+rjICX\c2YKJcG`L!$/fRrjI=~>
+rk<s`\c2ZgJcG`L!$/fRrk<m~>
+rjICX\c2Z:JcG`L!0k4trjI=~>
+rjICX\c2YKJcG`L!$/fRrjI=~>
+rk<s`\c2ZgJcG`L!$/fRrk<m~>
+rjICX\c2Z:JcG`L!0k4trjI=~>
+rjICX\c2YKJcG`L!$/fRrjI=~>
+rk<s`\c2ZgJcGcM!$/cQrk<m~>
+rjICX\c2Z:JcGcM!0k1srjI=~>
+rjICX\c2YKJcGcM!$/cQrjI=~>
+rk<s`\c2ZgJcGcM!$/cQrk<m~>
+rjICX\c2Z:JcGcM!0k1srjI=~>
+rjICX\c2YKJcGcM!$/cQrjI=~>
+rk<s`\c2ZgJcGcM!$/cQrk<m~>
+rjICX\c2Z:JcGcM!0k1srjI=~>
+rjICX\c2YKJcGcM!$/cQrjI=~>
+rk<s`\c2ZgJc>cN*PDFO^46~>
+rjICX\c2Z:Jc>cNPe@%q[X\~>
+rjICX\c2YKJc>cN*PDFO[X\~>
+rk<s`\c2ZgJc>cN*PDFO^46~>
+rjICX\c2Z:Jc>cNPe@%q[X\~>
+rjICX\c2YKJc>cN*PDFO[X\~>
+rk<s`\c2ZgJc>cN*PDFO^46~>
+rjICX\c2Z:Jc>cNPe@%q[X\~>
+rjICX\c2YKJc>cN*PDFO[X\~>
+rk<s`\c2ZgJc>]j]DqlEJ,~>
+rjICX\c2Z:Jc>_7]Dql=J,~>
+rjICX\c2YKJc>]j]Dql=J,~>
+rk<s`\c2ZgJc>]j]DqlEJ,~>
+rjICX\c2Z:Jc>_7]Dql=J,~>
+rjICX\c2YKJc>]j]Dql=J,~>
+rk<s`\c2ZgJc>]j]DqlEJ,~>
+rjICX\c2Z:Jc>_7]Dql=J,~>
+rjICX\c2YKJc>]j]Dql=J,~>
+rk<s`\c2ZgJc>]j]DqlEJ,~>
+rjICX\c2Z:Jc>_7]Dql=J,~>
+rjICX\c2YKJc>]j]Dql=J,~>
+rk<s`\c2ZgK)Yfk])VcDJ,~>
+rjICX\c2Z:K)Yh8])Vc<J,~>
+rjICX\c2YKK)Yfk])Vc<J,~>
+rk<s`\c2ZgK)Yfk])VcDJ,~>
+rjICX\c2Z:K)Yh8])Vc<J,~>
+rjICX\c2YKK)Yfk])Vc<J,~>
+rk<s`\c2ZgK)Yfk])VcDJ,~>
+rjICX\c2Z:K)Yh8])Vc<J,~>
+rjICX\c2YKK)Yfk])Vc<J,~>
+rk<s`\c2ZgKDtol\c;ZCJ,~>
+rjICX\c2Z:KDtq9\c;Z;J,~>
+rjICX\c2YKKDtol\c;Z;J,~>
+rk<s`\c2ZgKDtrm^UjIE^46~>
+rjICX\c2Z:KDtt:0tRDa[X\~>
+rjICX\c2YKKDtrm0tRDa[X\~>
+rk<s`\c2ZgKE(td])VcDJ,~>
+rjICX\c2Z:KE(s+])Vc<J,~>
+rjICX\c2YKKE(s+])Vc<J,~>
+rk<s`\c2ZgK`;#m\GuQBJ,~>
+rjICX\c2Z:K`;%:\GuQ:J,~>
+rjICX\c2YKK`;#m\GuQ:J,~>
+rk<s`\c2ZgK`;#m\GuQBJ,~>
+rjICX\c2Z:K`;%:\GuQ:J,~>
+rjICX\c2YKK`;#m\GuQ:J,~>
+rk<s`\c2ZgK`;#m\GuQBJ,~>
+rjICX\c2Z:K`;%:\GuQ:J,~>
+rjICX\c2YKK`;#m\GuQ:J,~>
+rk<s`\c2ZgL&V,n\,ZHAJ,~>
+rjICX\c2Z:L&V.;\,ZH9J,~>
+rjICX\c2YKL&V,n\,ZH9J,~>
+rk<s`\c2ZgL&V,n\,ZHAJ,~>
+rjICX\c2Z:L&V.;\,ZH9J,~>
+rjICX\c2YKL&V,n\,ZH9J,~>
+rk<s`\c2ZgLAq5o[f??@J,~>
+rjICX\c2Z:LAq7<[f??8J,~>
+rjICX\c2YKLAq5o[f??8J,~>
+rk<s`\c2ZgLAq5o[f??@J,~>
+rjICX\c2Z:LAq7<[f??8J,~>
+rjICX\c2YKLAq5o[f??8J,~>
+rk<s`\c2ZgLAq5o[f??@J,~>
+rjICX\c2Z:LAq7<[f??8J,~>
+rjICX\c2YKLAq5o[f??8J,~>
+rk<s`\c2ZgL]7>p[K$6?J,~>
+rjICX\c2Z:L]7@=[K$67J,~>
+rjICX\c2YKL]7>p[K$67J,~>
+rk<s`\c2ZgL]7>p[K$6?J,~>
+rjICX\c2Z:L]7@=[K$67J,~>
+rjICX\c2YKL]7>p[K$67J,~>
+rk<s`\c2ZgL]7>p[K$6?J,~>
+rjICX\c2Z:L]7@=[K$67J,~>
+rjICX\c2YKL]7>p[K$67J,~>
+rk<s`\c2ZgM#RGq[/^->J,~>
+rjICX\c2Z:M#RI>[/^-6J,~>
+rjICX\c2YKM#RGq[/^-6J,~>
+rk<s`\c2ZgM#RGq[/^->J,~>
+rjICX\c2Z:M#RI>[/^-6J,~>
+rjICX\c2YKM#RGq[/^-6J,~>
+rk<s`\c2ZgM>mPrZiC$=J,~>
+rjICX\c2Z:M>mR?ZiC$5J,~>
+rjICX\c2YKM>mPrZiC$5J,~>
+rk<s`\c2ZgM>mPrZiC$=J,~>
+rjICX\c2Z:M>mR?ZiC$5J,~>
+rjICX\c2YKM>mPrZiC$5J,~>
+rk<s`\c2ZgM>mPrZiC$=J,~>
+rjICX\c2Z:M>mR?ZiC$5J,~>
+rjICX\c2YKM>mPrZiC$5J,~>
+rk<s`\c2ZgMZ3YsZN'p<J,~>
+rjICX\c2Z:MZ3[@ZN'p4J,~>
+rjICX\c2YKMZ3YsZN'p4J,~>
+rk<s`\c2ZgMZ3\t^U*t>^46~>
+rjICX\c2Z:MZ3^A0sgoZ[X\~>
+rjICX\c2YKMZ3\t0sgoZ[X\~>
+rk<s`\c2ZgMZ<^kZiC$=J,~>
+rjICX\c2Z:MZ<]2ZiC$5J,~>
+rjICX\c2YKMZ<]2ZiC$5J,~>
+rk<s`\c2ZgMuNbtZ2ag;J,~>
+rjICX\c2Z:MuNdAZ2ag3J,~>
+rjICX\c2YKMuNbtZ2ag3J,~>
+rk<s`\c2ZgMuNbtZ2ag;J,~>
+rjICX\c2Z:MuNdAZ2ag3J,~>
+rjICX\c2YKMuNbtZ2ag3J,~>
+rk<s`\c2ZgN;ikuYlF^:J,~>
+rjICX\c2Z:N;imBYlF^2J,~>
+rjICX\c2YKN;ikuYlF^2J,~>
+rk<s`\c2ZgN;ikuYlF^:J,~>
+rjICX\c2Z:N;imBYlF^2J,~>
+rjICX\c2YKN;ikuYlF^2J,~>
+rk<s`\c2ZgNW/u!YQ+U9J,~>
+rjICX\c2Z:NW0!CYQ+U1J,~>
+rjICX\c2YKNW/u!YQ+U1J,~>
+rk<s`\c2ZgNW/u!YQ+U9J,~>
+rjICX\c2Z:NW0!CYQ+U1J,~>
+rjICX\c2YKNW/u!YQ+U1J,~>
+rk<s`\c2ZgNrK)"Y5eL8J,~>
+rjICX\c2Z:NrK*DY5eL0J,~>
+rjICX\c2YKNrK)"Y5eL0J,~>
+rk<s`\c2ZgNrK)"Y5eL8J,~>
+rjICX\c2Z:NrK*DY5eL0J,~>
+rjICX\c2YKNrK)"Y5eL0J,~>
+rk<s`\c2ZgO8f2#XoJC7J,~>
+rjICX\c2Z:O8f3EXoJC/J,~>
+rjICX\c2YKO8f2#XoJC/J,~>
+rk<s`\c2ZgO8f2#XoJC7J,~>
+rjICX\c2Z:O8f3EXoJC/J,~>
+rjICX\c2YKO8f2#XoJC/J,~>
+rk<s`\c2ZgOT,;$XT/:6J,~>
+rjICX\c2Z:OT,<FXT/:.J,~>
+rjICX\c2YKOT,;$XT/:.J,~>
+rk<s`\c2ZgOT,;$XT/:6J,~>
+rjICX\c2Z:OT,<FXT/:.J,~>
+rjICX\c2YKOT,;$XT/:.J,~>
+rk<s`\c2ZgOoGD%X8i15J,~>
+rjICX\c2Z:OoGEGX8i1-J,~>
+rjICX\c2YKOoGD%X8i1-J,~>
+rk<s`\c2ZgOoGD%X8i15J,~>
+rjICX\c2Z:OoGEGX8i1-J,~>
+rjICX\c2YKOoGD%X8i1-J,~>
+rk<s`\c2ZgP5bM&WrN(4J,~>
+rjICX\c2Z:P5bNHWrN(,J,~>
+rjICX\c2YKP5bM&WrN(,J,~>
+rk<s`\c2ZgP5bP'^T7D6^46~>
+rjICX\c2Z:P5bQI0rt?R[X\~>
+rjICX\c2YKP5bP'0rt?R[X\~>
+rk<s`\c2ZgPQ(\)^V?iLrk<m~>
+rjICX\c2Z:PQ(]K0eoa/rjI=~>
+rjICX\c2YKPQ(\)0eoa/rjI=~>
+rk<s`\c2ZgPQ(V'WW2t3J,~>
+rjICX\c2Z:PQ(WIWW2t+J,~>
+rjICX\c2YKPQ(V'WW2t+J,~>
+rk<s`\c2ZgPlC_(W;lk2J,~>
+rjICX\c2Z:PlC`JW;lk*J,~>
+rjICX\c2YKPlC_(W;lk*J,~>
+rk<s`\c2ZgPlC_(W;lk2J,~>
+rjICX\c2Z:PlC`JW;lk*J,~>
+rjICX\c2YKPlC_(W;lk*J,~>
+rk<s`\c2ZgQ2^h)VuQb1J,~>
+rjICX\c2Z:Q2^iKVuQb)J,~>
+rjICX\c2YKQ2^h)VuQb)J,~>
+rk<s`\c2ZgQ2^h)VuQb1J,~>
+rjICX\c2Z:Q2^iKVuQb)J,~>
+rjICX\c2YKQ2^h)VuQb)J,~>
+rk<s`\c2ZgQN$q*VZ6Y0J,~>
+rjICX\c2Z:QN$rLVZ6Y(J,~>
+rjICX\c2YKQN$q*VZ6Y(J,~>
+rk<s`\c2ZgQi@%+V>pP/J,~>
+rjICX\c2Z:Qi@&MV>pP'J,~>
+rjICX\c2YKQi@%+V>pP'J,~>
+rk<s`\c2ZgQi@%+V>pP/J,~>
+rjICX\c2Z:Qi@&MV>pP'J,~>
+rjICX\c2YKQi@%+V>pP'J,~>
+rk<s`\c2ZgR/[.,V#UG.J,~>
+rjICX\c2Z:R/[/NV#UG&J,~>
+rjICX\c2YKR/[.,V#UG&J,~>
+rk<s`\c2ZgR/[.,V#UG.J,~>
+rjICX\c2Z:R/[/NV#UG&J,~>
+rjICX\c2YKR/[.,V#UG&J,~>
+rk<s`\c2ZgRK!7-U]:>-J,~>
+rjICX\c2Z:RK!8OU]:>%J,~>
+rjICX\c2YKRK!7-U]:>%J,~>
+rk<s`\c2ZgRK!7-U]:>-J,~>
+rjICX\c2Z:RK!8OU]:>%J,~>
+rjICX\c2YKRK!7-U]:>%J,~>
+rk<s`\c2ZgRf<C/^SCi.^46~>
+rjICX\c2Z:Rf<DQ0r+dJ[X\~>
+rjICX\c2YKRf<C/0r+dJ[X\~>
+rk<s`\c2ZgS,WO1^V?QDrk<m~>
+rjICX\c2Z:S,WPS0eoI'rjI=~>
+rjICX\c2YKS,WO10eoI'rjI=~>
+rk<s`\c2ZgS,WI/U&Y,+J,~>
+rjICX\c2Z:S,WJQU&Y,#J,~>
+rjICX\c2YKS,WI/U&Y,#J,~>
+rk<s`\c2ZgSGrR0T`>#*J,~>
+rjICX\c2Z:SGrSRT`>#"J,~>
+rjICX\c2YKSGrR0T`>#"J,~>
+rk<s`\c2ZgSGrR0T`>#*J,~>
+rjICX\c2Z:SGrSRT`>#"J,~>
+rjICX\c2YKSGrR0T`>#"J,~>
+rk<s`\c2ZgSc8[1TE"o)J,~>
+rjICX\c2Z:Sc8\STE"o!J,~>
+rjICX\c2YKSc8[1TE"o!J,~>
+rk<s`\c2ZgT)Sd2T)\f(J,~>
+rjICX\c2Z:T)SeTT)\euJ,~>
+rjICX\c2YKT)Sd2T)\euJ,~>
+rk<s`\c2ZgT)Sd2T)\f(J,~>
+rjICX\c2Z:T)SeTT)\euJ,~>
+rjICX\c2YKT)Sd2T)\euJ,~>
+rk<s`\c2ZgTDnm3ScA]'J,~>
+rjICX\c2Z:TDnnUScA\tJ,~>
+rjICX\c2YKTDnm3ScA\tJ,~>
+rk<s`\c2ZgTDnm3ScA]'J,~>
+rjICX\c2Z:TDnnUScA\tJ,~>
+rjICX\c2YKTDnm3ScA\tJ,~>
+rk<s`\c2ZgT`5!4SH&T&J,~>
+rjICX\c2Z:T`5"VSH&SsJ,~>
+rjICX\c2YKT`5!4SH&SsJ,~>
+rk<s`\c2ZgT`5!4SH&T&J,~>
+rjICX\c2Z:T`5"VSH&SsJ,~>
+rjICX\c2YKT`5!4SH&SsJ,~>
+rk<s`\c2ZgU&P-6^RY?'^46~>
+rjICX\c2Z:U&P.X0qA:C[X\~>
+rjICX\c2YKU&P-60qA:C[X\~>
+rk<s`\c2ZgUAk98^V?<=rk<m~>
+rjICX\c2Z:UAk:Z0eo3urjI=~>
+rjICX\c2YKUAk980eo3urjI=~>
+rk<s`\c2ZgU]1<7RK*9#J,~>
+rjICX\c2Z:U]1=YRK*8pJ,~>
+rjICX\c2YKU]1<7RK*8pJ,~>
+rk<s`\c2ZgU]1<7RK*9#J,~>
+rjICX\c2Z:U]1=YRK*8pJ,~>
+rjICX\c2YKU]1<7RK*8pJ,~>
+rk<s`\c2ZgV#LE8R/d0"J,~>
+rjICX\c2Z:V#LFZR/d/oJ,~>
+rjICX\c2YKV#LE8R/d/oJ,~>
+rk<s`\c2ZgV>gN9QiI'!J,~>
+rjICX\c2Z:V>gO[QiI&nJ,~>
+rjICX\c2YKV>gN9QiI&nJ,~>
+rk<s`\c2ZgVZ-W:QN-ruJ,~>
+rjICX\c2Z:VZ-X\QN-rmJ,~>
+rjICX\c2YKVZ-W:QN-rmJ,~>
+rk<s`\c2ZgVuH`;Q2gitJ,~>
+rjICX\c2Z:VuHa]Q2gilJ,~>
+rjICX\c2YKVuH`;Q2gilJ,~>
+rk<s`\c2ZgVuH`;Q2gitJ,~>
+rjICX\c2Z:VuHa]Q2gilJ,~>
+rjICX\c2YKVuH`;Q2gilJ,~>
+rk<s`\c2ZgW;ci<PlL`sJ,~>
+rjICX\c2Z:W;cj^PlL`kJ,~>
+rjICX\c2YKW;ci<PlL`kJ,~>
+rk<s`\c2ZgWW)u>^Qect^46~>
+rjICX\c2Z:WW*!`0pM_;[X\~>
+rjICX\c2YKWW)u>0pM_;[X\~>
+rk<s`\c2ZgWrE,@^V?$5rk<m~>
+rjICX\c2Z:WrE-b0enpmrjI=~>
+rjICX\c2YKWrE,@0enpmrjI=~>
+rk<s`\c2ZgX8`/?OoPEpJ,~>
+rjICX\c2Z:X8`0aOoPEhJ,~>
+rjICX\c2YKX8`/?OoPEhJ,~>
+rk<s`\c2ZgXT&8@OT5<oJ,~>
+rjICX\c2Z:XT&9bOT5<gJ,~>
+rjICX\c2YKXT&8@OT5<gJ,~>
+rk<s`\c2ZgXoAAAO8o3nJ,~>
+rjICX\c2Z:XoABcO8o3fJ,~>
+rjICX\c2YKXoAAAO8o3fJ,~>
+rk<s`\c2ZgXoAAAO8o3nJ,~>
+rjICX\c2Z:XoABcO8o3fJ,~>
+rjICX\c2YKXoAAAO8o3fJ,~>
+rk<s`\c2ZgY5\JBNrT*mJ,~>
+rjICX\c2Z:Y5\KdNrT*eJ,~>
+rjICX\c2YKY5\JBNrT*eJ,~>
+rk<s`\c2ZgYQ"SCNW9!lJ,~>
+rjICX\c2Z:YQ"TeNW9!dJ,~>
+rjICX\c2YKYQ"SCNW9!dJ,~>
+rk<s`\c2ZgYl=_E^Q&9m^46~>
+rjICX\c2Z:Yl=`g0oc54[X\~>
+rjICX\c2YKYl=_E0oc54[X\~>
+rk<s`\c2ZgZN'qFs1aQnrk<m~>
+rjICX\c2Z:ZN'rhs"TN5rjI=~>
+rjICX\c2YKZN'qFs"TN5rjI=~>
+rk<s`\c2ZgZi:"GM?!RhJ,~>
+rjICX\c2Z:Zi:#iM?!R`J,~>
+rjICX\c2YKZi:"GM?!R`J,~>
+rk<s`\c2Zg[/U+HM#[IgJ,~>
+rjICX\c2Z:[/U,jM#[I_J,~>
+rjICX\c2YK[/U+HM#[I_J,~>
+rk<s`\c2Zg[f?@JL]@@fJ,~>
+rjICX\c2Z:[f?AlL]@@^J,~>
+rjICX\c2YK[f?@JL]@@^J,~>
+rk<s`\c2Zg\,QFKL&_.dJ,~>
+rjICX\c2Z:\,QGmL&_.\J,~>
+rjICX\c2YK\,QFKL&_.\J,~>
+rk<s`\c2Zg\GlRM^P2^e^46~>
+rjICX\c2Z:\GlSo0noZ,[X\~>
+rjICX\c2YK\GlRM0noZ,[X\~>
+rk<s`\c2Zg])VdNs1a9frk<m~>
+rjICX\c2Z:])Veps"T6-rjI=~>
+rjICX\c2YK])VdNs"T6-rjI=~>
+rk<s`\c2Zg]DhjOJcG_`J,~>
+rjICX\c2Z:]DhkqJcG_XJ,~>
+rjICX\c2YK]DhjOJcG_XJ,~>
+rk<s`\c2Zg]`.sPJc>`Mrk<m~>
+rjICX\c2Z:]`.trJc>`MrjI=~>
+rjICX\c2YK]`.sPJc>`MrjI=~>
+rk<s`\c2Zg^An3RJcGcMrk<m~>
+rjICX\c2Z:^An4tJcGcMrjI=~>
+rjICX\c2YK^An3RJcGcMrjI=~>
+rk<s`\c2Zg^]+<T^OcFas8K`_~>
+rjICX\c2Z:^]+>!0nKB(s8KHW~>
+rjICX\c2YK^]+<T0nKB(s8KHW~>
+rk<s`\c2Zg_>jNUs1a-brr;u3J,~>
+rjICX\c2Z:_>jP"s"T*)rr;u+J,~>
+rjICX\c2YK_>jNUs"T*)rr;u+J,~>
+rk<s`\c2Zg_uK`WJcGTHrk<m~>
+rjICX\c2Z:_uKb$JcGTHrjI=~>
+rjICX\c2YK_uK`WJcGTHrjI=~>
+rk<s`\c2Zg`W,rYJcGNFrk<m~>
+rjICX\c2Z:`W,t&JcGNFrjI=~>
+rjICX\c2YK`W,rYJcGNFrjI=~>
+rk<s`\c2Zga8c/[!5F*bp](6,J,~>
+rjICX\c2Z:a8c1(!&9')p](6$J,~>
+rjICX\c2YKa8c/[!&9')p](6$J,~>
+rk<s`\c2Zgb5_G]!rp$MJcGKErk<m~>
+rjICX\c2Z:b5_I*!rju0JcGKErjI=~>
+rjICX\c2YKb5_G]!rju0JcGKErjI=~>
+rk<s`\c2Zgbl@\`JcG9?rk<m~>
+rjICX\c2Z:bl@^-JcG9?rjI=~>
+rjICX\c2YKbl@\`JcG9?rjI=~>
+rk<s`\c2Zgd/X%bJcG3=rk<m~>
+rjICX\c2Z:d/X'/JcG3=rjI=~>
+rjICX\c2YKd/X%bJcG3=rjI=~>
+rk<s`\c2ZgeGoIfs8W,6JcG3=rk<m~>
+rjICX\c2Z:eGoK3s8W*RJcG3=rjI=~>
+rjICX\c2YKeGoIfs8W*RJcG3=rjI=~>
+rk<s`\c2ZgfDkgjJcFp5rk<m~>
+rjICX\c2Z:fDki7JcFp5rjI=~>
+rjICX\c2YKfDkgjJcFp5rjI=~>
+rk<s`\c2Zgg].3m!rp$MJcFp5rk<m~>
+rjICX\c2Z:g].5:!rju0JcFp5rjI=~>
+rjICX\c2YKg].3m!rju0JcFp5rjI=~>
+rk<s`\c2Zgi;`]qJcF[.rk<m~>
+rjICX\c2Z:i;`_>JcF[.rjI=~>
+rjICX\c2YKi;`]qJcF[.rjI=~>
+rk<s`\c2Zgn,Mr!rr<#5JcF[.rk<m~>
+rjICX\c2Z:n,MsCrr<!QJcF[.rjI=~>
+rjICX\c2YKn,Mr!rr<!QJcF[.rjI=~>
+rk@dY!?Jq+iUPmN*WG$t^\d!i^Ob@siVpQA~>
+rjM4$!L,<i[.1NIPlA&i1&J?X0nH^b[/RLa~>
+rjM35!?EnGE:Ink*WC$X1&Gqi0nF;sE;m:r~>
+rk@e"!P]Y+s7lWj*WH*=^\e'2^\n-3^\e'2^\n-3^\e'2^\e'2^OcF-s8K`_~>
+rjM4o!ATgis7lWjPlC^_1&M"N1&V(O1&M"N1&V(O1&M"N1&M"N0nKAIs8KHW~>
+rjM4o!APUGs7lWj*WH*=1&M"N1&V(O1&M"N1&V(O1&M"N1&M"N0nKAIs8KHW~>
+rk@^u!$-Xjq&TJ7s1dCi!9&M/])VcDJ,~>
+rjM.m!0i'7q3:mYs"W@0!47=W])Vc<J,~>
+rjM.m!$-Xjq&TJ7s"W@0!-!Mh])Vc<J,~>
+rk@[truI$tq&TG6s1d.b!9&M/])VcDJ,~>
+rjM+ls-/HAq3:jXs"W+)!47=W])Vc<J,~>
+rjM+lruI$tq&TG6s"W+)!-!Mh])Vc<J,~>
+rk@Ur!$.:'qAoP7s1ckZ!9&M/])VcDJ,~>
+rjM%j!0i]IqNUsYs"Vh!!47=W])Vc<J,~>
+rjM%j!$.:'qAoP7s"Vh!!-!Mh])Vc<J,~>
+rk@Rq!$.L-r#Pe:s1cSR!9&M/])VcDJ,~>
+rjM"i!0ioOr073\s"VOn!47=W])Vc<J,~>
+rjM"i!$.L-r#Pe:s"VOn!-!Mh])Vc<J,~>
+rk@Op!?JqIs8<r>s1c=`rrD#/s1870^46~>
+rjLth!L,=2s8A/`s"Q7CrrBEWs1870[X\~>
+rjLth!?Enes8<r>s"Q7Crr@"hs1870[X\~>
+rk@Op!l#`rV#UB6\GlQfJcE=]rk<m~>
+rjLth!\oq(V#UCX\GlQ9JcE=]rjI=~>
+rjLth!\k]9V#UB6\GlPJJcE=]rjI=~>
+rk@Fm!$/'=r>kq<s1c)D!9&M/])VcDJ,~>
+rjLke!0jJ_rKR?^s"V%`!47=W])Vc<J,~>
+rjLke!$/'=r>kq<s"V%`!-!Mh])Vc<J,~>
+rk@ClruJ?Dr#N$A!9&M/])VcDJ,~>
+rjLhds-0bfr04Gc!47=W])Vc<J,~>
+rjLhdruJ?Dr#N$A!-!Mh])Vc<J,~>
+rk@=jruJWLq]5\9s1bf<!9&M/])VcDJ,~>
+rjLbbs-1%nqiq*[s"UbX!47=W])Vc<J,~>
+rjLbbruJWLq]5\9s"UbX!-!Mh])Vc<J,~>
+rk@7hruJiRr>kq<s1bQ5!9&M/])VcDJ,~>
+rjL\`s-17trKR?^s"UMQ!47=W])Vc<J,~>
+rjL\`ruJiRr>kq<s"UMQ!-!Mh])Vc<J,~>
+rk@7hs1eRS_uK]VU&P,OJcE=]rk<m~>
+rjL\`s"XP<_uK_#U&P,"JcE=]rjI=~>
+rjL\`s"XNo_uK]VU&P+3JcE=]rjI=~>
+rk@+druK5]r>bt>^V?KB!9&M/])VcDJ,~>
+rjLP\s-1Y*rKIB`0eoC%!47=W])Vc<J,~>
+rjLP\ruK5]r>bt>0eoC%!-!Mh])Vc<J,~>
+rk@%brZ0Geq]2.*!9&M/])VcDJ,~>
+rjLJZrfkk2qimQL!47=W])Vc<J,~>
+rjLJZrZ0Geq]2.*!-!Mh])Vc<J,~>
+rk@"as1eLQh#I6lrVuo4Rf<BHJcE=]rk<m~>
+rjLGYs"XJ:h#I89rVumPRf<ApJcE=]rjI=~>
+rjLGYs"XHmh#I6lrVumPRf<A,JcE=]rjI=~>
+rk?e[q]4i!r>kq<s1a`s!9&M/])VcDJ,~>
+rjL5Sqip7CrKR?^s"T]:!47=W])Vc<J,~>
+rjL5Sq]4i!r>kq<s"T]:!-!Mh])Vc<J,~>
+rk?_Ys1eU6qAoD3oc8qi!9&M/])VcDJ,~>
+rjL/Qs"XQRqNUgUoot@6!47=W])Vc<J,~>
+rjL/Qs"XQRqAoD3oc8qi!-!Mh])Vc<J,~>
+rk?JRs1eU6q&TJ7s1eL3s1aHk!9&M/])VcDJ,~>
+rjKoJs"XQRq3:mYs"XHOs"TE2!47=W])Vc<J,~>
+rjKoJs"XQRq&TJ7s"XHOs"TE2!-!Mh])Vc<J,~>
+rk?2Js1a-br;QcUJcE=]rk<m~>
+rjKWBs"T*)r;Qc(JcE=]rjI=~>
+rjKWBs"T*)r;Qb9JcE=]rjI=~>
+rk<s`\c2ZgJcE=]rk<m~>
+rjICX\c2Z:JcE=]rjI=~>
+rjICX\c2YKJcE=]rjI=~>
+rk<s`\c2ZgJcE=]rk<m~>
+rjICX\c2Z:JcE=]rjI=~>
+rjICX\c2YKJcE=]rjI=~>
+rk<s`\c2ZgJcE=]rk<m~>
+rjICX\c2Z:JcE=]rjI=~>
+rjICX\c2YKJcE=]rjI=~>
+rk<s`\c2ZgJcE=]rk<m~>
+rjICX\c2Z:JcE=]rjI=~>
+rjICX\c2YKJcE=]rjI=~>
+rk<s`\c2ZgJcE=]rk<m~>
+rjICX\c2Z:JcE=]rjI=~>
+rjICX\c2YKJcE=]rjI=~>
+rk<s`\c2ZgJcE=]rk<m~>
+rjICX\c2Z:JcE=]rjI=~>
+rjICX\c2YKJcE=]rjI=~>
+rk<s`\c2ZgJcE=]rk<m~>
+rjICX\c2Z:JcE=]rjI=~>
+rjICX\c2YKJcE=]rjI=~>
+J\H]LJ\LHaJ,~>
+J[U-<J[XmQJ,~>
+J[U-<J[XmQJ,~>
+J\H]LJ\LHaJ,~>
+J[U-<J[XmQJ,~>
+J[U-<J[XmQJ,~>
+J\H]LJ\LHaJ,~>
+J[U-<J[XmQJ,~>
+J[U-<J[XmQJ,~>
+%%EndData
+showpage
+%%Trailer
+end
+%%EOF
diff --git a/books/ps/v0plot2.eps b/books/ps/v0plot2.eps
new file mode 100644
index 0000000..85a7728
--- /dev/null
+++ b/books/ps/v0plot2.eps
@@ -0,0 +1,1322 @@
+%!PS-Adobe-3.0 EPSF-3.0
+%%Creator: GIMP PostScript file plugin V 1.17 by Peter Kirchgessner
+%%Title: v0plot2.eps
+%%CreationDate: Thu Mar 19 15:44:35 2009
+%%DocumentData: Clean7Bit
+%%LanguageLevel: 2
+%%Pages: 1
+%%BoundingBox: 14 14 142 146
+%%EndComments
+%%BeginProlog
+% Use own dictionary to avoid conflicts
+10 dict begin
+%%EndProlog
+%%Page: 1 1
+% Translate for offset
+14.173228346456694 14.173228346456694 translate
+% Translate to begin of first scanline
+0 131.17539273108105 translate
+127.10551181102363 -131.17539273108105 scale
+% Image geometry
+406 419 8
+% Transformation matrix
+[ 406 0 0 419 0 0 ]
+% Strings to hold RGB-samples per scanline
+/rstr 406 string def
+/gstr 406 string def
+/bstr 406 string def
+{currentfile /ASCII85Decode filter /RunLengthDecode filter rstr readstring pop}
+{currentfile /ASCII85Decode filter /RunLengthDecode filter gstr readstring pop}
+{currentfile /ASCII85Decode filter /RunLengthDecode filter bstr readstring pop}
+true 3
+%%BeginData:        42824 ASCII Bytes
+colorimage
+r;V<^JJ<YLob@?(J,~>
+r;V=WJRX1>oj[k!J,~>
+r;V>*JVo#9onr\IJ,~>
+rr<!4JH:<&VucHA!!`!H!!`!H!!`E'rtPJ4J,~>
+rr<"-JX:qSW0d(a!/'jO!/'jO!/(9;s'l!-J,~>
+rr<"UJ`hUIW9<aO!6"I.!6"I.!6"m"s,-gUJ,~>
+s8N'5JHCB(V?-`Bo-sbG,P*Ac#:&gi!!iE'!Yk\7J,~>
+s8N(.JWt_MVN_(eo<A=FZh(F&I^AXN!.Oj1!b230J,~>
+s8N(VJ`21=VVqOToCi9us7>sc]`7Tt!5/6g!fI$XJ,~>
+!WNl1"7mXd"+^Qc!rs20-34Dio-OJE)#bie7S+sS-7;/Lr[%UOqZ?j5s*t~>
+!WQX*ORl(qOF`M)O8uKUWr[OMo;_n<YPtR'\@MR=!OfK:WrRJCO9&hjJ,~>
+!WS&Rg[g2OgO\+jgAq9Fn,]oroC)dfs8MNfo)8(Xo)A+Y[/8SYMZ82~>
+!WNl1"TT\<EW@55"nMm"$h=6DqZR%"s![:=$HMo/DZs)>rp$'eJHbWK!"JND!=KA6+p(#d:Ac:I
+$On:(7?`jB+sUW[P<pH;$i:).'`W[~>
+!WQX*N;uTDT)_K7NUr,3OSSpHqi(Z^s./S;$Kh6[]oB;ss7Xp)JW98\!3>^f!HkI?V#mpJ\,<'6
+FfV@8Zd[@;V5:uUe$>gHFo..!@fLr~>
+!WS&ReGtBtcN&`Oeaq;nf)>X'qpbc-s4ctl$MOJskLJSls8;?;J^sAB!<;ZT!NlD!klU5CmJQ2[
+XoIYMm.Br=l07^0o^(i,Xo$WLMZ82~>
+!#555!?cFW1]_V>JHk]M"%rUmFSc7D%Nu/H"q$>BT_f@$s$B?AUk&aA"onbs*rucPq]>lhK7WqB
+&.AX_+$,HuNaH1RCQCCr*t7uM!#0q~>
+!+Pb\!D9!YAHADqJViuT"0)>#^&*WfNL#IiM$h@pdf#60s.u^ee:EJJM#aLGT)ir1qk!r2b/sRR
+&94Y@T<$;QcFUX5^X&mOT5j^a!+LH~>
+!/gTu!Jf"qU]JesJ^<r6"5NqVjSR7)dF?P2cO/pgmJbMis4Z9)m=EUTcN+":iW5nUqr.\Fn*g26
+&>fEdio]asnET<.m-s,rihcLt!/c:~>
+!#556%>b&9f\+p1g"P6:h>`:^#P/0=R-hc-#CYhSe"g"D.L1Iokun<ls0)0jVtc\V#74l>)--\d
+#C#tSJHtfP!!Dg3!=f5/)ZkV5K)?Pr%KdXh**eG9N/VG/>5fH@%f-D1'S$~>
+!+PbY%>t2?gYCQ=h;-rFhuARbL@^-<c1^,TL;3AAlI)d6Q\N<OoWEqMs4I4reGRSfL'b3dO0&AJ
+L;!MBJVNfO!2K.R!H"V/R0(FFa8D>+D57)u#I_gfbKIN@[JlQoD>Jte@Xn~>
+!/gTo%>Fi3eCE(!f%8R-gAckXan*Uml21&BalE6Bp$:?3dE1GHqV0-Gs6fjNm/H8GaU-f'c.`3F
+al36BJ][Q+!;H*>!M9&_gB-^*lhoK<T(i6=#Nb@9mHs*(jo4!7T)-P/MLY~>
+!#557#DiE5g"P-5g]$"1huAL`#kJ<@jKF.4)@Y$Kko!M$.k^jCRIL_ds*fS"H[u,4r!3WDd^'3Z
+s!n@Xs!!""oEYF"o+qE="TB2G7"'TMEKl!%6l-XN"TB2A(g2`-AVsXh(B>$C#QPQh~>
+!+PbU!fI$5rS7\7hr*GOs,)AZo7@qOf"_3BK]hapMlH`@Q2eA<pk5XH^;0c]^]0/gJdR=tfn-4'
+P_,t9O+DoTJcMG7P6#?hrf[bh_Sj^4c,@JtPET[PrK@DjaLAY"Z2KjdB_m;\@Xn~>
+!/gTi%>Fi5f%8L)f\,!4h#E(Z_t1bbq!6l;a2IWEqT%1ebKU"Bk5<0Ks5;l9hr+OTr5/l]o^0QI
+s3&=3s2fi0oYU[uo@*f,nG^oGgumkdjm2*mgsji>nGUi?i9B:^l/;Ni!1*K!!/c:~>
+!#559!f6m2r7hJ3hr*GmLk,p*$62/-E^]q<$>BI"$<R6Z;u\RWs!1\G03A0)<rXTH$4@BXg`-Z&
+s"+S)q@\>doEkR$o+V3;"TB)DKQh9M@Vot+KG5+4"TB)?'j-9%@u",#rY,>Eq?d3:J,~>
+!+PbR!K-pTh?MlqiSrksMLg9LIiOmV[@R?#J$AskJ#E=/V>ld[s,ErVPGeGCVuMhVIg^k`m>6=j
+s,hfBr.BQMoR?k0o8Nc]Rf89T_nERiZadNY_i9XdRf/3LY/R`R`NK0!!+bqU!+LH~>
+!/gTc%>Fi6f\+p1g"Y9:h>`1[^%AuXb5^/>s4+g6s5:T=s2NIdaOC1-df7A9s2NId`VmIX^?tX2
+^!cr#^"iV%J\C]h!9s+"!KQFDbm`^ni8EJMi8WkCc&V&eblunbhVRDLrQP>&qRlldJ,~>
+!#55:%>b&>h;6uEhr!ANiW"^b$hOf,L].5hYnc-?o-[Z?/MR3GS+7+ms".@Q.Tl^#r<it2njOl8
+=T:calDT7Ao*YO%o+1p9"o]&P6@FBGD309r64a\A"V;4W=+t%:Kj]R5&J,Keq?m9;J,~>
+!+PbN%>t2Chr*DMiSieVj8Y!fHh;Xb^A\'JeU[&JpkkmINfX4HanU=\s,NoTN26K4rHemupm[+g
+V#QmUo[&/9o6UJ'o7m?RQMuXJTYA1][`?.sTSJ;0QMuXEX2;'W_QUeTreCJ\qKi3OJ,~>
+!/gT]%>Fi7g"P-5gt^`BhuAC]\+I-0h#76hkdpHVqnLGV_8?6'iVU.1s2!"\^s;tqrO3-qqoHO^
+cMtu/q;m1:o="_Zo>Ufdir6q+dbs*Ggu[MQd`0:^ir6q&fAbKCin<>Brl+qnqR6H^J,~>
+!#55;%>b&?hV[2Ii8N\Tj8Xpd%.jrJe&sd5VtHM9(<*dcs"4_4o]fcl=T:!Us!h.N.fBeSrrsrT
+s8MD\(kE+e$igJ1$ir>,r,W$[2@L!/"oA]0H>7d($kO-W$k+qG?%Z!PJmF'a$k*mI$igul~>
+!+PbK%>t2DiSrhUj5]4^jo:3hGk?5#kMhVdcM>NJIG`YNs,2-5q=CJ.UAp.Gs,!KMM>_\trs"=S
+s8M]8It;k9GQ<p+JH;.Gr3cd9Q[s]lP5Be3]!ApFJIl%KJUs*%X1tL-^8o&6JUq&%GQ;3'~>
+!/gTW%>Fi9gYCQ=h;7&Hi;\L^Z1P:@na=3.j8@g-[-["us1GVgqtSC?aoB#qs1?DQ]D]#5rs$*W
+s8VoR[=PUSYlNPX^B)O2r7V>-b.k]@g\\_egt:E[^CYnL^V@nJeDAU#hULH)^V>9pYlKZ3~>
+!#55<%>b&Ai8NPMi8N\Tj8Xpd%=nu"%0-V3#m#6kr+ZCYE<upf#5\].F`MX&#nRmW#mi>@KM;a[
+:P=HT#mhFE%0.)m~>
+!+PbG%>t2FioB"Wj5]4^jo:3hFFePFF9%="Hi^^ar3-@5Z[@.%NVe))[^<L@Hk9A=I!h'k^7]k%
+U:n='I!f#lF9#d#~>
+!/gTQ%>Fi;h;-i@h;7&Hi;\L^X+@=_WrUZK\,k76r6to%f!r57eGH`Wf@JRO\.Eo7\@BH3grm4;
+bhLpj\@?e[WrS$-~>
+!#55>%>b&Ai8NVQioB([jo:-f%tP8&%fck6#luu*r,r6`2$jR)#Q"f/3ds0g#mM.M#mgtm/H,q[
+$8*q<#mhCD%fd;o~>
+!+PbD%>t2FioB%Yj5f=ak5U<iEIi,@E<(jpHNBA;r3Z^7PC%XYM>MW$Q+E:ZHNmT/H[C.$NrFA0
+I#j>9H[AlkE<'Hu~>
+!/gTK!ep[0rS7\7i8EVSs+Q$#JYfrS!6tMO!Q<OdecjUA[^LM,qmHRFfu<lt#("P&[^X)grO2aB
+rjDfQqP=1LJ,~>
+!#55?!/U=J!/Q1;JIoC(!!i*&!>Yq3$3:nIo*PI5q@EW@J,~>
+!+Pb@!/gIL!/c>EJShu8!/0ri!Et0JH3%3&o6LC?qJ?4AJ,~>
+!/gTE!/:+G!/5urJY0NG!64W<!I_uZ[/k]qo<eRHqO[bFJ,~>
+!#55@o8%r0JJ#I*!!r0'!>Yt4$3:nJo*PI5q@N]AJ,~>
+!+Pb=o88*6JSMc2!.aZd!F(*GGl_-"o6C=?qJ$">J,~>
+!/gT?o7_a`JXO*;!5J-3!J%rVZN5Tko<SFIqO%>@J,~>
+JJ<YLJJ@DaJ,~>
+JRX1>JR[qSJ,~>
+JVo#9JVrcNJ,~>
+rY0q`JcC<$nc/S&J,~>
+!b,YLJcC<$JcG9?s'l%<J,~>
+!fDtsJcC<$JcG9?s,@#9J,~>
+rY0q`JcC<$nc/S&J,~>
+!b,YLJcC<$JcG9?s'l%<J,~>
+!fDtsJcC<$JcG9?s,@#9J,~>
+rY0q`JcC<$nc/S&J,~>
+!b,YLJcC<$JcG9?s'l%<J,~>
+!fDtsJcC<$JcG9?s,@#9J,~>
+rY0q`JcC<$nc/S&J,~>
+!b,YLJcC<$JcG9?s'l%<J,~>
+!fDtsJcC<$JcG9?s,@#9J,~>
+rY0q`JcC<$nc/S&J,~>
+!b,YLJcC<$JcG9?s'l%<J,~>
+!fDtsJcC<$JcG9?s,@#9J,~>
+rY0q`JcC<$nc/S&J,~>
+!b,YLJcC<$JcG9?s'l%<J,~>
+!fDtsJcC<$JcG9?s,@#9J,~>
+rY0q`bl7[Xrr2u5rr3&7s8W)5rr;u4s8N)6rr3&7s8W)5s8W&4JcEsorY0k~>
+!b,YLJcEso!,DN5!,DN5!c%c8rbDH4rbDK5!,DN5!c%c8rbDK5rG$o`bl@]Q!+LH~>
+!fDtsJcEso!&=KQ!&=KQ!\s`Tr\=EPr\=HQ!&=KQ!\s`Tr\=HQr@rm'bl@^&!/c:~>
+rY0q`c2Rs^s1eU6^]+65^]+65^]+65^]+67^]2(JrrTt8^]+6;^]4>Ks8Tibs3:TC'S$~>
+!b,YLJcF!p"`"'Ps8Qj5rr?g5rr?g5rr?g5rrQs8CB"57CB&&Jrs!6<s(_T6C4ZE0s8QR/@Xn~>
+!fDtsJcF!p"Yp$3s8OhQrr=eQrr=eQrr=eQrrOqT1&h1S1&j!-rrt4Xs"XQR0nKALs8S&YMLY~>
+rY0q`cMmmZrr3/:s8Tk6^]"04^]+65^]+6=^]2'`s1c>K^]+6;^]4>Ks8Tibs3:TC'S$~>
+!b,YLJcF$q!,DN5"`");CB&&Irr?g5rr?g5rs3B>C23c`CB&&Jrs!6<s(_T6C4ZE0s8QR/@Xn~>
+!fDtsJcF$q!&=KQ"Yp&W1&j!,rr=eQrr=eQrs1@Z0er\_1&j!-rrt4Xs"XQR0nKALs8S&YMLY~>
+rY0q`cMmmZrr3/:s8Tk6^]"04^]+65^]+6;^]2(K^]2(Hrs$7<s1eU6^OcF0s8E^_~>
+!b,YLJcF$q!,DN5"`");CB&&Irr?g5rr?g5rs!6<CB&&KCAe)9CB+<Ks8Qhbs3:TD@fTtg~>
+!fDtsJcF$q!&=KQ"Yp&W1&j!,rr=eQrr=eQrrt4X1&j!.1&V%U1&q8.s8Og)s3:TDN<"id~>
+rY0q`cMmmZrr2u5rr2u5r;Qc3rr2u5rr32;s1eTKs1eO4!5JO5"2Fm9^OcF0s8E^_~>
+!b,YLJcF$q!,DN5!,DN5!,DH3!,DN5!,DN5#&=0Qs(_RKrVlk4rr3(8s8Qhbs3:TD@fTtg~>
+!fDtsJcF$q!&=KQ!&=KQ!&=EO!&=KQ!&=KQ"u6-4s"XO.rVljPrr3'Ts8Og)s3:TDN<"id~>
+rY0q`cN!gWs8N/8s1eO4!5JO5!5JO5!l+cMrr2u5rr2u5rVlu7s8Tibs3:TC'S$~>
+!b,YLJcF$qr+c93!c%aMrVlk4rr2t5rr3%7s(_Q5!,DN5!,DK4")@l9C4ZE0s8QR/@Xn~>
+!fDtsJcF$qr%\6O!\s^0rVljPrr2sQrr3$Ss"XNQ!&=KQ!&=HP"#9iU0nKALs8S&YMLY~>
+rY0q`cMmmZrr3/:s8Tk6^]"04^]+65^]+67^]2(Jrr^%9s1eL3"2Fm9^OcF0s8E^_~>
+!b,YLJcF$q!,DN5"`");CB&&Irr?g5rr?g5rrQs8CB"58CB+<Kr;Qk6s8Qhbs3:TD@fTtg~>
+!fDtsJcF$q!&=KQ"Yp&W1&j!,rr=eQrr=eQrrOqT1&h1T1&q8.r;QjRs8Og)s3:TDN<"id~>
+rY0q`cMmmZrr3&7s1eR5!5JO5!5JO5!5JO5!l+cMrr3&7s1eI2"2Fm9^OcF0s8E^_~>
+!b,YLJcF$q!,DN5!c%aMrr2t5rr2t5rr2t5rr3%7s(_Q5!c%aMqu6b5s8Qhbs3:TD@fTtg~>
+!fDtsJcF$q!&=KQ!\s^0rr2sQrr2sQrr2sQrr3$Ss"XNQ!\s^0qu6aQs8Og)s3:TDN<"id~>
+rY0q`cMmmZrr3&7s1eR5!l+d8rkJI4rkJL5!5JO5!Pe[4^B"<4^OcF/s8E^_~>
+!b,YLJcF$q!,DN5!c%aMrr3%7s8W(5rr;t4s8N(6rr3"6s86U3s8?\`s31NC@fTtg~>
+!fDtsJcF$q!&=KQ!\s^0rr3$Ss8W'Qrr;sPs8N'Rrr3!Rs84SOs8=['s31NCN<"id~>
+rY0q`JcC<$nc/S&J,~>
+!b,YLJcC<$JcG9?s'l%<J,~>
+!fDtsJcC<$JcG9?s,@#9J,~>
+rY0q`JcC<$nc/S&J,~>
+!b,YLJcC<$JcG9?s'l%<J,~>
+!fDtsJcC<$JcG9?s,@#9J,~>
+rY0q`JcC<$nc/S&J,~>
+!b,YLJcC<$JcG9?s'l%<J,~>
+!fDtsJcC<$JcG9?s,@#9J,~>
+rY0q`JcC<$nc/S&J,~>
+!b,YLJcC<$JcG9?s'l%<J,~>
+!fDtsJcC<$JcG9?s,@#9J,~>
+rY0q`JcC<$nc/S&J,~>
+!b,YLJcC<$JcG9?s'l%<J,~>
+!fDtsJcC<$JcG9?s,@#9J,~>
+rY0q`JcC<$nc/S&J,~>
+!b,YLJcC<$JcG9?s'l%<J,~>
+!fDtsJcC<$JcG9?s,@#9J,~>
+rY0q`JcC<$nc/S&J,~>
+!b,YLJcC<$JcG9?s'l%<J,~>
+!fDtsJcC<$JcG9?s,@#9J,~>
+rY0q`JcC<$nc/S&J,~>
+!b,YLJcC<$JcG9?s'l%<J,~>
+!fDtsJcC<$JcG9?s,@#9J,~>
+rY0q`JcC<$nc/S&J,~>
+!b,YLJcC<$JcG9?s'l%<J,~>
+!fDtsJcC<$JcG9?s,@#9J,~>
+rY0q`\c2ZgJcE=]rY0k~>
+!b,YLJcE:\!47=W])Ve?!+LH~>
+!fDtsJcE:\!-!Mh])Vei!/c:~>
+rY0q`\c2ZgJcE=]rY0k~>
+!b,YLJcE:\!47=W])Ve?!+LH~>
+!fDtsJcE:\!-!Mh])Vei!/c:~>
+rY0q`\c2ZgJcE=]rY0k~>
+!b,YLJcE:\!47=W])Ve?!+LH~>
+!fDtsJcE:\!-!Mh])Vei!/c:~>
+rY0q`\c2ZgJcE=]rY0k~>
+!b,YLJcE:\!47=W])Ve?!+LH~>
+!fDtsJcE:\!-!Mh])Vei!/c:~>
+rY0q`\c2ZgJcE=]rY0k~>
+!b,YLJcE:\!47=W])Ve?!+LH~>
+!fDtsJcE:\!-!Mh])Vei!/c:~>
+rY0q`\c2ZgJcE=]rY0k~>
+!b,YLJcE:\!47=W])Ve?!+LH~>
+!fDtsJcE:\!-!Mh])Vei!/c:~>
+rY0q`\c2ZgJcE=]rY0k~>
+!b,YLJcE:\!47=W])Ve?!+LH~>
+!fDtsJcE:\!-!Mh])Vei!/c:~>
+rY0q`\c2ZgJcF'rs1e"%rY0k~>
+!b,YLJcE:\!47=Wci=#"mf3;s!+LH~>
+!fDtsJcE:\!-!Mhci=#"mf3<H!/c:~>
+rY0q`\c2ZgJcF'rs1e"%rY0k~>
+!b,YLJcE:\!47=Wci=#"mf3;s!+LH~>
+!fDtsJcE:\!-!Mhci=#"mf3<H!/c:~>
+rY0q`\c2ZgJcF'r!$1J,rY0k~>
+!b,YLJcE:\!47=Wci4!0mJm2r!+LH~>
+!fDtsJcE:\!-!Mhci3tcmJm3G!/c:~>
+rY0q`\c2ZgJcF'r!$1J,rY0k~>
+!b,YLJcE:\!47=Wci4!0mJm2r!+LH~>
+!fDtsJcE:\!-!Mhci3tcmJm3G!/c:~>
+rY0q`\c2ZgJcF*s!$1G+rY0k~>
+!b,YLJcE:\!47=Wd/O*1m/R)q!+LH~>
+!fDtsJcE:\!-!Mhd/O(dm/R*F!/c:~>
+rY0q`\c2ZgJcF*s!$1G+rY0k~>
+!b,YLJcE:\!47=Wd/O*1m/R)q!+LH~>
+!fDtsJcE:\!-!Mhd/O(dm/R*F!/c:~>
+rY0q`\c2ZgJcF*s!$1G+rY0k~>
+!b,YLJcE:\!47=Wd/O*1m/R)q!+LH~>
+!fDtsJcE:\!-!Mhd/O(dm/R*F!/c:~>
+rY0q`\c2ZgJcF*s!$1G+rY0k~>
+!b,YLJcE:\!47=Wd/O*1m/R)q!+LH~>
+!fDtsJcE:\!-!Mhd/O(dm/R*F!/c:~>
+rY0q`\c2ZgJcF*s!$1G+rY0k~>
+!b,YLJcE:\!47=Wd/O*1m/R)q!+LH~>
+!fDtsJcE:\!-!Mhd/O(dm/R*F!/c:~>
+rY0q`\c2ZgJcF*s!$1G+rY0k~>
+!b,YLJcE:\!47=Wd/O*1m/R)q!+LH~>
+!fDtsJcE:\!-!Mhd/O(dm/R*F!/c:~>
+rY0q`\c2ZgJcF*s!$1G+rY0k~>
+!b,YLJcE:\!47=Wd/O*1m/R)q!+LH~>
+!fDtsJcE:\!-!Mhd/O(dm/R*F!/c:~>
+rY0q`\c2ZgJcF-t!$1D*rY0k~>
+!b,YLJcE:\!47=WdJj32li6up!+LH~>
+!fDtsJcE:\!-!MhdJj1eli7!E!/c:~>
+rY0q`\c2ZgJcF-t!$1D*rY0k~>
+!b,YLJcE:\!47=WdJj32li6up!+LH~>
+!fDtsJcE:\!-!MhdJj1eli7!E!/c:~>
+rY0q`\c2ZgJcF-t!$1D*rY0k~>
+!b,YLJcE:\!47=WdJj32li6up!+LH~>
+!fDtsJcE:\!-!MhdJj1eli7!E!/c:~>
+rY0q`\c2ZgJcF-t!$1D*rY0k~>
+!b,YLJcE:\!47=WdJj32li6up!+LH~>
+!fDtsJcE:\!-!MhdJj1eli7!E!/c:~>
+rY0q`\c2ZgJcF-t!$1D*rY0k~>
+!b,YLJcE:\!47=WdJj32li6up!+LH~>
+!fDtsJcE:\!-!MhdJj1eli7!E!/c:~>
+rY0q`\c2ZgJcF-t!$1D*rY0k~>
+!b,YLJcE:\!47=WdJj32li6up!+LH~>
+!fDtsJcE:\!-!MhdJj1eli7!E!/c:~>
+rY0q`\c2ZgJcF-t!$1D*rY0k~>
+!b,YLJcE:\!47=WdJj32li6up!+LH~>
+!fDtsJcE:\!-!MhdJj1eli7!E!/c:~>
+rY0q`\c2ZgJcF-t!$1D*rY0k~>
+!b,YLJcE:\!47=WdJj32li6up!+LH~>
+!fDtsJcE:\!-!MhdJj1eli7!E!/c:~>
+rY0q`\c2ZgJcF0u!$1A)rY0k~>
+!b,YLJcE:\!47=Wdf0<3lMplo!+LH~>
+!fDtsJcE:\!-!Mhdf0:flMpmD!/c:~>
+rY0q`\c2ZgJcF0u!$1A)rY0k~>
+!b,YLJcE:\!47=Wdf0<3lMplo!+LH~>
+!fDtsJcE:\!-!Mhdf0:flMpmD!/c:~>
+rY0q`\c2ZgJcF0u!$1A)rY0k~>
+!b,YLJcE:\!47=Wdf0<3lMplo!+LH~>
+!fDtsJcE:\!-!Mhdf0:flMpmD!/c:~>
+rY0q`\c2ZgJcF0u!$1A)rY0k~>
+!b,YLJcE:\!47=Wdf0<3lMplo!+LH~>
+!fDtsJcE:\!-!Mhdf0:flMpmD!/c:~>
+rY0q`\c2ZgJcF0u!$1A)rY0k~>
+!b,YLJcE:\!47=Wdf0<3lMplo!+LH~>
+!fDtsJcE:\!-!Mhdf0:flMpmD!/c:~>
+rY0q`\c2ZgJcF0u!$1A)rY0k~>
+!b,YLJcE:\!47=Wdf0<3lMplo!+LH~>
+!fDtsJcE:\!-!Mhdf0:flMpmD!/c:~>
+rY0q`\c2ZgJcF0u!$1A)rY0k~>
+!b,YLJcE:\!47=Wdf0<3lMplo!+LH~>
+!fDtsJcE:\!-!Mhdf0:flMpmD!/c:~>
+rY0q`\c2ZgJcF4!!$1>(rY0k~>
+!b,YLJcE:\!47=We,KE4l2Ucn!+LH~>
+!fDtsJcE:\!-!Mhe,KCgl2UdC!/c:~>
+rY0q`\c2ZgJcF4!!$1>(rY0k~>
+!b,YLJcE:\!47=We,KE4l2Ucn!+LH~>
+!fDtsJcE:\!-!Mhe,KCgl2UdC!/c:~>
+rY0q`\c2ZgJcF4!!$1>(rY0k~>
+!b,YLJcE:\!47=We,KE4l2Ucn!+LH~>
+!fDtsJcE:\!-!Mhe,KCgl2UdC!/c:~>
+rY0q`\c2ZgJcF4!!$1>(rY0k~>
+!b,YLJcE:\!47=We,KE4l2Ucn!+LH~>
+!fDtsJcE:\!-!Mhe,KCgl2UdC!/c:~>
+rY0q`\c2ZgJcF4!!$1>(rY0k~>
+!b,YLJcE:\!47=We,KE4l2Ucn!+LH~>
+!fDtsJcE:\!-!Mhe,KCgl2UdC!/c:~>
+rY0q`\c2ZgJcF4!!$1>(rY0k~>
+!b,YLJcE:\!47=We,KE4l2Ucn!+LH~>
+!fDtsJcE:\!-!Mhe,KCgl2UdC!/c:~>
+rY0q`\c2ZgJcF4!!$1>(rY0k~>
+!b,YLJcE:\!47=We,KE4l2Ucn!+LH~>
+!fDtsJcE:\!-!Mhe,KCgl2UdC!/c:~>
+rY0q`\c2ZgJcF7"!$1;'rY0k~>
+!b,YLJcE:\!47=WeGfN5kl:Zm!+LH~>
+!fDtsJcE:\!-!MheGfLhkl:[B!/c:~>
+rY0q`\c2ZgJcF7"!$1;'rY0k~>
+!b,YLJcE:\!47=WeGfN5kl:Zm!+LH~>
+!fDtsJcE:\!-!MheGfLhkl:[B!/c:~>
+rY0q`\c2ZgJcF7"!$1;'rY0k~>
+!b,YLJcE:\!47=WeGfN5kl:Zm!+LH~>
+!fDtsJcE:\!-!MheGfLhkl:[B!/c:~>
+rY0q`\c2ZgJcF7"!$1;'rY0k~>
+!b,YLJcE:\!47=WeGfN5kl:Zm!+LH~>
+!fDtsJcE:\!-!MheGfLhkl:[B!/c:~>
+rY0q`\c2ZgJcF7"!$1;'rY0k~>
+!b,YLJcE:\!47=WeGfN5kl:Zm!+LH~>
+!fDtsJcE:\!-!MheGfLhkl:[B!/c:~>
+rY0q`\c2ZgJcF7"!$1;'rY0k~>
+!b,YLJcE:\!47=WeGfN5kl:Zm!+LH~>
+!fDtsJcE:\!-!MheGfLhkl:[B!/c:~>
+rY0q`\c2ZgJcF7"!$1;'rY0k~>
+!b,YLJcE:\!47=WeGfN5kl:Zm!+LH~>
+!fDtsJcE:\!-!MheGfLhkl:[B!/c:~>
+rY0q`\c2ZgJcF7"!$1;'rY0k~>
+!b,YLJcE:\!47=WeGfN5kl:Zm!+LH~>
+!fDtsJcE:\!-!MheGfLhkl:[B!/c:~>
+rY0q`\c2ZgJcF:#!$18&rY0k~>
+!b,YLJcE:\!47=Wec,W6kPtQl!+LH~>
+!fDtsJcE:\!-!Mhec,UikPtRA!/c:~>
+rY0q`\c2ZgJcF:#!$18&rY0k~>
+!b,YLJcE:\!47=Wec,W6kPtQl!+LH~>
+!fDtsJcE:\!-!Mhec,UikPtRA!/c:~>
+rY0q`\c2ZgJcF:#!$18&rY0k~>
+!b,YLJcE:\!47=Wec,W6kPtQl!+LH~>
+!fDtsJcE:\!-!Mhec,UikPtRA!/c:~>
+rY0q`\c2ZgJcF:#!$18&rY0k~>
+!b,YLJcE:\!47=Wec,W6kPtQl!+LH~>
+!fDtsJcE:\!-!Mhec,UikPtRA!/c:~>
+rY0q`\c2ZgJcF:#!$18&rY0k~>
+!b,YLJcE:\!47=Wec,W6kPtQl!+LH~>
+!fDtsJcE:\!-!Mhec,UikPtRA!/c:~>
+rY0q`\c2ZgJcF:#!$18&rY0k~>
+!b,YLJcE:\!47=Wec,W6kPtQl!+LH~>
+!fDtsJcE:\!-!Mhec,UikPtRA!/c:~>
+rY0q`\c2ZgJcF:#!$18&rY0k~>
+!b,YLJcE:\!47=Wec,W6kPtQl!+LH~>
+!fDtsJcE:\!-!Mhec,UikPtRA!/c:~>
+rY0q`\c2ZgJcF=$!$15%rY0k~>
+!b,YLJcE:\!47=Wf)G`7k5YHk!+LH~>
+!fDtsJcE:\!-!Mhf)G^jk5YI@!/c:~>
+rY0q`\c2ZgJcF=$!$15%rY0k~>
+!b,YLJcE:\!47=Wf)G`7k5YHk!+LH~>
+!fDtsJcE:\!-!Mhf)G^jk5YI@!/c:~>
+rY0q`\c2ZgJcF=$!$15%rY0k~>
+!b,YLJcE:\!47=Wf)G`7k5YHk!+LH~>
+!fDtsJcE:\!-!Mhf)G^jk5YI@!/c:~>
+rY0q`\c2ZgJcF=$!?Jr<s8E^_~>
+!b,YLJcE:\!47=Wf)Gc81$AT:@fTtg~>
+!fDtsJcE:\!-!Mhf)Gak1$AT:N<"id~>
+rY0q`\c2ZgJcF=$s1dasrY0k~>
+!b,YLJcE:\!47=Wf)Pb)kPtQl!+LH~>
+!fDtsJcE:\!-!Mhf)Pb)kPtRA!/c:~>
+rY0q`\c2ZgJcF=$!$15%rY0k~>
+!b,YLJcE:\!47=Wf)G`7k5YHk!+LH~>
+!fDtsJcE:\!-!Mhf)G^jk5YI@!/c:~>
+rY0q`\c2ZgJcF@%!$12$rY0k~>
+!b,YLJcE:\!47=WfDbi8jo>?j!+LH~>
+!fDtsJcE:\!-!MhfDbgkjo>@?!/c:~>
+rY0q`\c2ZgJcF@%!$12$rY0k~>
+!b,YLJcE:\!47=WfDbi8jo>?j!+LH~>
+!fDtsJcE:\!-!MhfDbgkjo>@?!/c:~>
+rY0q`\c2ZgJcF@%!$12$rY0k~>
+!b,YLJcE:\!47=WfDbi8jo>?j!+LH~>
+!fDtsJcE:\!-!MhfDbgkjo>@?!/c:~>
+rY0q`\c2ZgJcF@%!$12$rY0k~>
+!b,YLJcE:\!47=WfDbi8jo>?j!+LH~>
+!fDtsJcE:\!-!MhfDbgkjo>@?!/c:~>
+rY0q`\c2ZgJcF@%!$12$rY0k~>
+!b,YLJcE:\!47=WfDbi8jo>?j!+LH~>
+!fDtsJcE:\!-!MhfDbgkjo>@?!/c:~>
+rY0q`\c2ZgJcF@%!$12$rY0k~>
+!b,YLJcE:\!47=WfDbi8jo>?j!+LH~>
+!fDtsJcE:\!-!MhfDbgkjo>@?!/c:~>
+rY0q`\c2ZgJcFC&!$1/#rY0k~>
+!b,YLJcE:\!47=Wf`(r9jT#6i!+LH~>
+!fDtsJcE:\!-!Mhf`(pljT#7>!/c:~>
+rY0q`\c2ZgJcFC&!$1/#rY0k~>
+!b,YLJcE:\!47=Wf`(r9jT#6i!+LH~>
+!fDtsJcE:\!-!Mhf`(pljT#7>!/c:~>
+rY0q`\c2ZgJcFC&!$1/#rY0k~>
+!b,YLJcE:\!47=Wf`(r9jT#6i!+LH~>
+!fDtsJcE:\!-!Mhf`(pljT#7>!/c:~>
+rY0q`\c2ZgJcFC&!$1/#rY0k~>
+!b,YLJcE:\!47=Wf`(r9jT#6i!+LH~>
+!fDtsJcE:\!-!Mhf`(pljT#7>!/c:~>
+rY0q`\c2ZgJcFC&!$1/#rY0k~>
+!b,YLJcE:\!47=Wf`(r9jT#6i!+LH~>
+!fDtsJcE:\!-!Mhf`(pljT#7>!/c:~>
+rY0q`\c2ZgJcFC&!$1/#rY0k~>
+!b,YLJcE:\!47=Wf`(r9jT#6i!+LH~>
+!fDtsJcE:\!-!Mhf`(pljT#7>!/c:~>
+rY0q`\c2ZgJcFF'!$1,"rY0k~>
+!b,YLJcE:\!47=Wg&D&:j8]-h!+LH~>
+!fDtsJcE:\!-!Mhg&D$mj8].=!/c:~>
+rY0q`\c2ZgJcFF'!$1,"rY0k~>
+!b,YLJcE:\!47=Wg&D&:j8]-h!+LH~>
+!fDtsJcE:\!-!Mhg&D$mj8].=!/c:~>
+rY0q`\c2ZgJcFF'!$1,"rY0k~>
+!b,YLJcE:\!47=Wg&D&:j8]-h!+LH~>
+!fDtsJcE:\!-!Mhg&D$mj8].=!/c:~>
+rY0q`\c2ZgJcFF'!$1,"rY0k~>
+!b,YLJcE:\!47=Wg&D&:j8]-h!+LH~>
+!fDtsJcE:\!-!Mhg&D$mj8].=!/c:~>
+rY0q`\c2ZgJcFF'!$1,"rY0k~>
+!b,YLJcE:\!47=Wg&D&:j8]-h!+LH~>
+!fDtsJcE:\!-!Mhg&D$mj8].=!/c:~>
+rY0q`\c2ZgJcFF'!$1,"rY0k~>
+!b,YLJcE:\!47=Wg&D&:j8]-h!+LH~>
+!fDtsJcE:\!-!Mhg&D$mj8].=!/c:~>
+rY0q`\c2ZgJcFI(!$1)!rY0k~>
+!b,YLJcE:\!47=WgA_/;irB$g!+LH~>
+!fDtsJcE:\!-!MhgA_-nirB%<!/c:~>
+rY0q`\c2ZgJcFI(!$1)!rY0k~>
+!b,YLJcE:\!47=WgA_/;irB$g!+LH~>
+!fDtsJcE:\!-!MhgA_-nirB%<!/c:~>
+rY0q`\c2ZgJcFI(!$1)!rY0k~>
+!b,YLJcE:\!47=WgA_/;irB$g!+LH~>
+!fDtsJcE:\!-!MhgA_-nirB%<!/c:~>
+rY0q`\c2ZgJcFI(!$1)!rY0k~>
+!b,YLJcE:\!47=WgA_/;irB$g!+LH~>
+!fDtsJcE:\!-!MhgA_-nirB%<!/c:~>
+rY0q`\c2ZgJcFI(!$1)!rY0k~>
+!b,YLJcE:\!47=WgA_/;irB$g!+LH~>
+!fDtsJcE:\!-!MhgA_-nirB%<!/c:~>
+rY0q`\c2ZgJcFL)!$1%urY0k~>
+!b,YLJcE:\!47=Wg]%8<iW&pf!+LH~>
+!fDtsJcE:\!-!Mhg]%6oiW&q;!/c:~>
+rY0q`\c2ZgJcFL)!$1%urY0k~>
+!b,YLJcE:\!47=Wg]%8<iW&pf!+LH~>
+!fDtsJcE:\!-!Mhg]%6oiW&q;!/c:~>
+rY0q`\c2ZgJcFL)!$1%urY0k~>
+!b,YLJcE:\!47=Wg]%8<iW&pf!+LH~>
+!fDtsJcE:\!-!Mhg]%6oiW&q;!/c:~>
+rY0q`\c2ZgJcFL)!$1%urY0k~>
+!b,YLJcE:\!47=Wg]%8<iW&pf!+LH~>
+!fDtsJcE:\!-!Mhg]%6oiW&q;!/c:~>
+rY0q`\c2ZgJcFL)!$1%urY0k~>
+!b,YLJcE:\!47=Wg]%8<iW&pf!+LH~>
+!fDtsJcE:\!-!Mhg]%6oiW&q;!/c:~>
+rY0q`\c2ZgJcFL)!$1%urY0k~>
+!b,YLJcE:\!47=Wg]%8<iW&pf!+LH~>
+!fDtsJcE:\!-!Mhg]%6oiW&q;!/c:~>
+rY0q`\c2ZgJcFO*!$1"trY0k~>
+!b,YLJcE:\!47=Wh#@A=i;`ge!+LH~>
+!fDtsJcE:\!-!Mhh#@?pi;`h:!/c:~>
+rY0q`\c2ZgJcFO*!$1"trY0k~>
+!b,YLJcE:\!47=Wh#@A=i;`ge!+LH~>
+!fDtsJcE:\!-!Mhh#@?pi;`h:!/c:~>
+rY0q`\c2ZgJcFO*!$1"trY0k~>
+!b,YLJcE:\!47=Wh#@A=i;`ge!+LH~>
+!fDtsJcE:\!-!Mhh#@?pi;`h:!/c:~>
+rY0q`\c2ZgJcFO*!$1"trY0k~>
+!b,YLJcE:\!47=Wh#@A=i;`ge!+LH~>
+!fDtsJcE:\!-!Mhh#@?pi;`h:!/c:~>
+rY0q`\c2ZgJcFO*!$1"trY0k~>
+!b,YLJcE:\!47=Wh#@A=i;`ge!+LH~>
+!fDtsJcE:\!-!Mhh#@?pi;`h:!/c:~>
+rY0q`\c2ZgJcFO*!$1"trY0k~>
+!b,YLJcE:\!47=Wh#@A=i;`ge!+LH~>
+!fDtsJcE:\!-!Mhh#@?pi;`h:!/c:~>
+rY0q`\c2ZgJcFR+!$0tsrY0k~>
+!b,YLJcE:\!47=Wh>[J>huE^d!+LH~>
+!fDtsJcE:\!-!Mhh>[HqhuE_9!/c:~>
+rY0q`\c2ZgJcFR+!$0tsrY0k~>
+!b,YLJcE:\!47=Wh>[J>huE^d!+LH~>
+!fDtsJcE:\!-!Mhh>[HqhuE_9!/c:~>
+rY0q`\c2ZgJcFR+!$0tsrY0k~>
+!b,YLJcE:\!47=Wh>[J>huE^d!+LH~>
+!fDtsJcE:\!-!Mhh>[HqhuE_9!/c:~>
+rY0q`\c2ZgJcFR+!$0tsrY0k~>
+!b,YLJcE:\!47=Wh>[J>huE^d!+LH~>
+!fDtsJcE:\!-!Mhh>[HqhuE_9!/c:~>
+rY0q`\c2ZgJcFR+!$0tsrY0k~>
+!b,YLJcE:\!47=Wh>[J>huE^d!+LH~>
+!fDtsJcE:\!-!Mhh>[HqhuE_9!/c:~>
+rY0q`\c2ZgJcFR+!$0tsrY0k~>
+!b,YLJcE:\!47=Wh>[J>huE^d!+LH~>
+!fDtsJcE:\!-!Mhh>[HqhuE_9!/c:~>
+rY0q`\c2ZgJcFU,!$0qrrY0k~>
+!b,YLJcE:\!47=WhZ!S?hZ*Uc!+LH~>
+!fDtsJcE:\!-!MhhZ!QrhZ*V8!/c:~>
+rY0q`\c2ZgJcFU,!$0qrrY0k~>
+!b,YLJcE:\!47=WhZ!S?hZ*Uc!+LH~>
+!fDtsJcE:\!-!MhhZ!QrhZ*V8!/c:~>
+rY0q`\c2ZgJcFU,!?Jr4s8E^_~>
+!b,YLJcE:\!47=WhZ!V@1#N$2@fTtg~>
+!fDtsJcE:\!-!MhhZ!Ts1#N$2N<"id~>
+rY0q`\c2ZgJcFU,s1dIkrY0k~>
+!b,YLJcE:\!47=WhZ*U1huE^d!+LH~>
+!fDtsJcE:\!-!MhhZ*U1huE_9!/c:~>
+rY0q`\c2ZgJcFU,!$0qrrY0k~>
+!b,YLJcE:\!47=WhZ!S?hZ*Uc!+LH~>
+!fDtsJcE:\!-!MhhZ!QrhZ*V8!/c:~>
+rY0q`\c2ZgJcFX-!$0nqrY0k~>
+!b,YLJcE:\!47=Whu<\@h>dLb!+LH~>
+!fDtsJcE:\!-!Mhhu<Zsh>dM7!/c:~>
+rY0q`\c2ZgJcFX-!$0nqrY0k~>
+!b,YLJcE:\!47=Whu<\@h>dLb!+LH~>
+!fDtsJcE:\!-!Mhhu<Zsh>dM7!/c:~>
+rY0q`\c2ZgJcFX-!$0nqrY0k~>
+!b,YLJcE:\!47=Whu<\@h>dLb!+LH~>
+!fDtsJcE:\!-!Mhhu<Zsh>dM7!/c:~>
+rY0q`\c2ZgJcFX-!$0nqrY0k~>
+!b,YLJcE:\!47=Whu<\@h>dLb!+LH~>
+!fDtsJcE:\!-!Mhhu<Zsh>dM7!/c:~>
+rY0q`\c2ZgJcFX-!$0nqrY0k~>
+!b,YLJcE:\!47=Whu<\@h>dLb!+LH~>
+!fDtsJcE:\!-!Mhhu<Zsh>dM7!/c:~>
+rY0q`\c2ZgJcFX-!$0nqrY0k~>
+!b,YLJcE:\!47=Whu<\@h>dLb!+LH~>
+!fDtsJcE:\!-!Mhhu<Zsh>dM7!/c:~>
+rY0q`\c2ZgJcF[.!$0kprY0k~>
+!b,YLJcE:\!47=Wi;WeAh#ICa!+LH~>
+!fDtsJcE:\!-!Mhi;Wcth#ID6!/c:~>
+rY0q`\c2ZgJcF[.!$0kprY0k~>
+!b,YLJcE:\!47=Wi;WeAh#ICa!+LH~>
+!fDtsJcE:\!-!Mhi;Wcth#ID6!/c:~>
+rY0q`\c2ZgJcF[.!$0kprY0k~>
+!b,YLJcE:\!47=Wi;WeAh#ICa!+LH~>
+!fDtsJcE:\!-!Mhi;Wcth#ID6!/c:~>
+rY0q`\c2ZgJcF[.!$0kprY0k~>
+!b,YLJcE:\!47=Wi;WeAh#ICa!+LH~>
+!fDtsJcE:\!-!Mhi;Wcth#ID6!/c:~>
+rY0q`\c2ZgJcF[.!$0kprY0k~>
+!b,YLJcE:\!47=Wi;WeAh#ICa!+LH~>
+!fDtsJcE:\!-!Mhi;Wcth#ID6!/c:~>
+rY0q`\c2ZgJcF[.!$0kprY0k~>
+!b,YLJcE:\!47=Wi;WeAh#ICa!+LH~>
+!fDtsJcE:\!-!Mhi;Wcth#ID6!/c:~>
+rY0q`\c2ZgJcF^/!$0horY0k~>
+!b,YLJcE:\!47=WiVrnBg].:`!+LH~>
+!fDtsJcE:\!-!MhiVrlug].;5!/c:~>
+rY0q`\c2ZgJcF^/!$0horY0k~>
+!b,YLJcE:\!47=WiVrnBg].:`!+LH~>
+!fDtsJcE:\!-!MhiVrlug].;5!/c:~>
+rY0q`\c2ZgJcF^/!$0horY0k~>
+!b,YLJcE:\!47=WiVrnBg].:`!+LH~>
+!fDtsJcE:\!-!MhiVrlug].;5!/c:~>
+rY0q`\c2ZgJcF^/!$0horY0k~>
+!b,YLJcE:\!47=WiVrnBg].:`!+LH~>
+!fDtsJcE:\!-!MhiVrlug].;5!/c:~>
+rY0q`\c2ZgJcF^/!$0horY0k~>
+!b,YLJcE:\!47=WiVrnBg].:`!+LH~>
+!fDtsJcE:\!-!MhiVrlug].;5!/c:~>
+rY0q`\c2ZgJcF^/!$0horY0k~>
+!b,YLJcE:\!47=WiVrnBg].:`!+LH~>
+!fDtsJcE:\!-!MhiVrlug].;5!/c:~>
+rY0q`\c2ZgJcFa0!$0enrY0k~>
+!b,YLJcE:\!47=Wir9"CgAh1_!+LH~>
+!fDtsJcE:\!-!Mhir9!!gAh24!/c:~>
+rY0q`\c2ZgJcFa0!$0enrY0k~>
+!b,YLJcE:\!47=Wir9"CgAh1_!+LH~>
+!fDtsJcE:\!-!Mhir9!!gAh24!/c:~>
+rY0q`\c2ZgJcFa0!$0enrY0k~>
+!b,YLJcE:\!47=Wir9"CgAh1_!+LH~>
+!fDtsJcE:\!-!Mhir9!!gAh24!/c:~>
+rY0q`\c2ZgJcFa0!$0enrY0k~>
+!b,YLJcE:\!47=Wir9"CgAh1_!+LH~>
+!fDtsJcE:\!-!Mhir9!!gAh24!/c:~>
+rY0q`\c2ZgJcFa0!$0enrY0k~>
+!b,YLJcE:\!47=Wir9"CgAh1_!+LH~>
+!fDtsJcE:\!-!Mhir9!!gAh24!/c:~>
+rY0q`\c2ZgJcFa0!$0enrY0k~>
+!b,YLJcE:\!47=Wir9"CgAh1_!+LH~>
+!fDtsJcE:\!-!Mhir9!!gAh24!/c:~>
+rY0q`\c2ZgJcFd1!$0bmrY0k~>
+!b,YLJcE:\!47=Wj8T+Dg&M(^!+LH~>
+!fDtsJcE:\!-!Mhj8T*"g&M)3!/c:~>
+rY0q`\c2ZgJcFd1!$0bmrY0k~>
+!b,YLJcE:\!47=Wj8T+Dg&M(^!+LH~>
+!fDtsJcE:\!-!Mhj8T*"g&M)3!/c:~>
+rY0q`\c2ZgJcFd1!$0bmrY0k~>
+!b,YLJcE:\!47=Wj8T+Dg&M(^!+LH~>
+!fDtsJcE:\!-!Mhj8T*"g&M)3!/c:~>
+rY0q`\c2ZgJcFd1!$0bmrY0k~>
+!b,YLJcE:\!47=Wj8T+Dg&M(^!+LH~>
+!fDtsJcE:\!-!Mhj8T*"g&M)3!/c:~>
+rY0q`\c2ZgJcFd1!$0bmrY0k~>
+!b,YLJcE:\!47=Wj8T+Dg&M(^!+LH~>
+!fDtsJcE:\!-!Mhj8T*"g&M)3!/c:~>
+rY0q`\c2ZgJcFd1!$0bmrY0k~>
+!b,YLJcE:\!47=Wj8T+Dg&M(^!+LH~>
+!fDtsJcE:\!-!Mhj8T*"g&M)3!/c:~>
+rY0q`\c2ZgJcFg2!$0_lrY0k~>
+!b,YLJcE:\!47=WjSo4Ef`1t]!+LH~>
+!fDtsJcE:\!-!MhjSo3#f`1u2!/c:~>
+rY0q`\c2ZgJcFg2!$0_lrY0k~>
+!b,YLJcE:\!47=WjSo4Ef`1t]!+LH~>
+!fDtsJcE:\!-!MhjSo3#f`1u2!/c:~>
+rY0q`\c2ZgJcFg2!$0_lrY0k~>
+!b,YLJcE:\!47=WjSo4Ef`1t]!+LH~>
+!fDtsJcE:\!-!MhjSo3#f`1u2!/c:~>
+rY0q`\c2ZgJcFg2!$0_lrY0k~>
+!b,YLJcE:\!47=WjSo4Ef`1t]!+LH~>
+!fDtsJcE:\!-!MhjSo3#f`1u2!/c:~>
+rY0q`\c2ZgJcFg2!$0_lrY0k~>
+!b,YLJcE:\!47=WjSo4Ef`1t]!+LH~>
+!fDtsJcE:\!-!MhjSo3#f`1u2!/c:~>
+rY0q`\c2ZgJcFg2!$0_lrY0k~>
+!b,YLJcE:\!47=WjSo4Ef`1t]!+LH~>
+!fDtsJcE:\!-!MhjSo3#f`1u2!/c:~>
+rY0q`\c2ZgJcFj3!$0\krY0k~>
+!b,YLJcE:\!47=Wjo5=FfDkk\!+LH~>
+!fDtsJcE:\!-!Mhjo5<$fDkl1!/c:~>
+rY0q`\c2ZgJcFj3!$0\krY0k~>
+!b,YLJcE:\!47=Wjo5=FfDkk\!+LH~>
+!fDtsJcE:\!-!Mhjo5<$fDkl1!/c:~>
+rY0q`\c2ZgJcFj3!?Jr-s8E^_~>
+!b,YLJcE:\!47=Wjo5@G1"cO+@fTtg~>
+!fDtsJcE:\!-!Mhjo5?%1"cO+N<"id~>
+rY0q`\c2ZgJcFj3s1d4drY0k~>
+!b,YLJcE:\!47=Wjo>?8f`1t]!+LH~>
+!fDtsJcE:\!-!Mhjo>?8f`1u2!/c:~>
+rY0q`\c2ZgJcFj3!$0\krY0k~>
+!b,YLJcE:\!47=Wjo5=FfDkk\!+LH~>
+!fDtsJcE:\!-!Mhjo5<$fDkl1!/c:~>
+rY0q`\c2ZgJcFm4!$0YjrY0k~>
+!b,YLJcE:\!47=Wk5PFGf)Pb[!+LH~>
+!fDtsJcE:\!-!Mhk5PE%f)Pc0!/c:~>
+rY0q`\c2ZgJcFm4!$0YjrY0k~>
+!b,YLJcE:\!47=Wk5PFGf)Pb[!+LH~>
+!fDtsJcE:\!-!Mhk5PE%f)Pc0!/c:~>
+rY0q`\c2ZgJcFm4!$0YjrY0k~>
+!b,YLJcE:\!47=Wk5PFGf)Pb[!+LH~>
+!fDtsJcE:\!-!Mhk5PE%f)Pc0!/c:~>
+rY0q`\c2ZgJcFm4!$0YjrY0k~>
+!b,YLJcE:\!47=Wk5PFGf)Pb[!+LH~>
+!fDtsJcE:\!-!Mhk5PE%f)Pc0!/c:~>
+rY0q`\c2ZgJcFp5!$0VirY0k~>
+!b,YLJcE:\!47=WkPkOHec5YZ!+LH~>
+!fDtsJcE:\!-!MhkPkN&ec5Z/!/c:~>
+rY0q`\c2ZgJcFp5!$0VirY0k~>
+!b,YLJcE:\!47=WkPkOHec5YZ!+LH~>
+!fDtsJcE:\!-!MhkPkN&ec5Z/!/c:~>
+rY0q`\c2ZgJcFp5!$0VirY0k~>
+!b,YLJcE:\!47=WkPkOHec5YZ!+LH~>
+!fDtsJcE:\!-!MhkPkN&ec5Z/!/c:~>
+rY0q`\c2ZgJcFp5!$0VirY0k~>
+!b,YLJcE:\!47=WkPkOHec5YZ!+LH~>
+!fDtsJcE:\!-!MhkPkN&ec5Z/!/c:~>
+rY0q`\c2ZgJcFp5!$0VirY0k~>
+!b,YLJcE:\!47=WkPkOHec5YZ!+LH~>
+!fDtsJcE:\!-!MhkPkN&ec5Z/!/c:~>
+rY0q`\c2ZgJcFs6!$0ShrY0k~>
+!b,YLJcE:\!47=Wkl1XIeGoPY!+LH~>
+!fDtsJcE:\!-!Mhkl1W'eGoQ.!/c:~>
+rY0q`\c2ZgJcFs6!$0ShrY0k~>
+!b,YLJcE:\!47=Wkl1XIeGoPY!+LH~>
+!fDtsJcE:\!-!Mhkl1W'eGoQ.!/c:~>
+rY0q`\c2ZgJcFs6!$0ShrY0k~>
+!b,YLJcE:\!47=Wkl1XIeGoPY!+LH~>
+!fDtsJcE:\!-!Mhkl1W'eGoQ.!/c:~>
+rY0q`\c2ZgJcFs6!$0ShrY0k~>
+!b,YLJcE:\!47=Wkl1XIeGoPY!+LH~>
+!fDtsJcE:\!-!Mhkl1W'eGoQ.!/c:~>
+rY0q`\c2ZgJcG!7!$0PgrY0k~>
+!b,YLJcE:\!47=Wl2LaJe,TGX!+LH~>
+!fDtsJcE:\!-!Mhl2L`(e,TH-!/c:~>
+rY0q`\c2ZgJcG!7!$0PgrY0k~>
+!b,YLJcE:\!47=Wl2LaJe,TGX!+LH~>
+!fDtsJcE:\!-!Mhl2L`(e,TH-!/c:~>
+rY0q`\c2ZgJcG!7!$0PgrY0k~>
+!b,YLJcE:\!47=Wl2LaJe,TGX!+LH~>
+!fDtsJcE:\!-!Mhl2L`(e,TH-!/c:~>
+rY0q`\c2ZgJcG!7!$0PgrY0k~>
+!b,YLJcE:\!47=Wl2LaJe,TGX!+LH~>
+!fDtsJcE:\!-!Mhl2L`(e,TH-!/c:~>
+rY0q`\c2ZgJcG!7!$0PgrY0k~>
+!b,YLJcE:\!47=Wl2LaJe,TGX!+LH~>
+!fDtsJcE:\!-!Mhl2L`(e,TH-!/c:~>
+rY0q`\c2ZgJcG$8!$0MfrY0k~>
+!b,YLJcE:\!47=WlMgjKdf9>W!+LH~>
+!fDtsJcE:\!-!MhlMgi)df9?,!/c:~>
+rY0q`\c2ZgJcG$8!$0MfrY0k~>
+!b,YLJcE:\!47=WlMgjKdf9>W!+LH~>
+!fDtsJcE:\!-!MhlMgi)df9?,!/c:~>
+rY0q`\c2ZgJcG$8!$0MfrY0k~>
+!b,YLJcE:\!47=WlMgjKdf9>W!+LH~>
+!fDtsJcE:\!-!MhlMgi)df9?,!/c:~>
+rY0q`\c2ZgJcG$8!$0MfrY0k~>
+!b,YLJcE:\!47=WlMgjKdf9>W!+LH~>
+!fDtsJcE:\!-!MhlMgi)df9?,!/c:~>
+rY0q`\c2ZgJcG'9!$0JerY0k~>
+!b,YLJcE:\!47=Wli-sLdJs5V!+LH~>
+!fDtsJcE:\!-!Mhli-r*dJs6+!/c:~>
+rY0q`\c2ZgJcG'9!$0JerY0k~>
+!b,YLJcE:\!47=Wli-sLdJs5V!+LH~>
+!fDtsJcE:\!-!Mhli-r*dJs6+!/c:~>
+rY0q`\c2ZgJcG'9!$0JerY0k~>
+!b,YLJcE:\!47=Wli-sLdJs5V!+LH~>
+!fDtsJcE:\!-!Mhli-r*dJs6+!/c:~>
+rY0q`\c2ZgJcG'9!$0JerY0k~>
+!b,YLJcE:\!47=Wli-sLdJs5V!+LH~>
+!fDtsJcE:\!-!Mhli-r*dJs6+!/c:~>
+rY0q`\c2ZgJcG'9!$0JerY0k~>
+!b,YLJcE:\!47=Wli-sLdJs5V!+LH~>
+!fDtsJcE:\!-!Mhli-r*dJs6+!/c:~>
+rY0q`\c2ZgJcG*:!$0GdrY0k~>
+!b,YLJcE:\!47=Wm/I'Md/X,U!+LH~>
+!fDtsJcE:\!-!Mhm/I&+d/X-*!/c:~>
+rY0q`\c2ZgJcG*:!$0GdrY0k~>
+!b,YLJcE:\!47=Wm/I'Md/X,U!+LH~>
+!fDtsJcE:\!-!Mhm/I&+d/X-*!/c:~>
+rY0q`\c2ZgJcG*:!$0GdrY0k~>
+!b,YLJcE:\!47=Wm/I'Md/X,U!+LH~>
+!fDtsJcE:\!-!Mhm/I&+d/X-*!/c:~>
+rY0q`\c2ZgJcG*:!$0GdrY0k~>
+!b,YLJcE:\!47=Wm/I'Md/X,U!+LH~>
+!fDtsJcE:\!-!Mhm/I&+d/X-*!/c:~>
+rY0q`\c2ZgJcG-;!$0DcrY0k~>
+!b,YLJcE:\!47=WmJd0Nci=#T!+LH~>
+!fDtsJcE:\!-!MhmJd/,ci=$)!/c:~>
+rY0q`\c2ZgJcG-;!$0DcrY0k~>
+!b,YLJcE:\!47=WmJd0Nci=#T!+LH~>
+!fDtsJcE:\!-!MhmJd/,ci=$)!/c:~>
+rY0q`\c2ZgJcG-;!?Jr%s8E^_~>
+!b,YLJcE:\!47=WmJd3O1!ot#@fTtg~>
+!fDtsJcE:\!-!MhmJd2-1!ot#N<"id~>
+rY0q`\c2ZgJcG-;s1cq\rY0k~>
+!b,YLJcE:\!47=WmJm2@d/X,U!+LH~>
+!fDtsJcE:\!-!MhmJm2@d/X-*!/c:~>
+rY0q`\c2ZgJcG-;!$0DcrY0k~>
+!b,YLJcE:\!47=WmJd0Nci=#T!+LH~>
+!fDtsJcE:\!-!MhmJd/,ci=$)!/c:~>
+rY0q`\c2ZgJcG0<!$0AbrY0k~>
+!b,YLJcE:\!47=Wmf*9OcN!oS!+LH~>
+!fDtsJcE:\!-!Mhmf*8-cN!p(!/c:~>
+rY0q`\c2ZgJcG0<!$0AbrY0k~>
+!b,YLJcE:\!47=Wmf*9OcN!oS!+LH~>
+!fDtsJcE:\!-!Mhmf*8-cN!p(!/c:~>
+rY0q`\c2ZgJcG0<!$0AbrY0k~>
+!b,YLJcE:\!47=Wmf*9OcN!oS!+LH~>
+!fDtsJcE:\!-!Mhmf*8-cN!p(!/c:~>
+rY0q`\c2ZgJcG0<!$0AbrY0k~>
+!b,YLJcE:\!47=Wmf*9OcN!oS!+LH~>
+!fDtsJcE:\!-!Mhmf*8-cN!p(!/c:~>
+rY0q`\c2ZgJcG3=!$0>arY0k~>
+!b,YLJcE:\!47=Wn,EBPc2[fR!+LH~>
+!fDtsJcE:\!-!Mhn,EA.c2[g'!/c:~>
+rY0q`\c2ZgJcG3=!$0>arY0k~>
+!b,YLJcE:\!47=Wn,EBPc2[fR!+LH~>
+!fDtsJcE:\!-!Mhn,EA.c2[g'!/c:~>
+rY0q`\c2ZgJcG3=!$0>arY0k~>
+!b,YLJcE:\!47=Wn,EBPc2[fR!+LH~>
+!fDtsJcE:\!-!Mhn,EA.c2[g'!/c:~>
+rY0q`\c2ZgJcG3=!$0>arY0k~>
+!b,YLJcE:\!47=Wn,EBPc2[fR!+LH~>
+!fDtsJcE:\!-!Mhn,EA.c2[g'!/c:~>
+rY0q`\c2ZgJcG3=!$0>arY0k~>
+!b,YLJcE:\!47=Wn,EBPc2[fR!+LH~>
+!fDtsJcE:\!-!Mhn,EA.c2[g'!/c:~>
+rY0q`\c2ZgJcG6>!$0;`rY0k~>
+!b,YLJcE:\!47=WnG`KQbl@]Q!+LH~>
+!fDtsJcE:\!-!MhnG`J/bl@^&!/c:~>
+rY0q`\c2ZgJcG6>!$0;`rY0k~>
+!b,YLJcE:\!47=WnG`KQbl@]Q!+LH~>
+!fDtsJcE:\!-!MhnG`J/bl@^&!/c:~>
+rY0q`\c2ZgJcG6>!$0;`rY0k~>
+!b,YLJcE:\!47=WnG`KQbl@]Q!+LH~>
+!fDtsJcE:\!-!MhnG`J/bl@^&!/c:~>
+rY0q`\c2ZgJcG6>!$0;`rY0k~>
+!b,YLJcE:\!47=WnG`KQbl@]Q!+LH~>
+!fDtsJcE:\!-!MhnG`J/bl@^&!/c:~>
+rY0q`\c2ZgJcG9?!$08_rY0k~>
+!b,YLJcE:\!47=Wnc&TRbQ%TP!+LH~>
+!fDtsJcE:\!-!Mhnc&S0bQ%U%!/c:~>
+rY0q`\c2ZgJcG9?!$08_rY0k~>
+!b,YLJcE:\!47=Wnc&TRbQ%TP!+LH~>
+!fDtsJcE:\!-!Mhnc&S0bQ%U%!/c:~>
+rY0q`\c2ZgJcG9?!$08_rY0k~>
+!b,YLJcE:\!47=Wnc&TRbQ%TP!+LH~>
+!fDtsJcE:\!-!Mhnc&S0bQ%U%!/c:~>
+rY0q`\c2ZgJcG9?!$08_rY0k~>
+!b,YLJcE:\!47=Wnc&TRbQ%TP!+LH~>
+!fDtsJcE:\!-!Mhnc&S0bQ%U%!/c:~>
+rY0q`\c2ZgJcG<@!$05^rY0k~>
+!b,YLJcE:\!47=Wo)A]Sb5_KO!+LH~>
+!fDtsJcE:\!-!Mho)A\1b5_L$!/c:~>
+rY0q`\c2ZgJcG<@!$05^rY0k~>
+!b,YLJcE:\!47=Wo)A]Sb5_KO!+LH~>
+!fDtsJcE:\!-!Mho)A\1b5_L$!/c:~>
+rY0q`\c2ZgJcG<@!$05^rY0k~>
+!b,YLJcE:\!47=Wo)A]Sb5_KO!+LH~>
+!fDtsJcE:\!-!Mho)A\1b5_L$!/c:~>
+rY0q`\c2ZgJcG<@!$05^rY0k~>
+!b,YLJcE:\!47=Wo)A]Sb5_KO!+LH~>
+!fDtsJcE:\!-!Mho)A\1b5_L$!/c:~>
+rY0q`\c2ZgJcG<@!$05^rY0k~>
+!b,YLJcE:\!47=Wo)A]Sb5_KO!+LH~>
+!fDtsJcE:\!-!Mho)A\1b5_L$!/c:~>
+rY0q`\c2ZgJcG?A!$02]rY0k~>
+!b,YLJcE:\!47=WoD\fTaoDBN!+LH~>
+!fDtsJcE:\!-!MhoD\e2aoDC#!/c:~>
+rY0q`\c2ZgJcG?A!$02]rY0k~>
+!b,YLJcE:\!47=WoD\fTaoDBN!+LH~>
+!fDtsJcE:\!-!MhoD\e2aoDC#!/c:~>
+rY0q`\c2ZgJcG?A!$02]rY0k~>
+!b,YLJcE:\!47=WoD\fTaoDBN!+LH~>
+!fDtsJcE:\!-!MhoD\e2aoDC#!/c:~>
+rY0q`\c2ZgJcG?A!$02]rY0k~>
+!b,YLJcE:\!47=WoD\fTaoDBN!+LH~>
+!fDtsJcE:\!-!MhoD\e2aoDC#!/c:~>
+rY0q`\c2ZgJcGBB!$0/\rY0k~>
+!b,YLJcE:\!47=Wo`"oUaT)9M!+LH~>
+!fDtsJcE:\!-!Mho`"n3aT):"!/c:~>
+rY0q`\c2ZgJcGBB!$0/\rY0k~>
+!b,YLJcE:\!47=Wo`"oUaT)9M!+LH~>
+!fDtsJcE:\!-!Mho`"n3aT):"!/c:~>
+rY0q`\c2ZgJcGBB!?Jqss8E^_~>
+!b,YLJcE:\!47=Wo`"rV1!0Iq@fTtg~>
+!fDtsJcE:\!-!Mho`"q41!0IqN<"id~>
+rY0q`\c2ZgJcGBBs1c\UrY0k~>
+!b,YLJcE:\!47=Wo`+qGaoDBN!+LH~>
+!fDtsJcE:\!-!Mho`+qGaoDC#!/c:~>
+rY0q`\c2ZgJcGEC!$0,[rY0k~>
+!b,YLJcE:\!47=Wp&>#Va8c0L!+LH~>
+!fDtsJcE:\!-!Mhp&>"4a8c1!!/c:~>
+rY0q`\c2ZgJcGEC!$0,[rY0k~>
+!b,YLJcE:\!47=Wp&>#Va8c0L!+LH~>
+!fDtsJcE:\!-!Mhp&>"4a8c1!!/c:~>
+rY0q`\c2ZgJcGEC!$0,[rY0k~>
+!b,YLJcE:\!47=Wp&>#Va8c0L!+LH~>
+!fDtsJcE:\!-!Mhp&>"4a8c1!!/c:~>
+rY0q`\c2ZgJcGEC!$0,[rY0k~>
+!b,YLJcE:\!47=Wp&>#Va8c0L!+LH~>
+!fDtsJcE:\!-!Mhp&>"4a8c1!!/c:~>
+rY0q`\c2ZgJcGHD!$0)ZrY0k~>
+!b,YLJcE:\!47=WpAY,W`rH'K!+LH~>
+!fDtsJcE:\!-!MhpAY+5`rH'u!/c:~>
+rY0q`\c2ZgJcGHD!$0)ZrY0k~>
+!b,YLJcE:\!47=WpAY,W`rH'K!+LH~>
+!fDtsJcE:\!-!MhpAY+5`rH'u!/c:~>
+rY0q`\c2ZgJcGHD!$0)ZrY0k~>
+!b,YLJcE:\!47=WpAY,W`rH'K!+LH~>
+!fDtsJcE:\!-!MhpAY+5`rH'u!/c:~>
+rY0q`\c2ZgJcGKE!$0&YrY0k~>
+!b,YLJcE:\!47=Wp\t5X`W,sJ!+LH~>
+!fDtsJcE:\!-!Mhp\t46`W,st!/c:~>
+rY0q`\c2ZgJcGKE!$0&YrY0k~>
+!b,YLJcE:\!47=Wp\t5X`W,sJ!+LH~>
+!fDtsJcE:\!-!Mhp\t46`W,st!/c:~>
+rY0q`\c2ZgJcGKE!$0&YrY0k~>
+!b,YLJcE:\!47=Wp\t5X`W,sJ!+LH~>
+!fDtsJcE:\!-!Mhp\t46`W,st!/c:~>
+rY0q`\c2ZgJcGNF!$0#XrY0k~>
+!b,YLJcE:\!47=Wq#:>Y`;fjI!+LH~>
+!fDtsJcE:\!-!Mhq#:=7`;fjs!/c:~>
+rY0q`\c2ZgJcGNF!$0#XrY0k~>
+!b,YLJcE:\!47=Wq#:>Y`;fjI!+LH~>
+!fDtsJcE:\!-!Mhq#:=7`;fjs!/c:~>
+rY0q`\c2ZgJcGNF!$0#XrY0k~>
+!b,YLJcE:\!47=Wq#:>Y`;fjI!+LH~>
+!fDtsJcE:\!-!Mhq#:=7`;fjs!/c:~>
+rY0q`\c2ZgJcGNF!$0#XrY0k~>
+!b,YLJcE:\!47=Wq#:>Y`;fjI!+LH~>
+!fDtsJcE:\!-!Mhq#:=7`;fjs!/c:~>
+rY0q`\c2ZgJcGQG!$/uWrY0k~>
+!b,YLJcE:\!47=Wq>UGZ_uKaH!+LH~>
+!fDtsJcE:\!-!Mhq>UF8_uKar!/c:~>
+rY0q`\c2ZgJcGQG!$/uWrY0k~>
+!b,YLJcE:\!47=Wq>UGZ_uKaH!+LH~>
+!fDtsJcE:\!-!Mhq>UF8_uKar!/c:~>
+rY0q`\c2ZgJcGQG!$/uWrY0k~>
+!b,YLJcE:\!47=Wq>UGZ_uKaH!+LH~>
+!fDtsJcE:\!-!Mhq>UF8_uKar!/c:~>
+rY0q`\c2ZgJcGTH!$/rVrY0k~>
+!b,YLJcE:\!47=WqYpP[_Z0XG!+LH~>
+!fDtsJcE:\!-!MhqYpO9_Z0Xq!/c:~>
+rY0q`\c2ZgJcGTH!$/rVrY0k~>
+!b,YLJcE:\!47=WqYpP[_Z0XG!+LH~>
+!fDtsJcE:\!-!MhqYpO9_Z0Xq!/c:~>
+rY0q`\c2ZgJcGTH!$/rVrY0k~>
+!b,YLJcE:\!47=WqYpP[_Z0XG!+LH~>
+!fDtsJcE:\!-!MhqYpO9_Z0Xq!/c:~>
+rY0q`\c2ZgJcGWI!$/oUrY0k~>
+!b,YLJcE:\!47=Wqu6Y\_>jOF!+LH~>
+!fDtsJcE:\!-!Mhqu6X:_>jOp!/c:~>
+rY0q`\c2ZgJcGWI!$/oUrY0k~>
+!b,YLJcE:\!47=Wqu6Y\_>jOF!+LH~>
+!fDtsJcE:\!-!Mhqu6X:_>jOp!/c:~>
+rY0q`\c2ZgJcGWI!$/oUrY0k~>
+!b,YLJcE:\!47=Wqu6Y\_>jOF!+LH~>
+!fDtsJcE:\!-!Mhqu6X:_>jOp!/c:~>
+rY0q`\c2ZgJcGWI!$/oUrY0k~>
+!b,YLJcE:\!47=Wqu6Y\_>jOF!+LH~>
+!fDtsJcE:\!-!Mhqu6X:_>jOp!/c:~>
+rY0q`\c2ZgJcGZJ!$/lTrY0k~>
+!b,YLJcE:\!47=Wr;Qb]_#OFE!+LH~>
+!fDtsJcE:\!-!Mhr;Qa;_#OFo!/c:~>
+rY0q`\c2ZgJcGZJ!?Jqks8E^_~>
+!b,YLJcE:\!47=Wr;Qe^0u<ni@fTtg~>
+!fDtsJcE:\!-!Mhr;Qd<0u<niN<"id~>
+rY0q`\c2ZgJcGZJs1cDMrY0k~>
+!b,YLJcE:\!47=Wr;ZdO_>jOF!+LH~>
+!fDtsJcE:\!-!Mhr;ZdO_>jOp!/c:~>
+rY0q`\c2ZgJcG]K!$/iSrY0k~>
+!b,YLJcE:\!47=WrVlk^^]4=D!+LH~>
+!fDtsJcE:\!-!MhrVlj<^]4=n!/c:~>
+rY0q`\c2ZgJcG]K!$/iSrY0k~>
+!b,YLJcE:\!47=WrVlk^^]4=D!+LH~>
+!fDtsJcE:\!-!MhrVlj<^]4=n!/c:~>
+rY0q`\c2ZgJcG]K!$/iSrY0k~>
+!b,YLJcE:\!47=WrVlk^^]4=D!+LH~>
+!fDtsJcE:\!-!MhrVlj<^]4=n!/c:~>
+rY0q`\c2ZgJcG]K!$/iSrY0k~>
+!b,YLJcE:\!47=WrVlk^^]4=D!+LH~>
+!fDtsJcE:\!-!MhrVlj<^]4=n!/c:~>
+rY0q`\c2ZgJcG`L!$/fRrY0k~>
+!b,YLJcE:\!47=Wrr2t_^An4C!+LH~>
+!fDtsJcE:\!-!Mhrr2s=^An4m!/c:~>
+rY4c"!?Jq+s3L]FiIV%.rr=(Rs8E^_~>
+!b,YLmJd3O0nKANrrBEWs8N#uPeR1t@fTtg~>
+!fDtsmJd2-0nKANrr@"hs8N#u*PVRRN<"id~>
+rY4c"!?Jq+s3L]FiIV%.rr=(Rs8E^_~>
+!b,YLmJd3O0nKANrrBEWs8N#uPeR1t@fTtg~>
+!fDtsmJd2-0nKANrr@"hs8N#u*PVRRN<"id~>
+rY4`!!$-Xjci4"(JcGcM!$/cQrY0k~>
+!b,YLm/I'MJcF'r!47=Ws8N(`^&S+B!+LH~>
+!fDtsm/I&+JcF'r!-!Mhs8N'>^&S+l!/c:~>
+rY4`!!$-Xjci4"(JcGcM!$/cQrY0k~>
+!b,YLm/I'MJcF'r!47=Ws8N(`^&S+B!+LH~>
+!fDtsm/I&+JcF'r!-!Mhs8N'>^&S+l!/c:~>
+rY4`!!$-Xjci4"(JcGcM!$/cQrY0k~>
+!b,YLm/I'MJcF'r!47=Ws8N(`^&S+B!+LH~>
+!fDtsm/I&+JcF'r!-!Mhs8N'>^&S+l!/c:~>
+rY4\u!$-Xjd/O+)Jc>cN*PDFO'S$~>
+!b,YLli-sLJcF*s!47=W!WSCss8QR/@Xn~>
+!fDtsli-r*JcF*s!-!Mh!WO1Qs8S&YMLY~>
+rY4\u!$-Xjd/O+)Jc>cN*PDFO'S$~>
+!b,YLli-sLJcF*s!47=W!WSCss8QR/@Xn~>
+!fDtsli-r*JcF*s!-!Mh!WO1Qs8S&YMLY~>
+rY4\u!$-Xjd/O+)Jc>cN*PDFO'S$~>
+!b,YLli-sLJcF*s!47=W!WSCss8QR/@Xn~>
+!fDtsli-r*JcF*s!-!Mh!WO1Qs8S&YMLY~>
+rY4\u!$-Xjd/O+)Jc>cN*PDFO'S$~>
+!b,YLli-sLJcF*s!47=W!WSCss8QR/@Xn~>
+!fDtsli-r*JcF*s!-!Mh!WO1Qs8S&YMLY~>
+rY4Yt!$-XjdJj4*Jc>]j]DqjEJ,~>
+!b,YLlMgjKJcF-t!47=W!0k+qs'l%<J,~>
+!fDtslMgi)JcF-t!-!Mh!$/]Os,@#9J,~>
+rY4Yt!$-XjdJj4*Jc>]j]DqjEJ,~>
+!b,YLlMgjKJcF-t!47=W!0k+qs'l%<J,~>
+!fDtslMgi)JcF-t!-!Mh!$/]Os,@#9J,~>
+rY4Yt!$-XjdJj4*Jc>]j]DqjEJ,~>
+!b,YLlMgjKJcF-t!47=W!0k+qs'l%<J,~>
+!fDtslMgi)JcF-t!-!Mh!$/]Os,@#9J,~>
+rY4Vs!$-Xjdf0=+K)Yfk])VaDJ,~>
+!b,YLl2LaJJcF0u!47@X!0k(ps'l%<J,~>
+!fDtsl2L`(JcF0u!-!Pi!$/ZNs,@#9J,~>
+rY4Vs!$-Xjdf0=+K)Yfk])VaDJ,~>
+!b,YLl2LaJJcF0u!47@X!0k(ps'l%<J,~>
+!fDtsl2L`(JcF0u!-!Pi!$/ZNs,@#9J,~>
+rY4Vs!$-Xjdf0=+K)Yfk])VaDJ,~>
+!b,YLl2LaJJcF0u!47@X!0k(ps'l%<J,~>
+!fDtsl2L`(JcF0u!-!Pi!$/ZNs,@#9J,~>
+rY4Sr!$-Xje,KF,K)Yfk])VaDJ,~>
+!b,YLkl1XIJcF4!!47@X!0k(ps'l%<J,~>
+!fDtskl1W'JcF4!!-!Pi!$/ZNs,@#9J,~>
+rY4Sr!$-Xje,KF,KDtol\c;XCJ,~>
+!b,YLkl1XIJcF4!!47CY!0k%os'l%<J,~>
+!fDtskl1W'JcF4!!-!Sj!$/WMs,@#9J,~>
+rY4Sr!$-Xje,KF,KDtrm^UjIE'S$~>
+!b,YLkl1XIJcF4!!47CY!L,=Ms8QR/@Xn~>
+!fDtskl1W'JcF4!!-!Sj!?Eo+s8S&YMLY~>
+rY4Sr!$-Xje,KF,KE(td])VaDJ,~>
+!b,YLkl1XIJcF4!!47CYs"V+bs'l%<J,~>
+!fDtskl1W'JcF4!!-!Sjs"V+bs,@#9J,~>
+rY4Pq!$-XjeGfO-K`;#m\GuOBJ,~>
+!b,YLkPkOHJcF7"!47FZ!0k"ns'l%<J,~>
+!fDtskPkN&JcF7"!-!Vk!$/TLs,@#9J,~>
+rY4Pq!$-XjeGfO-K`;#m\GuOBJ,~>
+!b,YLkPkOHJcF7"!47FZ!0k"ns'l%<J,~>
+!fDtskPkN&JcF7"!-!Vk!$/TLs,@#9J,~>
+rY4Pq!$-XjeGfO-K`;#m\GuOBJ,~>
+!b,YLkPkOHJcF7"!47FZ!0k"ns'l%<J,~>
+!fDtskPkN&JcF7"!-!Vk!$/TLs,@#9J,~>
+rY4Mp!$-Xjec,X.L&V,n\,ZFAJ,~>
+!b,YLk5PFGJcF:#!47I[!0jtms'l%<J,~>
+!fDtsk5PE%JcF:#!-!Yl!$/QKs,@#9J,~>
+rY4Mp!?Jq+s472MiJ%:3*Ol(J'S$~>
+!b,YLk5PIH0nKAUrrBE[rrA:ms8QR/@Xn~>
+!fDtsk5PH&0nKAUrr@"lrr=(Ks8S&YMLY~>
+rY4Mp!?Jq+s472MiJ%:3*Ol(J'S$~>
+!b,YLk5PIH0nKAUrrBE[rrA:ms8QR/@Xn~>
+!fDtsk5PH&0nKAUrr@"lrr=(Ks8S&YMLY~>
+rY4Jo!$-Xjf)Ga/LAq5o[f?=@J,~>
+!b,YLjo5=FJcF=$!47L\!0jqls'l%<J,~>
+!fDtsjo5<$JcF=$!-!\m!$/NJs,@#9J,~>
+rY4Jo!$-Xjf)Ga/LAq5o[f?=@J,~>
+!b,YLjo5=FJcF=$!47L\!0jqls'l%<J,~>
+!fDtsjo5<$JcF=$!-!\m!$/NJs,@#9J,~>
+rY4Gn!$-XjfDbj0L]7>p[K$4?J,~>
+!b,YLjSo4EJcF@%!47O]!0jnks'l%<J,~>
+!fDtsjSo3#JcF@%!-!_n!$/KIs,@#9J,~>
+rY4Gn!$-XjfDbj0L]7>p[K$4?J,~>
+!b,YLjSo4EJcF@%!47O]!0jnks'l%<J,~>
+!fDtsjSo3#JcF@%!-!_n!$/KIs,@#9J,~>
+rY4Dm!$-Xjf`(s1L]7>p[K$4?J,~>
+!b,YLj8T+DJcFC&!47O]!0jnks'l%<J,~>
+!fDtsj8T*"JcFC&!-!_n!$/KIs,@#9J,~>
+rY4Dm!$-Xjf`(s1M#RGq[/^+>J,~>
+!b,YLj8T+DJcFC&!47R^!0jkjs'l%<J,~>
+!fDtsj8T*"JcFC&!-!bo!$/HHs,@#9J,~>
+rY4Dm!$-Xjf`(s1M#RGq[/^+>J,~>
+!b,YLj8T+DJcFC&!47R^!0jkjs'l%<J,~>
+!fDtsj8T*"JcFC&!-!bo!$/HHs,@#9J,~>
+rY4Al!$-Xjg&D'2M#RGq[/^+>J,~>
+!b,YLir9"CJcFF'!47R^!0jkjs'l%<J,~>
+!fDtsir9!!JcFF'!-!bo!$/HHs,@#9J,~>
+rY4Al!$-Xjg&D'2M>mPrZiC"=J,~>
+!b,YLir9"CJcFF'!47U_!0jhis'l%<J,~>
+!fDtsir9!!JcFF'!-!ep!$/EGs,@#9J,~>
+rY4>k!$-XjgA_03M>mPrZiC"=J,~>
+!b,YLiVrnBJcFI(!47U_!0jhis'l%<J,~>
+!fDtsiVrluJcFI(!-!ep!$/EGs,@#9J,~>
+rY4>k!$-XjgA_03M>mPrZiC"=J,~>
+!b,YLiVrnBJcFI(!47U_!0jhis'l%<J,~>
+!fDtsiVrluJcFI(!-!ep!$/EGs,@#9J,~>
+rY4>k!$-XjgA_03MZ3YsZN'n<J,~>
+!b,YLiVrnBJcFI(!47X`!0jehs'l%<J,~>
+!fDtsiVrluJcFI(!-!hq!$/BFs,@#9J,~>
+rY4;j!$-Xjg]%94MZ3\t^U*t>'S$~>
+!b,YLi;WeAJcFL)!47X`!L,=Fs8QR/@Xn~>
+!fDtsi;WctJcFL)!-!hq!?Eo$s8S&YMLY~>
+rY4;j!$-Xjg]%94MZ<^kZiC"=J,~>
+!b,YLi;WeAJcFL)!47X`s"Uk[s'l%<J,~>
+!fDtsi;WctJcFL)!-!hqs"Uk[s,@#9J,~>
+rY48i!$-Xjh#@B5MuNbtZ2ae;J,~>
+!b,YLhu<\@JcFO*!47[a!0jbgs'l%<J,~>
+!fDtshu<ZsJcFO*!-!kr!$/?Es,@#9J,~>
+rY48i!$-Xjh#@B5MuNbtZ2ae;J,~>
+!b,YLhu<\@JcFO*!47[a!0jbgs'l%<J,~>
+!fDtshu<ZsJcFO*!-!kr!$/?Es,@#9J,~>
+rY45h!$-Xjh>[K6N;ikuYlF\:J,~>
+!b,YLhZ!S?JcFR+!47^b!0j_fs'l%<J,~>
+!fDtshZ!QrJcFR+!-!ns!$/<Ds,@#9J,~>
+rY45h!?Jq+s5*bUiJdd:*O,SC'S$~>
+!b,YLhZ!V@0nKA]rrBEbrrA:fs8QR/@Xn~>
+!fDtshZ!Ts0nKA]rr@"srr=(Ds8S&YMLY~>
+rY45h!?Jq+s5*bUiJmj;*O#MB'S$~>
+!b,YLhZ!V@0nKA]rrBEcrrA:es8QR/@Xn~>
+!fDtshZ!Ts0nKA]rr@"trr=(Cs8S&YMLY~>
+rY42g!$-XjhZ!T7NW/u!YQ+S9J,~>
+!b,YLh>[J>JcFU,!47ac!0j\es'l%<J,~>
+!fDtsh>[HqJcFU,!-!qt!$/9Cs,@#9J,~>
+rY42g!$-XjhZ!T7NrK)"Y5eJ8J,~>
+!b,YLh>[J>JcFU,!47dd!0jYds'l%<J,~>
+!fDtsh>[HqJcFU,!-!tu!$/6Bs,@#9J,~>
+rY4/f!$-Xjhu<]8NrK)"Y5eJ8J,~>
+!b,YLh#@A=JcFX-!47dd!0jYds'l%<J,~>
+!fDtsh#@?pJcFX-!-!tu!$/6Bs,@#9J,~>
+rY4/f!$-Xjhu<]8O8f2#XoJA7J,~>
+!b,YLh#@A=JcFX-!47ge!0jVcs'l%<J,~>
+!fDtsh#@?pJcFX-!-"#!!$/3As,@#9J,~>
+rY4/f!$-Xjhu<]8O8f2#XoJA7J,~>
+!b,YLh#@A=JcFX-!47ge!0jVcs'l%<J,~>
+!fDtsh#@?pJcFX-!-"#!!$/3As,@#9J,~>
+rY4,e!$-Xji;Wf9OT,;$XT/86J,~>
+!b,YLg]%8<JcF[.!47jf!0jSbs'l%<J,~>
+!fDtsg]%6oJcF[.!-"&"!$/0@s,@#9J,~>
+rY4,e!$-Xji;Wf9OT,;$XT/86J,~>
+!b,YLg]%8<JcF[.!47jf!0jSbs'l%<J,~>
+!fDtsg]%6oJcF[.!-"&"!$/0@s,@#9J,~>
+rY4)d!$-XjiVro:OoGD%X8i/5J,~>
+!b,YLgA_/;JcF^/!47mg!0jPas'l%<J,~>
+!fDtsgA_-nJcF^/!-")#!$/-?s,@#9J,~>
+rY4)d!$-XjiVro:OoGD%X8i/5J,~>
+!b,YLgA_/;JcF^/!47mg!0jPas'l%<J,~>
+!fDtsgA_-nJcF^/!-")#!$/-?s,@#9J,~>
+rY4&c!$-Xjir9#;P5bM&WrN&4J,~>
+!b,YLg&D&:JcFa0!47ph!0jM`s'l%<J,~>
+!fDtsg&D$mJcFa0!-",$!$/*>s,@#9J,~>
+rY4&c!$-Xjir9#;P5bP'^T7D6'S$~>
+!b,YLg&D&:JcFa0!47ph!L,=>s8QR/@Xn~>
+!fDtsg&D$mJcFa0!-",$!?Enqs8S&YMLY~>
+rY4&c!$-Xjir9#;PQ(\)^V?iLrY0k~>
+!b,YLg&D&:JcFa0!47si!gGDoX8i30!+LH~>
+!fDtsg&D$mJcFa0!-"/%!Za!MX8i3Z!/c:~>
+rY4#b!$-Xjj8T,<PQ(V'WW2r3J,~>
+!b,YLf`(r9JcFd1!47si!0jJ_s'l%<J,~>
+!fDtsf`(plJcFd1!-"/%!$/'=s,@#9J,~>
+rY4#b!$-Xjj8T,<PlC_(W;li2J,~>
+!b,YLf`(r9JcFd1!48!j!0jG^s'l%<J,~>
+!fDtsf`(plJcFd1!-"2&!$/$<s,@#9J,~>
+rY3ua!$-XjjSo5=PlC_(W;li2J,~>
+!b,YLfDbi8JcFg2!48!j!0jG^s'l%<J,~>
+!fDtsfDbgkJcFg2!-"2&!$/$<s,@#9J,~>
+rY3ua!?Jq+s5j7\iKaEC*N/r:'S$~>
+!b,YLfDbl90nKAdrrBEkrrA:]s8QR/@Xn~>
+!fDtsfDbjl0nKAdrr@#'rr=(;s8S&YMLY~>
+rY3ua!P]Y+s5j7\iKaEC*N/r:'S$~>
+!b,YLfDbk+P_&krrrBEkrrA:]s8QR/@Xn~>
+!fDtsfDbk+*J+7Prr@#'rr=(;s8S&YMLY~>
+rY3r`!$-Xjjo5>>QN$q*VZ6W0J,~>
+!b,YLf)G`7JcFj3!48'l!0jA\s'l%<J,~>
+!fDtsf)G^jJcFj3!-"8(!$.s:s,@#9J,~>
+rY3o_!$-Xjk5PG?Qi@%+V>pN/J,~>
+!b,YLec,W6JcFm4!48*m!0j>[s'l%<J,~>
+!fDtsec,UiJcFm4!-";)!$.p9s,@#9J,~>
+rY3o_!$-Xjk5PG?Qi@%+V>pN/J,~>
+!b,YLec,W6JcFm4!48*m!0j>[s'l%<J,~>
+!fDtsec,UiJcFm4!-";)!$.p9s,@#9J,~>
+rY3l^!$-XjkPkP@R/[.,V#UE.J,~>
+!b,YLeGfN5JcFp5!48-n!0j;Zs'l%<J,~>
+!fDtseGfLhJcFp5!-">*!$.m8s,@#9J,~>
+rY3l^!$-XjkPkP@R/[.,V#UE.J,~>
+!b,YLeGfN5JcFp5!48-n!0j;Zs'l%<J,~>
+!fDtseGfLhJcFp5!-">*!$.m8s,@#9J,~>
+rY3i]!$-Xjkl1YARK!7-U]:<-J,~>
+!b,YLe,KE4JcFs6!480o!0j8Ys'l%<J,~>
+!fDtse,KCgJcFs6!-"A+!$.j7s,@#9J,~>
+rY3f\!$-Xjl2LbBRK!7-U]:<-J,~>
+!b,YLdf0<3JcG!7!480o!0j8Ys'l%<J,~>
+!fDtsdf0:fJcG!7!-"A+!$.j7s,@#9J,~>
+rY3f\!$-Xjl2LbBRf<C/^SCi.'S$~>
+!b,YLdf0<3JcG!7!483p!L,=6s8QR/@Xn~>
+!fDtsdf0:fJcG!7!-"D,!?Enis8S&YMLY~>
+rY3c[!$-XjlMgkCS,WO1^V?QDrY0k~>
+!b,YLdJj32JcG$8!486q!gGDoU]:@(!+LH~>
+!fDtsdJj1eJcG$8!-"G-!Za!MU]:@R!/c:~>
+rY3c[!$-XjlMgkCS,WI/U&Y*+J,~>
+!b,YLdJj32JcG$8!486q!0j2Ws'l%<J,~>
+!fDtsdJj1eJcG$8!-"G-!$.d5s,@#9J,~>
+rY3`Z!$-Xjli-tDSGrR0T`>!*J,~>
+!b,YLd/O*1JcG'9!489r!0j/Vs'l%<J,~>
+!fDtsd/O(dJcG'9!-"J.!$.a4s,@#9J,~>
+rY3`Z!$-Xjli-tDSGrR0T`>!*J,~>
+!b,YLd/O*1JcG'9!489r!0j/Vs'l%<J,~>
+!fDtsd/O(dJcG'9!-"J.!$.a4s,@#9J,~>
+rY3]Y!?Jq+s6]gdiLTuK*M<B2'S$~>
+!b,YLci4$10nKAlrrBEsrrA:Us8QR/@Xn~>
+!fDtsci4"d0nKAlrr@#/rr=(3s8S&YMLY~>
+rY3]Y!P]Y+s6]gdiL^&L*M3<1'S$~>
+!b,YLci4##P_&l%rrBEtrrA:Ts8QR/@Xn~>
+!fDtsci4##*J+7Xrr@#0rr=(2s8S&YMLY~>
+rY3ZX!$-XjmJd1FT)Sd2T)\d(J,~>
+!b,YLcMmm/JcG-;!48?t!0j)Ts'l%<J,~>
+!fDtscMmkbJcG-;!-"P0!$.[2s,@#9J,~>
+rY3WW!$-Xjmf*:GTDnm3ScA['J,~>
+!b,YLc2Rd.JcG0<!48Bu!0j&Ss'l%<J,~>
+!fDtsc2RbaJcG0<!-"S1!$.X1s,@#9J,~>
+rY3WW!$-Xjmf*:GTDnm3ScA['J,~>
+!b,YLc2Rd.JcG0<!48Bu!0j&Ss'l%<J,~>
+!fDtsc2RbaJcG0<!-"S1!$.X1s,@#9J,~>
+rY3TV!$-Xjn,ECHT`5!4SH&R&J,~>
+!b,YLbl7[-JcG3=!48F!!0j#Rs'l%<J,~>
+!fDtsbl7Y`JcG3=!-"V2!$.U0s,@#9J,~>
+rY3QU!$-XjnG`LIT`5!4SH&R&J,~>
+!b,YLbPqR,JcG6>!48F!!0j#Rs'l%<J,~>
+!fDtsbPqP_JcG6>!-"V2!$.U0s,@#9J,~>
+rY3QU!$-XjnG`LIU&P-6^RY?''S$~>
+!b,YLbPqR,JcG6>!48I"!L,=/s8QR/@Xn~>
+!fDtsbPqP_JcG6>!-"Y3!?Enbs8S&YMLY~>
+rY3NT!$-Xjnc&UJUAk98^V?<=rY0k~>
+!b,YLb5VI+JcG9?!48L#!gGDoSH&V!!+LH~>
+!fDtsb5VG^JcG9?!-"\4!Za!MSH&VK!/c:~>
+rY3NT!$-Xjnc&UJU]1<7RK*7#J,~>
+!b,YLb5VI+JcG9?!48O$!0ioOs'l%<J,~>
+!fDtsb5VG^JcG9?!-"_5!$.L-s,@#9J,~>
+rY3KS!$-Xjo)A^KV#LE8R/d."J,~>
+!b,YLao;@*JcG<@!48R%!0ilNs'l%<J,~>
+!fDtsao;>]JcG<@!-"b6!$.I,s,@#9J,~>
+rY3KS!$-Xjo)A^KV>gN9QiI%!J,~>
+!b,YLao;@*JcG<@!48U&!0iiMs'l%<J,~>
+!fDtsao;>]JcG<@!-"e7!$.F+s,@#9J,~>
+rY3HR!?Jq+s7H<kiMHPS*LHg*'S$~>
+!b,YLaSu:*0nKAsrrBF&rrA:Ms8QR/@Xn~>
+!fDtsaSu8]0nKAsrr@#7rr=(+s8S&YMLY~>
+rY3HR!P]Y+s7H<kiMQVT*L?a)'S$~>
+!b,YLaSu8qP_&l,rrBF'rrA:Ls8QR/@Xn~>
+!fDtsaSu8q*J+7_rr@#8rr=(*s8S&YMLY~>
+rY3BP!$-Xjp&>$NVuH`;Q2ggtJ,~>
+!b,YL`r?%'JcGEC!48[(!0icKs'l%<J,~>
+!fDts`r?#ZJcGEC!-"k9!$.@)s,@#9J,~>
+rY3?O!$-XjpAY-OW;ci<PlL^sJ,~>
+!b,YL`W#q&JcGHD!48^)!0i`Js'l%<J,~>
+!fDts`W#oYJcGHD!-"n:!$.=(s,@#9J,~>
+rY3<N!$-Xjp\t6PWW)u>^Qect'S$~>
+!b,YL`;]h%JcGKE!48a*!L,='s8QR/@Xn~>
+!fDts`;]fXJcGKE!-"q;!?EnZs8S&YMLY~>
+rY3<N!$-Xjp\t6PWrE,@^V?$5rY0k~>
+!b,YL`;]h%JcGKE!48d+!gGDoPlLbn!+LH~>
+!fDts`;]fXJcGKE!-"t<!Za!MPlLcC!/c:~>
+rY39M!$-Xjq#:?QX8`/?OoPCpJ,~>
+!b,YL_uB_$JcGNF!48g,!0iWGs'l%<J,~>
+!fDts_uB]WJcGNF!-#"=!$.4%s,@#9J,~>
+rY36L!$-Xjq>UHRXT&8@OT5:oJ,~>
+!b,YL_Z'V#JcGQG!48j-!0iTFs'l%<J,~>
+!fDts_Z'TVJcGQG!-#%>!$.1$s,@#9J,~>
+rY33K!$-XjqYpQSXoAAAO8o1nJ,~>
+!b,YL_>aM"JcGTH!48m.!0iQEs'l%<J,~>
+!fDts_>aKUJcGTH!-#(?!$..#s,@#9J,~>
+rY30J!?Jq+s8;lsiN<+[*KU7"'S$~>
+!b,YL_#FG"0nKB&rrBF.rrA:Es8QR/@Xn~>
+!fDts_#FEU0nKB&rr@#?rr=(#s8S&YMLY~>
+rY30J!P]Y+s8;lsiNE1\*KL1!'S$~>
+!b,YL_#FEiP_&l4rrBF/rrA:Ds8QR/@Xn~>
+!fDts_#FEi*J+7grr@#@rr=("s8S&YMLY~>
+rY3*H!$-XjrVllVYQ"SCNW8tlJ,~>
+!b,YL^Ae1tJcG]K!48s0!0iKCs'l%<J,~>
+!fDts^Ae0RJcG]K!-#.A!$.(!s,@#9J,~>
+rY3'G!$-Xjrr2uWYl=_E^Q&9m'S$~>
+!b,YL^&J(sJcG`L!49!1!L,<us8QR/@Xn~>
+!fDts^&J'QJcG`L!-#1B!?EnSs8S&YMLY~>
+rY3$F!$-Xjs8N)XZN'qFs1aQnrY0k~>
+!b,YL]`.trJcGcM!49'3s-3O<NW9#g!+LH~>
+!fDts]`.sPJcGcM!-#7DruM+oNW9$<!/c:~>
+rY3!E!$-Xj!WV,brr='rs8E^_~>
+!b,YL]DhkqJc>cN['Tc4P_oG?@fTtg~>
+!fDts]DhjOJc>cNE3oQE*JsgrN<"id~>
+rY2sD!$-Xj!9(<b!$-mqrY0k~>
+!b,YL])MbpJc>_W[/U,jM#[Kb!+LH~>
+!fDts])MaNJc>^h[/U+HM#[L7!/c:~>
+rY2pC!?Jq-rrD#ds8O*ps8E^_~>
+!b,YL\c2\p0n]K+['p#7P_];=@fTtg~>
+!fDts\c2[N0n]K+E45fH*Ja[pN<"id~>
+rY2pC!P]Y-rrD#err='ns8E^_~>
+!b,YL\c2[bP_8u9[($&8P_K/;@fTtg~>
+!fDts\c2[b*J=@lE4>iI*JOOnN<"id~>
+rY2jA!$-am!9(Hf!?Jq/s8E^_~>
+!b,YL\,QGmK`;%Z\GlSo0noZ-@fTtg~>
+!fDts\,QFKK`;$k\GlRM0noZ-N<"id~>
+rY2g@ruHjo!9(NhruM-SL&_,dJ,~>
+!b,YL[f?AlLAq7\])Veps"T6-s'l%<J,~>
+!fDts[f?@JLAq6m])VdNs"T6-s,@#9J,~>
+rY2a>!$-jp!9(Qi!$-XjrY0k~>
+!b,YL[/U,jL]7@]]DhkqJcGa[!+LH~>
+!fDts[/U+HL]7?n]DhjOJcGb0!/c:~>
+rY2^=!$-mq!9(Tj!$-Xj!<<$4J,~>
+!b,YLZi:#iM#RI^]`.trJc>iP@q/tu~>
+!fDtsZi:"GM#RHo]`.sPJc>iPNK&gG~>
+rY2[<!?Jq4rrD#ls8O*js8W,u'S$~>
+!b,YLZMsri0oGu2[(cS?P_&l7s8QR/@Xn~>
+!fDtsZMsqG0oGu2E5)AP*J+7js8S&YMLY~>
+rY2[<!l#`rMuNe9^]+<T^OcFas8E^_~>
+!b,YLZMst\Pa%++!49N@!L,<is8N&u@fTtg~>
+!fDtsZMst\*?C(<!-#^Q!?EnGs8N&uN<"id~>
+rY2R9!$.$u!9(coruM-SJcG`LrY0k~>
+!b,YLYQ"TeN;imb_>jP"s"T*)rr<".!+LH~>
+!fDtsYQ"SCN;ils_>jNUs"T*)rr<"X!/c:~>
+rY2O8ruI."!9(iqruH[jqZ$O/J,~>
+!b,YLY5eNdNrK*d_uKb$JcGTHs'l%<J,~>
+!fDtsY5eMBNrK)u_uK`WJcGTHs,@#9J,~>
+rY2I6ruI4$!9(osruH[jq#C=-J,~>
+!b,YLXT/<bOT,<f`W,t&JcGNFs'l%<J,~>
+!fDtsXT/;@OT,<"`W,rYJcGNFs,@#9J,~>
+rY2C4ruI:&!9)$!rZ)!RJcGKErY0k~>
+!b,YLWrN*`P5bNhaT)7(!&9')p](8'!+LH~>
+!fDtsWrN)>P5bN$aT)5[!&9')p](8Q!/c:~>
+rY2C4s1eRSPlCaBbl@V^s8W,6JcGKErY0k~>
+!b,YLWrN)Rs-/cJ!49uMrKR?^s"T*)p](8'!+LH~>
+!fDtsWrN)RruI@(!-$0^r>kq<s"T*)p](8Q!/c:~>
+rY270rZ.@*!9)<)r>gIhn,NA$J,~>
+!b,YLVZ6X[Qi@&md/X'/JcG3=s'l%<J,~>
+!fDtsVZ6W9Qi@&)d/X%bJcG3=s,@#9J,~>
+rY2.-rZ.I-!9)H-r>kq<s1a-bn,NA$J,~>
+!b,YLU]:=XRf<ApeGoK3s8W*RJcG3=s'l%<J,~>
+!fDtsU]:<6Rf<A,eGoIfs8W*RJcG3=s,@#9J,~>
+rY2+,s1eRSSGrTJfDkgjJcFp5rY0k~>
+!b,YLUAt6Js-0&R!4:AXrfi!6kPtQl!+LH~>
+!fDtsUAt6JruIX0!-$QirZ-RikPtRA!/c:~>
+rY1t(ruI^2!9)]4r>bt>^V>@"kPtMqJ,~>
+!b,YLT)\hTT)Setg].5:!rju0JcFp5s'l%<J,~>
+!fDtsT)\g2T)Se0g].3m!rju0JcFp5s,@#9J,~>
+rY1n&r#MR4!9*/AoGrM_i;`cjJ,~>
+!b,YLSH&MOU]1>$kl::>JcF[.s'l%<J,~>
+!fDtsSH&L-U]1=5kl:8qJcF[.s,@#9J,~>
+rY1j\s1eTmq&RK6bT6Z@s1eKjs1a-Di8OYLJ,~>
+!b,YLS$`2Ms0VTd`jEsSrNuSZr3ZJYJ[F@Bs'l%<J,~>
+!fDtsRrJB^s)@cS`c0-BrG_ckr,DZjJT0Ods,@#9J,~>
+rY1Rrs1eU6qAno%iuS*us1eL3s1eI2s1eL3s1eI2s1eI2s1eL3s1a-bdJs1[J,~>
+!b,YLPQ1Y;s8Vq[li6"0rVumPr;ZdOqu?[Nr;ZdOqu?[Nqu?[Nr;ZdOJcF-ts'l%<J,~>
+!fDtsPQ1Y;s8Vp9li5ucrVumPr;ZdOqu?[Nr;ZdOqu?[Nqu?[Nr;ZdOJcF-ts,@#9J,~>
+rY1=ks1eU6lQ,s(s1eI2s1eL3s1eL3s1dXp!9&M/])VaDJ,~>
+!b,YLN;ro4s8VDLrVumPqu?[Nr;ZdOr;ZdOjSo4eJcE=]s'l%<J,~>
+!fDtsN;ro4s8VC*rVumPqu?[Nr;ZdOr;ZdOjSo4!JcE=]s,@#9J,~>
+rY1%cs1eL3s1eL3s1cSR!9&M/])VaDJ,~>
+!b,YLK`D',r;ZdOr;ZdO`r?%GJcE=]s'l%<J,~>
+!fDtsK`D',r;ZdOr;ZdO`r?$XJcE=]s,@#9J,~>
+rY0q`\c2ZgJcE=]rY0k~>
+!b,YLJcE:\!47=W])Ve?!+LH~>
+!fDtsJcE:\!-!Mh])Vei!/c:~>
+rY0q`\c2ZgJcE=]rY0k~>
+!b,YLJcE:\!47=W])Ve?!+LH~>
+!fDtsJcE:\!-!Mh])Vei!/c:~>
+rY0q`\c2ZgJcE=]rY0k~>
+!b,YLJcE:\!47=W])Ve?!+LH~>
+!fDtsJcE:\!-!Mh])Vei!/c:~>
+rY0q`\c2ZgJcE=]rY0k~>
+!b,YLJcE:\!47=W])Ve?!+LH~>
+!fDtsJcE:\!-!Mh])Vei!/c:~>
+rY0q`\c2ZgJcE=]rY0k~>
+!b,YLJcE:\!47=W])Ve?!+LH~>
+!fDtsJcE:\!-!Mh])Vei!/c:~>
+rY0q`\c2ZgJcE=]rY0k~>
+!b,YLJcE:\!47=W])Ve?!+LH~>
+!fDtsJcE:\!-!Mh])Vei!/c:~>
+rY0q`\c2ZgJcE=]rY0k~>
+!b,YLJcE:\!47=W])Ve?!+LH~>
+!fDtsJcE:\!-!Mh])Vei!/c:~>
+JJ<YLJJ@DaJ,~>
+!+LLhJRa7@m:--*J,~>
+!/c>eJW55?m>V+'J,~>
+JJ<YLJJ@DaJ,~>
+!+LLhJRa7@m:--*J,~>
+!/c>eJW55?m>V+'J,~>
+JJ<YLJJ@DaJ,~>
+JRX1>JR[qSJ,~>
+JVo#9JVrcNJ,~>
+%%EndData
+showpage
+%%Trailer
+end
+%%EOF
diff --git a/books/ps/v0plot3.eps b/books/ps/v0plot3.eps
new file mode 100644
index 0000000..a3ead88
--- /dev/null
+++ b/books/ps/v0plot3.eps
@@ -0,0 +1,1322 @@
+%!PS-Adobe-3.0 EPSF-3.0
+%%Creator: GIMP PostScript file plugin V 1.17 by Peter Kirchgessner
+%%Title: v0plot3.eps
+%%CreationDate: Thu Mar 19 15:49:18 2009
+%%DocumentData: Clean7Bit
+%%LanguageLevel: 2
+%%Pages: 1
+%%BoundingBox: 14 14 142 146
+%%EndComments
+%%BeginProlog
+% Use own dictionary to avoid conflicts
+10 dict begin
+%%EndProlog
+%%Page: 1 1
+% Translate for offset
+14.173228346456694 14.173228346456694 translate
+% Translate to begin of first scanline
+0 131.17539273108105 translate
+127.10551181102363 -131.17539273108105 scale
+% Image geometry
+406 419 8
+% Transformation matrix
+[ 406 0 0 419 0 0 ]
+% Strings to hold RGB-samples per scanline
+/rstr 406 string def
+/gstr 406 string def
+/bstr 406 string def
+{currentfile /ASCII85Decode filter /RunLengthDecode filter rstr readstring pop}
+{currentfile /ASCII85Decode filter /RunLengthDecode filter gstr readstring pop}
+{currentfile /ASCII85Decode filter /RunLengthDecode filter bstr readstring pop}
+true 3
+%%BeginData:        40036 ASCII Bytes
+colorimage
+r;V>^J\H]LotLA(J,~>
+r;V>VJ[U-<osXeuJ,~>
+r;V>VJ[U-<osXeuJ,~>
+rr<#4J_G\/W7h74o@sAojR_.-dH'oS!7Cf"s1\L4J,~>
+rr<#,J^f8#W71h*o@F#di:GP$bM`!D!6bAks0hq,J,~>
+rr<#,J^f8#W71h*o@F#di:GP$bM`!D!6bAks0hq,J,~>
+s8N)5J_5P+VUtn-o@X/jiUb_'cf+KK!71Sq!l"^7J,~>
+s8N)-J^T+tVU>J#o@*f_h=K+sakcR<!6P/e!k/./J,~>
+s8N)-J^T+tVU>J#o@*f_h=K+sakcR<!6P/e!k/./J,~>
+!WTn1f(1#8eq)D`ec=V!f)a.Ro@F#fhu;4.gYDbZs4dP)!6tDl!P\Sa~>
+!WTV)d.9k\d"0QTciDhldK.DCo?mZ[g]#Y$fDX+uf%9oL!6=u`!Oi#Y~>
+!WTV)d.<$Dd"0QTciDhldK.DCo?mZ[g]#Y$fDX+uf%9oL!6=u`!Oi#Y~>
+!WTn1e,UWaEW@55eFV/lec#O%qpY]+s4Znj$MFDrk1&Ais8268J^j;@!8[7s!R0BseH4Fbg\fS5
+bh^h"g?%GQe^`O<jk827bkolj^Ai]~>
+!WTV)c2^K0T)_K7cL]<`ci!gnqp#9!s4-P_$M=;pj3HK\s8200J^3l4!86ti!QEahcN;VSf)3i*
+`S&S`eD]B>cd1>(iRH3"`V[p][f:j~>
+!WTV)c2`XmcN&`OcL]<`ci!gnqp#9!s4-P_$M=;pj3HK\s8200J^3l4!86ti!QEahcN;VSf)3i*
+`S&S`eD]B>cd1>(iRH3"`V[p][f:j~>
+!5A9W!?cFW1]_V>J^X/<"5a(Xk53R.e(<(:dL,9mmf(_os4uQ/mt&pYdK&%ndfIVGqpPW*io0ga
+&B`bVe(<X:j4rGMhW*29e&qO8!5<s~>
+!4M^I!D9!YAHADqJ^!`0"5<eTj87%%cI0u*bR3R`m/G;cs4H'%m"*CPbQ-5cblP`5qoo2uhVJ+S
+&B!)Dc-kP(hq6T=g>LB'c,9D%!4IC~>
+!4M^I!Jf"qU]JesJ^!`0"5<eTj87%%cI0u*bR3R`m/G;cs4H'%m"*CPbQ-5cblP`5qoo2uhVJ+S
+&B!)Dc-kP(hq6T=g>LB'c,9D%!4IC~>
+!5A9U%>b&9f\+p1g"P6:h>`:^d.>U&lhg;Fd,t5Tp[6r=f?i^Zqr#iYs7$$Tmf)SLcjA\2e)12W
+d,k8SJ^F&9!86tk!Q`skd/r:`iV_((aP$R?#M\7oio8eRgA]J"aSO6`^46~>
+!4M^G%>t2?gYCQ=h;-rFhuARbb4Eaol21&Bb2`?Dp?UK5dE:PJqV96Js6fjOm/H8GapHr)cJ/BH
+b2WEEJ]dW-!7^V`!Q!:_b6$MRh>GFs_:8J-#M.bahVQoAf)Ehm_>;:S[X\~>
+!4M^G%>Fi3eCE(!f%8R-gAckXb4Eaol21&Bb2`?Dp?UK5dE:PJqV96Js6fjOm/H8GapHr)cJ/BH
+b2WEEJ]dW-!7^V`!Q!:_b6$MRh>GFs_:8J-#M.bahVQoAf)Ehm_>;:S[X\~>
+!5A9S#DiE5g"P-5g]$"1huAL`cL]=#qX<SGda.X^qpF7"e^a][lho)bs5iDCjlZTjr6>Yrp@-A`
+s4,EOs3lPEoZdHgo?RHXfDa))f&,BEh;[>Lf$D[_fDX#!g#:]?iS"1U!6=r]!5<s~>
+!4M^E!fI$5rS7\7hr*GOs,)BKo>hmHmGn2ian>E)bh<$Cd/W%fr5mXlioC'uj8[=#a9p,`m`=)]
+d)ar@c@O(/a8jZ[a8s'(rl>Mpg=tK:hV6c2aN2-ErQ#/lgt('3e,@>f^\Z"O[X\~>
+!4M^E%>Fi5f%8L)f\,!4h#E(ZaRdIlq<d5AbfTPPqTRXmd*VgNkkrQUs5N)=ioC'^r5]5gp$ToS
+s3Sj@s3?2:oZ.$\o>gsIdf.;rd+[72f\YB:d)a;Cdf%5jeD/X+gsc5C!5JBO!4IC~>
+!5A9R!f6m2r7hJ3hr*GmLk3hCboG@8in=@hc/AWcc/&ELh#Gp]s3fa'e_U8Th#Gk%bmVhepsI@B
+s4#<Srm-/?oZ[Bdo?@<Tec*f%hqd&Ag"Y9;hp'Ebec!_rf\bE:hq7nP!6+fZ!5<s~>
+!4M^C!K-pTh?MlqiSrksMLie>`Z3D+hUDMZ`n^UU`n:=:fDj1Ms30-qce/9Cf`04p`XBiVpWCM.
+s3AXBrlBZ1oYpmWo>UgEci1omg=Y!-eCN4'g;_.Gci(iedbE:$gX?&?!586K!4IC~>
+!4M^C%>Fi6f\+p1g"Y9:h>`1[`q77jdJr(Ps4bQKs5h8Qs3B6rce8?Bf`0:Ms3B9sc2GWia7/iG
+`n:=:`o-j;J]@?%!718V!PQhY`XLSRf%/@%f%A]r`kB^s`WafFeC<7$rPeiNqSiNDJ,~>
+!5A9P%>b&>h;6uEhr!ANiW"^bbOisXk5G;rm`kP!r6a:!daS6TlMSl\s3f[%dbFfMrQ>Q7r7B??
+g],mYqs8mWo?.-_o?%*Oe,IJudbNX8g#(T?d`T_Me,IJpf%ns7h:LK5rlP5YqTAlQJ,~>
+!4M^A%>t2Chr*DMiSieVj8Y!f`:UtJir/lnm)Jekr6*^lbg$1DkPW<Ns30*pbLcd;rPT'.r6ia,
+fDj:KqW`XMo>CXRo>C[Bc2PWic.L_)e_Jj1c,@Q5c2PWddG!('g=+a%rknfLqSWBBJ,~>
+!4M^A%>Fi7g"P-5gt^`BhuAC]`:UtJir/lnm)Jekr6*^lbg$1DkPW<Ns30*pbLcd;rPT'.r6ia,
+fDj:KqW`XMo>CXRo>C[Bc2PWic.L_)e_Jj1c,@Q5c2PWddG!('g=+a%rknfLqSWBBJ,~>
+!5A9N%>b&?hV[2Ii8N\Tj8Xpdan3[pp%-Y]m/?2DbOY,Us3\sKr;,0igAfRSs3TL"d/D)brs$j(
+s8Vu]b^mn-aT0`fa8jQ_f`]XBaMQ@%a9(,Kg\f,(_U6HGcJ7"+e(!1(gs4!^_YV@S^46~>
+!4M^?%>t2DiSrhUj5]4^jo:3h_Xt\bo^^8Ol29]<`:30Es3&:;r;,$^ec3hCs2rmlb5K3Urs$Wr
+s8VrZ`IYnt_>qdY_#VURe-*n0_7Ihe_#i3:f)3>q]$%q+aOnklcHb%gfZ:nF])'8D[X\~>
+!4M^?%>Fi9gYCQ=h;7&Hi;\L^_Xt\bo^^8Ol29]<`:30Es3&:;r;,$^ec3hCs2rmlb5K3Urs$Wr
+s8VrZ`IYnt_>qdY_#VURe-*n0_7Ihe_#i3:f)3>q]$%q+aOnklcHb%gfZ:nF])'8D[X\~>
+!5A9L%>b&Ai8NPMi8N\Tj8Xpda+;:B`rOHb`W=cFr7;,*fZ(qHchk]`g">!U`Xor3`l?9YgX=*]
+dbER$`l>gj`rNi(~>
+!4M^=%>t2FioB"Wj5]4^jo:3h^k';4^];IT^]2g]dKS.L^V@;"qnE3^e("<1&@ffr^W4sXbeLp;
+f@S$W^UX-U!4IC~>
+!4M^=%>Fi;h;-i@h;7&Hi;\L^^k';4^];IT^]2g]dKS.L^V@;"qnE3^e("<1&@ffr^W4sXbeLp;
+f@S$W^UX-U!4IC~>
+!5A9J%>b&Ai8NVQioB([jo:-f`IZ">`;n0^_uS$Xf*'=9`4jLn_ue3:c2>K\^<QYq!R&Xa`;e!Z
+_uROJ`;mW&~>
+!4M^;%>t2FioB%Yj5f=ak5U<i^4F#0^&Z1P]`H.$r6kht`kB'o`r!FNa4/0-]`GR]rk/?O`;RCL
+`;[FM[ed]<[X\~>
+!4M^;!ep[0rS7\7i8EVSs+Q$<J\J_0!65#O!QNRcdfn1>]tLkoqn3'OeAqL#!Og#I]`H*jrOr6L
+rk/<?qRus<J,~>
+!5A9H!/U=J!/Q3DJ]#(:!6auN!PQ\J_?%?no>1L@qSN<IJ,~>
+!4M^9!/gIL!/c??J\8S,!6"K?!OTf:\cK1Vo==q/qRcg:J,~>
+!4M^9!/:+G!/6!:J\8S,!6"K?!OTf:\cK1Vo==q/qRcg:J,~>
+!5A9Fo8%t6J\eq6!6OiJ!P?JF^]D'ho=t@<qS<0GJ,~>
+!4M^7o88+1J\&G(!5\9:!OBQ5\,inOo=+e+qRQ[8J,~>
+!4M^7o7_b,J\&G(!5\9:!OBQ5\,inOo=+e+qRQ[8J,~>
+J\H]LUV6`Ko=b79a7I"G\]=<U!4hp>J,~>
+J[U-<UUC0;o<n\(^[nl7YeTe<!3l:-J,~>
+J[U-<UUC0;o<n\(^[nl7YeTe<!3l:-J,~>
+rk<s`JcC<$nc/U&J,~>
+rjICXJcC<$nc/TsJ,~>
+rjICXJcC<$nc/TsJ,~>
+rk<s`JcC<$nc/U&J,~>
+rjICXJcC<$nc/TsJ,~>
+rjICXJcC<$nc/TsJ,~>
+rk<s`JcC<$nc/U&J,~>
+rjICXJcC<$nc/TsJ,~>
+rjICXJcC<$nc/TsJ,~>
+rk<s`JcC<$nc/U&J,~>
+rjICXJcC<$nc/TsJ,~>
+rjICXJcC<$nc/TsJ,~>
+rk<s`JcC<$nc/U&J,~>
+rjICXJcC<$nc/TsJ,~>
+rjICXJcC<$nc/TsJ,~>
+rk<s`JcC<$nc/U&J,~>
+rjICXJcC<$nc/TsJ,~>
+rjICXJcC<$nc/TsJ,~>
+rk<s`bl7[Xrr2u5rr3&7s8W)5rr;u4s8N)6rr3&7s8W)5s8W&4JcEsork<m~>
+rjICXbl7ZXrr2t5rr3%7s8W(5rr;t4s8N(6rr3%7s8W(5s8W%4JcEsorjI=~>
+rjICXbl7Ytrr2sQrr3$Ss8W'Qrr;sPs8N'Rrr3$Ss8W'Qs8W$PJcEsorjI=~>
+rk<s`c2Rs^s1eU6^]+65^]+65^]+65^]+67^]2(JrrTt8^]+6;^]4>Ks8Tibs3:TC^46~>
+rjICXc2Rr^s(_T6CB"55CB"55CB"55CB"57CB&&JrrQs8CB"5;CB+<Ks8Qhbs3:TC[X\~>
+rjICXc2Rr%s"XQR1&h1Q1&h1Q1&h1Q1&h1S1&j!-rrOqT1&h1W1&q8.s8Og)s3:TC[X\~>
+rk<s`cMmmZrr3/:s8Tk6^]"04^]+65^]+6=^]2'`s1c>K^]+6;^]4>Ks8Tibs3:TC^46~>
+rjICXcMmlZrr3.:s8Qj6CAn/4CB"55CB"5=CB&$`s(Z<KCB"5;CB+<Ks8Qhbs3:TC[X\~>
+rjICXcMml!rr3-Vs8OhR1&_+P1&h1Q1&h1Y1&is_s"Q8.1&h1W1&q8.s8Og)s3:TC[X\~>
+rk<s`cMmmZrr3/:s8Tk6^]"04^]+65^]+6;^]2(K^]2(Hrs$7<s1eU6^OcF0s8K`_~>
+rjICXcMmlZrr3.:s8Qj6CAn/4CB"55CB"5;CB&&KCB&&Hrs!6<s(_T6C4ZE0s8KHW~>
+rjICXcMml!rr3-Vs8OhR1&_+P1&h1Q1&h1W1&j!.1&j!+rrt4Xs"XQR0nKALs8KHW~>
+rk<s`cMmmZrr2u5rr2u5r;Qc3rr2u5rr32;s1eTKs1eO4!5JO5"2Fm9^OcF0s8K`_~>
+rjICXcMmlZrr2t5rr2t5r;Qb3rr2t5rr31;s(_RKs(_N4!,DN5")@l9C4ZE0s8KHW~>
+rjICXcMml!rr2sQrr2sQr;QaOrr2sQrr30Ws"XO.s"XKP!&=KQ"#9iU0nKALs8KHW~>
+rk<s`cN!gWs8N/8s1eO4!5JO5!5JO5!l+cMrr2u5rr2u5rVlu7s8Tibs3:TC^46~>
+rjICXcN!fWs8N.8s(_N4!,DN5!,DN5!c%aMrr2t5rr2t5rVlt7s8Qhbs3:TC[X\~>
+rjICXcN!ess8N-Ts"XKP!&=KQ!&=KQ!\s^0rr2sQrr2sQrVlsSs8Og)s3:TC[X\~>
+rk<s`cMmmZrr3/:s8Tk6^]"04^]+65^]+67^]2(Jrr^%9s1eL3"2Fm9^OcF0s8K`_~>
+rjICXcMmlZrr3.:s8Qj6CAn/4CB"55CB"57CB&&Jrr[$9s(_K3")@l9C4ZE0s8KHW~>
+rjICXcMml!rr3-Vs8OhR1&_+P1&h1Q1&h1S1&j!-rrY"Us"XHO"#9iU0nKALs8KHW~>
+rk<s`cMmmZrr3&7s1eR5!5JO5!5JO5!5JO5!l+cMrr3&7s1eI2"2Fm9^OcF0s8K`_~>
+rjICXcMmlZrr3%7s(_Q5!,DN5!,DN5!,DN5!c%aMrr3%7s(_H2")@l9C4ZE0s8KHW~>
+rjICXcMml!rr3$Ss"XNQ!&=KQ!&=KQ!&=KQ!\s^0rr3$Ss"XEN"#9iU0nKALs8KHW~>
+rk<s`cMmmZrr3&7s1eR5!l+d8rkJI4rkJL5!5JO5!Pe[4^B"<4^OcF/s8K`_~>
+rjICXcMmlZrr3%7s(_Q5!c%c8rbDH4rbDK5!,DN5!G_Z4C&n;4C4ZE/s8KHW~>
+rjICXcMml!rr3$Ss"XNQ!\s`Tr\=EPr\=HQ!&=KQ!AXWP0`_7P0nKAKs8KHW~>
+rk<s`JcC<$nc/U&J,~>
+rjICXJcC<$nc/TsJ,~>
+rjICXJcC<$nc/TsJ,~>
+rk<s`JcC<$nc/U&J,~>
+rjICXJcC<$nc/TsJ,~>
+rjICXJcC<$nc/TsJ,~>
+rk<s`JcC<$nc/U&J,~>
+rjICXJcC<$nc/TsJ,~>
+rjICXJcC<$nc/TsJ,~>
+rk<s`JcC<$nc/U&J,~>
+rjICXJcC<$nc/TsJ,~>
+rjICXJcC<$nc/TsJ,~>
+rk<s`JcC<$nc/U&J,~>
+rjICXJcC<$nc/TsJ,~>
+rjICXJcC<$nc/TsJ,~>
+rk<s`JcC<$nc/U&J,~>
+rjICXJcC<$nc/TsJ,~>
+rjICXJcC<$nc/TsJ,~>
+rk<s`JcC<$nc/U&J,~>
+rjICXJcC<$nc/TsJ,~>
+rjICXJcC<$nc/TsJ,~>
+rk<s`JcC<$nc/U&J,~>
+rjICXJcC<$nc/TsJ,~>
+rjICXJcC<$nc/TsJ,~>
+rk<s`JcC<$nc/U&J,~>
+rjICXJcC<$nc/TsJ,~>
+rjICXJcC<$nc/TsJ,~>
+rk<s`\c2ZgJcE=]rk<m~>
+rjICX\c2Z:JcE=]rjI=~>
+rjICX\c2YKJcE=]rjI=~>
+rk<s`\c2ZgJcE=]rk<m~>
+rjICX\c2Z:JcE=]rjI=~>
+rjICX\c2YKJcE=]rjI=~>
+rk<s`\c2ZgJcE=]rk<m~>
+rjICX\c2Z:JcE=]rjI=~>
+rjICX\c2YKJcE=]rjI=~>
+rk<s`\c2ZgJcE=]rk<m~>
+rjICX\c2Z:JcE=]rjI=~>
+rjICX\c2YKJcE=]rjI=~>
+rk<s`\c2ZgJcE=]rk<m~>
+rjICX\c2Z:JcE=]rjI=~>
+rjICX\c2YKJcE=]rjI=~>
+rk<s`\c2ZgJcE=]rk<m~>
+rjICX\c2Z:JcE=]rjI=~>
+rjICX\c2YKJcE=]rjI=~>
+rk<s`\c2ZgJcE=]rk<m~>
+rjICX\c2Z:JcE=]rjI=~>
+rjICX\c2YKJcE=]rjI=~>
+rk<s`\c2ZgJcF'rs1e"%rk<m~>
+rjICX\c2Z:JcF'rs"WsArjI=~>
+rjICX\c2YKJcF'rs"WsArjI=~>
+rk<s`\c2ZgJcF'rs1e"%rk<m~>
+rjICX\c2Z:JcF'rs"WsArjI=~>
+rjICX\c2YKJcF'rs"WsArjI=~>
+rk<s`\c2ZgJcF'r!$1J,rk<m~>
+rjICX\c2Z:JcF'r!0lmNrjI=~>
+rjICX\c2YKJcF'r!$1J,rjI=~>
+rk<s`\c2ZgJcF'r!$1J,rk<m~>
+rjICX\c2Z:JcF'r!0lmNrjI=~>
+rjICX\c2YKJcF'r!$1J,rjI=~>
+rk<s`\c2ZgJcF*s!$1G+rk<m~>
+rjICX\c2Z:JcF*s!0ljMrjI=~>
+rjICX\c2YKJcF*s!$1G+rjI=~>
+rk<s`\c2ZgJcF*s!$1G+rk<m~>
+rjICX\c2Z:JcF*s!0ljMrjI=~>
+rjICX\c2YKJcF*s!$1G+rjI=~>
+rk<s`\c2ZgJcF*s!$1G+rk<m~>
+rjICX\c2Z:JcF*s!0ljMrjI=~>
+rjICX\c2YKJcF*s!$1G+rjI=~>
+rk<s`\c2ZgJcF*s!$1G+rk<m~>
+rjICX\c2Z:JcF*s!0ljMrjI=~>
+rjICX\c2YKJcF*s!$1G+rjI=~>
+rk<s`\c2ZgJcF*s!$1G+rk<m~>
+rjICX\c2Z:JcF*s!0ljMrjI=~>
+rjICX\c2YKJcF*s!$1G+rjI=~>
+rk<s`\c2ZgJcF*s!$1G+rk<m~>
+rjICX\c2Z:JcF*s!0ljMrjI=~>
+rjICX\c2YKJcF*s!$1G+rjI=~>
+rk<s`\c2ZgJcF*s!$1G+rk<m~>
+rjICX\c2Z:JcF*s!0ljMrjI=~>
+rjICX\c2YKJcF*s!$1G+rjI=~>
+rk<s`\c2ZgJcF*s!$1G+rk<m~>
+rjICX\c2Z:JcF*s!0ljMrjI=~>
+rjICX\c2YKJcF*s!$1G+rjI=~>
+rk<s`\c2ZgJcF-t!$1D*rk<m~>
+rjICX\c2Z:JcF-t!0lgLrjI=~>
+rjICX\c2YKJcF-t!$1D*rjI=~>
+rk<s`\c2ZgJcF-t!$1D*rk<m~>
+rjICX\c2Z:JcF-t!0lgLrjI=~>
+rjICX\c2YKJcF-t!$1D*rjI=~>
+rk<s`\c2ZgJcF-t!$1D*rk<m~>
+rjICX\c2Z:JcF-t!0lgLrjI=~>
+rjICX\c2YKJcF-t!$1D*rjI=~>
+rk<s`\c2ZgJcF-t!$1D*rk<m~>
+rjICX\c2Z:JcF-t!0lgLrjI=~>
+rjICX\c2YKJcF-t!$1D*rjI=~>
+rk<s`\c2ZgJcF-t!$1D*rk<m~>
+rjICX\c2Z:JcF-t!0lgLrjI=~>
+rjICX\c2YKJcF-t!$1D*rjI=~>
+rk<s`\c2ZgJcF-t!$1D*rk<m~>
+rjICX\c2Z:JcF-t!0lgLrjI=~>
+rjICX\c2YKJcF-t!$1D*rjI=~>
+rk<s`\c2ZgJcF-t!$1D*rk<m~>
+rjICX\c2Z:JcF-t!0lgLrjI=~>
+rjICX\c2YKJcF-t!$1D*rjI=~>
+rk<s`\c2ZgJcF0u!$1A)rk<m~>
+rjICX\c2Z:JcF0u!0ldKrjI=~>
+rjICX\c2YKJcF0u!$1A)rjI=~>
+rk<s`\c2ZgJcF0u!$1A)rk<m~>
+rjICX\c2Z:JcF0u!0ldKrjI=~>
+rjICX\c2YKJcF0u!$1A)rjI=~>
+rk<s`\c2ZgJcF0u!$1A)rk<m~>
+rjICX\c2Z:JcF0u!0ldKrjI=~>
+rjICX\c2YKJcF0u!$1A)rjI=~>
+rk<s`\c2ZgJcF0u!$1A)rk<m~>
+rjICX\c2Z:JcF0u!0ldKrjI=~>
+rjICX\c2YKJcF0u!$1A)rjI=~>
+rk<s`\c2ZgJcF0u!$1A)rk<m~>
+rjICX\c2Z:JcF0u!0ldKrjI=~>
+rjICX\c2YKJcF0u!$1A)rjI=~>
+rk<s`\c2ZgJcF0u!$1A)rk<m~>
+rjICX\c2Z:JcF0u!0ldKrjI=~>
+rjICX\c2YKJcF0u!$1A)rjI=~>
+rk<s`\c2ZgJcF0u!$1A)rk<m~>
+rjICX\c2Z:JcF0u!0ldKrjI=~>
+rjICX\c2YKJcF0u!$1A)rjI=~>
+rk<s`\c2ZgJcF0u!$1A)rk<m~>
+rjICX\c2Z:JcF0u!0ldKrjI=~>
+rjICX\c2YKJcF0u!$1A)rjI=~>
+rk<s`\c2ZgJcF4!!$1>(rk<m~>
+rjICX\c2Z:JcF4!!0laJrjI=~>
+rjICX\c2YKJcF4!!$1>(rjI=~>
+rk<s`\c2ZgJcF4!!$1>(rk<m~>
+rjICX\c2Z:JcF4!!0laJrjI=~>
+rjICX\c2YKJcF4!!$1>(rjI=~>
+rk<s`\c2ZgJcF4!!$1>(rk<m~>
+rjICX\c2Z:JcF4!!0laJrjI=~>
+rjICX\c2YKJcF4!!$1>(rjI=~>
+rk<s`\c2ZgJcF4!!$1>(rk<m~>
+rjICX\c2Z:JcF4!!0laJrjI=~>
+rjICX\c2YKJcF4!!$1>(rjI=~>
+rk<s`\c2ZgJcF4!!$1>(rk<m~>
+rjICX\c2Z:JcF4!!0laJrjI=~>
+rjICX\c2YKJcF4!!$1>(rjI=~>
+rk<s`\c2ZgJcF4!!$1>(rk<m~>
+rjICX\c2Z:JcF4!!0laJrjI=~>
+rjICX\c2YKJcF4!!$1>(rjI=~>
+rk<s`\c2ZgJcF4!!$1>(rk<m~>
+rjICX\c2Z:JcF4!!0laJrjI=~>
+rjICX\c2YKJcF4!!$1>(rjI=~>
+rk<s`\c2ZgJcF4!!$1>(rk<m~>
+rjICX\c2Z:JcF4!!0laJrjI=~>
+rjICX\c2YKJcF4!!$1>(rjI=~>
+rk<s`\c2ZgJcF7"!$1;'rk<m~>
+rjICX\c2Z:JcF7"!0l^IrjI=~>
+rjICX\c2YKJcF7"!$1;'rjI=~>
+rk<s`\c2ZgJcF7"!$1;'rk<m~>
+rjICX\c2Z:JcF7"!0l^IrjI=~>
+rjICX\c2YKJcF7"!$1;'rjI=~>
+rk<s`\c2ZgJcF7"!$1;'rk<m~>
+rjICX\c2Z:JcF7"!0l^IrjI=~>
+rjICX\c2YKJcF7"!$1;'rjI=~>
+rk<s`\c2ZgJcF7"!$1;'rk<m~>
+rjICX\c2Z:JcF7"!0l^IrjI=~>
+rjICX\c2YKJcF7"!$1;'rjI=~>
+rk<s`\c2ZgJcF7"!$1;'rk<m~>
+rjICX\c2Z:JcF7"!0l^IrjI=~>
+rjICX\c2YKJcF7"!$1;'rjI=~>
+rk<s`\c2ZgJcF7"!$1;'rk<m~>
+rjICX\c2Z:JcF7"!0l^IrjI=~>
+rjICX\c2YKJcF7"!$1;'rjI=~>
+rk<s`\c2ZgJcF7"!$1;'rk<m~>
+rjICX\c2Z:JcF7"!0l^IrjI=~>
+rjICX\c2YKJcF7"!$1;'rjI=~>
+rk<s`\c2ZgJcF:#!$18&rk<m~>
+rjICX\c2Z:JcF:#!0l[HrjI=~>
+rjICX\c2YKJcF:#!$18&rjI=~>
+rk<s`\c2ZgJcF:#!$18&rk<m~>
+rjICX\c2Z:JcF:#!0l[HrjI=~>
+rjICX\c2YKJcF:#!$18&rjI=~>
+rk<s`\c2ZgJcF:#!$18&rk<m~>
+rjICX\c2Z:JcF:#!0l[HrjI=~>
+rjICX\c2YKJcF:#!$18&rjI=~>
+rk<s`\c2ZgJcF:#!$18&rk<m~>
+rjICX\c2Z:JcF:#!0l[HrjI=~>
+rjICX\c2YKJcF:#!$18&rjI=~>
+rk<s`\c2ZgJcF:#!$18&rk<m~>
+rjICX\c2Z:JcF:#!0l[HrjI=~>
+rjICX\c2YKJcF:#!$18&rjI=~>
+rk<s`\c2ZgJcF:#!$18&rk<m~>
+rjICX\c2Z:JcF:#!0l[HrjI=~>
+rjICX\c2YKJcF:#!$18&rjI=~>
+rk<s`\c2ZgJcF:#!$18&rk<m~>
+rjICX\c2Z:JcF:#!0l[HrjI=~>
+rjICX\c2YKJcF:#!$18&rjI=~>
+rk<s`\c2ZgJcF:#!$18&rk<m~>
+rjICX\c2Z:JcF:#!0l[HrjI=~>
+rjICX\c2YKJcF:#!$18&rjI=~>
+rk<s`\c2ZgJcF=$!$15%rk<m~>
+rjICX\c2Z:JcF=$!0lXGrjI=~>
+rjICX\c2YKJcF=$!$15%rjI=~>
+rk<s`\c2ZgJcF=$!$15%rk<m~>
+rjICX\c2Z:JcF=$!0lXGrjI=~>
+rjICX\c2YKJcF=$!$15%rjI=~>
+rk<s`\c2ZgJcF=$!$15%rk<m~>
+rjICX\c2Z:JcF=$!0lXGrjI=~>
+rjICX\c2YKJcF=$!$15%rjI=~>
+rk<s`\c2ZgJcF=$!?Jr<s8K`_~>
+rjICX\c2Z:JcF=$!L,>%s8KHW~>
+rjICX\c2YKJcF=$!?EoXs8KHW~>
+rk<s`\c2ZgJcF=$s1dasrk<m~>
+rjICX\c2Z:JcF=$s"W^:rjI=~>
+rjICX\c2YKJcF=$s"W^:rjI=~>
+rk<s`\c2ZgJcF=$!$15%rk<m~>
+rjICX\c2Z:JcF=$!0lXGrjI=~>
+rjICX\c2YKJcF=$!$15%rjI=~>
+rk<s`\c2ZgJcF@%!$12$rk<m~>
+rjICX\c2Z:JcF@%!0lUFrjI=~>
+rjICX\c2YKJcF@%!$12$rjI=~>
+rk<s`\c2ZgJcF@%!$12$rk<m~>
+rjICX\c2Z:JcF@%!0lUFrjI=~>
+rjICX\c2YKJcF@%!$12$rjI=~>
+rk<s`\c2ZgJcF@%!$12$rk<m~>
+rjICX\c2Z:JcF@%!0lUFrjI=~>
+rjICX\c2YKJcF@%!$12$rjI=~>
+rk<s`\c2ZgJcF@%!$12$rk<m~>
+rjICX\c2Z:JcF@%!0lUFrjI=~>
+rjICX\c2YKJcF@%!$12$rjI=~>
+rk<s`\c2ZgJcF@%!$12$rk<m~>
+rjICX\c2Z:JcF@%!0lUFrjI=~>
+rjICX\c2YKJcF@%!$12$rjI=~>
+rk<s`\c2ZgJcF@%!$12$rk<m~>
+rjICX\c2Z:JcF@%!0lUFrjI=~>
+rjICX\c2YKJcF@%!$12$rjI=~>
+rk<s`\c2ZgJcFC&!$1/#rk<m~>
+rjICX\c2Z:JcFC&!0lRErjI=~>
+rjICX\c2YKJcFC&!$1/#rjI=~>
+rk<s`\c2ZgJcFC&!$1/#rk<m~>
+rjICX\c2Z:JcFC&!0lRErjI=~>
+rjICX\c2YKJcFC&!$1/#rjI=~>
+rk<s`\c2ZgJcFC&!$1/#rk<m~>
+rjICX\c2Z:JcFC&!0lRErjI=~>
+rjICX\c2YKJcFC&!$1/#rjI=~>
+rk<s`\c2ZgJcFC&!$1/#rk<m~>
+rjICX\c2Z:JcFC&!0lRErjI=~>
+rjICX\c2YKJcFC&!$1/#rjI=~>
+rk<s`\c2ZgJcFC&!$1/#rk<m~>
+rjICX\c2Z:JcFC&!0lRErjI=~>
+rjICX\c2YKJcFC&!$1/#rjI=~>
+rk<s`\c2ZgJcFC&!$1/#rk<m~>
+rjICX\c2Z:JcFC&!0lRErjI=~>
+rjICX\c2YKJcFC&!$1/#rjI=~>
+rk<s`\c2ZgJcFF'!$1,"rk<m~>
+rjICX\c2Z:JcFF'!0lODrjI=~>
+rjICX\c2YKJcFF'!$1,"rjI=~>
+rk<s`\c2ZgJcFF'!$1,"rk<m~>
+rjICX\c2Z:JcFF'!0lODrjI=~>
+rjICX\c2YKJcFF'!$1,"rjI=~>
+rk<s`\c2ZgJcFF'!$1,"rk<m~>
+rjICX\c2Z:JcFF'!0lODrjI=~>
+rjICX\c2YKJcFF'!$1,"rjI=~>
+rk<s`\c2ZgJcFF'!$1,"rk<m~>
+rjICX\c2Z:JcFF'!0lODrjI=~>
+rjICX\c2YKJcFF'!$1,"rjI=~>
+rk<s`\c2ZgJcFF'!$1,"rk<m~>
+rjICX\c2Z:JcFF'!0lODrjI=~>
+rjICX\c2YKJcFF'!$1,"rjI=~>
+rk<s`\c2ZgJcFF'!$1,"rk<m~>
+rjICX\c2Z:JcFF'!0lODrjI=~>
+rjICX\c2YKJcFF'!$1,"rjI=~>
+rk<s`\c2ZgJcFI(!$1)!rk<m~>
+rjICX\c2Z:JcFI(!0lLCrjI=~>
+rjICX\c2YKJcFI(!$1)!rjI=~>
+rk<s`\c2ZgJcFI(!$1)!rk<m~>
+rjICX\c2Z:JcFI(!0lLCrjI=~>
+rjICX\c2YKJcFI(!$1)!rjI=~>
+rk<s`\c2ZgJcFI(!$1)!rk<m~>
+rjICX\c2Z:JcFI(!0lLCrjI=~>
+rjICX\c2YKJcFI(!$1)!rjI=~>
+rk<s`\c2ZgJcFI(!$1)!rk<m~>
+rjICX\c2Z:JcFI(!0lLCrjI=~>
+rjICX\c2YKJcFI(!$1)!rjI=~>
+rk<s`\c2ZgJcFI(!$1)!rk<m~>
+rjICX\c2Z:JcFI(!0lLCrjI=~>
+rjICX\c2YKJcFI(!$1)!rjI=~>
+rk<s`\c2ZgJcFI(!$1)!rk<m~>
+rjICX\c2Z:JcFI(!0lLCrjI=~>
+rjICX\c2YKJcFI(!$1)!rjI=~>
+rk<s`\c2ZgJcFL)!$1%urk<m~>
+rjICX\c2Z:JcFL)!0lIBrjI=~>
+rjICX\c2YKJcFL)!$1%urjI=~>
+rk<s`\c2ZgJcFL)!$1%urk<m~>
+rjICX\c2Z:JcFL)!0lIBrjI=~>
+rjICX\c2YKJcFL)!$1%urjI=~>
+rk<s`\c2ZgJcFL)!$1%urk<m~>
+rjICX\c2Z:JcFL)!0lIBrjI=~>
+rjICX\c2YKJcFL)!$1%urjI=~>
+rk<s`\c2ZgJcFL)!$1%urk<m~>
+rjICX\c2Z:JcFL)!0lIBrjI=~>
+rjICX\c2YKJcFL)!$1%urjI=~>
+rk<s`\c2ZgJcFL)!$1%urk<m~>
+rjICX\c2Z:JcFL)!0lIBrjI=~>
+rjICX\c2YKJcFL)!$1%urjI=~>
+rk<s`\c2ZgJcFL)!$1%urk<m~>
+rjICX\c2Z:JcFL)!0lIBrjI=~>
+rjICX\c2YKJcFL)!$1%urjI=~>
+rk<s`\c2ZgJcFO*!$1"trk<m~>
+rjICX\c2Z:JcFO*!0lFArjI=~>
+rjICX\c2YKJcFO*!$1"trjI=~>
+rk<s`\c2ZgJcFO*!$1"trk<m~>
+rjICX\c2Z:JcFO*!0lFArjI=~>
+rjICX\c2YKJcFO*!$1"trjI=~>
+rk<s`\c2ZgJcFO*!$1"trk<m~>
+rjICX\c2Z:JcFO*!0lFArjI=~>
+rjICX\c2YKJcFO*!$1"trjI=~>
+rk<s`\c2ZgJcFO*!$1"trk<m~>
+rjICX\c2Z:JcFO*!0lFArjI=~>
+rjICX\c2YKJcFO*!$1"trjI=~>
+rk<s`\c2ZgJcFO*!$1"trk<m~>
+rjICX\c2Z:JcFO*!0lFArjI=~>
+rjICX\c2YKJcFO*!$1"trjI=~>
+rk<s`\c2ZgJcFO*!$1"trk<m~>
+rjICX\c2Z:JcFO*!0lFArjI=~>
+rjICX\c2YKJcFO*!$1"trjI=~>
+rk<s`\c2ZgJcFR+!$0tsrk<m~>
+rjICX\c2Z:JcFR+!0lC@rjI=~>
+rjICX\c2YKJcFR+!$0tsrjI=~>
+rk<s`\c2ZgJcFR+!$0tsrk<m~>
+rjICX\c2Z:JcFR+!0lC@rjI=~>
+rjICX\c2YKJcFR+!$0tsrjI=~>
+rk<s`\c2ZgJcFR+!$0tsrk<m~>
+rjICX\c2Z:JcFR+!0lC@rjI=~>
+rjICX\c2YKJcFR+!$0tsrjI=~>
+rk<s`\c2ZgJcFR+!$0tsrk<m~>
+rjICX\c2Z:JcFR+!0lC@rjI=~>
+rjICX\c2YKJcFR+!$0tsrjI=~>
+rk<s`\c2ZgJcFR+!$0tsrk<m~>
+rjICX\c2Z:JcFR+!0lC@rjI=~>
+rjICX\c2YKJcFR+!$0tsrjI=~>
+rk<s`\c2ZgJcFR+!$0tsrk<m~>
+rjICX\c2Z:JcFR+!0lC@rjI=~>
+rjICX\c2YKJcFR+!$0tsrjI=~>
+rk<s`\c2ZgJcFU,!$0qrrk<m~>
+rjICX\c2Z:JcFU,!0l@?rjI=~>
+rjICX\c2YKJcFU,!$0qrrjI=~>
+rk<s`\c2ZgJcFU,!$0qrrk<m~>
+rjICX\c2Z:JcFU,!0l@?rjI=~>
+rjICX\c2YKJcFU,!$0qrrjI=~>
+rk<s`\c2ZgJcFU,!$0qrrk<m~>
+rjICX\c2Z:JcFU,!0l@?rjI=~>
+rjICX\c2YKJcFU,!$0qrrjI=~>
+rk<s`\c2ZgJcFU,!?Jr4s8K`_~>
+rjICX\c2Z:JcFU,!L,=rs8KHW~>
+rjICX\c2YKJcFU,!?EoPs8KHW~>
+rk<s`\c2ZgJcFU,s1dIkrk<m~>
+rjICX\c2Z:JcFU,s"WF2rjI=~>
+rjICX\c2YKJcFU,s"WF2rjI=~>
+rk<s`\c2ZgJcFU,!$0qrrk<m~>
+rjICX\c2Z:JcFU,!0l@?rjI=~>
+rjICX\c2YKJcFU,!$0qrrjI=~>
+rk<s`\c2ZgJcFX-!$0nqrk<m~>
+rjICX\c2Z:JcFX-!0l=>rjI=~>
+rjICX\c2YKJcFX-!$0nqrjI=~>
+rk<s`\c2ZgJcFX-!$0nqrk<m~>
+rjICX\c2Z:JcFX-!0l=>rjI=~>
+rjICX\c2YKJcFX-!$0nqrjI=~>
+rk<s`\c2ZgJcFX-!$0nqrk<m~>
+rjICX\c2Z:JcFX-!0l=>rjI=~>
+rjICX\c2YKJcFX-!$0nqrjI=~>
+rk<s`\c2ZgJcFX-!$0nqrk<m~>
+rjICX\c2Z:JcFX-!0l=>rjI=~>
+rjICX\c2YKJcFX-!$0nqrjI=~>
+rk<s`\c2ZgJcFX-!$0nqrk<m~>
+rjICX\c2Z:JcFX-!0l=>rjI=~>
+rjICX\c2YKJcFX-!$0nqrjI=~>
+rk<s`\c2ZgJcFX-!$0nqrk<m~>
+rjICX\c2Z:JcFX-!0l=>rjI=~>
+rjICX\c2YKJcFX-!$0nqrjI=~>
+rk<s`\c2ZgJcF[.!$0kprk<m~>
+rjICX\c2Z:JcF[.!0l:=rjI=~>
+rjICX\c2YKJcF[.!$0kprjI=~>
+rk<s`\c2ZgJcF[.!$0kprk<m~>
+rjICX\c2Z:JcF[.!0l:=rjI=~>
+rjICX\c2YKJcF[.!$0kprjI=~>
+rk<s`\c2ZgJcF[.!$0kprk<m~>
+rjICX\c2Z:JcF[.!0l:=rjI=~>
+rjICX\c2YKJcF[.!$0kprjI=~>
+rk<s`\c2ZgJcF[.!$0kprk<m~>
+rjICX\c2Z:JcF[.!0l:=rjI=~>
+rjICX\c2YKJcF[.!$0kprjI=~>
+rk<s`\c2ZgJcF[.!$0kprk<m~>
+rjICX\c2Z:JcF[.!0l:=rjI=~>
+rjICX\c2YKJcF[.!$0kprjI=~>
+rk<s`\c2ZgJcF[.!$0kprk<m~>
+rjICX\c2Z:JcF[.!0l:=rjI=~>
+rjICX\c2YKJcF[.!$0kprjI=~>
+rk<s`\c2ZgJcF^/!$0hork<m~>
+rjICX\c2Z:JcF^/!0l7<rjI=~>
+rjICX\c2YKJcF^/!$0horjI=~>
+rk<s`\c2ZgJcF^/!$0hork<m~>
+rjICX\c2Z:JcF^/!0l7<rjI=~>
+rjICX\c2YKJcF^/!$0horjI=~>
+rk<s`\c2ZgJcF^/!$0hork<m~>
+rjICX\c2Z:JcF^/!0l7<rjI=~>
+rjICX\c2YKJcF^/!$0horjI=~>
+rk<s`\c2ZgJcF^/!$0hork<m~>
+rjICX\c2Z:JcF^/!0l7<rjI=~>
+rjICX\c2YKJcF^/!$0horjI=~>
+rk<s`\c2ZgJcF^/!$0hork<m~>
+rjICX\c2Z:JcF^/!0l7<rjI=~>
+rjICX\c2YKJcF^/!$0horjI=~>
+rk<s`\c2ZgJcF^/!$0hork<m~>
+rjICX\c2Z:JcF^/!0l7<rjI=~>
+rjICX\c2YKJcF^/!$0horjI=~>
+rk<s`\c2ZgJcFa0!$0enrk<m~>
+rjICX\c2Z:JcFa0!0l4;rjI=~>
+rjICX\c2YKJcFa0!$0enrjI=~>
+rk<s`\c2ZgJcFa0!$0enrk<m~>
+rjICX\c2Z:JcFa0!0l4;rjI=~>
+rjICX\c2YKJcFa0!$0enrjI=~>
+rk<s`\c2ZgJcFa0!$0enrk<m~>
+rjICX\c2Z:JcFa0!0l4;rjI=~>
+rjICX\c2YKJcFa0!$0enrjI=~>
+rk<s`\c2ZgJcFa0!$0enrk<m~>
+rjICX\c2Z:JcFa0!0l4;rjI=~>
+rjICX\c2YKJcFa0!$0enrjI=~>
+rk<s`\c2ZgJcFa0!$0enrk<m~>
+rjICX\c2Z:JcFa0!0l4;rjI=~>
+rjICX\c2YKJcFa0!$0enrjI=~>
+rk<s`\c2ZgJcFa0!$0enrk<m~>
+rjICX\c2Z:JcFa0!0l4;rjI=~>
+rjICX\c2YKJcFa0!$0enrjI=~>
+rk<s`\c2ZgJcFd1!$0bmrk<m~>
+rjICX\c2Z:JcFd1!0l1:rjI=~>
+rjICX\c2YKJcFd1!$0bmrjI=~>
+rk<s`\c2ZgJcFd1!$0bmrk<m~>
+rjICX\c2Z:JcFd1!0l1:rjI=~>
+rjICX\c2YKJcFd1!$0bmrjI=~>
+rk<s`\c2ZgJcFd1!$0bmrk<m~>
+rjICX\c2Z:JcFd1!0l1:rjI=~>
+rjICX\c2YKJcFd1!$0bmrjI=~>
+rk<s`\c2ZgJcFd1!$0bmrk<m~>
+rjICX\c2Z:JcFd1!0l1:rjI=~>
+rjICX\c2YKJcFd1!$0bmrjI=~>
+rk<s`\c2ZgJcFd1!$0bmrk<m~>
+rjICX\c2Z:JcFd1!0l1:rjI=~>
+rjICX\c2YKJcFd1!$0bmrjI=~>
+rk<s`\c2ZgJcFd1!$0bmrk<m~>
+rjICX\c2Z:JcFd1!0l1:rjI=~>
+rjICX\c2YKJcFd1!$0bmrjI=~>
+rk<s`\c2ZgJcFg2!$0_lrk<m~>
+rjICX\c2Z:JcFg2!0l.9rjI=~>
+rjICX\c2YKJcFg2!$0_lrjI=~>
+rk<s`\c2ZgJcFg2!$0_lrk<m~>
+rjICX\c2Z:JcFg2!0l.9rjI=~>
+rjICX\c2YKJcFg2!$0_lrjI=~>
+rk<s`\c2ZgJcFg2!$0_lrk<m~>
+rjICX\c2Z:JcFg2!0l.9rjI=~>
+rjICX\c2YKJcFg2!$0_lrjI=~>
+rk<s`\c2ZgJcFg2!$0_lrk<m~>
+rjICX\c2Z:JcFg2!0l.9rjI=~>
+rjICX\c2YKJcFg2!$0_lrjI=~>
+rk<s`\c2ZgJcFg2!$0_lrk<m~>
+rjICX\c2Z:JcFg2!0l.9rjI=~>
+rjICX\c2YKJcFg2!$0_lrjI=~>
+rk<s`\c2ZgJcFg2!$0_lrk<m~>
+rjICX\c2Z:JcFg2!0l.9rjI=~>
+rjICX\c2YKJcFg2!$0_lrjI=~>
+rk<s`\c2ZgJcFj3!$0\krk<m~>
+rjICX\c2Z:JcFj3!0l+8rjI=~>
+rjICX\c2YKJcFj3!$0\krjI=~>
+rk<s`\c2ZgJcFj3!$0\krk<m~>
+rjICX\c2Z:JcFj3!0l+8rjI=~>
+rjICX\c2YKJcFj3!$0\krjI=~>
+rk<s`\c2ZgJcFj3!$0\krk<m~>
+rjICX\c2Z:JcFj3!0l+8rjI=~>
+rjICX\c2YKJcFj3!$0\krjI=~>
+rk<s`\c2ZgJcFj3!?Jr-s8K`_~>
+rjICX\c2Z:JcFj3!L,=ks8KHW~>
+rjICX\c2YKJcFj3!?EoIs8KHW~>
+rk@e"!?Jq+s3L]FiIV$js8Tjds8K`_~>
+rjM4o!L,<is3L]F["88=s8Oh+s8KHW~>
+rjM4o!?EnGs3L]FE.S&Ns8Oh+s8KHW~>
+rk@e"!?Jq+s3L]FiIV$jrr=(ks8K`_~>
+rjM4o!L,<is3L]F["88=rrA;8s8KHW~>
+rjM4o!?EnGs3L]FE.S&Nrr=(ks8KHW~>
+rk@e"!$-XjcMmn'JcFm4!$0Yjrk<m~>
+rjM4o!0i'7cMmmOJcFm4!0l(7rjI=~>
+rjM4o!$-XjcMml`JcFm4!$0YjrjI=~>
+rk@b!!$-Xjci4"(JcFm4!$0Yjrk<m~>
+rjM1n!0i'7ci4!PJcFm4!0l(7rjI=~>
+rjM1n!$-Xjci3uaJcFm4!$0YjrjI=~>
+rk@b!!$-Xjci4"(JcFm4!$0Yjrk<m~>
+rjM1n!0i'7ci4!PJcFm4!0l(7rjI=~>
+rjM1n!$-Xjci3uaJcFm4!$0YjrjI=~>
+rk@b!!$-Xjci4"(JcFm4!$0Yjrk<m~>
+rjM1n!0i'7ci4!PJcFm4!0l(7rjI=~>
+rjM1n!$-Xjci3uaJcFm4!$0YjrjI=~>
+rk@b!!$-Xjci4"(JcFp5!$0Virk<m~>
+rjM1n!0i'7ci4!PJcFp5!0l%6rjI=~>
+rjM1n!$-Xjci3uaJcFp5!$0VirjI=~>
+rk@b!!$-Xjci4"(JcFp5!$0Virk<m~>
+rjM1n!0i'7ci4!PJcFp5!0l%6rjI=~>
+rjM1n!$-Xjci3uaJcFp5!$0VirjI=~>
+rk@^u!$-Xjd/O+)JcFp5!$0Virk<m~>
+rjM.m!0i'7d/O*QJcFp5!0l%6rjI=~>
+rjM.m!$-Xjd/O)bJcFp5!$0VirjI=~>
+rk@^u!$-Xjd/O+)JcFp5!$0Virk<m~>
+rjM.m!0i'7d/O*QJcFp5!0l%6rjI=~>
+rjM.m!$-Xjd/O)bJcFp5!$0VirjI=~>
+rk@^u!$-Xjd/O+)JcFp5!$0Virk<m~>
+rjM.m!0i'7d/O*QJcFp5!0l%6rjI=~>
+rjM.m!$-Xjd/O)bJcFp5!$0VirjI=~>
+rk@^u!$-Xjd/O+)JcFs6!$0Shrk<m~>
+rjM.m!0i'7d/O*QJcFs6!0l"5rjI=~>
+rjM.m!$-Xjd/O)bJcFs6!$0ShrjI=~>
+rk@^u!$-Xjd/O+)JcFs6!$0Shrk<m~>
+rjM.m!0i'7d/O*QJcFs6!0l"5rjI=~>
+rjM.m!$-Xjd/O)bJcFs6!$0ShrjI=~>
+rk@[t!$-XjdJj4*JcFs6!$0Shrk<m~>
+rjM+l!0i'7dJj3RJcFs6!0l"5rjI=~>
+rjM+l!$-XjdJj2cJcFs6!$0ShrjI=~>
+rk@[t!$-XjdJj4*JcFs6!$0Shrk<m~>
+rjM+l!0i'7dJj3RJcFs6!0l"5rjI=~>
+rjM+l!$-XjdJj2cJcFs6!$0ShrjI=~>
+rk@[t!$-XjdJj4*JcG!7!$0Pgrk<m~>
+rjM+l!0i'7dJj3RJcG!7!0kt4rjI=~>
+rjM+l!$-XjdJj2cJcG!7!$0PgrjI=~>
+rk@[t!$-XjdJj4*JcG!7!$0Pgrk<m~>
+rjM+l!0i'7dJj3RJcG!7!0kt4rjI=~>
+rjM+l!$-XjdJj2cJcG!7!$0PgrjI=~>
+rk@[t!$-XjdJj4*JcG!7!$0Pgrk<m~>
+rjM+l!0i'7dJj3RJcG!7!0kt4rjI=~>
+rjM+l!$-XjdJj2cJcG!7!$0PgrjI=~>
+rk@Xs!$-Xjdf0=+JcG!7!$0Pgrk<m~>
+rjM(k!0i'7df0<SJcG!7!0kt4rjI=~>
+rjM(k!$-Xjdf0;dJcG!7!$0PgrjI=~>
+rk@Xs!$-Xjdf0=+JcG!7!$0Pgrk<m~>
+rjM(k!0i'7df0<SJcG!7!0kt4rjI=~>
+rjM(k!$-Xjdf0;dJcG!7!$0PgrjI=~>
+rk@Xs!$-Xjdf0=+JcG$8!$0Mfrk<m~>
+rjM(k!0i'7df0<SJcG$8!0kq3rjI=~>
+rjM(k!$-Xjdf0;dJcG$8!$0MfrjI=~>
+rk@Xs!$-Xjdf0=+JcG$8!$0Mfrk<m~>
+rjM(k!0i'7df0<SJcG$8!0kq3rjI=~>
+rjM(k!$-Xjdf0;dJcG$8!$0MfrjI=~>
+rk@Xs!$-Xjdf0=+JcG$8!$0Mfrk<m~>
+rjM(k!0i'7df0<SJcG$8!0kq3rjI=~>
+rjM(k!$-Xjdf0;dJcG$8!$0MfrjI=~>
+rk@Xs!$-Xjdf0=+JcG$8!$0Mfrk<m~>
+rjM(k!0i'7df0<SJcG$8!0kq3rjI=~>
+rjM(k!$-Xjdf0;dJcG$8!$0MfrjI=~>
+rk@Ur!$-Xje,KF,JcG'9!$0Jerk<m~>
+rjM%j!0i'7e,KETJcG'9!0kn2rjI=~>
+rjM%j!$-Xje,KDeJcG'9!$0JerjI=~>
+rk@Ur!$-Xje,KF,JcG'9!$0Jerk<m~>
+rjM%j!0i'7e,KETJcG'9!0kn2rjI=~>
+rjM%j!$-Xje,KDeJcG'9!$0JerjI=~>
+rk@Ur!$-Xje,KF,JcG'9!$0Jerk<m~>
+rjM%j!0i'7e,KETJcG'9!0kn2rjI=~>
+rjM%j!$-Xje,KDeJcG'9!$0JerjI=~>
+rk@Ur!$-Xje,KF,JcG'9!$0Jerk<m~>
+rjM%j!0i'7e,KETJcG'9!0kn2rjI=~>
+rjM%j!$-Xje,KDeJcG'9!$0JerjI=~>
+rk@Ur!$-Xje,KF,JcG'9!$0Jerk<m~>
+rjM%j!0i'7e,KETJcG'9!0kn2rjI=~>
+rjM%j!$-Xje,KDeJcG'9!$0JerjI=~>
+rk@Rq!$-XjeGfO-JcG*:!$0Gdrk<m~>
+rjM"i!0i'7eGfNUJcG*:!0kk1rjI=~>
+rjM"i!$-XjeGfMfJcG*:!$0GdrjI=~>
+rk@Rq!$-XjeGfO-JcG*:!$0Gdrk<m~>
+rjM"i!0i'7eGfNUJcG*:!0kk1rjI=~>
+rjM"i!$-XjeGfMfJcG*:!$0GdrjI=~>
+rk@Rq!$-XjeGfO-JcG*:!$0Gdrk<m~>
+rjM"i!0i'7eGfNUJcG*:!0kk1rjI=~>
+rjM"i!$-XjeGfMfJcG*:!$0GdrjI=~>
+rk@Rq!$-XjeGfO-JcG*:!$0Gdrk<m~>
+rjM"i!0i'7eGfNUJcG*:!0kk1rjI=~>
+rjM"i!$-XjeGfMfJcG*:!$0GdrjI=~>
+rk@Rq!$-XjeGfO-JcG-;!$0Dcrk<m~>
+rjM"i!0i'7eGfNUJcG-;!0kh0rjI=~>
+rjM"i!$-XjeGfMfJcG-;!$0DcrjI=~>
+rk@Op!$-Xjec,X.JcG-;!$0Dcrk<m~>
+rjLth!0i'7ec,WVJcG-;!0kh0rjI=~>
+rjLth!$-Xjec,VgJcG-;!$0DcrjI=~>
+rk@Op!$-Xjec,X.JcG-;!?Jr%s8K`_~>
+rjLth!0i'7ec,WVJcG-;!L,=cs8KHW~>
+rjLth!$-Xjec,VgJcG-;!?EoAs8KHW~>
+rk@Op!?Jq+s472MiIV$rs8Tj\s8K`_~>
+rjLth!L,<is472M["88Es8Oh#s8KHW~>
+rjLth!?EnGs472ME.S&Vs8Oh#s8KHW~>
+rk@Op!?Jq+s472MiIV$rrr=(cs8K`_~>
+rjLth!L,<is472M["88ErrA;0s8KHW~>
+rjLth!?EnGs472ME.S&Vrr=(cs8KHW~>
+rk@Lo!$-Xjf)Ga/JcG0<!$0Abrk<m~>
+rjLqg!0i'7f)G`WJcG0<!0ke/rjI=~>
+rjLqg!$-Xjf)G_hJcG0<!$0AbrjI=~>
+rk@Lo!$-Xjf)Ga/JcG0<!$0Abrk<m~>
+rjLqg!0i'7f)G`WJcG0<!0ke/rjI=~>
+rjLqg!$-Xjf)G_hJcG0<!$0AbrjI=~>
+rk@Lo!$-Xjf)Ga/JcG0<!$0Abrk<m~>
+rjLqg!0i'7f)G`WJcG0<!0ke/rjI=~>
+rjLqg!$-Xjf)G_hJcG0<!$0AbrjI=~>
+rk@Lo!$-Xjf)Ga/JcG0<!$0Abrk<m~>
+rjLqg!0i'7f)G`WJcG0<!0ke/rjI=~>
+rjLqg!$-Xjf)G_hJcG0<!$0AbrjI=~>
+rk@In!$-XjfDbj0JcG3=!$0>ark<m~>
+rjLnf!0i'7fDbiXJcG3=!0kb.rjI=~>
+rjLnf!$-XjfDbhiJcG3=!$0>arjI=~>
+rk@In!$-XjfDbj0JcG3=!$0>ark<m~>
+rjLnf!0i'7fDbiXJcG3=!0kb.rjI=~>
+rjLnf!$-XjfDbhiJcG3=!$0>arjI=~>
+rk@In!$-XjfDbj0JcG3=!$0>ark<m~>
+rjLnf!0i'7fDbiXJcG3=!0kb.rjI=~>
+rjLnf!$-XjfDbhiJcG3=!$0>arjI=~>
+rk@In!$-XjfDbj0JcG3=!$0>ark<m~>
+rjLnf!0i'7fDbiXJcG3=!0kb.rjI=~>
+rjLnf!$-XjfDbhiJcG3=!$0>arjI=~>
+rk@Fm!$-Xjf`(s1JcG3=!$0>ark<m~>
+rjLke!0i'7f`(rYJcG3=!0kb.rjI=~>
+rjLke!$-Xjf`(qjJcG3=!$0>arjI=~>
+rk@Fm!$-Xjf`(s1JcG6>!$0;`rk<m~>
+rjLke!0i'7f`(rYJcG6>!0k_-rjI=~>
+rjLke!$-Xjf`(qjJcG6>!$0;`rjI=~>
+rk@Fm!$-Xjf`(s1JcG6>!$0;`rk<m~>
+rjLke!0i'7f`(rYJcG6>!0k_-rjI=~>
+rjLke!$-Xjf`(qjJcG6>!$0;`rjI=~>
+rk@Fm!$-Xjf`(s1JcG6>!$0;`rk<m~>
+rjLke!0i'7f`(rYJcG6>!0k_-rjI=~>
+rjLke!$-Xjf`(qjJcG6>!$0;`rjI=~>
+rk@Cl!$-Xjg&D'2JcG6>!$0;`rk<m~>
+rjLhd!0i'7g&D&ZJcG6>!0k_-rjI=~>
+rjLhd!$-Xjg&D%kJcG6>!$0;`rjI=~>
+rk@Cl!$-Xjg&D'2JcG9?!$08_rk<m~>
+rjLhd!0i'7g&D&ZJcG9?!0k\,rjI=~>
+rjLhd!$-Xjg&D%kJcG9?!$08_rjI=~>
+rk@Cl!$-Xjg&D'2JcG9?!$08_rk<m~>
+rjLhd!0i'7g&D&ZJcG9?!0k\,rjI=~>
+rjLhd!$-Xjg&D%kJcG9?!$08_rjI=~>
+rk@Cl!$-Xjg&D'2JcG9?!$08_rk<m~>
+rjLhd!0i'7g&D&ZJcG9?!0k\,rjI=~>
+rjLhd!$-Xjg&D%kJcG9?!$08_rjI=~>
+rk@@k!$-XjgA_03JcG9?!$08_rk<m~>
+rjLec!0i'7gA_/[JcG9?!0k\,rjI=~>
+rjLec!$-XjgA_.lJcG9?!$08_rjI=~>
+rk@@k!$-XjgA_03JcG9?!$08_rk<m~>
+rjLec!0i'7gA_/[JcG9?!0k\,rjI=~>
+rjLec!$-XjgA_.lJcG9?!$08_rjI=~>
+rk@@k!$-XjgA_03JcG<@!$05^rk<m~>
+rjLec!0i'7gA_/[JcG<@!0kY+rjI=~>
+rjLec!$-XjgA_.lJcG<@!$05^rjI=~>
+rk@@k!$-XjgA_03JcG<@!$05^rk<m~>
+rjLec!0i'7gA_/[JcG<@!0kY+rjI=~>
+rjLec!$-XjgA_.lJcG<@!$05^rjI=~>
+rk@=j!$-Xjg]%94JcG<@!$05^rk<m~>
+rjLbb!0i'7g]%8\JcG<@!0kY+rjI=~>
+rjLbb!$-Xjg]%7mJcG<@!$05^rjI=~>
+rk@=j!$-Xjg]%94JcG<@!$05^rk<m~>
+rjLbb!0i'7g]%8\JcG<@!0kY+rjI=~>
+rjLbb!$-Xjg]%7mJcG<@!$05^rjI=~>
+rk@=j!$-Xjg]%94JcG<@!$05^rk<m~>
+rjLbb!0i'7g]%8\JcG<@!0kY+rjI=~>
+rjLbb!$-Xjg]%7mJcG<@!$05^rjI=~>
+rk@=j!$-Xjg]%94JcG?A!$02]rk<m~>
+rjLbb!0i'7g]%8\JcG?A!0kV*rjI=~>
+rjLbb!$-Xjg]%7mJcG?A!$02]rjI=~>
+rk@:i!$-Xjh#@B5JcG?A!$02]rk<m~>
+rjL_a!0i'7h#@A]JcG?A!0kV*rjI=~>
+rjL_a!$-Xjh#@@nJcG?A!$02]rjI=~>
+rk@:i!$-Xjh#@B5JcG?A!$02]rk<m~>
+rjL_a!0i'7h#@A]JcG?A!0kV*rjI=~>
+rjL_a!$-Xjh#@@nJcG?A!$02]rjI=~>
+rk@:i!$-Xjh#@B5JcG?A!$02]rk<m~>
+rjL_a!0i'7h#@A]JcG?A!0kV*rjI=~>
+rjL_a!$-Xjh#@@nJcG?A!$02]rjI=~>
+rk@:i!$-Xjh#@B5JcGBB!$0/\rk<m~>
+rjL_a!0i'7h#@A]JcGBB!0kS)rjI=~>
+rjL_a!$-Xjh#@@nJcGBB!$0/\rjI=~>
+rk@7h!$-Xjh>[K6JcGBB!$0/\rk<m~>
+rjL\`!0i'7h>[J^JcGBB!0kS)rjI=~>
+rjL\`!$-Xjh>[IoJcGBB!$0/\rjI=~>
+rk@7h!$-Xjh>[K6JcGBB!?Jqss8K`_~>
+rjL\`!0i'7h>[J^JcGBB!L,=\s8KHW~>
+rjL\`!$-Xjh>[IoJcGBB!?Eo:s8KHW~>
+rk@7h!?Jq+s5*bUiIV%$s8TjUs8K`_~>
+rjL\`!L,<is5*bU["88Ls8Ogqs8KHW~>
+rjL\`!?EnGs5*bUE.S&]s8Ogqs8KHW~>
+rk@7h!?Jq+s5*bUiIV%%rr=([s8K`_~>
+rjL\`!L,<is5*bU["88MrrA;(s8KHW~>
+rjL\`!?EnGs5*bUE.S&^rr=([s8KHW~>
+rk@4g!$-XjhZ!T7JcGEC!$0,[rk<m~>
+rjLY_!0i'7hZ!S_JcGEC!0kP(rjI=~>
+rjLY_!$-XjhZ!RpJcGEC!$0,[rjI=~>
+rk@4g!$-XjhZ!T7JcGEC!$0,[rk<m~>
+rjLY_!0i'7hZ!S_JcGEC!0kP(rjI=~>
+rjLY_!$-XjhZ!RpJcGEC!$0,[rjI=~>
+rk@4g!$-XjhZ!T7JcGEC!$0,[rk<m~>
+rjLY_!0i'7hZ!S_JcGEC!0kP(rjI=~>
+rjLY_!$-XjhZ!RpJcGEC!$0,[rjI=~>
+rk@4g!$-XjhZ!T7JcGHD!$0)Zrk<m~>
+rjLY_!0i'7hZ!S_JcGHD!0kM'rjI=~>
+rjLY_!$-XjhZ!RpJcGHD!$0)ZrjI=~>
+rk@1f!$-Xjhu<]8JcGHD!$0)Zrk<m~>
+rjLV^!0i'7hu<\`JcGHD!0kM'rjI=~>
+rjLV^!$-Xjhu<[qJcGHD!$0)ZrjI=~>
+rk@1f!$-Xjhu<]8JcGHD!$0)Zrk<m~>
+rjLV^!0i'7hu<\`JcGHD!0kM'rjI=~>
+rjLV^!$-Xjhu<[qJcGHD!$0)ZrjI=~>
+rk@1f!$-Xjhu<]8JcGKE!$0&Yrk<m~>
+rjLV^!0i'7hu<\`JcGKE!0kJ&rjI=~>
+rjLV^!$-Xjhu<[qJcGKE!$0&YrjI=~>
+rk@1f!$-Xjhu<]8JcGKE!$0&Yrk<m~>
+rjLV^!0i'7hu<\`JcGKE!0kJ&rjI=~>
+rjLV^!$-Xjhu<[qJcGKE!$0&YrjI=~>
+rk@.e!$-Xji;Wf9JcGKE!$0&Yrk<m~>
+rjLS]!0i'7i;WeaJcGKE!0kJ&rjI=~>
+rjLS]!$-Xji;WdrJcGKE!$0&YrjI=~>
+rk@.e!$-Xji;Wf9JcGNF!$0#Xrk<m~>
+rjLS]!0i'7i;WeaJcGNF!0kG%rjI=~>
+rjLS]!$-Xji;WdrJcGNF!$0#XrjI=~>
+rk@.e!$-Xji;Wf9JcGNF!$0#Xrk<m~>
+rjLS]!0i'7i;WeaJcGNF!0kG%rjI=~>
+rjLS]!$-Xji;WdrJcGNF!$0#XrjI=~>
+rk@.e!$-Xji;Wf9JcGNF!$0#Xrk<m~>
+rjLS]!0i'7i;WeaJcGNF!0kG%rjI=~>
+rjLS]!$-Xji;WdrJcGNF!$0#XrjI=~>
+rk@+d!$-XjiVro:JcGNF!$0#Xrk<m~>
+rjLP\!0i'7iVrnbJcGNF!0kG%rjI=~>
+rjLP\!$-XjiVrmsJcGNF!$0#XrjI=~>
+rk@+d!$-XjiVro:JcGQG!$/uWrk<m~>
+rjLP\!0i'7iVrnbJcGQG!0kD$rjI=~>
+rjLP\!$-XjiVrmsJcGQG!$/uWrjI=~>
+rk@+d!$-XjiVro:JcGQG!$/uWrk<m~>
+rjLP\!0i'7iVrnbJcGQG!0kD$rjI=~>
+rjLP\!$-XjiVrmsJcGQG!$/uWrjI=~>
+rk@+d!$-XjiVro:JcGQG!$/uWrk<m~>
+rjLP\!0i'7iVrnbJcGQG!0kD$rjI=~>
+rjLP\!$-XjiVrmsJcGQG!$/uWrjI=~>
+rk@(c!$-Xjir9#;JcGTH!$/rVrk<m~>
+rjLM[!0i'7ir9"cJcGTH!0kA#rjI=~>
+rjLM[!$-Xjir9!tJcGTH!$/rVrjI=~>
+rk@(c!$-Xjir9#;JcGTH!$/rVrk<m~>
+rjLM[!0i'7ir9"cJcGTH!0kA#rjI=~>
+rjLM[!$-Xjir9!tJcGTH!$/rVrjI=~>
+rk@(c!$-Xjir9#;JcGTH!$/rVrk<m~>
+rjLM[!0i'7ir9"cJcGTH!0kA#rjI=~>
+rjLM[!$-Xjir9!tJcGTH!$/rVrjI=~>
+rk@(c!$-Xjir9#;JcGWI!$/oUrk<m~>
+rjLM[!0i'7ir9"cJcGWI!0k>"rjI=~>
+rjLM[!$-Xjir9!tJcGWI!$/oUrjI=~>
+rk@%b!$-Xjj8T,<JcGWI!$/oUrk<m~>
+rjLJZ!0i'7j8T+dJcGWI!0k>"rjI=~>
+rjLJZ!$-Xjj8T*uJcGWI!$/oUrjI=~>
+rk@%b!$-Xjj8T,<JcGWI!$/oUrk<m~>
+rjLJZ!0i'7j8T+dJcGWI!0k>"rjI=~>
+rjLJZ!$-Xjj8T*uJcGWI!$/oUrjI=~>
+rk@%b!$-Xjj8T,<JcGWI!$/oUrk<m~>
+rjLJZ!0i'7j8T+dJcGWI!0k>"rjI=~>
+rjLJZ!$-Xjj8T*uJcGWI!$/oUrjI=~>
+rk@%b!$-Xjj8T,<JcGZJ!$/lTrk<m~>
+rjLJZ!0i'7j8T+dJcGZJ!0k;!rjI=~>
+rjLJZ!$-Xjj8T*uJcGZJ!$/lTrjI=~>
+rk@"a!$-XjjSo5=JcGZJ!?Jqks8K`_~>
+rjLGY!0i'7jSo4eJcGZJ!L,=Ts8KHW~>
+rjLGY!$-XjjSo4!JcGZJ!?Eo2s8KHW~>
+rk@"a!?Jq+s5j7\iIV%,s8TjMs8K`_~>
+rjLGY!L,<is5j7\["88Ts8Ogis8KHW~>
+rjLGY!?EnGs5j7\E.S&es8Ogis8KHW~>
+rk@"a!?Jq+s5j7\iIV%-rr=(Ss8K`_~>
+rjLGY!L,<is5j7\["88UrrA:us8KHW~>
+rjLGY!?EnGs5j7\E.S&frr=(Ss8KHW~>
+rk?t`!$-Xjjo5>>JcG]K!$/iSrk<m~>
+rjLDX!0i'7jo5=fJcG]K!0k7urjI=~>
+rjLDX!$-Xjjo5="JcG]K!$/iSrjI=~>
+rk?t`!$-Xjjo5>>JcG]K!$/iSrk<m~>
+rjLDX!0i'7jo5=fJcG]K!0k7urjI=~>
+rjLDX!$-Xjjo5="JcG]K!$/iSrjI=~>
+rk?t`!$-Xjjo5>>JcG]K!$/iSrk<m~>
+rjLDX!0i'7jo5=fJcG]K!0k7urjI=~>
+rjLDX!$-Xjjo5="JcG]K!$/iSrjI=~>
+rk?q_!$-Xjk5PG?JcG`L!$/fRrk<m~>
+rjLAW!0i'7k5PFgJcG`L!0k4trjI=~>
+rjLAW!$-Xjk5PF#JcG`L!$/fRrjI=~>
+rk?q_!$-Xjk5PG?JcG`L!$/fRrk<m~>
+rjLAW!0i'7k5PFgJcG`L!0k4trjI=~>
+rjLAW!$-Xjk5PF#JcG`L!$/fRrjI=~>
+rk?q_!$-Xjk5PG?JcG`L!$/fRrk<m~>
+rjLAW!0i'7k5PFgJcG`L!0k4trjI=~>
+rjLAW!$-Xjk5PF#JcG`L!$/fRrjI=~>
+rk?n^!$-XjkPkP@JcGcM!$/cQrk<m~>
+rjL>V!0i'7kPkOhJcGcM!0k1srjI=~>
+rjL>V!$-XjkPkO$JcGcM!$/cQrjI=~>
+rk?n^!$-XjkPkP@JcGcM!$/cQrk<m~>
+rjL>V!0i'7kPkOhJcGcM!0k1srjI=~>
+rjL>V!$-XjkPkO$JcGcM!$/cQrjI=~>
+rk?n^!$-XjkPkP@JcGcM!$/cQrk<m~>
+rjL>V!0i'7kPkOhJcGcM!0k1srjI=~>
+rjL>V!$-XjkPkO$JcGcM!$/cQrjI=~>
+rk?k]!$-Xjkl1YAJc>cN*PDFO^46~>
+rjL;U!0i'7kl1XiJc>cNPe@%q[X\~>
+rjL;U!$-Xjkl1X%Jc>cN*PDFO[X\~>
+rk?k]!$-Xjkl1YAJc>cN*PDFO^46~>
+rjL;U!0i'7kl1XiJc>cNPe@%q[X\~>
+rjL;U!$-Xjkl1X%Jc>cN*PDFO[X\~>
+rk?h\!$-Xjl2LbBJc>cN*PDFO^46~>
+rjL8T!0i'7l2LajJc>cNPe@%q[X\~>
+rjL8T!$-Xjl2La&Jc>cN*PDFO[X\~>
+rk?h\!$-Xjl2LbBJc>cN*PDFO^46~>
+rjL8T!0i'7l2LajJc>cNPe@%q[X\~>
+rjL8T!$-Xjl2La&Jc>cN*PDFO[X\~>
+rk?h\!$-Xjl2LbBJc>]j]DqlEJ,~>
+rjL8T!0i'7l2LajJc>_7]Dql=J,~>
+rjL8T!$-Xjl2La&Jc>]j]Dql=J,~>
+rk?e[!$-XjlMgkCJc>]j]DqlEJ,~>
+rjL5S!0i'7lMgjkJc>_7]Dql=J,~>
+rjL5S!$-XjlMgj'Jc>]j]Dql=J,~>
+rk?e[!$-XjlMgkCJc>]j]DqlEJ,~>
+rjL5S!0i'7lMgjkJc>_7]Dql=J,~>
+rjL5S!$-XjlMgj'Jc>]j]Dql=J,~>
+rk?e[!$-XjlMgkCK)Yfk])VcDJ,~>
+rjL5S!0i'7lMgjkK)Yh8])Vc<J,~>
+rjL5S!$-XjlMgj'K)Yfk])Vc<J,~>
+rk?bZ!$-Xjli-tDK)Yfk])VcDJ,~>
+rjL2R!0i'7li-slK)Yh8])Vc<J,~>
+rjL2R!$-Xjli-s(K)Yfk])Vc<J,~>
+rk?bZ!$-Xjli-tDK)Yfk])VcDJ,~>
+rjL2R!0i'7li-slK)Yh8])Vc<J,~>
+rjL2R!$-Xjli-s(K)Yfk])Vc<J,~>
+rk?bZ!$-Xjli-tDK)Yfk])VcDJ,~>
+rjL2R!0i'7li-slK)Yh8])Vc<J,~>
+rjL2R!$-Xjli-s(K)Yfk])Vc<J,~>
+rk?_Y!$-Xjm/I(EKDtol\c;ZCJ,~>
+rjL/Q!0i'7m/I'mKDtq9\c;Z;J,~>
+rjL/Q!$-Xjm/I')KDtol\c;Z;J,~>
+rk?_Y!?Jq+s6]gdiIh.2*P]2crk<m~>
+rjL/Q!L,<is6]gd["JAZPVKcLrjI=~>
+rjL/Q!?EnGs6]gdE.e/k*AP/*rjI=~>
+rk?_Y!?Jq+s6]gdiIh11^UjIE^46~>
+rjL/Q!L,<is6]gd["JDY0tRDa[X\~>
+rjL/Q!?EnGs6]gdE.e2j0tRDa[X\~>
+rk?\X!$-XjmJd1FK`;#m\GuQBJ,~>
+rjL,P!0i'7mJd0nK`;%:\GuQ:J,~>
+rjL,P!$-XjmJd0*K`;#m\GuQ:J,~>
+rk?\X!$-XjmJd1FK`;#m\GuQBJ,~>
+rjL,P!0i'7mJd0nK`;%:\GuQ:J,~>
+rjL,P!$-XjmJd0*K`;#m\GuQ:J,~>
+rk?\X!$-XjmJd1FK`;#m\GuQBJ,~>
+rjL,P!0i'7mJd0nK`;%:\GuQ:J,~>
+rjL,P!$-XjmJd0*K`;#m\GuQ:J,~>
+rk?YW!$-Xjmf*:GL&V,n\,ZHAJ,~>
+rjL)O!0i'7mf*9oL&V.;\,ZH9J,~>
+rjL)O!$-Xjmf*9+L&V,n\,ZH9J,~>
+rk?YW!$-Xjmf*:GL&V,n\,ZHAJ,~>
+rjL)O!0i'7mf*9oL&V.;\,ZH9J,~>
+rjL)O!$-Xjmf*9+L&V,n\,ZH9J,~>
+rk?YW!$-Xjmf*:GLAq5o[f??@J,~>
+rjL)O!0i'7mf*9oLAq7<[f??8J,~>
+rjL)O!$-Xjmf*9+LAq5o[f??8J,~>
+rk?VV!$-Xjn,ECHLAq5o[f??@J,~>
+rjL&N!0i'7n,EBpLAq7<[f??8J,~>
+rjL&N!$-Xjn,EB,LAq5o[f??8J,~>
+rk?VV!$-Xjn,ECHLAq5o[f??@J,~>
+rjL&N!0i'7n,EBpLAq7<[f??8J,~>
+rjL&N!$-Xjn,EB,LAq5o[f??8J,~>
+rk?SU!$-XjnG`LIL]7>p[K$6?J,~>
+rjL#M!0i'7nG`KqL]7@=[K$67J,~>
+rjL#M!$-XjnG`K-L]7>p[K$67J,~>
+rk?SU!$-XjnG`LIL]7>p[K$6?J,~>
+rjL#M!0i'7nG`KqL]7@=[K$67J,~>
+rjL#M!$-XjnG`K-L]7>p[K$67J,~>
+rk?SU!$-XjnG`LIL]7>p[K$6?J,~>
+rjL#M!0i'7nG`KqL]7@=[K$67J,~>
+rjL#M!$-XjnG`K-L]7>p[K$67J,~>
+rk?PT!$-Xjnc&UJM#RGq[/^->J,~>
+rjKuL!0i'7nc&TrM#RI>[/^-6J,~>
+rjKuL!$-Xjnc&T.M#RGq[/^-6J,~>
+rk?PT!$-Xjnc&UJM#RGq[/^->J,~>
+rjKuL!0i'7nc&TrM#RI>[/^-6J,~>
+rjKuL!$-Xjnc&T.M#RGq[/^-6J,~>
+rk?PT!$-Xjnc&UJM>mPrZiC$=J,~>
+rjKuL!0i'7nc&TrM>mR?ZiC$5J,~>
+rjKuL!$-Xjnc&T.M>mPrZiC$5J,~>
+rk?MS!$-Xjo)A^KM>mPrZiC$=J,~>
+rjKrK!0i'7o)A]sM>mR?ZiC$5J,~>
+rjKrK!$-Xjo)A]/M>mPrZiC$5J,~>
+rk?MS!$-Xjo)A^KM>mPrZiC$=J,~>
+rjKrK!0i'7o)A]sM>mR?ZiC$5J,~>
+rjKrK!$-Xjo)A]/M>mPrZiC$5J,~>
+rk?MS!$-Xjo)A^KMZ3YsZN'p<J,~>
+rjKrK!0i'7o)A]sMZ3[@ZN'p4J,~>
+rjKrK!$-Xjo)A]/MZ3YsZN'p4J,~>
+rk?JR!$-XjoD\gLMZ3\t^U*t>^46~>
+rjKoJ!0i'7oD\ftMZ3^A0sgoZ[X\~>
+rjKoJ!$-XjoD\f0MZ3\t0sgoZ[X\~>
+rk?JR!?Jq+s7H<kiJR[8^U*t>^46~>
+rjKoJ!L,<is7H<k[#4n`0sgoZ[X\~>
+rjKoJ!?EnGs7H<kE/O\q0sgoZ[X\~>
+rk?JR!?Jq+s7H<kiJ[^9*O5YD^46~>
+rjKoJ!L,<is7H<k[#=qaPd18f[X\~>
+rjKoJ!?EnGs7H<kE/X_r*O5YD[X\~>
+rk?GQ!$-Xjo`"pMMuNbtZ2ag;J,~>
+rjKlI!0i'7o`"ouMuNdAZ2ag3J,~>
+rjKlI!$-Xjo`"o1MuNbtZ2ag3J,~>
+rk?GQ!$-Xjo`"pMN;ikuYlF^:J,~>
+rjKlI!0i'7o`"ouN;imBYlF^2J,~>
+rjKlI!$-Xjo`"o1N;ikuYlF^2J,~>
+rk?DP!$-Xjp&>$NN;ikuYlF^:J,~>
+rjKiH!0i'7p&>$!N;imBYlF^2J,~>
+rjKiH!$-Xjp&>#2N;ikuYlF^2J,~>
+rk?DP!$-Xjp&>$NNW/u!YQ+U9J,~>
+rjKiH!0i'7p&>$!NW0!CYQ+U1J,~>
+rjKiH!$-Xjp&>#2NW/u!YQ+U1J,~>
+rk?AO!$-XjpAY-ONW/u!YQ+U9J,~>
+rjKfG!0i'7pAY-"NW0!CYQ+U1J,~>
+rjKfG!$-XjpAY,3NW/u!YQ+U1J,~>
+rk?AO!$-XjpAY-ONrK)"Y5eL8J,~>
+rjKfG!0i'7pAY-"NrK*DY5eL0J,~>
+rjKfG!$-XjpAY,3NrK)"Y5eL0J,~>
+rk?>N!$-Xjp\t6PNrK)"Y5eL8J,~>
+rjKcF!0i'7p\t6#NrK*DY5eL0J,~>
+rjKcF!$-Xjp\t54NrK)"Y5eL0J,~>
+rk?>N!$-Xjp\t6PO8f2#XoJC7J,~>
+rjKcF!0i'7p\t6#O8f3EXoJC/J,~>
+rjKcF!$-Xjp\t54O8f2#XoJC/J,~>
+rk?;M!$-Xjq#:?QO8f2#XoJC7J,~>
+rjK`E!0i'7q#:?$O8f3EXoJC/J,~>
+rjK`E!$-Xjq#:>5O8f2#XoJC/J,~>
+rk?;M!$-Xjq#:?QOT,;$XT/:6J,~>
+rjK`E!0i'7q#:?$OT,<FXT/:.J,~>
+rjK`E!$-Xjq#:>5OT,;$XT/:.J,~>
+rk?8L!$-Xjq>UHROT,;$XT/:6J,~>
+rjK]D!0i'7q>UH%OT,<FXT/:.J,~>
+rjK]D!$-Xjq>UG6OT,;$XT/:.J,~>
+rk?8L!$-Xjq>UHROoGD%X8i15J,~>
+rjK]D!0i'7q>UH%OoGEGX8i1-J,~>
+rjK]D!$-Xjq>UG6OoGD%X8i1-J,~>
+rk?5K!$-XjqYpQSOoGD%X8i15J,~>
+rjKZC!0i'7qYpQ&OoGEGX8i1-J,~>
+rjKZC!$-XjqYpP7OoGD%X8i1-J,~>
+rk?5K!$-XjqYpQSP5bM&WrN(4J,~>
+rjKZC!0i'7qYpQ&P5bNHWrN(,J,~>
+rjKZC!$-XjqYpP7P5bM&WrN(,J,~>
+rk?2J!$-Xjqu6ZTP5bP'^T7D6^46~>
+rjKWB!0i'7qu6Z'P5bQI0rt?R[X\~>
+rjKWB!$-Xjqu6Y8P5bP'0rt?R[X\~>
+rk?2J!?Jq+s8;lsiKO9C*P]@is8K`_~>
+rjKWB!L,<is8;ls[$1LkPVFnns8KHW~>
+rjKWB!?EnGs8;lsE0L;'*AK:Ls8KHW~>
+rk?2J!P]Y+s8;lsiKO9A*NB)<^46~>
+rjKWB!ATgis8;ls[$1LiPc=]^[X\~>
+rjKWB!APUGs8;lsE0L;%*NB)<[X\~>
+rk?/I!$-Xjr;QcUPlC_(W;lk2J,~>
+rjKTA!0i'7r;Qc(PlC`JW;lk*J,~>
+rjKTA!$-Xjr;Qb9PlC_(W;lk*J,~>
+rk?,H!$-XjrVllVPlC_(W;lk2J,~>
+rjKQ@!0i'7rVll)PlC`JW;lk*J,~>
+rjKQ@!$-XjrVlk:PlC_(W;lk*J,~>
+rk?,H!$-XjrVllVQ2^h)VuQb1J,~>
+rjKQ@!0i'7rVll)Q2^iKVuQb)J,~>
+rjKQ@!$-XjrVlk:Q2^h)VuQb)J,~>
+rk?)G!$-Xjrr2uWQ2^h)VuQb1J,~>
+rjKN?!0i'7rr2u*Q2^iKVuQb)J,~>
+rjKN?!$-Xjrr2t;Q2^h)VuQb)J,~>
+rk?)G!$-Xjrr2uWQN$q*VZ6Y0J,~>
+rjKN?!0i'7rr2u*QN$rLVZ6Y(J,~>
+rjKN?!$-Xjrr2t;QN$q*VZ6Y(J,~>
+rk?&F!$-Xjs8N)XQi@%+V>pP/J,~>
+rjKK>!0i'7s8N)+Qi@&MV>pP'J,~>
+rjKK>!$-Xjs8N(<Qi@%+V>pP'J,~>
+rk?&F!$-Xjs8N)XQi@%+V>pP/J,~>
+rjKK>!0i'7s8N)+Qi@&MV>pP'J,~>
+rjKK>!$-Xjs8N(<Qi@%+V>pP'J,~>
+rk?#E!$-Xj!WV,Grr=(8s8K`_~>
+rjKH=!0i'7!WTNorrA:Zs8KHW~>
+rjKH=!$-Xj!WR,+rr=(8s8KHW~>
+rk?#E!$-Xj!WV,Grr=(8s8K`_~>
+rjKH=!0i'7!WTNorrA:Zs8KHW~>
+rjKH=!$-Xj!WR,+rr=(8s8KHW~>
+rk>uD!$-Xj!9'@G!$.j7rk<m~>
+rjKE<!0i'7!480o!0j8YrjI=~>
+rjKE<!$-Xj!-"A+!$.j7rjI=~>
+rk>uD!$-Xj!9'@G!$.j7rk<m~>
+rjKE<!0i'7!480o!0j8YrjI=~>
+rjKE<!$-Xj!-"A+!$.j7rjI=~>
+rk>rC!$-[k!9'CH!?JqMs8K`_~>
+rjKB;!0i*8!483p!L,=6s8KHW~>
+rjKB;!$-[k!-"D,!?Enis8KHW~>
+rk>rC!?Jq-rrD#IrrO4U^SCi.^46~>
+rjKB;!L,<krrBEqrrSE>0r+dJ[X\~>
+rjKB;!?EnIrr@#-rrO2q0r+dJ[X\~>
+rk>rC!P]Y-rrD#Irr=(5s8K`_~>
+rjKB;!ATgkrrBEqrrA:Ws8KHW~>
+rjKB;!APUIrr@#-rr=(5s8KHW~>
+rk>oB!$-^l!9'IJ!$.a4rk<m~>
+rjK?:!0i-9!489r!0j/VrjI=~>
+rjK?:!$-^l!-"J.!$.a4rjI=~>
+rk>lA!$-am!9'LK!$.^3rk<m~>
+rjK<9!0i0:!48<s!0j,UrjI=~>
+rjK<9!$-am!-"M/!$.^3rjI=~>
+rk>i@!$-dn!9'LK!$.^3rk<m~>
+rjK98!0i3;!48<s!0j,UrjI=~>
+rjK98!$-dn!-"M/!$.^3rjI=~>
+rk>i@!$-dn!9'OL!$.[2rk<m~>
+rjK98!0i3;!48?t!0j)TrjI=~>
+rjK98!$-dn!-"P0!$.[2rjI=~>
+rk>f?!$-go!9'OL!$.[2rk<m~>
+rjK67!0i6<!48?t!0j)TrjI=~>
+rjK67!$-go!-"P0!$.[2rjI=~>
+rk>f?!$-go!9'RM!$.X1rk<m~>
+rjK67!0i6<!48Bu!0j&SrjI=~>
+rjK67!$-go!-"S1!$.X1rjI=~>
+rk>c>!$-jp!9'UN!$.U0rk<m~>
+rjK36!0i9=!48F!!0j#RrjI=~>
+rjK36!$-jp!-"V2!$.U0rjI=~>
+rk>`=!$-mq!9'UN!$.U0rk<m~>
+rjK05!0i<>!48F!!0j#RrjI=~>
+rjK05!$-mq!-"V2!$.U0rjI=~>
+rk>`=!$-mq!9'XO!?JqFs8K`_~>
+rjK05!0i<>!48I"!L,=/s8KHW~>
+rjK05!$-mq!-"Y3!?Enbs8KHW~>
+rk>]<!?Jq4rrD#PrrO4U^RY?'^46~>
+rjK-4!L,<rrrBF#rrSE>0qA:C[X\~>
+rjK-4!?EnPrr@#4rrO2q0qA:C[X\~>
+rk>]<!P]Y4rrD#Qrr=(-s8K`_~>
+rjK-4!ATgrrrBF$rrA:Os8KHW~>
+rjK-4!APUPrr@#5rr=(-s8KHW~>
+rk>W:!$.!t!9'^Q!$.L-rk<m~>
+rjK'2!0iEA!48O$!0ioOrjI=~>
+rjK'2!$.!t!-"_5!$.L-rjI=~>
+rk>T9!$.$u!9'aR!$.I,rk<m~>
+rjK$1!0iHB!48R%!0ilNrjI=~>
+rjK$1!$.$u!-"b6!$.I,rjI=~>
+rk>Q8!$.(!!9'dS!$.F+rk<m~>
+rjK!0!0iKC!48U&!0iiMrjI=~>
+rjK!0!$.(!!-"e7!$.F+rjI=~>
+rk>Q8!$.(!!9'gT!$.C*rk<m~>
+rjK!0!0iKC!48X'!0ifLrjI=~>
+rjK!0!$.(!!-"h8!$.C*rjI=~>
+rk>N7!$.+"!9'jU!$.@)rk<m~>
+rjJs/!0iND!48[(!0icKrjI=~>
+rjJs/!$.+"!-"k9!$.@)rjI=~>
+rk>K6!$..#!9'jU!$.@)rk<m~>
+rjJp.!0iQE!48[(!0icKrjI=~>
+rjJp.!$..#!-"k9!$.@)rjI=~>
+rk>H5!$.1$!9'mV!$.=(rk<m~>
+rjJm-!0iTF!48^)!0i`JrjI=~>
+rjJm-!$.1$!-"n:!$.=(rjI=~>
+rk>E4!?Jq<rrD#WrrF.TPlL`sJ,~>
+rjJj,!L,=%rrBF*rrJ?=PlL`kJ,~>
+rjJj,!?EnXrr@#;rrF,pPlL`kJ,~>
+rk>E4!P]Y<rrD#XrrO4U^Qect^46~>
+rjJj,!ATh%rrBF+rrSE>0pM_;[X\~>
+rjJj,!APUXrr@#<rrO2q0pM_;[X\~>
+rk>?2!$.:'!9(!Y!$.4%rk<m~>
+rjJd*!0i]I!48g,!0iWGrjI=~>
+rjJd*!$.:'!-#"=!$.4%rjI=~>
+rk><1!$.=(!9($Z!$.1$rk<m~>
+rjJa)!0i`J!48j-!0iTFrjI=~>
+rjJa)!$.=(!-#%>!$.1$rjI=~>
+rk>90!$.@)!9('[!$..#rk<m~>
+rjJ^(!0icK!48m.!0iQErjI=~>
+rjJ^(!$.@)!-#(?!$..#rjI=~>
+rk>6/!$.C*!9(*\!$.+"rk<m~>
+rjJ['!0ifL!48p/!0iNDrjI=~>
+rjJ['!$.C*!-#+@!$.+"rjI=~>
+rk>3.!$.F+!9(-]!$.(!rk<m~>
+rjJX&!0iiM!48s0!0iKCrjI=~>
+rjJX&!$.F+!-#.A!$.(!rjI=~>
+rk>0-!$.I,!9(0^!?Jq7s8K`_~>
+rjJU%!0ilN!49!1!L,<us8KHW~>
+rjJU%!$.I,!-#1B!?EnSs8KHW~>
+rk>-,!?JqDrrD#`s8O,>^Q&9m^46~>
+rjJR$!L,=-rrBF3s8S>`0oc54[X\~>
+rjJR$!?En`rr@#Ds8O,>0oc54[X\~>
+rk>-,!l#`rS,WKIZi:"GM?!RhJ,~>
+rjJR$!\oq(S,WJqZi:#iM?!R`J,~>
+rjJR$!\k]9S,WJ-Zi:"GM?!R`J,~>
+rk>$)!$.U0!9(<b!$-mqrk<m~>
+rjJI!!0j#R!49-5!0i<>rjI=~>
+rjJI!!$.U0!-#=F!$-mqrjI=~>
+rk>!(!$.X1!9(BdruHmprk<m~>
+rjJEu!0j&S!4937s-/<=rjI=~>
+rjJEu!$.X1!-#CHruHmprjI=~>
+rk=s'ruIa3!9(Ee!$-dnrk<m~>
+rjJBts-0/U!4968!0i3;rjI=~>
+rjJBtruIa3!-#FI!$-dnrjI=~>
+rk=m%!?JqKrrD#frrF.TL&_.dJ,~>
+rjJ<r!L,=4rrBF9rrJ?=L&_.\J,~>
+rjJ<r!?Engrr@#JrrF,pL&_.\J,~>
+rk=m%!l#`rUAk5P])VdNs1a9frk<m~>
+rjJ<r!\oq(UAk5#])Veps"T6-rjI=~>
+rjJ<r!\k]9UAk44])VdNs"T6-rjI=~>
+rk=d"!$.j7!9(TjruH[jrk<m~>
+rjJ3o!0j8Y!49E=s-/*7rjI=~>
+rjJ3o!$.j7!-#UNruH[jrjI=~>
+rk=a!ruIs9!9(ZlruH[js8W)4J,~>
+rjJ0ns-0A[!49K?s-/*7s8W),J,~>
+rjJ0nruIs9!-#[PruH[js8W),J,~>
+rk=ZtruJ$;!9(`nruD*SJcG`Lrk<m~>
+rjJ*ls-0G]!49QAs-*L<JcG`LrjI=~>
+rjJ*lruJ$;!-#aRruD(oJcG`LrjI=~>
+rk=TrruJ*=!9(fpruD1@^V>@"rr;u3J,~>
+rjJ$js-0M_!49WCs-*Tb0en7Zrr;u+J,~>
+rjJ$jruJ*=!-#gTruD1@0en7Zrr;u+J,~>
+rk=Trs1eRSX8`1Y`;fiXJcGQGrk<m~>
+rjJ$js"XP<X8`1,`;fk%JcGQGrjI=~>
+rjJ$js"XNoX8`0=`;fiXJcGQGrjI=~>
+rk=HnruJ6A!9(uurZ-Rip](6,J,~>
+rjImfs-0Yc!49fHrfi!6p](6$J,~>
+rjImfruJ6A!-$!YrZ-Rip](6$J,~>
+rk=BlrZ/6C!9)*#rZ)(?^V>@"p](6,J,~>
+rjIgdrfjYe!49oKrfdKa0en7Zp](6$J,~>
+rjIgdrZ/6C!-$*\rZ)(?0en7Zp](6$J,~>
+rk=?ks1eLQ[/U-bbl@\`JcG9?rk<m~>
+rjIdcs"XJ:[/U-5bl@^-JcG9?rjI=~>
+rjIdcs"XHm[/U,Fbl@\`JcG9?rjI=~>
+rk=-er>iEJ!9)B+q]17fn,NC$J,~>
+rjIR]rKOhl!4:2Sqil[3n,NBqJ,~>
+rjIR]r>iEJ!-$Bdq]17fn,NBqJ,~>
+rk='cs1eLQ]`.ujg&LmhrVuo4JcG3=rk<m~>
+rjIL[s"XJ:]`.u=g&Lo5rVumPJcG3=rjI=~>
+rjIL[s"XHm]`.tNg&LmhrVumPJcG3=rjI=~>
+rk<s`rr;m:_>aMoi;`Worr<#5JcFp5rk<m~>
+rjICXrr;n\_>aMBi;`Y<rr<!QJcFp5rjI=~>
+rjICXrr;m:_>aLSi;`Worr<!QJcFp5rjI=~>
+rk<s`rVuo4s8VX1d/O+)n,Mr!rr<#5JcF[.rk<m~>
+rjICXrVumPs8VYSd/O*Qn,MsCrr<!QJcF[.rjI=~>
+rjICXrVumPs8VX1d/O)bn,Mr!rr<!QJcF[.rjI=~>
+rk<sBp>Q%dqr.Ris5CX3ro*mlqr.RiJ`5;@rk<m~>
+rjIBbp9aiSqm?AXs0TJ(rj;\[qm?AXJ[F+;rjI=~>
+rjIAsp2L$dqf)Qis)>Xlrc%llqf)QiJT0:]rjI=~>
+rk<s`k5YIrr;Zf3r;Zf3qu?]2r;Zf3qu?]2r;Zf3qu?]2qu?]2JcEmmrk<m~>
+rjICXk5YH9r;ZdOr;ZdOqu?[Nr;ZdOqu?[Nr;ZdOqu?[Nqu?[NJcEmmrjI=~>
+rjICXk5YH9r;ZdOr;ZdOqu?[Nr;ZdOqu?[Nr;ZdOqu?[Nqu?[NJcEmmrjI=~>
+rk<s`\c2ZgJcE=]rk<m~>
+rjICX\c2Z:JcE=]rjI=~>
+rjICX\c2YKJcE=]rjI=~>
+rk<s`\c2ZgJcE=]rk<m~>
+rjICX\c2Z:JcE=]rjI=~>
+rjICX\c2YKJcE=]rjI=~>
+rk<s`\c2ZgJcE=]rk<m~>
+rjICX\c2Z:JcE=]rjI=~>
+rjICX\c2YKJcE=]rjI=~>
+rk<s`\c2ZgJcE=]rk<m~>
+rjICX\c2Z:JcE=]rjI=~>
+rjICX\c2YKJcE=]rjI=~>
+rk<s`\c2ZgJcE=]rk<m~>
+rjICX\c2Z:JcE=]rjI=~>
+rjICX\c2YKJcE=]rjI=~>
+rk<s`\c2ZgJcE=]rk<m~>
+rjICX\c2Z:JcE=]rjI=~>
+rjICX\c2YKJcE=]rjI=~>
+rk<s`\c2ZgJcE=]rk<m~>
+rjICX\c2Z:JcE=]rjI=~>
+rjICX\c2YKJcE=]rjI=~>
+J\H]LJ\LHaJ,~>
+J[U-<J[XmQJ,~>
+J[U-<J[XmQJ,~>
+J\H]LJ\LHaJ,~>
+J[U-<J[XmQJ,~>
+J[U-<J[XmQJ,~>
+J\H]LJ\LHaJ,~>
+J[U-<J[XmQJ,~>
+J[U-<J[XmQJ,~>
+%%EndData
+showpage
+%%Trailer
+end
+%%EOF
diff --git a/books/ps/v0plot4.eps b/books/ps/v0plot4.eps
new file mode 100644
index 0000000..1518c37
--- /dev/null
+++ b/books/ps/v0plot4.eps
@@ -0,0 +1,1343 @@
+%!PS-Adobe-3.0 EPSF-3.0
+%%Creator: GIMP PostScript file plugin V 1.17 by Peter Kirchgessner
+%%Title: v0plot4.eps
+%%CreationDate: Thu Mar 19 15:52:32 2009
+%%DocumentData: Clean7Bit
+%%LanguageLevel: 2
+%%Pages: 1
+%%BoundingBox: 14 14 142 146
+%%EndComments
+%%BeginProlog
+% Use own dictionary to avoid conflicts
+10 dict begin
+%%EndProlog
+%%Page: 1 1
+% Translate for offset
+14.173228346456694 14.173228346456694 translate
+% Translate to begin of first scanline
+0 131.17539273108105 translate
+127.10551181102363 -131.17539273108105 scale
+% Image geometry
+406 419 8
+% Transformation matrix
+[ 406 0 0 419 0 0 ]
+% Strings to hold RGB-samples per scanline
+/rstr 406 string def
+/gstr 406 string def
+/bstr 406 string def
+{currentfile /ASCII85Decode filter /RunLengthDecode filter rstr readstring pop}
+{currentfile /ASCII85Decode filter /RunLengthDecode filter gstr readstring pop}
+{currentfile /ASCII85Decode filter /RunLengthDecode filter bstr readstring pop}
+true 3
+%%BeginData:        54616 ASCII Bytes
+colorimage
+r;V>^J\H]LotLA(J,~>
+r;V>VJ[U-<osXeuJ,~>
+r;V>VJ[U-<osXeuJ,~>
+rr<#4J_G\/W7h74o@sAojR_.-dH'oS!7Cf"s1\L4J,~>
+rr<#,J^f8#W71h*o@F#di:GP$bM`!D!6bAks0hq,J,~>
+rr<#,J^f8#W71h*o@F#di:GP$bM`!D!6bAks0hq,J,~>
+s8N)5J_5P+VUtn-o@X/jiUb_'cf+KK!71Sq!l"^7J,~>
+s8N)-J^T+tVU>J#o@*f_h=K+sakcR<!6P/e!k/./J,~>
+s8N)-J^T+tVU>J#o@*f_h=K+sakcR<!6P/e!k/./J,~>
+!WTn1f(1#8eq)D`ec=V!f)a.Ro@F#fhu;4.gYDbZs4dP)!6tDl!P\Sa~>
+!WTV)d.9k\d"0QTciDhldK.DCo?mZ[g]#Y$fDX+uf%9oL!6=u`!Oi#Y~>
+!WTV)d.<$Dd"0QTciDhldK.DCo?mZ[g]#Y$fDX+uf%9oL!6=u`!Oi#Y~>
+!WTn1e,UWaEW@55eFV/lec#O%qpY]+s4Znj$MFDrk1&Ais8268J^j;@!8[7s!R0BseH4Fbg\fS5
+bh^h"g?%GQe^`O<jk827bkolj^Ai]~>
+!WTV)c2^K0T)_K7cL]<`ci!gnqp#9!s4-P_$M=;pj3HK\s8200J^3l4!86ti!QEahcN;VSf)3i*
+`S&S`eD]B>cd1>(iRH3"`V[p][f:j~>
+!WTV)c2`XmcN&`OcL]<`ci!gnqp#9!s4-P_$M=;pj3HK\s8200J^3l4!86ti!QEahcN;VSf)3i*
+`S&S`eD]B>cd1>(iRH3"`V[p][f:j~>
+!5A9W!?cFW1]_V>J^X/<"5a(Xk53R.e(<(:dL,9mmf(_os4uQ/mt&pYdK&%ndfIVGqpPW*io0ga
+&B`bVe(<X:j4rGMhW*29e&qO8!5<s~>
+!4M^I!D9!YAHADqJ^!`0"5<eTj87%%cI0u*bR3R`m/G;cs4H'%m"*CPbQ-5cblP`5qoo2uhVJ+S
+&B!)Dc-kP(hq6T=g>LB'c,9D%!4IC~>
+!4M^I!Jf"qU]JesJ^!`0"5<eTj87%%cI0u*bR3R`m/G;cs4H'%m"*CPbQ-5cblP`5qoo2uhVJ+S
+&B!)Dc-kP(hq6T=g>LB'c,9D%!4IC~>
+!5A9U%>b&9f\+p1g"P6:h>`:^d.>U&lhg;Fd,t5Tp[6r=f?i^Zqr#iYs7$$Tmf)SLcjA\2e)12W
+d,k8SJ^F&9!86tk!Q`skd/r:`iV_((aP$R?#M\7oio8eRgA]J"aSO6`^46~>
+!4M^G%>t2?gYCQ=h;-rFhuARbb4Eaol21&Bb2`?Dp?UK5dE:PJqV96Js6fjOm/H8GapHr)cJ/BH
+b2WEEJ]dW-!7^V`!Q!:_b6$MRh>GFs_:8J-#M.bahVQoAf)Ehm_>;:S[X\~>
+!4M^G%>Fi3eCE(!f%8R-gAckXb4Eaol21&Bb2`?Dp?UK5dE:PJqV96Js6fjOm/H8GapHr)cJ/BH
+b2WEEJ]dW-!7^V`!Q!:_b6$MRh>GFs_:8J-#M.bahVQoAf)Ehm_>;:S[X\~>
+!5A9S#DiE5g"P-5g]$"1huAL`cL]=#qX<SGda.X^qpF7"e^a][lho)bs5iDCjlZTjr6>Yrp@-A`
+s4,EOs3lPEoZdHgo?RHXfDa))f&,BEh;[>Lf$D[_fDX#!g#:]?iS"1U!6=r]!5<s~>
+!4M^E!fI$5rS7\7hr*GOs,)BKo>hmHmGn2ian>E)bh<$Cd/W%fr5mXlioC'uj8[=#a9p,`m`=)]
+d)ar@c@O(/a8jZ[a8s'(rl>Mpg=tK:hV6c2aN2-ErQ#/lgt('3e,@>f^\Z"O[X\~>
+!4M^E%>Fi5f%8L)f\,!4h#E(ZaRdIlq<d5AbfTPPqTRXmd*VgNkkrQUs5N)=ioC'^r5]5gp$ToS
+s3Sj@s3?2:oZ.$\o>gsIdf.;rd+[72f\YB:d)a;Cdf%5jeD/X+gsc5C!5JBO!4IC~>
+!5A9R!f6m2r7hJ3hr*GmLk3hCboG@8in=@hc/AWcc/&ELh#Gp]s3fa'e_U8Th#Gk%bmVhepsI@B
+s4#<Srm-/?oZ[Bdo?@<Tec*f%hqd&Ag"Y9;hp'Ebec!_rf\bE:hq7nP!6+fZ!5<s~>
+!4M^C!K-pTh?MlqiSrksMLie>`Z3D+hUDMZ`n^UU`n:=:fDj1Ms30-qce/9Cf`04p`XBiVpWCM.
+s3AXBrlBZ1oYpmWo>UgEci1omg=Y!-eCN4'g;_.Gci(iedbE:$gX?&?!586K!4IC~>
+!4M^C%>Fi6f\+p1g"Y9:h>`1[`q77jdJr(Ps4bQKs5h8Qs3B6rce8?Bf`0:Ms3B9sc2GWia7/iG
+`n:=:`o-j;J]@?%!718V!PQhY`XLSRf%/@%f%A]r`kB^s`WafFeC<7$rPeiNqSiNDJ,~>
+!5A9P%>b&>h;6uEhr!ANiW"^bbOisXk5G;rm`kP!r6a:!daS6TlMSl\s3f[%dbFfMrQ>Q7r7B??
+g],mYqs8mWo?.-_o?%*Oe,IJudbNX8g#(T?d`T_Me,IJpf%ns7h:LK5rlP5YqTAlQJ,~>
+!4M^A%>t2Chr*DMiSieVj8Y!f`:UtJir/lnm)Jekr6*^lbg$1DkPW<Ns30*pbLcd;rPT'.r6ia,
+fDj:KqW`XMo>CXRo>C[Bc2PWic.L_)e_Jj1c,@Q5c2PWddG!('g=+a%rknfLqSWBBJ,~>
+!4M^A%>Fi7g"P-5gt^`BhuAC]`:UtJir/lnm)Jekr6*^lbg$1DkPW<Ns30*pbLcd;rPT'.r6ia,
+fDj:KqW`XMo>CXRo>C[Bc2PWic.L_)e_Jj1c,@Q5c2PWddG!('g=+a%rknfLqSWBBJ,~>
+!5A9N%>b&?hV[2Ii8N\Tj8Xpdan3[pp%-Y]m/?2DbOY,Us3\sKr;,0igAfRSs3TL"d/D)brs$j(
+s8Vu]b^mn-aT0`fa8jQ_f`]XBaMQ@%a9(,Kg\f,(_U6HGcJ7"+e(!1(gs4!^_YV@S^46~>
+!4M^?%>t2DiSrhUj5]4^jo:3h_Xt\bo^^8Ol29]<`:30Es3&:;r;,$^ec3hCs2rmlb5K3Urs$Wr
+s8VrZ`IYnt_>qdY_#VURe-*n0_7Ihe_#i3:f)3>q]$%q+aOnklcHb%gfZ:nF])'8D[X\~>
+!4M^?%>Fi9gYCQ=h;7&Hi;\L^_Xt\bo^^8Ol29]<`:30Es3&:;r;,$^ec3hCs2rmlb5K3Urs$Wr
+s8VrZ`IYnt_>qdY_#VURe-*n0_7Ihe_#i3:f)3>q]$%q+aOnklcHb%gfZ:nF])'8D[X\~>
+!5A9L%>b&Ai8NPMi8N\Tj8Xpda+;:B`rOHb`W=cFr7;,*fZ(qHchk]`g">!U`Xor3`l?9YgX=*]
+dbER$`l>gj`rNi(~>
+!4M^=%>t2FioB"Wj5]4^jo:3h^k';4^];IT^]2g]dKS.L^V@;"qnE3^e("<1&@ffr^W4sXbeLp;
+f@S$W^UX-U!4IC~>
+!4M^=%>Fi;h;-i@h;7&Hi;\L^^k';4^];IT^]2g]dKS.L^V@;"qnE3^e("<1&@ffr^W4sXbeLp;
+f@S$W^UX-U!4IC~>
+!5A9J%>b&Ai8NVQioB([jo:-f`IZ">`;n0^_uS$Xf*'=9`4jLn_ue3:c2>K\^<QYq!R&Xa`;e!Z
+_uROJ`;mW&~>
+!4M^;%>t2FioB%Yj5f=ak5U<i^4F#0^&Z1P]`H.$r6kht`kB'o`r!FNa4/0-]`GR]rk/?O`;RCL
+`;[FM[ed]<[X\~>
+!4M^;!ep[0rS7\7i8EVSs+Q$<J\J_0!65#O!QNRcdfn1>]tLkoqn3'OeAqL#!Og#I]`H*jrOr6L
+rk/<?qRus<J,~>
+!5A9H!/U=J!/Q3DJ]#(:!6auN!PQ\J_?%?no>1L@qSN<IJ,~>
+!4M^9!/gIL!/c??J\8S,!6"K?!OTf:\cK1Vo==q/qRcg:J,~>
+!4M^9!/:+G!/6!:J\8S,!6"K?!OTf:\cK1Vo==q/qRcg:J,~>
+!5A9Fo8%t6J\eq6!6OiJ!P?JF^]D'ho=t@<qS<0GJ,~>
+!4M^7o88+1J\&G(!5\9:!OBQ5\,inOo=+e+qRQ[8J,~>
+!4M^7o7_b,J\&G(!5\9:!OBQ5\,inOo=+e+qRQ[8J,~>
+J\H]LUV6`Ko=b79a7I"G\]=<U!4hp>J,~>
+J[U-<UUC0;o<n\(^[nl7YeTe<!3l:-J,~>
+J[U-<UUC0;o<n\(^[nl7YeTe<!3l:-J,~>
+rk<s`JcC<$nc/U&J,~>
+rjICXJcC<$nc/TsJ,~>
+rjICXJcC<$nc/TsJ,~>
+rk<s`JcC<$nc/U&J,~>
+rjICXJcC<$nc/TsJ,~>
+rjICXJcC<$nc/TsJ,~>
+rk<s`JcC<$nc/U&J,~>
+rjICXJcC<$nc/TsJ,~>
+rjICXJcC<$nc/TsJ,~>
+rk<s`JcC<$nc/U&J,~>
+rjICXJcC<$nc/TsJ,~>
+rjICXJcC<$nc/TsJ,~>
+rk<s`JcC<$nc/U&J,~>
+rjICXJcC<$nc/TsJ,~>
+rjICXJcC<$nc/TsJ,~>
+rk<s`JcC<$nc/U&J,~>
+rjICXJcC<$nc/TsJ,~>
+rjICXJcC<$nc/TsJ,~>
+rk<s`jo>=pq#C?.p\t6.r;Qc3jo>@qJcEpnrk<m~>
+rjICXjo><pq#C>.p\t5.r;Qb3jo>?qJcEpnrjI=~>
+rjICXjo><7q#C=Jp\t4Jr;QaOjo>?8JcEpnrjI=~>
+rk<s`k5PFrrr2u5qYpQ1rr2u5q>^K0rVlr6s1d[q!5JI3!5J7-!5JL4!5F*birB"lJ,~>
+rjICXk5PErrr2t5qYpP1rr2t5q>^J0rVlq6s(^Zq!,DH3!,D6-!,DK4!,@)birB"dJ,~>
+rjICXk5PE9rr2sQqYpOMrr2sQq>^ILrVlpRs"WX8!&=EO!&=3I!&=HP!&9')irB"dJ,~>
+rk<s`k5PFrrr2u5qYpQ1rr2u5qYpW3s1eR5!5JO5!5I[r!5Ik"!5F*birB"lJ,~>
+rjICXk5PErrr2t5qYpP1rr2t5qYpV3s(_Q5!,DN5!,CZr!,Cj"!,@)birB"dJ,~>
+rjICXk5PE9rr2sQqYpOMrr2sQqYpUOs"XNQ!&=KQ!&<X9!&<g>!&9')irB"dJ,~>
+rk<s`ir9"npAY--q#:?/rr2u5rr2u5q>^H/s8N)6rr3#6s8B_2rrBh4s8Tk4s8Ke4s8Tk5s8B]`
+s5a4Z^46~>
+rjICXir9!npAY,-q#:>/rr2t5rr2t5q>^G/s8N(6rr3"6s8?^2rr?g4s8Qj4s8Hd4s8Qj5s8?\`
+s5a4Z[X\~>
+rjICXir9!5pAY+Iq#:=Krr2sQrr2sQq>^FKs8N'Rrr3!Rs8=\Nrr=ePs8OhPs8FbPs8OhQs8=['
+s5a4Z[X\~>
+rk<s`j8T+opAY--p\t6.rr2u5rr2u5qYpQ1rr38=s8Tk6^]4>Krr2u5rr2u5r;Qc3rr2u5rr2u5
+rr2u5rVll4JcFa0rk<m~>
+rjICXj8T*opAY,-p\t5.rr2t5rr2t5qYpP1rr37=s8Qj6CB+<Krr2t5rr2t5r;Qb3rr2t5rr2t5
+rr2t5rVlk4JcFa0rjI=~>
+rjICXj8T*6pAY+Ip\t4Jrr2sQrr2sQqYpOMrr36Ys8OhR1&q8.rr2sQrr2sQr;QaOrr2sQrr2sQ
+rr2sQrVljPJcFa0rjI=~>
+rk<s`jSo4ppAY--pAY--rr2u5rr2u5qZ$K.rr2u5rr2u5rr2u5rr2u5r;Qc3rr2u5qYpQ1rVll4
+JcFa0rk<m~>
+rjICXjSo3ppAY,-pAY,-rr2t5rr2t5qZ$J.rr2t5rr2t5rr2t5rr2t5r;Qb3rr2t5qYpP1rVlk4
+JcFa0rjI=~>
+rjICXjSo37pAY+IpAY+Irr2sQrr2sQqZ$IJrr2sQrr2sQrr2sQrr2sQr;QaOrr2sQqYpOMrVljP
+JcFa0rjI=~>
+rk<s`jo5=qpAY--p&>$,rr2u5rr2u5qYpQ1qYpQ1rr2u5rr2u5rr2u5r;Qc3rr2u5qYpQ1rVll4
+JcFa0rk<m~>
+rjICXjo5<qpAY,-p&>#,rr2t5rr2t5qYpP1qYpP1rr2t5rr2t5rr2t5r;Qb3rr2t5qYpP1rVlk4
+JcFa0rjI=~>
+rjICXjo5<8pAY+Ip&>"Hrr2sQrr2sQqYpOMqYpOMrr2sQrr2sQrr2sQr;QaOrr2sQqYpOMrVljP
+JcFa0rjI=~>
+rk<s`k5PFrqYpQ1rr2u5qYpQ1r;Qc3rVlr6s1eC0!5JO5#J^<=^]2(Ks8B_2rrBh3rrBh5rrBh5
+rrBh5rrBh4rr^%9s1a-bjo>=oJ,~>
+rjICXk5PErqYpP1rr2t5qYpP1r;Qb3rVlq6s(_B0!,DN5#AX;=CB&&Ks8?^2rr?g3rr?g5rr?g5
+rr?g5rr?g4rr[$9s([,bjo>=gJ,~>
+rjICXk5PE9qYpOMrr2sQqYpOMr;QaOrVlpRs"X?L!&=KQ#;Q8Y1&j!.s8=\Nrr=eOrr=eQrr=eQ
+rr=eQrr=ePrrY"Us"T*)jo>=gJ,~>
+rk<s`k5Y@os8W)5s8W#3s8W)5s8W#3rr2u5p](6-s8N)6rr3&7s1eI2rkJI4rkJI4rkJI4rkJF3
+s1a-bjT#4nJ,~>
+rjICXk5Y?os8W(5s8W"3s8W(5s8W"3rr2t5p](5-s8N(6rr3%7s(_H2rbDH4rbDH4rbDH4rbDE3
+s([,bjT#4fJ,~>
+rjICXk5Y?6s8W'Qs8W!Os8W'Qs8W!Orr2sQp](4Is8N'Rrr3$Ss"XENr\=EPr\=EPr\=EPr\=BO
+s"T*)jT#4fJ,~>
+rk<s`hZ!SjpAY--i;WelJcEXfrk<m~>
+rjICXhZ!RjpAY,-i;WdlJcEXfrjI=~>
+rjICXhZ!R1pAY+Ii;Wd3JcEXfrjI=~>
+rk<s`Yl=^<JcEXfrk<m~>
+rjICXYl=]<JcEXfrjI=~>
+rjICXYl=\XJcEXfrjI=~>
+rk<s`JcC<$nc/U&J,~>
+rjICXJcC<$nc/TsJ,~>
+rjICXJcC<$nc/TsJ,~>
+rk<s`JcC<$nc/U&J,~>
+rjICXJcC<$nc/TsJ,~>
+rjICXJcC<$nc/TsJ,~>
+rk<s`JcC<$nc/U&J,~>
+rjICXJcC<$nc/TsJ,~>
+rjICXJcC<$nc/TsJ,~>
+rk<s`JcC<$nc/U&J,~>
+rjICXJcC<$nc/TsJ,~>
+rjICXJcC<$nc/TsJ,~>
+rk<s`JcC<$nc/U&J,~>
+rjICXJcC<$nc/TsJ,~>
+rjICXJcC<$nc/TsJ,~>
+rk<s`JcC<$nc/U&J,~>
+rjICXJcC<$nc/TsJ,~>
+rjICXJcC<$nc/TsJ,~>
+rk<s`JcC<$nc/U&J,~>
+rjICXJcC<$nc/TsJ,~>
+rjICXJcC<$nc/TsJ,~>
+rk@7h!$-Xjh>[K6JcGEC!$1M-!$0hork<m~>
+rjL\`!0i'7h>[J^JcGEC!0lpO!0l7<rjI=~>
+rjL\`!$-Xjh>[IoJcGEC!$1M-!$0horjI=~>
+rk@7h!$-Xjh>[K6JcGEC!$1M-!$0hork<m~>
+rjL\`!0i'7h>[J^JcGEC!0lpO!0l7<rjI=~>
+rjL\`!$-Xjh>[IoJcGEC!$1M-!$0horjI=~>
+rk@7h!$-Xjh>[K6JcGEC!$1M-!$0hork<m~>
+rjL\`!0i'7h>[J^JcGEC!0lpO!0l7<rjI=~>
+rjL\`!$-Xjh>[IoJcGEC!$1M-!$0horjI=~>
+rk@4g!$-XjhZ!T7JcGEC!$1M-!$0hork<m~>
+rjLY_!0i'7hZ!S_JcGEC!0lpO!0l7<rjI=~>
+rjLY_!$-XjhZ!RpJcGEC!$1M-!$0horjI=~>
+rk@4g!$-XjhZ!T7JcGEC!$1M-!$0hork<m~>
+rjLY_!0i'7hZ!S_JcGEC!0lpO!0l7<rjI=~>
+rjLY_!$-XjhZ!RpJcGEC!$1M-!$0horjI=~>
+rk@4g!$-XjhZ!T7JcGEC!$1M-!$0hork<m~>
+rjLY_!0i'7hZ!S_JcGEC!0lpO!0l7<rjI=~>
+rjLY_!$-XjhZ!RpJcGEC!$1M-!$0horjI=~>
+rk@4g!$-XjhZ!T7JcGEC!$1P.!$0enrk<m~>
+rjLY_!0i'7hZ!S_JcGEC!0lsP!0l4;rjI=~>
+rjLY_!$-XjhZ!RpJcGEC!$1P.!$0enrjI=~>
+rk@4g!$-XjhZ!T7JcGEC!$1P.!$1P.s1e"%rk<m~>
+rjLY_!0i'7hZ!S_JcGEC!0lsP!0lsPs"WsArjI=~>
+rjLY_!$-XjhZ!RpJcGEC!$1P.!$1P.s"WsArjI=~>
+rk@4g!$-XjhZ!T7JcGHD!$1M-!$1P.s1e"%rk<m~>
+rjLY_!0i'7hZ!S_JcGHD!0lpO!0lsPs"WsArjI=~>
+rjLY_!$-XjhZ!RpJcGHD!$1M-!$1P.s"WsArjI=~>
+rk@4g!$-XjhZ!T7JcGHD!$1M-!$1P.!$1J,rk<m~>
+rjLY_!0i'7hZ!S_JcGHD!0lpO!0lsP!0lmNrjI=~>
+rjLY_!$-XjhZ!RpJcGHD!$1M-!$1P.!$1J,rjI=~>
+rk@4g!$-XjhZ!T7JcGHD!$1M-!$1P.!$1J,rk<m~>
+rjLY_!0i'7hZ!S_JcGHD!0lpO!0lsP!0lmNrjI=~>
+rjLY_!$-XjhZ!RpJcGHD!$1M-!$1P.!$1J,rjI=~>
+rk@4g!$-XjhZ!T7JcGHD!$1M-!$1S/!$1G+rk<m~>
+rjLY_!0i'7hZ!S_JcGHD!0lpO!0m!Q!0ljMrjI=~>
+rjLY_!$-XjhZ!RpJcGHD!$1M-!$1S/!$1G+rjI=~>
+rk@1f!$-Xjhu<]8JcGHD!$1M-!$1S/!$1G+rk<m~>
+rjLV^!0i'7hu<\`JcGHD!0lpO!0m!Q!0ljMrjI=~>
+rjLV^!$-Xjhu<[qJcGHD!$1M-!$1S/!$1G+rjI=~>
+rk@1f!$-Xjhu<]8JcGHD!$1M-!$1S/!$1G+rk<m~>
+rjLV^!0i'7hu<\`JcGHD!0lpO!0m!Q!0ljMrjI=~>
+rjLV^!$-Xjhu<[qJcGHD!$1M-!$1S/!$1G+rjI=~>
+rk@1f!$-Xjhu<]8JcGHD!$1P.!$1P.!$1G+rk<m~>
+rjLV^!0i'7hu<\`JcGHD!0lsP!0lsP!0ljMrjI=~>
+rjLV^!$-Xjhu<[qJcGHD!$1P.!$1P.!$1G+rjI=~>
+rk@1f!$-Xjhu<]8JcGHD!$1P.!$1P.!$1G+rk<m~>
+rjLV^!0i'7hu<\`JcGHD!0lsP!0lsP!0ljMrjI=~>
+rjLV^!$-Xjhu<[qJcGHD!$1P.!$1P.!$1G+rjI=~>
+rk@1f!$-Xjhu<]8JcGKE!$1M-!$1P.!$1G+rk<m~>
+rjLV^!0i'7hu<\`JcGKE!0lpO!0lsP!0ljMrjI=~>
+rjLV^!$-Xjhu<[qJcGKE!$1M-!$1P.!$1G+rjI=~>
+rk@1f!$-Xjhu<]8JcGKE!$1M-!$1P.!$1G+rk<m~>
+rjLV^!0i'7hu<\`JcGKE!0lpO!0lsP!0ljMrjI=~>
+rjLV^!$-Xjhu<[qJcGKE!$1M-!$1P.!$1G+rjI=~>
+rk@1f!$-Xjhu<]8JcGKE!$1M-!$1S/!$1D*rk<m~>
+rjLV^!0i'7hu<\`JcGKE!0lpO!0m!Q!0lgLrjI=~>
+rjLV^!$-Xjhu<[qJcGKE!$1M-!$1S/!$1D*rjI=~>
+rk@1f!$-Xjhu<]8JcGKE!$1M-!$1S/!$1D*rk<m~>
+rjLV^!0i'7hu<\`JcGKE!0lpO!0m!Q!0lgLrjI=~>
+rjLV^!$-Xjhu<[qJcGKE!$1M-!$1S/!$1D*rjI=~>
+rk@1f!$-Xjhu<]8JcGKE!$1M-!$1S/!$1D*rk<m~>
+rjLV^!0i'7hu<\`JcGKE!0lpO!0m!Q!0lgLrjI=~>
+rjLV^!$-Xjhu<[qJcGKE!$1M-!$1S/!$1D*rjI=~>
+rk@.e!$-Xji;Wf9JcGKE!$1M-!$1S/!$1D*rk<m~>
+rjLS]!0i'7i;WeaJcGKE!0lpO!0m!Q!0lgLrjI=~>
+rjLS]!$-Xji;WdrJcGKE!$1M-!$1S/!$1D*rjI=~>
+rk@.e!$-Xji;Wf9JcGKE!$1P.!$1P.!$1D*rk<m~>
+rjLS]!0i'7i;WeaJcGKE!0lsP!0lsP!0lgLrjI=~>
+rjLS]!$-Xji;WdrJcGKE!$1P.!$1P.!$1D*rjI=~>
+rk@.e!$-Xji;Wf9JcGKE!$1P.!$1P.!$1D*rk<m~>
+rjLS]!0i'7i;WeaJcGKE!0lsP!0lsP!0lgLrjI=~>
+rjLS]!$-Xji;WdrJcGKE!$1P.!$1P.!$1D*rjI=~>
+rk@.e!$-Xji;Wf9JcGNF!$1M-!$1S/!$1A)rk<m~>
+rjLS]!0i'7i;WeaJcGNF!0lpO!0m!Q!0ldKrjI=~>
+rjLS]!$-Xji;WdrJcGNF!$1M-!$1S/!$1A)rjI=~>
+rk@.e!$-Xji;Wf9JcGNF!$1M-!$1S/!$1A)rk<m~>
+rjLS]!0i'7i;WeaJcGNF!0lpO!0m!Q!0ldKrjI=~>
+rjLS]!$-Xji;WdrJcGNF!$1M-!$1S/!$1A)rjI=~>
+rk@.e!$-Xji;Wf9JcGNF!$1M-!$1S/!$1A)rk<m~>
+rjLS]!0i'7i;WeaJcGNF!0lpO!0m!Q!0ldKrjI=~>
+rjLS]!$-Xji;WdrJcGNF!$1M-!$1S/!$1A)rjI=~>
+rk@.e!$-Xji;Wf9JcGNF!$1M-!$1S/!$1A)rk<m~>
+rjLS]!0i'7i;WeaJcGNF!0lpO!0m!Q!0ldKrjI=~>
+rjLS]!$-Xji;WdrJcGNF!$1M-!$1S/!$1A)rjI=~>
+rk@.e!$-Xji;Wf9JcGNF!$1M-!$1S/!$1A)rk<m~>
+rjLS]!0i'7i;WeaJcGNF!0lpO!0m!Q!0ldKrjI=~>
+rjLS]!$-Xji;WdrJcGNF!$1M-!$1S/!$1A)rjI=~>
+rk@.e!$-Xji;Wf9JcGNF!$1M-!$1S/!$1A)rk<m~>
+rjLS]!0i'7i;WeaJcGNF!0lpO!0m!Q!0ldKrjI=~>
+rjLS]!$-Xji;WdrJcGNF!$1M-!$1S/!$1A)rjI=~>
+rk@+d!$-XjiVro:JcGNF!$1P.!$1P.!$1A)rk<m~>
+rjLP\!0i'7iVrnbJcGNF!0lsP!0lsP!0ldKrjI=~>
+rjLP\!$-XjiVrmsJcGNF!$1P.!$1P.!$1A)rjI=~>
+rk@+d!$-XjiVro:JcGNF!$1P.!$1S/!$1>(rk<m~>
+rjLP\!0i'7iVrnbJcGNF!0lsP!0m!Q!0laJrjI=~>
+rjLP\!$-XjiVrmsJcGNF!$1P.!$1S/!$1>(rjI=~>
+rk@+d!$-XjiVro:JcGQG!$1M-!$1S/!$1>(rk<m~>
+rjLP\!0i'7iVrnbJcGQG!0lpO!0m!Q!0laJrjI=~>
+rjLP\!$-XjiVrmsJcGQG!$1M-!$1S/!$1>(rjI=~>
+rk@+d!$-XjiVro:JcGQG!$1M-!$1S/!$1>(rk<m~>
+rjLP\!0i'7iVrnbJcGQG!0lpO!0m!Q!0laJrjI=~>
+rjLP\!$-XjiVrmsJcGQG!$1M-!$1S/!$1>(rjI=~>
+rk@+d!$-XjiVro:JcGQG!$1M-!?JrFrr=)(s8K`_~>
+rjLP\!0i'7iVrnbJcGQG!0lpO!L,>/rrA;Js8KHW~>
+rjLP\!$-XjiVrmsJcGQG!$1M-!?Eobrr=)(s8KHW~>
+rk@+d!$-XjiVro:JcGQG!$1M-s1e+(!$1>(rk<m~>
+rjLP\!0i'7iVrnbJcGQG!0lpOs"X'D!0laJrjI=~>
+rjLP\!$-XjiVrmsJcGQG!$1M-s"X'D!$1>(rjI=~>
+rk@+d!$-XjiVro:JcGQG!$1M-!$1S/!$1>(rk<m~>
+rjLP\!0i'7iVrnbJcGQG!0lpO!0m!Q!0laJrjI=~>
+rjLP\!$-XjiVrmsJcGQG!$1M-!$1S/!$1>(rjI=~>
+rk@+d!$-XjiVro:JcGQG!$1M-!$1S/!$1>(rk<m~>
+rjLP\!0i'7iVrnbJcGQG!0lpO!0m!Q!0laJrjI=~>
+rjLP\!$-XjiVrmsJcGQG!$1M-!$1S/!$1>(rjI=~>
+rk@+d!$-XjiVro:JcGQG!$1P.!$1S/!$1;'rk<m~>
+rjLP\!0i'7iVrnbJcGQG!0lsP!0m!Q!0l^IrjI=~>
+rjLP\!$-XjiVrmsJcGQG!$1P.!$1S/!$1;'rjI=~>
+rk@+d!$-XjiVro:JcGQG!$1P.!$1S/!$1;'rk<m~>
+rjLP\!0i'7iVrnbJcGQG!0lsP!0m!Q!0l^IrjI=~>
+rjLP\!$-XjiVrmsJcGQG!$1P.!$1S/!$1;'rjI=~>
+rk@(c!$-Xjir9#;JcGTH!$1M-!$1S/!$1;'rk<m~>
+rjLM[!0i'7ir9"cJcGTH!0lpO!0m!Q!0l^IrjI=~>
+rjLM[!$-Xjir9!tJcGTH!$1M-!$1S/!$1;'rjI=~>
+rk@(c!$-Xjir9#;JcGTH!$1M-!$1S/!$1;'rk<m~>
+rjLM[!0i'7ir9"cJcGTH!0lpO!0m!Q!0l^IrjI=~>
+rjLM[!$-Xjir9!tJcGTH!$1M-!$1S/!$1;'rjI=~>
+rk@(c!$-Xjir9#;JcGTH!$1M-!$1S/!$1;'rk<m~>
+rjLM[!0i'7ir9"cJcGTH!0lpO!0m!Q!0l^IrjI=~>
+rjLM[!$-Xjir9!tJcGTH!$1M-!$1S/!$1;'rjI=~>
+rk@(c!$-Xjir9#;JcGTH!$1M-!$1S/!$1;'rk<m~>
+rjLM[!0i'7ir9"cJcGTH!0lpO!0m!Q!0l^IrjI=~>
+rjLM[!$-Xjir9!tJcGTH!$1M-!$1S/!$1;'rjI=~>
+rk@(c!$-Xjir9#;JcGTH!$1P.!$1S/!$18&rk<m~>
+rjLM[!0i'7ir9"cJcGTH!0lsP!0m!Q!0l[HrjI=~>
+rjLM[!$-Xjir9!tJcGTH!$1P.!$1S/!$18&rjI=~>
+rk@(c!$-Xjir9#;JcGTH!$1P.!$1S/!$18&rk<m~>
+rjLM[!0i'7ir9"cJcGTH!0lsP!0m!Q!0l[HrjI=~>
+rjLM[!$-Xjir9!tJcGTH!$1P.!$1S/!$18&rjI=~>
+rk@(c!$-Xjir9#;JcGTH!$1P.!$1S/!$18&rk<m~>
+rjLM[!0i'7ir9"cJcGTH!0lsP!0m!Q!0l[HrjI=~>
+rjLM[!$-Xjir9!tJcGTH!$1P.!$1S/!$18&rjI=~>
+rk@(c!$-Xjir9#;JcGTH!$1P.!$1S/!$18&rk<m~>
+rjLM[!0i'7ir9"cJcGTH!0lsP!0m!Q!0l[HrjI=~>
+rjLM[!$-Xjir9!tJcGTH!$1P.!$1S/!$18&rjI=~>
+rk@(c!$-Xjir9#;JcGWI!$1M-!$1S/!$18&rk<m~>
+rjLM[!0i'7ir9"cJcGWI!0lpO!0m!Q!0l[HrjI=~>
+rjLM[!$-Xjir9!tJcGWI!$1M-!$1S/!$18&rjI=~>
+rk@%b!$-Xjj8T,<JcGWI!$1M-!$1S/!$18&rk<m~>
+rjLJZ!0i'7j8T+dJcGWI!0lpO!0m!Q!0l[HrjI=~>
+rjLJZ!$-Xjj8T*uJcGWI!$1M-!$1S/!$18&rjI=~>
+rk@%b!$-Xjj8T,<JcGWI!$1P.!$1P.!$18&rk<m~>
+rjLJZ!0i'7j8T+dJcGWI!0lsP!0lsP!0l[HrjI=~>
+rjLJZ!$-Xjj8T*uJcGWI!$1P.!$1P.!$18&rjI=~>
+rk@%b!$-Xjj8T,<JcGWI!$1P.!$1S/!$15%rk<m~>
+rjLJZ!0i'7j8T+dJcGWI!0lsP!0m!Q!0lXGrjI=~>
+rjLJZ!$-Xjj8T*uJcGWI!$1P.!$1S/!$15%rjI=~>
+rk@%b!$-Xjj8T,<JcGWI!$1P.!$1S/!$15%rk<m~>
+rjLJZ!0i'7j8T+dJcGWI!0lsP!0m!Q!0lXGrjI=~>
+rjLJZ!$-Xjj8T*uJcGWI!$1P.!$1S/!$15%rjI=~>
+rk@%b!$-Xjj8T,<JcGWI!$1P.!$1S/!$15%rk<m~>
+rjLJZ!0i'7j8T+dJcGWI!0lsP!0m!Q!0lXGrjI=~>
+rjLJZ!$-Xjj8T*uJcGWI!$1P.!$1S/!$15%rjI=~>
+rk@%b!$-Xjj8T,<JcGWI!$1P.!$1S/!?Jr<s8K`_~>
+rjLJZ!0i'7j8T+dJcGWI!0lsP!0m!Q!L,>%s8KHW~>
+rjLJZ!$-Xjj8T*uJcGWI!$1P.!$1S/!?EoXs8KHW~>
+rk@%b!$-Xjj8T,<JcGWI!$1P.!$1S/s1dasrk<m~>
+rjLJZ!0i'7j8T+dJcGWI!0lsP!0m!Qs"W^:rjI=~>
+rjLJZ!$-Xjj8T*uJcGWI!$1P.!$1S/s"W^:rjI=~>
+rk@%b!$-Xjj8T,<JcGZJ!$1M-!$1S/!$15%rk<m~>
+rjLJZ!0i'7j8T+dJcGZJ!0lpO!0m!Q!0lXGrjI=~>
+rjLJZ!$-Xjj8T*uJcGZJ!$1M-!$1S/!$15%rjI=~>
+rk@%b!$-Xjj8T,<JcGZJ!$1P.!$1S/!$12$rk<m~>
+rjLJZ!0i'7j8T+dJcGZJ!0lsP!0m!Q!0lUFrjI=~>
+rjLJZ!$-Xjj8T*uJcGZJ!$1P.!$1S/!$12$rjI=~>
+rk@"a!$-XjjSo5=JcGZJ!$1P.!$1S/!$12$rk<m~>
+rjLGY!0i'7jSo4eJcGZJ!0lsP!0m!Q!0lUFrjI=~>
+rjLGY!$-XjjSo4!JcGZJ!$1P.!$1S/!$12$rjI=~>
+rk@"a!$-XjjSo5=JcGZJ!$1P.!$1S/!$12$rk<m~>
+rjLGY!0i'7jSo4eJcGZJ!0lsP!0m!Q!0lUFrjI=~>
+rjLGY!$-XjjSo4!JcGZJ!$1P.!$1S/!$12$rjI=~>
+rk@"a!$-XjjSo5=JcGZJ!?JrErr=)/rr=)$s8K`_~>
+rjLGY!0i'7jSo4eJcGZJ!L,>.rrA;QrrA;Fs8KHW~>
+rjLGY!$-XjjSo4!JcGZJ!?Eoarr=)/rr=)$s8KHW~>
+rk@"a!$-XjjSo5=JcGZJs1e('!$1S/!$12$rk<m~>
+rjLGY!0i'7jSo4eJcGZJs"X$C!0m!Q!0lUFrjI=~>
+rjLGY!$-XjjSo4!JcGZJs"X$C!$1S/!$12$rjI=~>
+rk@"a!?Jq+s5j7\iIV%,rr=).rr=)0rr=)#s8K`_~>
+rjLGY!L,<is5j7\["88TrrA;PrrA;RrrA;Es8KHW~>
+rjLGY!?EnGs5j7\E.S&err=).rr=)0rr=)#s8KHW~>
+rk@"a!?Jq+s5j7\iIV%,rr=)/rr=)/rr=)#s8K`_~>
+rjLGY!L,<is5j7\["88TrrA;QrrA;QrrA;Es8KHW~>
+rjLGY!?EnGs5j7\E.S&err=)/rr=)/rr=)#s8KHW~>
+rk@"a!$-XjjSo5=JcG]K!$1P.!$1S/!$1/#rk<m~>
+rjLGY!0i'7jSo4eJcG]K!0lsP!0m!Q!0lRErjI=~>
+rjLGY!$-XjjSo4!JcG]K!$1P.!$1S/!$1/#rjI=~>
+rk@"a!$-XjjSo5=JcG]K!$1P.!$1S/!$1/#rk<m~>
+rjLGY!0i'7jSo4eJcG]K!0lsP!0m!Q!0lRErjI=~>
+rjLGY!$-XjjSo4!JcG]K!$1P.!$1S/!$1/#rjI=~>
+rk?t`!$-Xjjo5>>JcG]K!$1P.!$1S/!$1/#rk<m~>
+rjLDX!0i'7jo5=fJcG]K!0lsP!0m!Q!0lRErjI=~>
+rjLDX!$-Xjjo5="JcG]K!$1P.!$1S/!$1/#rjI=~>
+rk?t`!$-Xjjo5>>JcG]K!$1P.!$1S/!$1/#rk<m~>
+rjLDX!0i'7jo5=fJcG]K!0lsP!0m!Q!0lRErjI=~>
+rjLDX!$-Xjjo5="JcG]K!$1P.!$1S/!$1/#rjI=~>
+rk?t`!$-Xjjo5>>JcG]K!$1P.!$1V0!$1,"rk<m~>
+rjLDX!0i'7jo5=fJcG]K!0lsP!0m$R!0lODrjI=~>
+rjLDX!$-Xjjo5="JcG]K!$1P.!$1V0!$1,"rjI=~>
+rk?t`!$-Xjjo5>>JcG]K!$1P.!$1V0!$1,"rk<m~>
+rjLDX!0i'7jo5=fJcG]K!0lsP!0m$R!0lODrjI=~>
+rjLDX!$-Xjjo5="JcG]K!$1P.!$1V0!$1,"rjI=~>
+rk?t`!$-Xjjo5>>JcG]K!$1S/!$1S/!$1,"rk<m~>
+rjLDX!0i'7jo5=fJcG]K!0m!Q!0m!Q!0lODrjI=~>
+rjLDX!$-Xjjo5="JcG]K!$1S/!$1S/!$1,"rjI=~>
+rk?t`!$-Xjjo5>>JcG]K!$1S/!$1S/!$1,"rk<m~>
+rjLDX!0i'7jo5=fJcG]K!0m!Q!0m!Q!0lODrjI=~>
+rjLDX!$-Xjjo5="JcG]K!$1S/!$1S/!$1,"rjI=~>
+rk?t`!$-Xjjo5>>JcG`L!$1P.!$1S/!$1,"rk<m~>
+rjLDX!0i'7jo5=fJcG`L!0lsP!0m!Q!0lODrjI=~>
+rjLDX!$-Xjjo5="JcG`L!$1P.!$1S/!$1,"rjI=~>
+rk?q_!$-Xjk5PG?JcG`L!$1P.!$1V0!$1)!rk<m~>
+rjLAW!0i'7k5PFgJcG`L!0lsP!0m$R!0lLCrjI=~>
+rjLAW!$-Xjk5PF#JcG`L!$1P.!$1V0!$1)!rjI=~>
+rk?q_!$-Xjk5PG?JcG`L!$1P.!$1V0!$1)!rk<m~>
+rjLAW!0i'7k5PFgJcG`L!0lsP!0m$R!0lLCrjI=~>
+rjLAW!$-Xjk5PF#JcG`L!$1P.!$1V0!$1)!rjI=~>
+rk?q_!$-Xjk5PG?JcG`L!$1P.!$1V0!$1)!rk<m~>
+rjLAW!0i'7k5PFgJcG`L!0lsP!0m$R!0lLCrjI=~>
+rjLAW!$-Xjk5PF#JcG`L!$1P.!$1V0!$1)!rjI=~>
+rk?q_!$-Xjk5PG?JcG`L!$1S/!$1S/!$1)!rk<m~>
+rjLAW!0i'7k5PFgJcG`L!0m!Q!0m!Q!0lLCrjI=~>
+rjLAW!$-Xjk5PF#JcG`L!$1S/!$1S/!$1)!rjI=~>
+rk?q_!$-Xjk5PG?JcG`L!$1S/!$1S/!$1)!rk<m~>
+rjLAW!0i'7k5PFgJcG`L!0m!Q!0m!Q!0lLCrjI=~>
+rjLAW!$-Xjk5PF#JcG`L!$1S/!$1S/!$1)!rjI=~>
+rk?q_!$-Xjk5PG?JcG`L!$1S/!$1V0!$1%urk<m~>
+rjLAW!0i'7k5PFgJcG`L!0m!Q!0m$R!0lIBrjI=~>
+rjLAW!$-Xjk5PF#JcG`L!$1S/!$1V0!$1%urjI=~>
+rk?q_!$-Xjk5PG?JcG`L!$1S/!$1V0!$1%urk<m~>
+rjLAW!0i'7k5PFgJcG`L!0m!Q!0m$R!0lIBrjI=~>
+rjLAW!$-Xjk5PF#JcG`L!$1S/!$1V0!$1%urjI=~>
+rk?n^!$-XjkPkP@JcGcM!$1P.!$1V0!$1%urk<m~>
+rjL>V!0i'7kPkOhJcGcM!0lsP!0m$R!0lIBrjI=~>
+rjL>V!$-XjkPkO$JcGcM!$1P.!$1V0!$1%urjI=~>
+rk?n^!$-XjkPkP@JcGcM!$1P.!$1V0!$1%urk<m~>
+rjL>V!0i'7kPkOhJcGcM!0lsP!0m$R!0lIBrjI=~>
+rjL>V!$-XjkPkO$JcGcM!$1P.!$1V0!$1%urjI=~>
+rk?n^!$-XjkPkP@JcGcM!$1S/!$1S/!$1%urk<m~>
+rjL>V!0i'7kPkOhJcGcM!0m!Q!0m!Q!0lIBrjI=~>
+rjL>V!$-XjkPkO$JcGcM!$1S/!$1S/!$1%urjI=~>
+rk?n^!$-XjkPkP@JcGcM!$1S/!$1V0!$1"trk<m~>
+rjL>V!0i'7kPkOhJcGcM!0m!Q!0m$R!0lFArjI=~>
+rjL>V!$-XjkPkO$JcGcM!$1S/!$1V0!$1"trjI=~>
+rk?n^!$-XjkPkP@JcGcM!$1S/!$1V0!$1"trk<m~>
+rjL>V!0i'7kPkOhJcGcM!0m!Q!0m$R!0lFArjI=~>
+rjL>V!$-XjkPkO$JcGcM!$1S/!$1V0!$1"trjI=~>
+rk?n^!$-XjkPkP@JcGcM!$1S/!?JrGrr=(ts8K`_~>
+rjL>V!0i'7kPkOhJcGcM!0m!Q!L,>0rrA;As8KHW~>
+rjL>V!$-XjkPkO$JcGcM!$1S/!?Eocrr=(ts8KHW~>
+rk?n^!$-XjkPkP@JcGcM!$1S/s1e.)!$1"trk<m~>
+rjL>V!0i'7kPkOhJcGcM!0m!Qs"X*E!0lFArjI=~>
+rjL>V!$-XjkPkO$JcGcM!$1S/s"X*E!$1"trjI=~>
+rk?k]!$-Xjkl1YAJcGcM!$1S/!$1V0!$1"trk<m~>
+rjL;U!0i'7kl1XiJcGcM!0m!Q!0m$R!0lFArjI=~>
+rjL;U!$-Xjkl1X%JcGcM!$1S/!$1V0!$1"trjI=~>
+rk?k]!$-Xjkl1YAJc>cN*Uj".*V'.0*T6ts^46~>
+rjL;U!0i'7kl1XiJc>cNPjeVPPk"bRPi2T@[X\~>
+rjL;U!$-Xjkl1X%Jc>cN*Uj".*V'.0*T6ts[X\~>
+rk?k]!$-Xjkl1YAJc>cN*Us(/*V'.0*T-nr^46~>
+rjL;U!0i'7kl1XiJc>cNPjn\QPk"bRPi)N?[X\~>
+rjL;U!$-Xjkl1X%Jc>cN*Us(/*V'.0*T-nr[X\~>
+rk?k]!$-Xjkl1YAJc>cN*Us(/*V'.0*T-nr^46~>
+rjL;U!0i'7kl1XiJc>cNPjn\QPk"bRPi)N?[X\~>
+rjL;U!$-Xjkl1X%Jc>cN*Us(/*V'.0*T-nr[X\~>
+rk?k]!$-Xjkl1YAJc>cN*Us(/*V'.0*T-nr^46~>
+rjL;U!0i'7kl1XiJc>cNPjn\QPk"bRPi)N?[X\~>
+rjL;U!$-Xjkl1X%Jc>cN*Us(/*V'.0*T-nr[X\~>
+rk?k]!$-Xjkl1YAJc>cN*Us(/*V'.0*T-nr^46~>
+rjL;U!0i'7kl1XiJc>cNPjn\QPk"bRPi)N?[X\~>
+rjL;U!$-Xjkl1X%Jc>cN*Us(/*V'.0*T-nr[X\~>
+rk?k]!$-Xjkl1YAJc>cN*Us(/*V'.0*T-nr^46~>
+rjL;U!0i'7kl1XiJc>cNPjn\QPk"bRPi)N?[X\~>
+rjL;U!$-Xjkl1X%Jc>cN*Us(/*V'.0*T-nr[X\~>
+rk?h\!$-Xjl2LbBJc>cN*Us(/*V041*T$hq^46~>
+rjL8T!0i'7l2LajJc>cNPjn\QPk+hSPhuH>[X\~>
+rjL8T!$-Xjl2La&Jc>cN*Us(/*V041*T$hq[X\~>
+rk?h\!$-Xjl2LbBJc>cN*V'.0*V'.0*T$hq^46~>
+rjL8T!0i'7l2LajJc>cNPk"bRPk"bRPhuH>[X\~>
+rjL8T!$-Xjl2La&Jc>cN*V'.0*V'.0*T$hq[X\~>
+rk?h\!$-Xjl2LbBJc>]jnG`J/nc&V1^Yf(j^46~>
+rjL8T!0i'7l2LajJc>_7nG`KQnc&WS1#N$1[X\~>
+rjL8T!$-Xjl2La&Jc>]jnG`J/nc&V11#N$1[X\~>
+rk?h\!$-Xjl2LbBJc>]jnG`J/nc/X(huE\iJ,~>
+rjL8T!0i'7l2LajJc>_7nG`KQnc/VDhuE\aJ,~>
+rjL8T!$-Xjl2La&Jc>]jnG`J/nc/VDhuE\aJ,~>
+rk?h\!$-Xjl2LbBJc>]jnG`J/nc&S0hZ*ShJ,~>
+rjL8T!0i'7l2LajJc>_7nG`KQnc&TRhZ*S`J,~>
+rjL8T!$-Xjl2La&Jc>]jnG`J/nc&S0hZ*S`J,~>
+rk?h\!$-Xjl2LbBJc>]jnG`J/o)A\1h>dJgJ,~>
+rjL8T!0i'7l2LajJc>_7nG`KQo)A]Sh>dJ_J,~>
+rjL8T!$-Xjl2La&Jc>]jnG`J/o)A\1h>dJ_J,~>
+rk?h\!$-Xjl2LbBJc>]jnG`J/o)A\1h>dJgJ,~>
+rjL8T!0i'7l2LajJc>_7nG`KQo)A]Sh>dJ_J,~>
+rjL8T!$-Xjl2La&Jc>]jnG`J/o)A\1h>dJ_J,~>
+rk?e[!$-XjlMgkCJc>]jnG`J/o)A\1h>dJgJ,~>
+rjL5S!0i'7lMgjkJc>_7nG`KQo)A]Sh>dJ_J,~>
+rjL5S!$-XjlMgj'Jc>]jnG`J/o)A\1h>dJ_J,~>
+rk?e[!$-XjlMgkCJc>]jnc&S0nc&S0h>dJgJ,~>
+rjL5S!0i'7lMgjkJc>_7nc&TRnc&TRh>dJ_J,~>
+rjL5S!$-XjlMgj'Jc>]jnc&S0nc&S0h>dJ_J,~>
+rk?e[!$-XjlMgkCJc>]jnc&S0nc&S0h>dJgJ,~>
+rjL5S!0i'7lMgjkJc>_7nc&TRnc&TRh>dJ_J,~>
+rjL5S!$-XjlMgj'Jc>]jnc&S0nc&S0h>dJ_J,~>
+rk?e[!$-XjlMgkCK)YfknG`J/nc&S0h>dJgJ,~>
+rjL5S!0i'7lMgjkK)Yh8nG`KQnc&TRh>dJ_J,~>
+rjL5S!$-XjlMgj'K)YfknG`J/nc&S0h>dJ_J,~>
+rk?e[!$-XjlMgkCK)YfknG`J/o)A\1h#IAfJ,~>
+rjL5S!0i'7lMgjkK)Yh8nG`KQo)A]Sh#IA^J,~>
+rjL5S!$-XjlMgj'K)YfknG`J/o)A\1h#IA^J,~>
+rk?e[!$-XjlMgkCK)YfknG`J/o)A\1h#IAfJ,~>
+rjL5S!0i'7lMgjkK)Yh8nG`KQo)A]Sh#IA^J,~>
+rjL5S!$-XjlMgj'K)YfknG`J/o)A\1h#IA^J,~>
+rk?e[!$-XjlMgkCK)YfknG`J/o)A\1h#IAfJ,~>
+rjL5S!0i'7lMgjkK)Yh8nG`KQo)A]Sh#IA^J,~>
+rjL5S!$-XjlMgj'K)YfknG`J/o)A\1h#IA^J,~>
+rk?bZ!$-Xjli-tDK)Yfknc&S0nc&S0h#IAfJ,~>
+rjL2R!0i'7li-slK)Yh8nc&TRnc&TRh#IA^J,~>
+rjL2R!$-Xjli-s(K)Yfknc&S0nc&S0h#IA^J,~>
+rk?bZ!$-Xjli-tDK)Yfknc&S0nc&S0h#IAfJ,~>
+rjL2R!0i'7li-slK)Yh8nc&TRnc&TRh#IA^J,~>
+rjL2R!$-Xjli-s(K)Yfknc&S0nc&S0h#IA^J,~>
+rk?bZ!$-Xjli-tDK)Yfknc&S0o)A\1g].8eJ,~>
+rjL2R!0i'7li-slK)Yh8nc&TRo)A]Sg].8]J,~>
+rjL2R!$-Xjli-s(K)Yfknc&S0o)A\1g].8]J,~>
+rk?bZ!$-Xjli-tDK)Yfknc&S0o)A\1g].8eJ,~>
+rjL2R!0i'7li-slK)Yh8nc&TRo)A]Sg].8]J,~>
+rjL2R!$-Xjli-s(K)Yfknc&S0o)A\1g].8]J,~>
+rk?bZ!$-Xjli-tDKDtolnG`J/o)A\1g].8eJ,~>
+rjL2R!0i'7li-slKDtq9nG`KQo)A]Sg].8]J,~>
+rjL2R!$-Xjli-s(KDtolnG`J/o)A\1g].8]J,~>
+rk?bZ!$-Xjli-tDKDtolnG`J/o)A\1g].8eJ,~>
+rjL2R!0i'7li-slKDtq9nG`KQo)A]Sg].8]J,~>
+rjL2R!$-Xjli-s(KDtolnG`J/o)A\1g].8]J,~>
+rk?bZ!$-Xjli-tDKDtolnc&S0nc&S0g].8eJ,~>
+rjL2R!0i'7li-slKDtq9nc&TRnc&TRg].8]J,~>
+rjL2R!$-Xjli-s(KDtolnc&S0nc&S0g].8]J,~>
+rk?_Y!$-Xjm/I(EKDtolnc&S0o)A\1gAh/dJ,~>
+rjL/Q!0i'7m/I'mKDtq9nc&TRo)A]SgAh/\J,~>
+rjL/Q!$-Xjm/I')KDtolnc&S0o)A\1gAh/\J,~>
+rk?_Y!$-Xjm/I(EKDtrm^[hC)*V041*SUPm^46~>
+rjL/Q!0i'7m/I'mKDtt:1%P>EPk+hSPhQ0:[X\~>
+rjL/Q!$-Xjm/I')KDtrm1%P>E*V041*SUPm[X\~>
+rk?_Y!$-Xjm/I(EKE(tdo)A\1o)A\1gAh/dJ,~>
+rjL/Q!0i'7m/I'mKE(s+o)A]So)A]SgAh/\J,~>
+rjL/Q!$-Xjm/I')KE(s+o)A\1o)A\1gAh/\J,~>
+rk?_Y!?Jq+s6]gdiIh.1*V'.0*V041*SUPm^46~>
+rjL/Q!L,<is6]gd["JAYPk"bRPk+hSPhQ0:[X\~>
+rjL/Q!?EnGs6]gdE.e/j*V'.0*V041*SUPm[X\~>
+rk?_Y!?Jq+s6]gdiIh.1*V'.0*V041*SUPm^46~>
+rjL/Q!L,<is6]gd["JAYPk"bRPk+hSPhQ0:[X\~>
+rjL/Q!?EnGs6]gdE.e/j*V'.0*V041*SUPm[X\~>
+rk?_Y!$-Xjm/I(EK`;#mnG`J/o)A\1gAh/dJ,~>
+rjL/Q!0i'7m/I'mK`;%:nG`KQo)A]SgAh/\J,~>
+rjL/Q!$-Xjm/I')K`;#mnG`J/o)A\1gAh/\J,~>
+rk?_Y!$-Xjm/I(EK`;#mnc&S0o)A\1g&M&cJ,~>
+rjL/Q!0i'7m/I'mK`;%:nc&TRo)A]Sg&M&[J,~>
+rjL/Q!$-Xjm/I')K`;#mnc&S0o)A\1g&M&[J,~>
+rk?\X!$-XjmJd1FK`;#mnc&S0o)A\1g&M&cJ,~>
+rjL,P!0i'7mJd0nK`;%:nc&TRo)A]Sg&M&[J,~>
+rjL,P!$-XjmJd0*K`;#mnc&S0o)A\1g&M&[J,~>
+rk?\X!$-XjmJd1FK`;#mnc&S0o)A\1g&M&cJ,~>
+rjL,P!0i'7mJd0nK`;%:nc&TRo)A]Sg&M&[J,~>
+rjL,P!$-XjmJd0*K`;#mnc&S0o)A\1g&M&[J,~>
+rk?\X!$-XjmJd1FK`;#mnc&S0o)A\1g&M&cJ,~>
+rjL,P!0i'7mJd0nK`;%:nc&TRo)A]Sg&M&[J,~>
+rjL,P!$-XjmJd0*K`;#mnc&S0o)A\1g&M&[J,~>
+rk?\X!$-XjmJd1FK`;#mnc&S0o)A\1g&M&cJ,~>
+rjL,P!0i'7mJd0nK`;%:nc&TRo)A]Sg&M&[J,~>
+rjL,P!$-XjmJd0*K`;#mnc&S0o)A\1g&M&[J,~>
+rk?\X!$-XjmJd1FK`;#mnc&S0oD\e2f`1rbJ,~>
+rjL,P!0i'7mJd0nK`;%:nc&TRoD\fTf`1rZJ,~>
+rjL,P!$-XjmJd0*K`;#mnc&S0oD\e2f`1rZJ,~>
+rk?\X!$-XjmJd1FL&V,nnc&S0o)A\1f`1rbJ,~>
+rjL,P!0i'7mJd0nL&V.;nc&TRo)A]Sf`1rZJ,~>
+rjL,P!$-XjmJd0*L&V,nnc&S0o)A\1f`1rZJ,~>
+rk?\X!$-XjmJd1FL&V,nnc&S0o)A\1f`1rbJ,~>
+rjL,P!0i'7mJd0nL&V.;nc&TRo)A]Sf`1rZJ,~>
+rjL,P!$-XjmJd0*L&V,nnc&S0o)A\1f`1rZJ,~>
+rk?YW!$-Xjmf*:GL&V,nnc&S0o)A\1f`1rbJ,~>
+rjL)O!0i'7mf*9oL&V.;nc&TRo)A]Sf`1rZJ,~>
+rjL)O!$-Xjmf*9+L&V,nnc&S0o)A\1f`1rZJ,~>
+rk?YW!$-Xjmf*:GL&V,nnc&V1^[qI**SCDk^46~>
+rjL)O!0i'7mf*9oL&V.;nc&WS1%YDFPh?$8[X\~>
+rjL)O!$-Xjmf*9+L&V,nnc&V11%YDF*SCDk[X\~>
+rk?YW!$-Xjmf*:GL&V,nnc/X(oD\e2f`1rbJ,~>
+rjL)O!0i'7mf*9oL&V.;nc/VDoD\fTf`1rZJ,~>
+rjL)O!$-Xjmf*9+L&V,nnc/VDoD\e2f`1rZJ,~>
+rk?YW!$-Xjmf*:GL&V,nnc&S0oD\e2fDkiaJ,~>
+rjL)O!0i'7mf*9oL&V.;nc&TRoD\fTfDkiYJ,~>
+rjL)O!$-Xjmf*9+L&V,nnc&S0oD\e2fDkiYJ,~>
+rk?YW!$-Xjmf*:GLAq5onc&S0o)A\1fDkiaJ,~>
+rjL)O!0i'7mf*9oLAq7<nc&TRo)A]SfDkiYJ,~>
+rjL)O!$-Xjmf*9+LAq5onc&S0o)A\1fDkiYJ,~>
+rk?YW!$-Xjmf*:GLAq5onc&S0o)A_2^Y&Sc^46~>
+rjL)O!0i'7mf*9oLAq7<nc&TRo)A`T1"cO*[X\~>
+rjL)O!$-Xjmf*9+LAq5onc&S0o)A_21"cO*[X\~>
+rk?VV!$-Xjn,ECHLAq5onc&S0o)Ja)f`1rbJ,~>
+rjL&N!0i'7n,EBpLAq7<nc&TRo)J_Ef`1rZJ,~>
+rjL&N!$-Xjn,EB,LAq5onc&S0o)J_Ef`1rZJ,~>
+rk?VV!$-Xjn,ECHLAq5onc&S0o)A\1fDkiaJ,~>
+rjL&N!0i'7n,EBpLAq7<nc&TRo)A]SfDkiYJ,~>
+rjL&N!$-Xjn,EB,LAq5onc&S0o)A\1fDkiYJ,~>
+rk?VV!$-Xjn,ECHLAq5onc&S0oD\e2f)P``J,~>
+rjL&N!0i'7n,EBpLAq7<nc&TRoD\fTf)P`XJ,~>
+rjL&N!$-Xjn,EB,LAq5onc&S0oD\e2f)P`XJ,~>
+rk?VV!$-Xjn,ECHLAq5oo)A\1o)A\1f)P``J,~>
+rjL&N!0i'7n,EBpLAq7<o)A]So)A]Sf)P`XJ,~>
+rjL&N!$-Xjn,EB,LAq5oo)A\1o)A\1f)P`XJ,~>
+rk?VV!$-Xjn,ECHLAq5oo)A\1o)A\1f)P``J,~>
+rjL&N!0i'7n,EBpLAq7<o)A]So)A]Sf)P`XJ,~>
+rjL&N!$-Xjn,EB,LAq5oo)A\1o)A\1f)P`XJ,~>
+rk?VV!$-Xjn,ECHL]7>pnc&S0o)A\1f)P``J,~>
+rjL&N!0i'7n,EBpL]7@=nc&TRo)A]Sf)P`XJ,~>
+rjL&N!$-Xjn,EB,L]7>pnc&S0o)A\1f)P`XJ,~>
+rk?VV!$-Xjn,ECHL]7>pnc&S0oD\e2ec5W_J,~>
+rjL&N!0i'7n,EBpL]7@=nc&TRoD\fTec5WWJ,~>
+rjL&N!$-Xjn,EB,L]7>pnc&S0oD\e2ec5WWJ,~>
+rk?SU!$-XjnG`LIL]7>po)A\1o)A\1ec5W_J,~>
+rjL#M!0i'7nG`KqL]7@=o)A]So)A]Sec5WWJ,~>
+rjL#M!$-XjnG`K-L]7>po)A\1o)A\1ec5WWJ,~>
+rk?SU!$-XjnG`LIL]7>po)A\1o)A\1ec5W_J,~>
+rjL#M!0i'7nG`KqL]7@=o)A]So)A]Sec5WWJ,~>
+rjL#M!$-XjnG`K-L]7>po)A\1o)A\1ec5WWJ,~>
+rk?SU!$-XjnG`LIL]7>po)A\1o)A\1ec5W_J,~>
+rjL#M!0i'7nG`KqL]7@=o)A]So)A]Sec5WWJ,~>
+rjL#M!$-XjnG`K-L]7>po)A\1o)A\1ec5WWJ,~>
+rk?SU!$-XjnG`LIL]7>po)A\1oD\e2eGoN^J,~>
+rjL#M!0i'7nG`KqL]7@=o)A]SoD\fTeGoNVJ,~>
+rjL#M!$-XjnG`K-L]7>po)A\1oD\e2eGoNVJ,~>
+rk?SU!$-XjnG`LIL]7>po)A\1oD\e2eGoN^J,~>
+rjL#M!0i'7nG`KqL]7@=o)A]SoD\fTeGoNVJ,~>
+rjL#M!$-XjnG`K-L]7>po)A\1oD\e2eGoNVJ,~>
+rk?SU!$-XjnG`LIM#RGqo)A\1o)A\1eGoN^J,~>
+rjL#M!0i'7nG`KqM#RI>o)A]So)A]SeGoNVJ,~>
+rjL#M!$-XjnG`K-M#RGqo)A\1o)A\1eGoNVJ,~>
+rk?SU!$-XjnG`LIM#RGqo)A\1o)A\1eGoN^J,~>
+rjL#M!0i'7nG`KqM#RI>o)A]So)A]SeGoNVJ,~>
+rjL#M!$-XjnG`K-M#RGqo)A\1o)A\1eGoNVJ,~>
+rk?PT!$-Xjnc&UJM#RGqo)A\1oD\e2e,TE]J,~>
+rjKuL!0i'7nc&TrM#RI>o)A]SoD\fTe,TEUJ,~>
+rjKuL!$-Xjnc&T.M#RGqo)A\1oD\e2e,TEUJ,~>
+rk?PT!$-Xjnc&UJM#RGqo)A\1oD\e2e,TE]J,~>
+rjKuL!0i'7nc&TrM#RI>o)A]SoD\fTe,TEUJ,~>
+rjKuL!$-Xjnc&T.M#RGqo)A\1oD\e2e,TEUJ,~>
+rk?PT!$-Xjnc&UJM#RGqo)A\1oD\e2e,TE]J,~>
+rjKuL!0i'7nc&TrM#RI>o)A]SoD\fTe,TEUJ,~>
+rjKuL!$-Xjnc&T.M#RGqo)A\1oD\e2e,TEUJ,~>
+rk?PT!$-Xjnc&UJM#RGqoD\e2o)A\1e,TE]J,~>
+rjKuL!0i'7nc&TrM#RI>oD\fTo)A]Se,TEUJ,~>
+rjKuL!$-Xjnc&T.M#RGqoD\e2o)A\1e,TEUJ,~>
+rk?PT!$-Xjnc&UJM>mPro)A\1oD\e2df9<\J,~>
+rjKuL!0i'7nc&TrM>mR?o)A]SoD\fTdf9<TJ,~>
+rjKuL!$-Xjnc&T.M>mPro)A\1oD\e2df9<TJ,~>
+rk?PT!$-Xjnc&UJM>mPro)A\1oD\e2df9<\J,~>
+rjKuL!0i'7nc&TrM>mR?o)A]SoD\fTdf9<TJ,~>
+rjKuL!$-Xjnc&T.M>mPro)A\1oD\e2df9<TJ,~>
+rk?MS!$-Xjo)A^KM>mPro)A\1oD\e2df9<\J,~>
+rjKrK!0i'7o)A]sM>mR?o)A]SoD\fTdf9<TJ,~>
+rjKrK!$-Xjo)A]/M>mPro)A\1oD\e2df9<TJ,~>
+rk?MS!$-Xjo)A^KM>mPro)A\1oD\e2df9<\J,~>
+rjKrK!0i'7o)A]sM>mR?o)A]SoD\fTdf9<TJ,~>
+rjKrK!$-Xjo)A]/M>mPro)A\1oD\e2df9<TJ,~>
+rk?MS!$-Xjo)A^KM>mProD\e2oD\e2dJs3[J,~>
+rjKrK!0i'7o)A]sM>mR?oD\fToD\fTdJs3SJ,~>
+rjKrK!$-Xjo)A]/M>mProD\e2oD\e2dJs3SJ,~>
+rk?MS!$-Xjo)A^KM>mProD\e2oD\e2dJs3[J,~>
+rjKrK!0i'7o)A]sM>mR?oD\fToD\fTdJs3SJ,~>
+rjKrK!$-Xjo)A]/M>mProD\e2oD\e2dJs3SJ,~>
+rk?MS!$-Xjo)A^KM>mProD\e2oD\e2dJs3[J,~>
+rjKrK!0i'7o)A]sM>mR?oD\fToD\fTdJs3SJ,~>
+rjKrK!$-Xjo)A]/M>mProD\e2oD\e2dJs3SJ,~>
+rk?MS!$-Xjo)A^KMZ3Yso)A\1oD\e2dJs3[J,~>
+rjKrK!0i'7o)A]sMZ3[@o)A]SoD\fTdJs3SJ,~>
+rjKrK!$-Xjo)A]/MZ3Yso)A\1oD\e2dJs3SJ,~>
+rk?MS!$-Xjo)A^KMZ3YsoD\e2oD\e2d/X*ZJ,~>
+rjKrK!0i'7o)A]sMZ3[@oD\fToD\fTd/X*RJ,~>
+rjKrK!$-Xjo)A]/MZ3YsoD\e2oD\e2d/X*RJ,~>
+rk?JR!$-XjoD\gLMZ3YsoD\e2oD\e2d/X*ZJ,~>
+rjKoJ!0i'7oD\ftMZ3[@oD\fToD\fTd/X*RJ,~>
+rjKoJ!$-XjoD\f0MZ3YsoD\e2oD\e2d/X*RJ,~>
+rk?JR!$-XjoD\gLMZ3\t^\%O+*V9:2*ROic^46~>
+rjKoJ!0i'7oD\ftMZ3^A1%bJGPk4nTPgKI0[X\~>
+rjKoJ!$-XjoD\f0MZ3\t1%bJG*V9:2*ROic[X\~>
+rk?JR!$-XjoD\gLMZ<^ko`"n3oD\e2d/X*ZJ,~>
+rjKoJ!0i'7oD\ftMZ<]2o`"oUoD\fTd/X*RJ,~>
+rjKoJ!$-XjoD\f0MZ<]2o`"n3oD\e2d/X*RJ,~>
+rk?JR!?Jq+s7H<kiJRX8*V9:2*VB@3*RFcb^46~>
+rjKoJ!L,<is7H<k[#4k`Pk4nTPk=tUPgBC/[X\~>
+rjKoJ!?EnGs7H<kE/OYq*V9:2*VB@3*RFcb[X\~>
+rk?JR!?Jq+s7H<kiJ[^9*V9:2*V9:2*RFcb^46~>
+rjKoJ!L,<is7H<k[#=qaPk4nTPk4nTPgBC/[X\~>
+rjKoJ!?EnGs7H<kE/X_r*V9:2*V9:2*RFcb[X\~>
+rk?JR!$-XjoD\gLMuNbtoD\e2oD\h3^X3#[^46~>
+rjKoJ!0i'7oD\ftMuNdAoD\fToD\iU1!ot"[X\~>
+rjKoJ!$-XjoD\f0MuNbtoD\e2oD\h31!ot"[X\~>
+rk?GQ!$-Xjo`"pMMuNbtoD\h3^\%R+^X3#[^46~>
+rjKlI!0i'7o`"ouMuNdAoD\iU1%bMG1!ot"[X\~>
+rjKlI!$-Xjo`"o1MuNbtoD\h31%bMG1!ot"[X\~>
+rk?GQ!$-Xjo`"pMMuNbtoDej*o`"n3ci=!YJ,~>
+rjKlI!0i'7o`"ouMuNdAoDehFo`"oUci=!QJ,~>
+rjKlI!$-Xjo`"o1MuNbtoDehFo`"n3ci=!QJ,~>
+rk?GQ!$-Xjo`"pMMuNbtoD\e2o`"n3cN!mXJ,~>
+rjKlI!0i'7o`"ouMuNdAoD\fTo`"oUcN!mPJ,~>
+rjKlI!$-Xjo`"o1MuNbtoD\e2o`"n3cN!mPJ,~>
+rk?GQ!$-Xjo`"pMN;ikuoD\e2oD\e2cN!mXJ,~>
+rjKlI!0i'7o`"ouN;imBoD\fToD\fTcN!mPJ,~>
+rjKlI!$-Xjo`"o1N;ikuoD\e2oD\e2cN!mPJ,~>
+rk?GQ!$-Xjo`"pMN;ikuoD\e2oD\e2cN!mXJ,~>
+rjKlI!0i'7o`"ouN;imBoD\fToD\fTcN!mPJ,~>
+rjKlI!$-Xjo`"o1N;ikuoD\e2oD\e2cN!mPJ,~>
+rk?DP!$-Xjp&>$NN;ikuoD\e2oD\e2cN!mXJ,~>
+rjKiH!0i'7p&>$!N;imBoD\fToD\fTcN!mPJ,~>
+rjKiH!$-Xjp&>#2N;ikuoD\e2oD\e2cN!mPJ,~>
+rk?DP!$-Xjp&>$NN;ikuoD\e2o`"n3c2[dWJ,~>
+rjKiH!0i'7p&>$!N;imBoD\fTo`"oUc2[dOJ,~>
+rjKiH!$-Xjp&>#2N;ikuoD\e2o`"n3c2[dOJ,~>
+rk?DP!$-Xjp&>$NN;ikuoD\e2o`"n3c2[dWJ,~>
+rjKiH!0i'7p&>$!N;imBoD\fTo`"oUc2[dOJ,~>
+rjKiH!$-Xjp&>#2N;ikuoD\e2o`"n3c2[dOJ,~>
+rk?DP!$-Xjp&>$NNW/u!oD\e2oD\e2c2[dWJ,~>
+rjKiH!0i'7p&>$!NW0!CoD\fToD\fTc2[dOJ,~>
+rjKiH!$-Xjp&>#2NW/u!oD\e2oD\e2c2[dOJ,~>
+rk?DP!$-Xjp&>$NNW/u!oD\e2oD\e2c2[dWJ,~>
+rjKiH!0i'7p&>$!NW0!CoD\fToD\fTc2[dOJ,~>
+rjKiH!$-Xjp&>#2NW/u!oD\e2oD\e2c2[dOJ,~>
+rk@e"!?Jr0rr='js7ZHmiJmj;*V9:2*VB@3*R+Q_^46~>
+rjM4o!L,=nrrA:7s7ZHm[#P(cPk4nTPk=tUPg'1,[X\~>
+rjM4o!?EoLrr='js7ZHmE/jkt*V9:2*VB@3*R+Q_[X\~>
+rk@e"!?Jr0rr='js7ZHmiJmj;*V9:2*VB@3*R+Q_^46~>
+rjM4o!L,=nrrA:7s7ZHm[#P(cPk4nTPk=tUPg'1,[X\~>
+rjM4o!?EoLrr='js7ZHmE/jkt*V9:2*VB@3*R+Q_[X\~>
+rk@e"!$0en!$-XjpAY-ONW/u!oD\e2o`"n3bl@[VJ,~>
+rjM4o!0l4;!0i'7pAY-"NW0!CoD\fTo`"oUbl@[NJ,~>
+rjM4o!$0en!$-XjpAY,3NW/u!oD\e2o`"n3bl@[NJ,~>
+rk@b!!$0ho!$-XjpAY-ONrK)"oD\e2oD\e2bl@[VJ,~>
+rjM1n!0l7<!0i'7pAY-"NrK*DoD\fToD\fTbl@[NJ,~>
+rjM1n!$0ho!$-XjpAY,3NrK)"oD\e2oD\e2bl@[NJ,~>
+rk@b!!$0ho!$-XjpAY-ONrK)"oD\e2o`"n3bQ%RUJ,~>
+rjM1n!0l7<!0i'7pAY-"NrK*DoD\fTo`"oUbQ%RMJ,~>
+rjM1n!$0ho!$-XjpAY,3NrK)"oD\e2o`"n3bQ%RMJ,~>
+rk@b!!$0en!$-Xjp\t6PNrK)"oD\e2o`"n3bQ%RUJ,~>
+rjM1n!0l4;!0i'7p\t6#NrK*DoD\fTo`"oUbQ%RMJ,~>
+rjM1n!$0en!$-Xjp\t54NrK)"oD\e2o`"n3bQ%RMJ,~>
+rk@b!!$0en!$-Xjp\t6PNrK)"oD\e2o`"n3bQ%RUJ,~>
+rjM1n!0l4;!0i'7p\t6#NrK*DoD\fTo`"oUbQ%RMJ,~>
+rjM1n!$0en!$-Xjp\t54NrK)"oD\e2o`"n3bQ%RMJ,~>
+rk@b!!$0en!$-Xjp\t6PNrK)"o`"n3oD\e2bQ%RUJ,~>
+rjM1n!0l4;!0i'7p\t6#NrK*Do`"oUoD\fTbQ%RMJ,~>
+rjM1n!$0en!$-Xjp\t54NrK)"o`"n3oD\e2bQ%RMJ,~>
+rk@^u!$0ho!$-Xjp\t6PO8f2#oD\e2oD\e2bQ%RUJ,~>
+rjM.m!0l7<!0i'7p\t6#O8f3EoD\fToD\fTbQ%RMJ,~>
+rjM.m!$0ho!$-Xjp\t54O8f2#oD\e2oD\e2bQ%RMJ,~>
+rk@^u!$0en!$-Xjq#:?QO8f2#oD\e2o`"n3b5_ITJ,~>
+rjM.m!0l4;!0i'7q#:?$O8f3EoD\fTo`"oUb5_ILJ,~>
+rjM.m!$0en!$-Xjq#:>5O8f2#oD\e2o`"n3b5_ILJ,~>
+rk@^u!$0en!$-Xjq#:?QO8f2#oD\e2o`"n3b5_ITJ,~>
+rjM.m!0l4;!0i'7q#:?$O8f3EoD\fTo`"oUb5_ILJ,~>
+rjM.m!$0en!$-Xjq#:>5O8f2#oD\e2o`"n3b5_ILJ,~>
+rk@^u!$0en!$-Xjq#:?QO8f2#oD\e2o`"n3b5_ITJ,~>
+rjM.m!0l4;!0i'7q#:?$O8f3EoD\fTo`"oUb5_ILJ,~>
+rjM.m!$0en!$-Xjq#:>5O8f2#oD\e2o`"n3b5_ILJ,~>
+rk@[t!$0ho!$-Xjq#:?QO8f2#o`"n3oD\e2b5_ITJ,~>
+rjM+l!0l7<!0i'7q#:?$O8f3Eo`"oUoD\fTb5_ILJ,~>
+rjM+l!$0ho!$-Xjq#:>5O8f2#o`"n3oD\e2b5_ILJ,~>
+rk@[t!$0ho!$-Xjq#:?QOT,;$oD\e2o`"n3aoD@SJ,~>
+rjM+l!0l7<!0i'7q#:?$OT,<FoD\fTo`"oUaoD@KJ,~>
+rjM+l!$0ho!$-Xjq#:>5OT,;$oD\e2o`"n3aoD@KJ,~>
+rk@[t!$0en!$-Xjq>UHROT,;$oD\e2o`"n3aoD@SJ,~>
+rjM+l!0l4;!0i'7q>UH%OT,<FoD\fTo`"oUaoD@KJ,~>
+rjM+l!$0en!$-Xjq>UG6OT,;$oD\e2o`"n3aoD@KJ,~>
+rk@[t!$0en!$-Xjq>UHROT,;$oD\e2o`"n3aoD@SJ,~>
+rjM+l!0l4;!0i'7q>UH%OT,<FoD\fTo`"oUaoD@KJ,~>
+rjM+l!$0en!$-Xjq>UG6OT,;$oD\e2o`"n3aoD@KJ,~>
+rk@[t!$0en!$-Xjq>UHROT,;$oD\e2o`"n3aoD@SJ,~>
+rjM+l!0l4;!0i'7q>UH%OT,<FoD\fTo`"oUaoD@KJ,~>
+rjM+l!$0en!$-Xjq>UG6OT,;$oD\e2o`"n3aoD@KJ,~>
+rk@Xs!$0ho!$-Xjq>UHROT,;$o`"n3o`"n3aT)7RJ,~>
+rjM(k!0l7<!0i'7q>UH%OT,<Fo`"oUo`"oUaT)7JJ,~>
+rjM(k!$0ho!$-Xjq>UG6OT,;$o`"n3o`"n3aT)7JJ,~>
+rk@Xs!$0ho!$-Xjq>UHROoGD%oD\e2o`"n3aT)7RJ,~>
+rjM(k!0l7<!0i'7q>UH%OoGEGoD\fTo`"oUaT)7JJ,~>
+rjM(k!$0ho!$-Xjq>UG6OoGD%oD\e2o`"n3aT)7JJ,~>
+rk@Xs!$0en!$-XjqYpQSOoGD%oD\e2o`"q4^WHNT^46~>
+rjM(k!0l4;!0i'7qYpQ&OoGEGoD\fTo`"rV1!0Ip[X\~>
+rjM(k!$0en!$-XjqYpP7OoGD%oD\e2o`"q41!0Ip[X\~>
+rk@Xs!$0en!$-XjqYpQSOoGD%oD\e2o`+s+aoD@SJ,~>
+rjM(k!0l4;!0i'7qYpQ&OoGEGoD\fTo`+qGaoD@KJ,~>
+rjM(k!$0en!$-XjqYpP7OoGD%oD\e2o`+qGaoD@KJ,~>
+rk@Xs!$0en!$-XjqYpQSOoGD%oD\e2p&>"4a8c.QJ,~>
+rjM(k!0l4;!0i'7qYpQ&OoGEGoD\fTp&>#Va8c.IJ,~>
+rjM(k!$0en!$-XjqYpP7OoGD%oD\e2p&>"4a8c.IJ,~>
+rk@Ur!$0ho!$-XjqYpQSOoGD%o`"n3o`"n3a8c.QJ,~>
+rjM%j!0l7<!0i'7qYpQ&OoGEGo`"oUo`"oUa8c.IJ,~>
+rjM%j!$0ho!$-XjqYpP7OoGD%o`"n3o`"n3a8c.IJ,~>
+rk@Ur!$0ho!$-XjqYpQSP5bM&oD\e2o`"n3a8c.QJ,~>
+rjM%j!0l7<!0i'7qYpQ&P5bNHoD\fTo`"oUa8c.IJ,~>
+rjM%j!$0ho!$-XjqYpP7P5bM&oD\e2o`"n3a8c.IJ,~>
+rk@Ur!$0en!$-Xjqu6ZTP5bM&oD\h3^\7[-*QJ-Y^46~>
+rjM%j!0l4;!0i'7qu6Z'P5bNHoD\iU1%tVIPfEb&[X\~>
+rjM%j!$0en!$-Xjqu6Y8P5bM&oD\h31%tVI*QJ-Y[X\~>
+rk@Ur!$0en!$-Xjqu6ZTP5bP'^\%R+^\7[-*QJ-Y^46~>
+rjM%j!0l4;!0i'7qu6Z'P5bQI1%bMG1%tVIPfEb&[X\~>
+rjM%j!$0en!$-Xjqu6Y8P5bP'1%bMG1%tVI*QJ-Y[X\~>
+rk@Rq!$0ho!?Jq+s8;lsiKF6@^\.U,*VB@3*QJ-Y^46~>
+rjM"i!0l7<!L,<is8;ls[$(Ih1%kPHPk=tUPfEb&[X\~>
+rjM"i!$0ho!?EnGs8;lsE0C8$1%kPH*VB@3*QJ-Y[X\~>
+rk@Rq!$0ho!?Jq+s8;lsiKF3@*VB@3*VKF4*QA'X^46~>
+rjM"i!0l7<!L,<is8;ls[$(FhPk=tUPkG%VPf<\%[X\~>
+rjM"i!$0ho!?EnGs8;lsE0C5$*VB@3*VKF4*QA'X[X\~>
+rk@Rq!$0ho!$-Xjqu6ZTPQ(V'oD\e2p&>"4`W,qOJ,~>
+rjM"i!0l7<!0i'7qu6Z'PQ(WIoD\fTp&>#V`W,qGJ,~>
+rjM"i!$0ho!$-Xjqu6Y8PQ(V'oD\e2p&>"4`W,qGJ,~>
+rk@Rq!$0en!$-Xjr;QcUPQ(V'oD\e2p&>"4`W,qOJ,~>
+rjM"i!0l4;!0i'7r;Qc(PQ(WIoD\fTp&>#V`W,qGJ,~>
+rjM"i!$0en!$-Xjr;Qb9PQ(V'oD\e2p&>"4`W,qGJ,~>
+rk@Rq!$0en!$-Xjr;QcUPQ(V'o`"n3p&>"4`;fhNJ,~>
+rjM"i!0l4;!0i'7r;Qc(PQ(WIo`"oUp&>#V`;fhFJ,~>
+rjM"i!$0en!$-Xjr;Qb9PQ(V'o`"n3p&>"4`;fhFJ,~>
+rk@Op!$0ho!$-Xjr;QcUPQ(V'o`"n3p&>"4`;fhNJ,~>
+rjLth!0l7<!0i'7r;Qc(PQ(WIo`"oUp&>#V`;fhFJ,~>
+rjLth!$0ho!$-Xjr;Qb9PQ(V'o`"n3p&>"4`;fhFJ,~>
+rk@Op!$0ho!$-Xjr;QcUPlC_(oD\e2p&>"4`;fhNJ,~>
+rjLth!0l7<!0i'7r;Qc(PlC`JoD\fTp&>#V`;fhFJ,~>
+rjLth!$0ho!$-Xjr;Qb9PlC_(oD\e2p&>"4`;fhFJ,~>
+rk@Op!?Jr1rr='js8;lsiKX?B*V9:2*VKF4*Q8!W^46~>
+rjLth!L,=orrA:7s8;ls[$:RjPk4nTPkG%VPf3V$[X\~>
+rjLth!?EoMrr='js8;lsE0UA&*V9:2*VKF4*Q8!W[X\~>
+rk@Op!?Jr0rr='js8DrtiKX?B*VB@3*VKF4*Q.pV^46~>
+rjLth!L,=nrrA:7s8Drt[$:RjPk=tUPkG%VPf*P#[X\~>
+rjLth!?EoLrr='js8DrtE0UA&*VB@3*VKF4*Q.pV[X\~>
+rk@Lo!$0ho!$-XjrVllVPlC_(o`"n3p&>"4_uK_MJ,~>
+rjLqg!0l7<!0i'7rVll)PlC`Jo`"oUp&>#V_uK_EJ,~>
+rjLqg!$0ho!$-XjrVlk:PlC_(o`"n3p&>"4_uK_EJ,~>
+rk@Lo!$0ho!$-XjrVllVQ2^h)oD\e2p&>"4_uK_MJ,~>
+rjLqg!0l7<!0i'7rVll)Q2^iKoD\fTp&>#V_uK_EJ,~>
+rjLqg!$0ho!$-XjrVlk:Q2^h)oD\e2p&>"4_uK_EJ,~>
+rk@Lo!$0ho!$-XjrVllVQ2^h)oD\e2pAY+5_Z0VLJ,~>
+rjLqg!0l7<!0i'7rVll)Q2^iKoD\fTpAY,W_Z0VDJ,~>
+rjLqg!$0ho!$-XjrVlk:Q2^h)oD\e2pAY+5_Z0VDJ,~>
+rk@Lo!$0en!$-Xjrr2uWQ2^h)o`"n3p&>"4_Z0VLJ,~>
+rjLqg!0l4;!0i'7rr2u*Q2^iKo`"oUp&>#V_Z0VDJ,~>
+rjLqg!$0en!$-Xjrr2t;Q2^h)o`"n3p&>"4_Z0VDJ,~>
+rk@In!$0ho!$-Xjrr2uWQ2^h)o`"n3p&>"4_Z0VLJ,~>
+rjLnf!0l7<!0i'7rr2u*Q2^iKo`"oUp&>#V_Z0VDJ,~>
+rjLnf!$0ho!$-Xjrr2t;Q2^h)o`"n3p&>"4_Z0VDJ,~>
+rk@In!$0ho!$-Xjrr2uWQN$q*oD\e2pAY+5_>jMKJ,~>
+rjLnf!0l7<!0i'7rr2u*QN$rLoD\fTpAY,W_>jMCJ,~>
+rjLnf!$0ho!$-Xjrr2t;QN$q*oD\e2pAY+5_>jMCJ,~>
+rk@In!$0ho!$-Xjrr2uWQN$q*oD\e2pAY+5_>jMKJ,~>
+rjLnf!0l7<!0i'7rr2u*QN$rLoD\fTpAY,W_>jMCJ,~>
+rjLnf!$0ho!$-Xjrr2t;QN$q*oD\e2pAY+5_>jMCJ,~>
+rk@Fm!$0kp!$-Xjrr2uWQN$q*o`"n3p&>"4_>jMKJ,~>
+rjLke!0l:=!0i'7rr2u*QN$rLo`"oUp&>#V_>jMCJ,~>
+rjLke!$0kp!$-Xjrr2t;QN$q*o`"n3p&>"4_>jMCJ,~>
+rk@Fm!$0ho!$-Xjs8N)XQN$q*o`"n3pAY+5_#ODJJ,~>
+rjLke!0l7<!0i'7s8N)+QN$rLo`"oUpAY,W_#ODBJ,~>
+rjLke!$0ho!$-Xjs8N(<QN$q*o`"n3pAY+5_#ODBJ,~>
+rk@Fm!$0ho!$-Xjs8N)XQi@%+oD\e2pAY.6^VTsL^46~>
+rjLke!0l7<!0i'7s8N)+Qi@&MoD\fTpAY/X0u<nh[X\~>
+rjLke!$0ho!$-Xjs8N(<Qi@%+oD\e2pAY.60u<nh[X\~>
+rk@Fm!$0ho!$-Xjs8N)XQi@%+oD\e2pAb0-_>jMKJ,~>
+rjLke!0l7<!0i'7s8N)+Qi@&MoD\fTpAb.I_>jMCJ,~>
+rjLke!$0ho!$-Xjs8N(<Qi@%+oD\e2pAb.I_>jMCJ,~>
+rk@Cl!$0kp!$-Xjs8N)XQi@%+o`"n3pAY+5^]4;IJ,~>
+rjLhd!0l:=!0i'7s8N)+Qi@&Mo`"oUpAY,W^]4;AJ,~>
+rjLhd!$0kp!$-Xjs8N(<Qi@%+o`"n3pAY+5^]4;AJ,~>
+rk@Cl!$0kp!$-Xjs8N)XQi@%+o`"n3pAY+5^]4;IJ,~>
+rjLhd!0l:=!0i'7s8N)+Qi@&Mo`"oUpAY,W^]4;AJ,~>
+rjLhd!$0kp!$-Xjs8N(<Qi@%+o`"n3pAY+5^]4;AJ,~>
+rk@Cl!$0ho!$-Xj!WV,Grr=)2rr=)5rr=(Ss8K`_~>
+rjLhd!0l7<!0i'7!WTNorrA;TrrA;WrrA:us8KHW~>
+rjLhd!$0ho!$-Xj!WR,+rr=)2rr=)5rr=(Ss8KHW~>
+rk@@k!$0kp!$-Xj!WV,Grr=)2rr=)6rr=(Rs8K`_~>
+rjLec!0l:=!0i'7!WTNorrA;TrrA;XrrA:ts8KHW~>
+rjLec!$0kp!$-Xj!WR,+rr=)2rr=)6rr=(Rs8KHW~>
+rk@@k!$0kp!$-Xj!WV,Grr=)3rr=)5rr=(Rs8K`_~>
+rjLec!0l:=!0i'7!WTNorrA;UrrA;WrrA:ts8KHW~>
+rjLec!$0kp!$-Xj!WR,+rr=)3rr=)5rr=(Rs8KHW~>
+rk@@k!$0kp!$-Xj!WV,Grr=)3rr=)5rr=(Rs8K`_~>
+rjLec!0l:=!0i'7!WTNorrA;UrrA;WrrA:ts8KHW~>
+rjLec!$0kp!$-Xj!WR,+rr=)3rr=)5rr=(Rs8KHW~>
+rk@@k!$0ho!$-Xj!9'@G!$1\2!?JrLrr=(Rs8K`_~>
+rjLec!0l7<!0i'7!480o!0m*T!L,>5rrA:ts8KHW~>
+rjLec!$0ho!$-Xj!-"A+!$1\2!?Eohrr=(Rs8KHW~>
+rk@=j!$0kp!$-Xj!9'@G!$1\2s1e@/!$/cQrk<m~>
+rjLbb!0l:=!0i'7!480o!0m*Ts"X<K!0k1srjI=~>
+rjLbb!$0kp!$-Xj!-"A+!$1\2s"X<K!$/cQrjI=~>
+rk@=j!$0kp!$-Xj!9'@G!$1_3!$1e5!$/cQrk<m~>
+rjLbb!0l:=!0i'7!480o!0m-U!0m3W!0k1srjI=~>
+rjLbb!$0kp!$-Xj!-"A+!$1_3!$1e5!$/cQrjI=~>
+rk@=j!$0kp!$-Xj!9'@G!$1_3!$1e5!$/cQrk<m~>
+rjLbb!0l:=!0i'7!480o!0m-U!0m3W!0k1srjI=~>
+rjLbb!$0kp!$-Xj!-"A+!$1_3!$1e5!$/cQrjI=~>
+rk@:i!$0nq!$-Xj!9'CH!$1\2!$1h6!$/`Prk<m~>
+rjL_a!0l=>!0i'7!483p!0m*T!0m6X!0k.rrjI=~>
+rjL_a!$0nq!$-Xj!-"D,!$1\2!$1h6!$/`PrjI=~>
+rk@:i!$0kp!$-[k!9'CH!$1_3!$1e5!$/`Prk<m~>
+rjL_a!0l:=!0i*8!483p!0m-U!0m3W!0k.rrjI=~>
+rjL_a!$0kp!$-[k!-"D,!$1_3!$1e5!$/`PrjI=~>
+rk@:i!$0kp!$-[k!9'CH!?JrJrr=)5rr=(Ps8K`_~>
+rjL_a!0l:=!0i*8!483p!L,>3rrA;WrrA:rs8KHW~>
+rjL_a!$0kp!$-[k!-"D,!?Eofrr=)5rr=(Ps8KHW~>
+rk@:i!$0kp!?Jq-rrD#Hs8Tk,rr=)6rr=(Os8K`_~>
+rjL_a!0l:=!L,<krrBEps8OhHrrA;XrrA:qs8KHW~>
+rjL_a!$0kp!?EnIrr@#,s8OhHrr=)6rr=(Os8KHW~>
+rk@7h!$0nq!?Jq-rrD#Irr=)3rr=)5rr=(Os8K`_~>
+rjL\`!0l=>!L,<krrBEqrrA;UrrA;WrrA:qs8KHW~>
+rjL\`!$0nq!?EnIrr@#-rr=)3rr=)5rr=(Os8KHW~>
+rk@7h!?Jr2rr='lrrD#Irr=)3rr=)5rr=(Os8K`_~>
+rjL\`!L,=prrA:9rrBEqrrA;UrrA;WrrA:qs8KHW~>
+rjL\`!?EoNrr='lrr@#-rr=)3rr=)5rr=(Os8KHW~>
+rk@7h!?Jr2rr='lrrD#Irr=)3rr=)5rr=(Os8K`_~>
+rjL\`!L,=prrA:9rrBEqrrA;UrrA;WrrA:qs8KHW~>
+rjL\`!?EoNrr='lrr@#-rr=)3rr=)5rr=(Os8KHW~>
+rk@4g!$0nq!$-^l!9'FI!$1b4!$1e5!$/ZNrk<m~>
+rjLY_!0l=>!0i-9!486q!0m0V!0m3W!0k(prjI=~>
+rjLY_!$0nq!$-^l!-"G-!$1b4!$1e5!$/ZNrjI=~>
+rk@4g!$0nq!$-^l!9'IJ!$1_3!$1e5!$/ZNrk<m~>
+rjLY_!0l=>!0i-9!489r!0m-U!0m3W!0k(prjI=~>
+rjLY_!$0nq!$-^l!-"J.!$1_3!$1e5!$/ZNrjI=~>
+rk@4g!$0kp!$-am!9'IJ!$1_3!$1e5!$/ZNrk<m~>
+rjLY_!0l:=!0i0:!489r!0m-U!0m3W!0k(prjI=~>
+rjLY_!$0kp!$-am!-"J.!$1_3!$1e5!$/ZNrjI=~>
+rk@4g!$0kp!$-am!9'IJ!$1_3!$1h6!$/WMrk<m~>
+rjLY_!0l:=!0i0:!489r!0m-U!0m6X!0k%orjI=~>
+rjLY_!$0kp!$-am!-"J.!$1_3!$1h6!$/WMrjI=~>
+rk@1f!$0nq!$-am!9'IJ!$1b4!$1e5!?Jqds8K`_~>
+rjLV^!0l=>!0i0:!489r!0m0V!0m3W!L,=Ms8KHW~>
+rjLV^!$0nq!$-am!-"J.!$1b4!$1e5!?Eo+s8KHW~>
+rk@1f!$0nq!$-am!9'LK!$1_3!$1e5s1c/Frk<m~>
+rjLV^!0l=>!0i0:!48<s!0m-U!0m3Ws"V+brjI=~>
+rjLV^!$0nq!$-am!-"M/!$1_3!$1e5s"V+brjI=~>
+rk@1f!$0kp!$-dn!9'LK!$1_3!$1h6!$/TLrk<m~>
+rjLV^!0l:=!0i3;!48<s!0m-U!0m6X!0k"nrjI=~>
+rjLV^!$0kp!$-dn!-"M/!$1_3!$1h6!$/TLrjI=~>
+rk@.e!$0nq!$-dn!9'LK!$1b4!$1e5!$/TLrk<m~>
+rjLS]!0l=>!0i3;!48<s!0m0V!0m3W!0k"nrjI=~>
+rjLS]!$0nq!$-dn!-"M/!$1b4!$1e5!$/TLrjI=~>
+rk@.e!$0nq!$-dn!9'LK!$1b4!$1e5!$/TLrk<m~>
+rjLS]!0l=>!0i3;!48<s!0m0V!0m3W!0k"nrjI=~>
+rjLS]!$0nq!$-dn!-"M/!$1b4!$1e5!$/TLrjI=~>
+rk@.e!$0nq!$-dn!9'OL!$1_3!$1h6!$/QKrk<m~>
+rjLS]!0l=>!0i3;!48?t!0m-U!0m6X!0jtmrjI=~>
+rjLS]!$0nq!$-dn!-"P0!$1_3!$1h6!$/QKrjI=~>
+rk@+d!$0nq!$-go!9'OL!$1b4!$1e5!$/QKrk<m~>
+rjLP\!0l=>!0i6<!48?t!0m0V!0m3W!0jtmrjI=~>
+rjLP\!$0nq!$-go!-"P0!$1b4!$1e5!$/QKrjI=~>
+rk@+d!$0nq!$-go!9'OL!$1b4!$1h6!$/NJrk<m~>
+rjLP\!0l=>!0i6<!48?t!0m0V!0m6X!0jqlrjI=~>
+rjLP\!$0nq!$-go!-"P0!$1b4!$1h6!$/NJrjI=~>
+rk@+d!$0nq!$-go!9'OL!$1b4!$1h6!$/NJrk<m~>
+rjLP\!0l=>!0i6<!48?t!0m0V!0m6X!0jqlrjI=~>
+rjLP\!$0nq!$-go!-"P0!$1b4!$1h6!$/NJrjI=~>
+rk@+d!$0nq!$-go!9'RM!$1b4!$1e5!$/NJrk<m~>
+rjLP\!0l=>!0i6<!48Bu!0m0V!0m3W!0jqlrjI=~>
+rjLP\!$0nq!$-go!-"S1!$1b4!$1e5!$/NJrjI=~>
+rk@(c!$0nq!$-jp!9'RM!$1b4!?JrMrr=(Is8K`_~>
+rjLM[!0l=>!0i9=!48Bu!0m0V!L,>6rrA:ks8KHW~>
+rjLM[!$0nq!$-jp!-"S1!$1b4!?Eoirr=(Is8KHW~>
+rk@(c!$0nq!$-jp!9'RM!$1b4s1e@/!$/KIrk<m~>
+rjLM[!0l=>!0i9=!48Bu!0m0Vs"X<K!0jnkrjI=~>
+rjLM[!$0nq!$-jp!-"S1!$1b4s"X<K!$/KIrjI=~>
+rk@(c!$0nq!$-jp!9'RM!$1e5!$1e5!$/KIrk<m~>
+rjLM[!0l=>!0i9=!48Bu!0m3W!0m3W!0jnkrjI=~>
+rjLM[!$0nq!$-jp!-"S1!$1e5!$1e5!$/KIrjI=~>
+rk@%b!$0qr!$-jp!9'UN!$1b4!$1h6!$/HHrk<m~>
+rjLJZ!0l@?!0i9=!48F!!0m0V!0m6X!0jkjrjI=~>
+rjLJZ!$0qr!$-jp!-"V2!$1b4!$1h6!$/HHrjI=~>
+rk@%b!$0nq!$-mq!9'UN!$1e5!$1e5!$/HHrk<m~>
+rjLJZ!0l=>!0i<>!48F!!0m3W!0m3W!0jkjrjI=~>
+rjLJZ!$0nq!$-mq!-"V2!$1e5!$1e5!$/HHrjI=~>
+rk@%b!$0nq!$-mq!9'UN!$1e5!$1h6!$/EGrk<m~>
+rjLJZ!0l=>!0i<>!48F!!0m3W!0m6X!0jhirjI=~>
+rjLJZ!$0nq!$-mq!-"V2!$1e5!$1h6!$/EGrjI=~>
+rk@%b!$0nq!$-mq!9'UN!$1e5!$1h6!$/EGrk<m~>
+rjLJZ!0l=>!0i<>!48F!!0m3W!0m6X!0jhirjI=~>
+rjLJZ!$0nq!$-mq!-"V2!$1e5!$1h6!$/EGrjI=~>
+rk@"a!$0qr!$-mq!9'XO!$1e5!$1e5!$/EGrk<m~>
+rjLGY!0l@?!0i<>!48I"!0m3W!0m3W!0jhirjI=~>
+rjLGY!$0qr!$-mq!-"Y3!$1e5!$1e5!$/EGrjI=~>
+rk@"a!?Jr3rr='rrrD#OrrF.Tp\t46p\t46ZN'p<J,~>
+rjLGY!L,=qrrA:?rrBF"rrJ?=p\t5Xp\t5XZN'p4J,~>
+rjLGY!?EoOrr='rrr@#3rrF,pp\t46p\t46ZN'p4J,~>
+rk@"a!?Jr3rrF.TMZ3\8U&Y/-q#:=7pAY.6^U*t>^46~>
+rjLGY!L,=qrrJ?=MZ3[`U&Y-Iq#:>YpAY/X0sgoZ[X\~>
+rjLGY!?EoOrrF,pMZ3ZqU&Y-Iq#:=7pAY.60sgoZ[X\~>
+rk?t`!$0qr!?Jq4rrD#Prr=)5rr=)5s8Tj?s8K`_~>
+rjLDX!0l@?!L,<rrrBF#rrA;WrrA;Ws8Og[s8KHW~>
+rjLDX!$0qr!?EnPrr@#4rr=)5rr=)5s8Og[s8KHW~>
+rk?t`!$0nq!$-ss!9'[P!$1e5!$1h6!$/?Erk<m~>
+rjLDX!0l=>!0iB@!48L#!0m3W!0m6X!0jbgrjI=~>
+rjLDX!$0nq!$-ss!-"\4!$1e5!$1h6!$/?ErjI=~>
+rk?q_!$0qr!$-ss!9'[P!$1h6!$1e5!$/?Erk<m~>
+rjLAW!0l@?!0iB@!48L#!0m6X!0m3W!0jbgrjI=~>
+rjLAW!$0qr!$-ss!-"\4!$1h6!$1e5!$/?ErjI=~>
+rk?q_!$0qr!$-ss!9'^Q!$1e5!$1h6!$/<Drk<m~>
+rjLAW!0l@?!0iB@!48O$!0m3W!0m6X!0j_frjI=~>
+rjLAW!$0qr!$-ss!-"_5!$1e5!$1h6!$/<DrjI=~>
+rk?q_!$0nq!$.!t!9'^Q!$1h6!$1e5!$/<Drk<m~>
+rjLAW!0l=>!0iEA!48O$!0m6X!0m3W!0j_frjI=~>
+rjLAW!$0nq!$.!t!-"_5!$1h6!$1e5!$/<DrjI=~>
+rk?n^!$0qr!$.!t!9'aR!$1e5!$1h6!$/9Crk<m~>
+rjL>V!0l@?!0iEA!48R%!0m3W!0m6X!0j\erjI=~>
+rjL>V!$0qr!$.!t!-"b6!$1e5!$1h6!$/9CrjI=~>
+rk?n^!$0nq!$.$u!9'aR!$1e5!$1h6!$/9Crk<m~>
+rjL>V!0l=>!0iHB!48R%!0m3W!0m6X!0j\erjI=~>
+rjL>V!$0nq!$.$u!-"b6!$1e5!$1h6!$/9CrjI=~>
+rk?k]!$0qr!$.$u!9'aR!$1h6!$1h6!$/6Brk<m~>
+rjL;U!0l@?!0iHB!48R%!0m6X!0m6X!0jYdrjI=~>
+rjL;U!$0qr!$.$u!-"b6!$1h6!$1h6!$/6BrjI=~>
+rk?k]!$0qr!$.$u!9'dS!$1e5!$1h6!$/6Brk<m~>
+rjL;U!0l@?!0iHB!48U&!0m3W!0m6X!0jYdrjI=~>
+rjL;U!$0qr!$.$u!-"e7!$1e5!$1h6!$/6BrjI=~>
+rk?k]!$0nq!$.(!!9'dS!$1h6!$1h6!$/3Ark<m~>
+rjL;U!0l=>!0iKC!48U&!0m6X!0m6X!0jVcrjI=~>
+rjL;U!$0nq!$.(!!-"e7!$1h6!$1h6!$/3ArjI=~>
+rk?h\!$0qr!$.(!!9'dS!$1h6!?JrMrr=(As8K`_~>
+rjL8T!0l@?!0iKC!48U&!0m6X!L,>6rrA:cs8KHW~>
+rjL8T!$0qr!$.(!!-"e7!$1h6!?Eoirr=(As8KHW~>
+rk?h\!$0qr!$.(!!9'gT!$1e5s1eC0!$/0@rk<m~>
+rjL8T!0l@?!0iKC!48X'!0m3Ws"X?L!0jSbrjI=~>
+rjL8T!$0qr!$.(!!-"h8!$1e5s"X?L!$/0@rjI=~>
+rk?e[!$0qr!$.+"!9'gT!$1h6!$1h6!$/0@rk<m~>
+rjL5S!0l@?!0iND!48X'!0m6X!0m6X!0jSbrjI=~>
+rjL5S!$0qr!$.+"!-"h8!$1h6!$1h6!$/0@rjI=~>
+rk?e[!$0qr!$.+"!9'gT!$1h6!$1k7!$/-?rk<m~>
+rjL5S!0l@?!0iND!48X'!0m6X!0m9Y!0jParjI=~>
+rjL5S!$0qr!$.+"!-"h8!$1h6!$1k7!$/-?rjI=~>
+rk?e[!$0qr!$.+"!9'jU!$1h6!$1h6!$/-?rk<m~>
+rjL5S!0l@?!0iND!48[(!0m6X!0m6X!0jParjI=~>
+rjL5S!$0qr!$.+"!-"k9!$1h6!$1h6!$/-?rjI=~>
+rk?bZ!$0qr!$..#!9'jU!$1h6!$1k7!$/*>rk<m~>
+rjL2R!0l@?!0iQE!48[(!0m6X!0m9Y!0jM`rjI=~>
+rjL2R!$0qr!$..#!-"k9!$1h6!$1k7!$/*>rjI=~>
+rk?bZ!$0qr!$..#!9'mV!$1e5!$1k7!?JqUs8K`_~>
+rjL2R!0l@?!0iQE!48^)!0m3W!0m9Y!L,=>s8KHW~>
+rjL2R!$0qr!$..#!-"n:!$1e5!$1k7!?Enqs8KHW~>
+rk?_Y!$0qr!$.1$!9'mV!$1h6!$1k7!Zf%jX8i15J,~>
+rjL/Q!0l@?!0iTF!48^)!0m6X!0m9Y!gGDoX8i1-J,~>
+rjL/Q!$0qr!$.1$!-"n:!$1h6!$1k7!Za!MX8i1-J,~>
+rk?_Y!?Jr4rr=($rrD#Vrr=)6rr=)7rr=(=s8K`_~>
+rjL/Q!L,=rrrA:FrrBF)rrA;XrrA;YrrA:_s8KHW~>
+rjL/Q!?EoPrr=($rr@#:rr=)6rr=)7rr=(=s8KHW~>
+rk?_Y!?Jr4rr=($rrD#Wrr=)6rr=)7rr=(<s8K`_~>
+rjL/Q!L,=rrrA:FrrBF*rrA;XrrA;YrrA:^s8KHW~>
+rjL/Q!?EoPrr=($rr@#;rr=)6rr=)7rr=(<s8KHW~>
+rk?\X!$0qr!$.4%!9'pW!?JrMrr=)7rr=(<s8K`_~>
+rjL,P!0l@?!0iWG!48a*!L,>6rrA;YrrA:^s8KHW~>
+rjL,P!$0qr!$.4%!-"q;!?Eoirr=)7rr=(<s8KHW~>
+rk?\X!$0qr!?Jq<rrD#Ws8Tk0rr=)7rr=(;s8K`_~>
+rjL,P!0l@?!L,=%rrBF*s8OhLrrA;YrrA:]s8KHW~>
+rjL,P!$0qr!?EnXrr@#;s8OhLrr=)7rr=(;s8KHW~>
+rk?YW!$0ts!?Jq<rrD#Xrr=)6rr=)7rr=(;s8K`_~>
+rjL)O!0lC@!L,=%rrBF+rrA;XrrA;YrrA:]s8KHW~>
+rjL)O!$0ts!?EnXrr@#<rr=)6rr=)7rr=(;s8KHW~>
+rk?YW!$0qr!$.7&!9'sX!$1h6!$1n8!$.s:rk<m~>
+rjL)O!0l@?!0iZH!48d+!0m6X!0m<Z!0jA\rjI=~>
+rjL)O!$0qr!$.7&!-"t<!$1h6!$1n8!$.s:rjI=~>
+rk?VV!$0ts!$.7&!9(!Y!$1h6!$1n8!$.p9rk<m~>
+rjL&N!0lC@!0iZH!48g,!0m6X!0m<Z!0j>[rjI=~>
+rjL&N!$0ts!$.7&!-#"=!$1h6!$1n8!$.p9rjI=~>
+rk?VV!$0qr!$.:'!9(!Y!$1h6!$1n8!$.p9rk<m~>
+rjL&N!0l@?!0i]I!48g,!0m6X!0m<Z!0j>[rjI=~>
+rjL&N!$0qr!$.:'!-#"=!$1h6!$1n8!$.p9rjI=~>
+rk?SU!$0ts!$.:'!9(!Y!$1k7!$1n8!$.m8rk<m~>
+rjL#M!0lC@!0i]I!48g,!0m9Y!0m<Z!0j;ZrjI=~>
+rjL#M!$0ts!$.:'!-#"=!$1k7!$1n8!$.m8rjI=~>
+rk?SU!$0qr!$.=(!9($Z!$1h6!?JrOrr=(8s8K`_~>
+rjL#M!0l@?!0i`J!48j-!0m6X!L,>8rrA:Zs8KHW~>
+rjL#M!$0qr!$.=(!-#%>!$1h6!?Eokrr=(8s8KHW~>
+rk?SU!$0qr!$.=(!9($Z!$1k7!Zf%jqu6X:U]:>-J,~>
+rjL#M!0l@?!0i`J!48j-!0m9Y!gGDoqu6Y\U]:>%J,~>
+rjL#M!$0qr!$.=(!-#%>!$1k7!Za!Mqu6X:U]:>%J,~>
+rk?PT!$0qr!$.@)!9('[!$1h6!$1n8!$.j7rk<m~>
+rjKuL!0l@?!0icK!48m.!0m6X!0m<Z!0j8YrjI=~>
+rjKuL!$0qr!$.@)!-#(?!$1h6!$1n8!$.j7rjI=~>
+rk?PT!$0qr!$.@)!9('[!$1k7!$1n8!?JqMs8K`_~>
+rjKuL!0l@?!0icK!48m.!0m9Y!0m<Z!L,=6s8KHW~>
+rjKuL!$0qr!$.@)!-#(?!$1k7!$1n8!?Enis8KHW~>
+rk?MS!$0qr!$.C*!9(*\!$1h6!$1q9!Zf%jU]:>-J,~>
+rjKrK!0l@?!0ifL!48p/!0m6X!0m?[!gGDoU]:>%J,~>
+rjKrK!$0qr!$.C*!-#+@!$1h6!$1q9!Za!MU]:>%J,~>
+rk?MS!$0qr!$.C*!9(*\!$1k7!$1n8!$.d5rk<m~>
+rjKrK!0l@?!0ifL!48p/!0m9Y!0m<Z!0j2WrjI=~>
+rjKrK!$0qr!$.C*!-#+@!$1k7!$1n8!$.d5rjI=~>
+rk?JR!$0qr!$.F+!9(*\!$1k7!$1q9!$.a4rk<m~>
+rjKoJ!0l@?!0iiM!48p/!0m9Y!0m?[!0j/VrjI=~>
+rjKoJ!$0qr!$.F+!-#+@!$1k7!$1q9!$.a4rjI=~>
+rk?JR!?Jr4rr=(+rrD#]rr=)7rr=)8rr=(4s8K`_~>
+rjKoJ!L,=rrrA:MrrBF0rrA;YrrA;ZrrA:Vs8KHW~>
+rjKoJ!?EoPrr=(+rr@#Arr=)7rr=)8rr=(4s8KHW~>
+rk?JR!P]Z3rr=(,rrD#]rr=)8rr=)8rr=(3s8K`_~>
+rjKoJ!AThqrrA:NrrBF0rrA;ZrrA;ZrrA:Us8KHW~>
+rjKoJ!APVOrr=(,rr@#Arr=)8rr=)8rr=(3s8KHW~>
+rk?GQ!$0qr!$.I,!9(0^!$1k7!$1q9!$.[2rk<m~>
+rjKlI!0l@?!0ilN!49!1!0m9Y!0m?[!0j)TrjI=~>
+rjKlI!$0qr!$.I,!-#1B!$1k7!$1q9!$.[2rjI=~>
+rk?DP!$0qr!$.L-!9(0^!?JrOrr=)8rr=(2s8K`_~>
+rjKiH!0l@?!0ioO!49!1!L,>8rrA;ZrrA:Ts8KHW~>
+rjKiH!$0qr!$.L-!-#1B!?Eokrr=)8rr=(2s8KHW~>
+rk?DP!$0qr!?JqDrrD#_rrO4U^\[s1*W#d9*M*60^46~>
+rjKiH!0l@?!L,=-rrBF2rrSE>1&CnMPktC[Pb%jR[X\~>
+rjKiH!$0qr!?En`rr@#CrrO2q1&CnM*W#d9*M*60[X\~>
+rk?AO!$0ts!P]YDrrD#_rr=)8rr=)8rr=(1s8K`_~>
+rjKfG!0lC@!ATh-rrBF2rrA;ZrrA;ZrrA:Ss8KHW~>
+rjKfG!$0ts!APU`rr@#Crr=)8rr=)8rr=(1s8KHW~>
+rk?AO!$0qr!$.O.!9(6`!$1k7!$1q9!$.U0rk<m~>
+rjKfG!0l@?!0irP!49'3!0m9Y!0m?[!0j#RrjI=~>
+rjKfG!$0qr!$.O.!-#7D!$1k7!$1q9!$.U0rjI=~>
+rk?>N!$0qr!$.R/!9(6`!$1n8!?JrOrr=(0s8K`_~>
+rjKcF!0l@?!0iuQ!49'3!0m<Z!L,>8rrA:Rs8KHW~>
+rjKcF!$0qr!$.R/!-#7D!$1n8!?Eokrr=(0s8KHW~>
+rk?;M!$0ts!$.R/!9(9a!$1n8!Zf%jqu6[;^RY?'^46~>
+rjK`E!0lC@!0iuQ!49*4!0m<Z!gGDoqu6\]0qA:C[X\~>
+rjK`E!$0ts!$.R/!-#:E!$1n8!Za!Mqu6[;0qA:C[X\~>
+rk?;M!$0qr!$.U0!9(9a!$1n8!$1q9!Zf%jSH&T&J,~>
+rjK`E!0l@?!0j#R!49*4!0m<Z!0m?[!gGDoSH&SsJ,~>
+rjK`E!$0qr!$.U0!-#:E!$1n8!$1q9!Za!MSH&SsJ,~>
+rk?8L!$0ts!$.U0!9(<b!$1n8!$1q9!$.L-rk<m~>
+rjK]D!0lC@!0j#R!49-5!0m<Z!0m?[!0ioOrjI=~>
+rjK]D!$0ts!$.U0!-#=F!$1n8!$1q9!$.L-rjI=~>
+rk?8L!$0qr!$.X1!9(?c!$1n8!$1n8!$.L-rk<m~>
+rjK]D!0l@?!0j&S!4906!0m<Z!0m<Z!0ioOrjI=~>
+rjK]D!$0qr!$.X1!-#@G!$1n8!$1n8!$.L-rjI=~>
+rk?5K!$0ts!$.X1!9(?c!$1n8!$1q9!$.I,rk<m~>
+rjKZC!0lC@!0j&S!4906!0m<Z!0m?[!0ilNrjI=~>
+rjKZC!$0ts!$.X1!-#@G!$1n8!$1q9!$.I,rjI=~>
+rk?5K!$0qr!$.[2!9(Bd!$1n8!$1q9!$.F+rk<m~>
+rjKZC!0l@?!0j)T!4937!0m<Z!0m?[!0iiMrjI=~>
+rjKZC!$0qr!$.[2!-#CH!$1n8!$1q9!$.F+rjI=~>
+rk?2J!?Jr5rr=(2rrD#drr=)8rr=):rr=(*s8K`_~>
+rjKWB!L,=srrA:TrrBF7rrA;ZrrA;\rrA:Ls8KHW~>
+rjKWB!?EoQrr=(2rr@#Hrr=)8rr=):rr=(*s8KHW~>
+rk?2J!P]Z4rr=(3rrD#err=)8rr=):rr=()s8K`_~>
+rjKWB!AThrrrA:UrrBF8rrA;ZrrA;\rrA:Ks8KHW~>
+rjKWB!APVPrr=(3rr@#Irr=)8rr=):rr=()s8KHW~>
+rk?/I!$0ts!$.^3!9(Ee!$1q9!$1q9!$.@)rk<m~>
+rjKTA!0lC@!0j,U!4968!0m?[!0m?[!0icKrjI=~>
+rjKTA!$0ts!$.^3!-#FI!$1q9!$1q9!$.@)rjI=~>
+rk?,H!$0ts!$.a4!9(Hf!?JrOrr=):rr=((s8K`_~>
+rjKQ@!0lC@!0j/V!4999!L,>8rrA;\rrA:Js8KHW~>
+rjKQ@!$0ts!$.a4!-#IJ!?Eokrr=):rr=((s8KHW~>
+rk?)G!$1"t!?JqKrrD#grrO4U^\e$3*P_OP!?Jq>s8K`_~>
+rjKN?!0lFA!L,=4rrBF:rrSE>1&LtOPVN+9!L,='s8KHW~>
+rjKN?!$1"t!?Engrr@#KrrO2q1&LtO*ARKl!?EnZs8KHW~>
+rk?&F!$1%u!P]YKrrD#grr=)9rrO4U^]"06*P]@Rs8K`_~>
+rjKK>!0lIB!ATh4rrBF:rrA;[rrSE>1&_+RPVFnWs8KHW~>
+rjKK>!$1%u!APUgrr@#Krr=)9rrO2q1&_+R*AK:5s8KHW~>
+rk?&F!$0ts!$.g6!9(Nh!$1q9!$1t:!$.4%rk<m~>
+rjKK>!0lC@!0j5X!49?;!0m?[!0mB\!0iWGrjI=~>
+rjKK>!$0ts!$.g6!-#OL!$1q9!$1t:!$.4%rjI=~>
+rk?#E!$1"t!$.g6!9(Qi!$1q9!$1t:!$.1$rk<m~>
+rjKH=!0lFA!0j5X!49B<!0m?[!0mB\!0iTFrjI=~>
+rjKH=!$1"t!$.g6!-#RM!$1q9!$1t:!$.1$rjI=~>
+rk>uD!$1"t!$.j7!9(Tj!$1q9!$1t:!$..#rk<m~>
+rjKE<!0lFA!0j8Y!49E=!0m?[!0mB\!0iQErjI=~>
+rjKE<!$1"t!$.j7!-#UN!$1q9!$1t:!$..#rjI=~>
+rk>uD!$0ts!$.m8!9(Tj!$1q9!$1t:!$..#rk<m~>
+rjKE<!0lC@!0j;Z!49E=!0m?[!0mB\!0iQErjI=~>
+rjKE<!$0ts!$.m8!-#UN!$1q9!$1t:!$..#rjI=~>
+rk>rC!?Jr5rr=(9rrD#krr=)9rr=):rr=("s8K`_~>
+rjKB;!L,=srrA:[rrBF>rrA;[rrA;\rrA:Ds8KHW~>
+rjKB;!?EoQrr=(9rr@#Orr=)9rr=):rr=("s8KHW~>
+rk>rC!P]Z4rr=(:rrD#lrr=)9rr=):rr=(!s8K`_~>
+rjKB;!AThrrrA:\rrBF?rrA;[rrA;\rrA:Cs8KHW~>
+rjKB;!APVPrr=(:rr@#Prr=)9rr=):rr=(!s8KHW~>
+rk>lA!$1"t!$.s:!9(Zl!$1t:!$1t:!?Jq7s8K`_~>
+rjK<9!0lFA!0jA\!49K?!0mB\!0mB\!L,<us8KHW~>
+rjK<9!$1"t!$.s:!-#[P!$1t:!$1t:!?EnSs8KHW~>
+rk>lA!$0ts!$/!;!9(]m!?JrQrrF.TrVum<s1aQnrk<m~>
+rjK<9!0lC@!0jD]!49N@!L,>:rrJ?=rVun^s"TN5rjI=~>
+rjK<9!$0ts!$/!;!-#^Q!?EomrrF,prVum<s"TN5rjI=~>
+rk>i@!$0ts!?JqSrrD#nrrO4U^]"06*P]Agrr='rs8K`_~>
+rjK98!0lC@!L,=<rrBFArrSE>1&_+RPVFolrrA:?s8KHW~>
+rjK98!$0ts!?Enorr@#RrrO2q1&_+R*AK;Jrr='rs8KHW~>
+rk>f?!$1"t!P]YSrrD#orr=):rr=);rr='qs8K`_~>
+rjK67!0lFA!ATh<rrBFBrrA;\rrA;]rrA:>s8KHW~>
+rjK67!$1"t!APUorr@#Srr=):rr=);rr='qs8KHW~>
+rk>c>!$0ts!$/*>!9(fp!$1t:!$2%<ruHmprk<m~>
+rjK36!0lC@!0jM`!49WC!0mB\!0mH^s-/<=rjI=~>
+rjK36!$0ts!$/*>!-#gT!$1t:!$2%<ruHmprjI=~>
+rk>c>!$0qr!$/-?!9(iq!$1t:!$2%<!$-dnrk<m~>
+rjK36!0l@?!0jPa!49ZD!0mB\!0mH^!0i3;rjI=~>
+rjK36!$0qr!$/-?!-#jU!$1t:!$2%<!$-dnrjI=~>
+rk>`=!$0qr!$/0@!9(iq!$2";!$2%<!?Jq/s8K`_~>
+rjK05!0l@?!0jSb!49ZD!0mE]!0mH^!L,<ms8KHW~>
+rjK05!$0qr!$/0@!-#jU!$2";!$2%<!?EnKs8KHW~>
+rk>]<!?Jr5rr=(@rrD#rrr=);rr=)=s8O,>^P2^e^46~>
+rjK-4!L,=srrA:brrBFErrA;]rrA;_s8S>`0noZ,[X\~>
+rjK-4!?EoQrr=(@rr@#Vrr=);rr=)=s8O,>0noZ,[X\~>
+rk>]<!P]Z4rr=(ArrD#srr=);rra@Ws8O*js8K`_~>
+rjK-4!AThrrrA:crrBFFrrA;]rreQ@s8S=7s8KHW~>
+rjK-4!APVPrr=(Arr@#Wrr=);rra>ss8O*js8KHW~>
+rk>W:ruL%t!$/6B!9(rt!?JrSs8O,>^B+?TJc>`Mrk<m~>
+rjK'2s-2IA!0jYd!49cG!L,><s8S>`0`h<=Jc>`MrjI=~>
+rjK'2ruL%t!$/6B!-#sX!?Eoos8O,>0`h:pJc>`MrjI=~>
+rk>Q8!$1"t!?JqZrrD$!s8O,>^]4<6*WH*=*J+7js8K`_~>
+rjK!0!0lFA!L,=CrrBFIs8S>`1&q7RPlC^_P_&l7s8KHW~>
+rjK!0!$1"t!?Eo!rr@#Zs8O,>1&q7R*WH*=*J+7js8KHW~>
+rk>N7!$1%u!l#`rZ2Xg_ao;>]r;Qa;rr3!>^OcFas8K`_~>
+rjJs/!0lIB!\oq(Z2Xg2ao;@*r;Qb]rr3"`0nKB(s8KHW~>
+rjJs/!$1%u!\k]9Z2XfCao;>]r;Qa;rr3!>0nKB(s8KHW~>
+rk>K6ruL%t!$/BF!9)*#!$2%<ruM.>ruM-SJcG`Lrk<m~>
+rjJp.s-2IA!0jeh!49oK!0mH^s-3Q`s-3O<JcG`LrjI=~>
+rjJp.ruL%t!$/BF!-$*\!$2%<ruM.>ruM+oJcG`LrjI=~>
+rk>E4!?Jr6s8O+HrrD$%s8O,=s8O)A^],;pJcGTHrk<m~>
+rjJj,!L,=ts8S=jrrBFMs8S>_s8S;c1&mK&JcGTHrjI=~>
+rjJj,!?EoRs8O+Hrr@#^s8O,=s8O)A1&i77JcGTHrjI=~>
+rk>E4!l#`ri;`ft[f6?dc2Rbarr<!="96-N*J+7cs8K`_~>
+rjJj,!\oq(i;`hA[f6?7c2Rd.rr<"_"91)1P_&l0s8KHW~>
+rjJj,!\k]9i;`ft[f6>Hc2Rbarr<!="91)1*J+7cs8KHW~>
+rk><1!$0ts!?JqbrrD$(s8O)F^],;ps8O)[^OcFZs8K`_~>
+rjJa)!0lC@!L,=KrrBFPs8S;h1&mK&s8S=J0nKB!s8KHW~>
+rjJa)!$0ts!?Eo)rr@#as8O)F1&i77s8O)[0nKB!s8KHW~>
+rk>90ruL(u!l#`r\c2Zgdf9:e"TQ6O*WQ*Z!rp$MJcGKErk<m~>
+rjJ^(s-2LB!\oq(\c2Z:df9<2"TL22PlL`I!rju0JcGKErjI=~>
+rjJ^(ruL(u!\k]9\c2YKdf9:e"TL22*WQ*Z!rju0JcGKErjI=~>
+rk>3.ruL%truJ`O!9)H-ruM+=ruD0U*?B_2nc/U&J,~>
+rjJX&s-2IAs-1.q!4:8Us-3N_s-*R>Pa$b!nc/TsJ,~>
+rjJX&ruL%truJ`O!-$HfruM+=ruD.q*?B_2nc/TsJ,~>
+rk>-,ruL%truJfQ!9)Q0rZ2%=r>kpQJcG3=rk<m~>
+rjJR$s-2IAs-14s!4:AXrfmH_rKR=:JcG3=rjI=~>
+rjJR$ruL%truJfQ!-$QirZ2%=r>knmJcG3=rjI=~>
+rk>-,s1eRSi;`ft^]+;mg&M'm!rp$Mr>kq<s1a-bn,NC$J,~>
+rjJR$s"XP<i;`hA^]+;@g&M):!rju0rKR?^s"T*)n,NBqJ,~>
+rjJR$s"XNoi;`ft^]+:Qg&M'm!rju0r>kq<s"T*)n,NBqJ,~>
+rk>!(ruL,!s1eRS_>aMog].9os8W'=JcFp5rk<m~>
+rjJEus-2OCs"XP<_>aMBg].;<s8W(_JcFp5rjI=~>
+rjJEuruL,!s"XNo_>aLSg].9os8W'=JcFp5rjI=~>
+rk=p&rZ0ttruK#W!9)l9p`0G9^V>@"kPtOqJ,~>
+rjJ?srflCAs-1G$!4:\aplkj[0en7ZkPtOiJ,~>
+rjJ?srZ0ttruK#W!-$lrp`0G90en7ZkPtOiJ,~>
+rk=m%s1eRSiW&fraSu8!kl:>ss1a-bi;`ejJ,~>
+rjJ<rs"XP<iW&h?aSu7Ikl:@@s"T*)i;`ebJ,~>
+rjJ<rs"XNoiW&fraSu6Zkl:>ss"T*)i;`ebJ,~>
+rk=a!rZ1&!s1eU6q&Ri^!9*DHp)X1JruM+=s1a-bi;`ejJ,~>
+rjJ0nrflICs"XQRq398+!4;4pp6>S3s-3N_s"T*)i;`ebJ,~>
+rjJ0nrZ1&!s"XQRq&Ri^!-%E,p)X/fruM+=s"T*)i;`ebJ,~>
+rk<sBmc"2\s5CX3ro*mlJ`5#8rk<m~>
+rjIBbm^3!Ks0TJ(rj;\[J[Eh3rjI=~>
+rjIAsmVr1\s)>Xlrc%llJT0"UrjI=~>
+rk@e"!P]YSs8Tk6s8!c%s7IE4^\f,P^],>Rs8Tk2s8Tk3s8Tk2s8Tk3s8Tk2s8Tk2s8Tibs2tB@
+^46~>
+rjM4o!ATh<s8OhRs8%uGs7MWV1&R:91&mL;s8OhNs8OhOs8OhNs8OhOs8OhNs8OhNs8Og)s2tB@
+[X\~>
+rjM4o!APUos8OhRs8!c%s7IE41&N'l1&i9ns8OhNs8OhOs8OhNs8OhOs8OhNs8OhNs8Og)s2tB@
+[X\~>
+rk@^u!$.j7s1eU6lQ,s(s1eU6r>kpQruM+=s1dCi!9&M/])VcDJ,~>
+rjM.m!0j8Ys"XQRl]hAJs"XQRrKR=:s-3N_s"W@0!47=W])Vc<J,~>
+rjM.m!$.j7s"XQRlQ,s(s"XQRr>knmruM+=s"W@0!-!Mh])Vc<J,~>
+rk@[truI[1s1eL3s1eL3s1eU6q&TG6s1d.b!9&M/])VcDJ,~>
+rjM+ls-0)Ss"XHOs"XHOs"XQRq3:jXs"W+)!47=W])Vc<J,~>
+rjM+lruI[1s"XHOs"XHOs"XQRq&TG6s"W+)!-!Mh])Vc<J,~>
+rk@Ur!$.:'qAoP7s1ckZ!9&M/])VcDJ,~>
+rjM%j!0i]IqNUsYs"Vh!!47=W])Vc<J,~>
+rjM%j!$.:'qAoP7s"Vh!!-!Mh])Vc<J,~>
+rk@Rq!$.L-r#Pe:s1cSR!9&M/])VcDJ,~>
+rjM"i!0ioOr073\s"VOn!47=W])Vc<J,~>
+rjM"i!$.L-r#Pe:s"VOn!-!Mh])Vc<J,~>
+rk@Op!?JqIs8<r>s1c=`rrD#/s1870^46~>
+rjLth!L,=2s8A/`s"Q7CrrBEWs1870[X\~>
+rjLth!?Enes8<r>s"Q7Crr@"hs1870[X\~>
+rk@Op!l#`rV#UB6\GlQfJcE=]rk<m~>
+rjLth!\oq(V#UCX\GlQ9JcE=]rjI=~>
+rjLth!\k]9V#UB6\GlPJJcE=]rjI=~>
+rk@Fm!$/'=r>kq<s1c)D!9&M/])VcDJ,~>
+rjLke!0jJ_rKR?^s"V%`!47=W])Vc<J,~>
+rjLke!$/'=r>kq<s"V%`!-!Mh])Vc<J,~>
+rk@ClruJ?Dr#N$A!9&M/])VcDJ,~>
+rjLhds-0bfr04Gc!47=W])Vc<J,~>
+rjLhdruJ?Dr#N$A!-!Mh])Vc<J,~>
+rk@=jruJWLq]5\9s1bf<!9&M/])VcDJ,~>
+rjLbbs-1%nqiq*[s"UbX!47=W])Vc<J,~>
+rjLbbruJWLq]5\9s"UbX!-!Mh])Vc<J,~>
+rk@7hruJiRr>kq<s1bQ5!9&M/])VcDJ,~>
+rjL\`s-17trKR?^s"UMQ!47=W])Vc<J,~>
+rjL\`ruJiRr>kq<s"UMQ!-!Mh])Vc<J,~>
+rk@7hs1eRS_uK]VU&P,OJcE=]rk<m~>
+rjL\`s"XP<_uK_#U&P,"JcE=]rjI=~>
+rjL\`s"XNo_uK]VU&P+3JcE=]rjI=~>
+rk@+druK5]r>bt>^V?KB!9&M/])VcDJ,~>
+rjLP\s-1Y*rKIB`0eoC%!47=W])Vc<J,~>
+rjLP\ruK5]r>bt>0eoC%!-!Mh])Vc<J,~>
+rk@%brZ0Geq]2.*!9&M/])VcDJ,~>
+rjLJZrfkk2qimQL!47=W])Vc<J,~>
+rjLJZrZ0Geq]2.*!-!Mh])Vc<J,~>
+rk@"as1eLQh#I6lrVuo4Rf<BHJcE=]rk<m~>
+rjLGYs"XJ:h#I89rVumPRf<ApJcE=]rjI=~>
+rjLGYs"XHmh#I6lrVumPRf<A,JcE=]rjI=~>
+rk?e[q]4i!r>kq<s1a`s!9&M/])VcDJ,~>
+rjL5Sqip7CrKR?^s"T]:!47=W])Vc<J,~>
+rjL5Sq]4i!r>kq<s"T]:!-!Mh])Vc<J,~>
+rk?_Ys1eU6qAoD3oc8qi!9&M/])VcDJ,~>
+rjL/Qs"XQRqNUgUoot@6!47=W])Vc<J,~>
+rjL/Qs"XQRqAoD3oc8qi!-!Mh])Vc<J,~>
+rk?JRs1eU6q&TJ7s1eL3s1aHk!9&M/])VcDJ,~>
+rjKoJs"XQRq3:mYs"XHOs"TE2!47=W])Vc<J,~>
+rjKoJs"XQRq&TJ7s"XHOs"TE2!-!Mh])Vc<J,~>
+rk?2Js1a-br;QcUJcE=]rk<m~>
+rjKWBs"T*)r;Qc(JcE=]rjI=~>
+rjKWBs"T*)r;Qb9JcE=]rjI=~>
+rk<s`\c2ZgJcE=]rk<m~>
+rjICX\c2Z:JcE=]rjI=~>
+rjICX\c2YKJcE=]rjI=~>
+rk<s`\c2ZgJcE=]rk<m~>
+rjICX\c2Z:JcE=]rjI=~>
+rjICX\c2YKJcE=]rjI=~>
+rk<s`\c2ZgJcE=]rk<m~>
+rjICX\c2Z:JcE=]rjI=~>
+rjICX\c2YKJcE=]rjI=~>
+rk<s`\c2ZgJcE=]rk<m~>
+rjICX\c2Z:JcE=]rjI=~>
+rjICX\c2YKJcE=]rjI=~>
+rk<s`\c2ZgJcE=]rk<m~>
+rjICX\c2Z:JcE=]rjI=~>
+rjICX\c2YKJcE=]rjI=~>
+rk<s`\c2ZgJcE=]rk<m~>
+rjICX\c2Z:JcE=]rjI=~>
+rjICX\c2YKJcE=]rjI=~>
+rk<s`\c2ZgJcE=]rk<m~>
+rjICX\c2Z:JcE=]rjI=~>
+rjICX\c2YKJcE=]rjI=~>
+J\H]LJ\LHaJ,~>
+J[U-<J[XmQJ,~>
+J[U-<J[XmQJ,~>
+J\H]LJ\LHaJ,~>
+J[U-<J[XmQJ,~>
+J[U-<J[XmQJ,~>
+J\H]LJ\LHaJ,~>
+J[U-<J[XmQJ,~>
+J[U-<J[XmQJ,~>
+%%EndData
+showpage
+%%Trailer
+end
+%%EOF
diff --git a/changelog b/changelog
index be24ef0..0e692a6 100644
--- a/changelog
+++ b/changelog
@@ -1,3 +1,12 @@
+20090404 tpd src/axiom-website/patches.html 20090404.02.tpd.patch	
+20090404 tpd books/bookvol10.4 additional package unit tests
+20090404 tpd books/bookvol10.3 additional domain unit tests
+20090404 tpd books/bookvol0 add domain examples
+20090404 tpd src/algebra/Makefile add LazardSetSolvingPackage.help
+20090404 tpd books/ps/v0plot4.eps TwoDimensionalViewport example image 3
+20090404 tpd books/ps/v0plot3.eps TwoDimensionalViewport example image 3
+20090404 tpd books/ps/v0plot2.eps TwoDimensionalViewport example image 2
+20090404 tpd books/ps/v0plot1.eps TwoDimensionalViewport example image 1
 20090404 tpd src/axiom-website/patches.html 20090404.01.tpd.patch	
 20090404 tpd books/bookvol0 fix cross references
 20090403 tpd src/axiom-website/patches.html 20090403.02.tpd.patch	
diff --git a/src/algebra/Makefile.pamphlet b/src/algebra/Makefile.pamphlet
index d58506c..bde991e 100644
--- a/src/algebra/Makefile.pamphlet
+++ b/src/algebra/Makefile.pamphlet
@@ -16460,6 +16460,7 @@ SPADHELP=\
  ${HELP}/Integer.help                ${HELP}/IntegerLinearDependence.help \
  ${HELP}/IntegerNumberTheoryFunctions.help \
  ${HELP}/Kernel.help                 ${HELP}/KeyedAccessFile.help \
+ ${HELP}/LazardSetSolvingPackage.help \
  ${HELP}/LexTriangularPackage.help   ${HELP}/Library.help \
  ${HELP}/LieExponentials.help        ${HELP}/LiePolynomial.help  \
  ${HELP}/LinearOrdinaryDifferentialOperator.help \
@@ -16548,6 +16549,7 @@ REGRESS=\
  Integer.regress                IntegerLinearDependence.regress \
  IntegerNumberTheoryFunctions.regress \
  Kernel.regress                 KeyedAccessFile.regress \
+ LazardSetSolvingPackage.regress \
  LexTriangularPackage.regress   Library.regress \
  LieExponentials.regress        LiePolynomial.regress \
  LinearOrdinaryDifferentialOperator.regress \
@@ -17054,6 +17056,18 @@ ${HELP}/KeyedAccessFile.help: ${BOOKS}/bookvol10.3.pamphlet
             >${INPUT}/KeyedAccessFile.input
 	@echo "KeyedAccessFile (KAFILE)" >>${HELPFILE}
 
+${HELP}/LazardSetSolvingPackage.help: ${BOOKS}/bookvol10.3.pamphlet
+	@echo 7042 create LazardSetSolvingPackage.help from \
+              ${BOOKS}/bookvol10.3.pamphlet
+	@${TANGLE} -R"LazardSetSolvingPackage.help" \
+           ${BOOKS}/bookvol10.3.pamphlet \
+           >${HELP}/LazardSetSolvingPackage.help
+	@cp ${HELP}/LazardSetSolvingPackage.help ${HELP}/LAZM3PK.help
+	@${TANGLE} -R"LazardSetSolvingPackage.input" \
+            ${BOOKS}/bookvol10.3.pamphlet \
+            >${INPUT}/LazardSetSolvingPackage.input
+	@echo "LazardSetSolvingPackage (LAZM3PK)" >>${HELPFILE}
+
 ${HELP}/LexTriangularPackage.help: ${BOOKS}/bookvol10.4.pamphlet
 	@echo 7043 create LexTriangularPackage.help from \
            ${BOOKS}/bookvol10.4.pamphlet
diff --git a/src/axiom-website/patches.html b/src/axiom-website/patches.html
index 782bc59..cd448e8 100644
--- a/src/axiom-website/patches.html
+++ b/src/axiom-website/patches.html
@@ -1044,5 +1044,7 @@ remove gcl-2.6.7, gcl-2.6.8pre<br/>
 bookvol5 collect top level loop code<br/>
 <a href="patches/20090404.01.tpd.patch">20090404.01.tpd.patch</a>
 bookvol0 fix cross references<br/>
+<a href="patches/20090404.02.tpd.patch">20090404.02.tpd.patch</a>
+bookvol0 document additional domains<br/>
  </body>
 </html>
